package Locales::DB::Territory::sk;

# Auto generated from CLDR

$Locales::DB::Territory::sk::VERSION = '0.02';

$Locales::DB::Territory::sk::cldr_version = '1.7.1';

%Locales::DB::Territory::sk::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "Spojené\ arabské\ emiráty",
    'af' => 'Afganistan',
    'ag' => "Antigua\ a\ Barbados",
    'ai' => 'Anguilla',
    'al' => 'Albánsko',
    'am' => 'Arménsko',
    'an' => "Holandské\ Antily",
    'ao' => 'Angola',
    'aq' => 'Antarctica',
    'ar' => 'Argentína',
    'as' => "Americká\ Samoa",
    'at' => 'Rakúsko',
    'au' => 'Austrália',
    'aw' => 'Aruba',
    'ax' => "Alandské\ ostrovy",
    'az' => 'Azerbajdžan',
    'ba' => "Bosna\ a\ Hercegovina",
    'bb' => 'Barbados',
    'bd' => 'Bangladéš',
    'be' => 'Belgicko',
    'bf' => "Burkina\ Faso",
    'bg' => 'Bulharsko',
    'bh' => 'Bahrajn',
    'bi' => 'Burundi',
    'bj' => 'Benin',
    'bl' => "Svätý\ Bartolomej",
    'bm' => 'Bermudy',
    'bn' => 'Brunej',
    'bo' => 'Bolívia',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brazília',
    'bs' => 'Bahamy',
    'bt' => 'Bután',
    'bv' => "Bouvetov\ ostrov",
    'bw' => 'Botswana',
    'by' => 'Bielorusko',
    'bz' => 'Belize',
    'ca' => 'Kanada',
    'cc' => "Kokosové\ ostrovy",
    'cd' => "Konžská\ demokratická\ republika",
    'cf' => "Stredoafrická\ republika",
    'cg' => 'Kongo',
    'ch' => 'Švajčiarsko',
    'ci' => "Pobrežie\ Slonoviny",
    'ck' => "Cookove\ ostrovy",
    'cl' => 'Čile',
    'cm' => 'Kamerun',
    'cn' => 'Čína',
    'co' => 'Kolumbia',
    'cr' => 'Kostarika',
    'cs' => "Srbsko\ a\ Čierna\ Hora",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Kuba',
    'cv' => 'Kapverdy',
    'cx' => "Vianočný\ ostrov",
    'cy' => 'Cyprus',
    'cz' => "Česká\ republika",
    'dd' => "East\ Germany",
    'de' => 'Nemecko',
    'dj' => 'Džibuti',
    'dk' => 'Dánsko',
    'dm' => 'Dominika',
    'do' => "Dominikánska\ republika",
    'dz' => 'Alžírsko',
    'ec' => 'Ekvádor',
    'ee' => 'Estónsko',
    'eg' => 'Egypt',
    'eh' => "Západná\ Sahara",
    'er' => 'Eritrea',
    'es' => 'Španielsko',
    'et' => 'Etiópia',
    'fi' => 'Fínsko',
    'fj' => 'Fidži',
    'fk' => "Falklandské\ ostrovy",
    'fm' => 'Mikronézia',
    'fo' => "Faerské\ ostrovy",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Francúzsko',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabon',
    'gb' => "Spojené\ kráľovstvo",
    'gd' => 'Grenada',
    'ge' => 'Gruzínsko',
    'gf' => "Francúzska\ Guayana",
    'gg' => 'Guernsey',
    'gh' => 'Ghana',
    'gi' => 'Gibraltár',
    'gl' => 'Grónsko',
    'gm' => 'Gambia',
    'gn' => 'Guinea',
    'gp' => 'Guadeloupe',
    'gq' => "Rovníková\ Guinea",
    'gr' => 'Grécko',
    'gs' => "Južná\ Georgia\ a\ Južné\ Sandwichove\ ostrovy",
    'gt' => 'Guatemala',
    'gu' => 'Guam',
    'gw' => "Guinea\-Bissau",
    'gy' => 'Guayana',
    'hk' => "Hong\ Kong",
    'hm' => "Heardove\ ostrovy\ a\ McDonaldove\ ostrovy",
    'hn' => 'Honduras',
    'hr' => 'Chorvátsko',
    'ht' => 'Haiti',
    'hu' => 'Maďarsko',
    'id' => 'Indonézia',
    'ie' => 'Írsko',
    'il' => 'Izrael',
    'im' => "Ostrov\ Man",
    'in' => 'India',
    'io' => "Britské\ územie\ v\ Indickom\ oceáne",
    'iq' => 'Irak',
    'ir' => 'Irán',
    'is' => 'Island',
    'it' => 'Taliansko',
    'je' => 'Jersey',
    'jm' => 'Jamajka',
    'jo' => 'Jordánsko',
    'jp' => 'Japonsko',
    'jt' => "Johnston\ Island",
    'ke' => 'Keňa',
    'kg' => 'Kirgizsko',
    'kh' => 'Kambodža',
    'ki' => 'Kiribati',
    'km' => 'Komory',
    'kn' => "Saint\ Kitts\ a\ Nevis",
    'kp' => "Kórejská\ ľudovodemokratická\ republika",
    'kr' => "Kórejská\ republika",
    'kw' => 'Kuvajt',
    'ky' => "Kajmanské\ ostrovy",
    'kz' => 'Kazachstan',
    'la' => "Laoská\ ľudovodemokratická\ republika",
    'lb' => 'Libanon',
    'lc' => "Svätá\ Lucia",
    'li' => 'Lichtenštajnsko',
    'lk' => "Srí\ Lanka",
    'lr' => 'Libéria',
    'ls' => 'Lesotho',
    'lt' => 'Litva',
    'lu' => 'Luxembursko',
    'lv' => 'Lotyšsko',
    'ly' => "Lýbijská\ arabská\ džamahírija",
    'ma' => 'Maroko',
    'mc' => 'Monako',
    'md' => 'Moldavsko',
    'me' => "Čierna\ Hora",
    'mf' => "Svätý\ Martin",
    'mg' => 'Madagaskar',
    'mh' => "Marshallove\ ostrovy",
    'mi' => "Midway\ Islands",
    'mk' => 'Macedónsko',
    'ml' => 'Mali',
    'mm' => 'Mjanmarsko',
    'mn' => 'Mongolsko',
    'mo' => 'Macao',
    'mp' => "Severné\ Mariány",
    'mq' => 'Martinik',
    'mr' => 'Mauritánia',
    'ms' => 'Montserrat',
    'mt' => 'Malta',
    'mu' => 'Maurícius',
    'mv' => 'Maldivy',
    'mw' => 'Malawi',
    'mx' => 'Mexiko',
    'my' => 'Malajzia',
    'mz' => 'Mozambik',
    'na' => 'Namíbia',
    'nc' => "Nová\ Kaledónia",
    'ne' => 'Niger',
    'nf' => "Norfolkov\ ostrov",
    'ng' => 'Nigéria',
    'ni' => 'Nikaragua',
    'nl' => 'Holandsko',
    'no' => 'Nórsko',
    'np' => 'Nepál',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "Nový\ Zéland",
    'om' => 'Omán',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Peru',
    'pf' => "Francúzska\ Polynézia",
    'pg' => "Papua\ Nová\ Guinea",
    'ph' => 'Filipíny',
    'pk' => 'Pakistan',
    'pl' => 'Poľsko',
    'pm' => "Saint\ Pierre\ a\ Miquelon",
    'pn' => "Pitcairnove\ ostrovy",
    'pr' => 'Portoriko',
    'ps' => "Palestínske\ územie",
    'pt' => 'Portugalsko',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paraguaj',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Katar',
    'qo' => "Tichomorie\ \-\ ostatné",
    'qu' => "Európska\ únia",
    're' => 'Reunion',
    'ro' => 'Rumunsko',
    'rs' => 'Srbsko',
    'ru' => "Ruská\ federácia",
    'rw' => 'Rwanda',
    'sa' => "Saudská\ Arábia",
    'sb' => "Šalamúnove\ ostrovy",
    'sc' => "Seychelské\ ostrovy",
    'sd' => 'Sudán',
    'se' => 'Švédsko',
    'sg' => 'Singapur',
    'sh' => "Svätá\ Helena",
    'si' => 'Slovinsko',
    'sj' => "Špicbergy\ a\ Jan\ Mayen",
    'sk' => "Slovenská\ republika",
    'sl' => "Sierra\ Leone",
    'sm' => "San\ Maríno",
    'sn' => 'Senegal',
    'so' => 'Somálsko',
    'sr' => 'Surinam',
    'st' => "Svätý\ Tomáš\ a\ Princove\ ostrovy",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => 'Salvador',
    'sy' => "Sýrska\ arabská\ republika",
    'sz' => 'Svazijsko',
    'tc' => "Turks\ a\ Caicos",
    'td' => 'Čad',
    'tf' => "Francúzske\ južné\ územia",
    'tg' => 'Togo',
    'th' => 'Thajsko',
    'tj' => 'Tadžikistan',
    'tk' => 'Tokelau',
    'tl' => "Východný\ Timor",
    'tm' => 'Turkménsko',
    'tn' => 'Tunisko',
    'to' => 'Tonga',
    'tr' => 'Turecko',
    'tt' => "Trinidad\ a\ Tobago",
    'tv' => 'Tuvalu',
    'tw' => 'Tajwan',
    'tz' => 'Tanzánia',
    'ua' => 'Ukrajina',
    'ug' => 'Uganda',
    'um' => "Menšie\ odľahlé\ ostrovy\ USA",
    'us' => "Spojené\ štáty",
    'uy' => 'Uruguaj',
    'uz' => 'Uzbekistan',
    'va' => 'Vatikán',
    'vc' => "Svätý\ Vincent\ a\ Grenadíny",
    'vd' => "North\ Vietnam",
    've' => 'Venezuela',
    'vg' => "Britské\ panenské\ ostrovy",
    'vi' => "Panenské\ ostrovy\ \-\ USA",
    'vn' => 'Vietnam',
    'vu' => 'Vanuatu',
    'wf' => "Wallis\ a\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Jemen',
    'yt' => 'Mayotte',
    'za' => "Južná\ Afrika",
    'zm' => 'Zambia',
    'zw' => 'Zimbabwe',
    'zz' => "Neznámy\ alebo\ neplatný\ región",
);

%Locales::DB::Territory::sk::name_to_code = (
    'afganistan'                               => 'af',
    'alandskéostrovy'                         => 'ax',
    'albánsko'                                => 'al',
    'alžírsko'                               => 'dz',
    'americkásamoa'                           => 'as',
    'andorra'                                  => 'ad',
    'angola'                                   => 'ao',
    'anguilla'                                 => 'ai',
    'antarctica'                               => 'aq',
    'antiguaabarbados'                         => 'ag',
    'argentína'                               => 'ar',
    'arménsko'                                => 'am',
    'aruba'                                    => 'aw',
    'austrália'                               => 'au',
    'azerbajdžan'                             => 'az',
    'bahamy'                                   => 'bs',
    'bahrajn'                                  => 'bh',
    'bangladéš'                              => 'bd',
    'barbados'                                 => 'bb',
    'belgicko'                                 => 'be',
    'belize'                                   => 'bz',
    'benin'                                    => 'bj',
    'bermudy'                                  => 'bm',
    'bielorusko'                               => 'by',
    'bolívia'                                 => 'bo',
    'bosnaahercegovina'                        => 'ba',
    'botswana'                                 => 'bw',
    'bouvetovostrov'                           => 'bv',
    'brazília'                                => 'br',
    'britishantarcticterritory'                => 'bq',
    'britsképanenskéostrovy'                 => 'vg',
    'britskéúzemievindickomoceáne'          => 'io',
    'brunej'                                   => 'bn',
    'bulharsko'                                => 'bg',
    'burkinafaso'                              => 'bf',
    'burundi'                                  => 'bi',
    'bután'                                   => 'bt',
    'cantonandenderburyislands'                => 'ct',
    'chorvátsko'                              => 'hr',
    'cookoveostrovy'                           => 'ck',
    'cyprus'                                   => 'cy',
    'dominika'                                 => 'dm',
    'dominikánskarepublika'                   => 'do',
    'dronningmaudland'                         => 'nq',
    'dánsko'                                  => 'dk',
    'džibuti'                                 => 'dj',
    'eastgermany'                              => 'dd',
    'egypt'                                    => 'eg',
    'ekvádor'                                 => 'ec',
    'eritrea'                                  => 'er',
    'estónsko'                                => 'ee',
    'etiópia'                                 => 'et',
    'európskaúnia'                           => 'qu',
    'faerskéostrovy'                          => 'fo',
    'falklandskéostrovy'                      => 'fk',
    'fidži'                                   => 'fj',
    'filipíny'                                => 'ph',
    'francúzskaguayana'                       => 'gf',
    'francúzskapolynézia'                    => 'pf',
    'francúzskejužnéúzemia'                => 'tf',
    'francúzsko'                              => 'fr',
    'frenchsouthernandantarcticterritories'    => 'fq',
    'fínsko'                                  => 'fi',
    'gabon'                                    => 'ga',
    'gambia'                                   => 'gm',
    'ghana'                                    => 'gh',
    'gibraltár'                               => 'gi',
    'grenada'                                  => 'gd',
    'gruzínsko'                               => 'ge',
    'grécko'                                  => 'gr',
    'grónsko'                                 => 'gl',
    'guadeloupe'                               => 'gp',
    'guam'                                     => 'gu',
    'guatemala'                                => 'gt',
    'guayana'                                  => 'gy',
    'guernsey'                                 => 'gg',
    'guinea'                                   => 'gn',
    'guineabissau'                             => 'gw',
    'haiti'                                    => 'ht',
    'heardoveostrovyamcdonaldoveostrovy'       => 'hm',
    'holandsko'                                => 'nl',
    'holandskéantily'                         => 'an',
    'honduras'                                 => 'hn',
    'hongkong'                                 => 'hk',
    'india'                                    => 'in',
    'indonézia'                               => 'id',
    'irak'                                     => 'iq',
    'irán'                                    => 'ir',
    'island'                                   => 'is',
    'izrael'                                   => 'il',
    'jamajka'                                  => 'jm',
    'japonsko'                                 => 'jp',
    'jemen'                                    => 'ye',
    'jersey'                                   => 'je',
    'johnstonisland'                           => 'jt',
    'jordánsko'                               => 'jo',
    'južnáafrika'                            => 'za',
    'južnágeorgiaajužnésandwichoveostrovy' => 'gs',
    'kajmanskéostrovy'                        => 'ky',
    'kambodža'                                => 'kh',
    'kamerun'                                  => 'cm',
    'kanada'                                   => 'ca',
    'kapverdy'                                 => 'cv',
    'katar'                                    => 'qa',
    'kazachstan'                               => 'kz',
    'keňa'                                    => 'ke',
    'kirgizsko'                                => 'kg',
    'kiribati'                                 => 'ki',
    'kokosovéostrovy'                         => 'cc',
    'kolumbia'                                 => 'co',
    'komory'                                   => 'km',
    'kongo'                                    => 'cg',
    'konžskádemokratickárepublika'          => 'cd',
    'kostarika'                                => 'cr',
    'kuba'                                     => 'cu',
    'kuvajt'                                   => 'kw',
    'kórejskárepublika'                      => 'kr',
    'kórejskáľudovodemokratickárepublika'  => 'kp',
    'laoskáľudovodemokratickárepublika'     => 'la',
    'lesotho'                                  => 'ls',
    'libanon'                                  => 'lb',
    'libéria'                                 => 'lr',
    'lichtenštajnsko'                         => 'li',
    'litva'                                    => 'lt',
    'lotyšsko'                                => 'lv',
    'luxembursko'                              => 'lu',
    'lýbijskáarabskádžamahírija'          => 'ly',
    'macao'                                    => 'mo',
    'macedónsko'                              => 'mk',
    'madagaskar'                               => 'mg',
    'malajzia'                                 => 'my',
    'malawi'                                   => 'mw',
    'maldivy'                                  => 'mv',
    'mali'                                     => 'ml',
    'malta'                                    => 'mt',
    'maroko'                                   => 'ma',
    'marshalloveostrovy'                       => 'mh',
    'martinik'                                 => 'mq',
    'mauritánia'                              => 'mr',
    'maurícius'                               => 'mu',
    'mayotte'                                  => 'yt',
    'maďarsko'                                => 'hu',
    'menšieodľahléostrovyusa'               => 'um',
    'metropolitanfrance'                       => 'fx',
    'mexiko'                                   => 'mx',
    'midwayislands'                            => 'mi',
    'mikronézia'                              => 'fm',
    'mjanmarsko'                               => 'mm',
    'moldavsko'                                => 'md',
    'monako'                                   => 'mc',
    'mongolsko'                                => 'mn',
    'montserrat'                               => 'ms',
    'mozambik'                                 => 'mz',
    'namíbia'                                 => 'na',
    'nauru'                                    => 'nr',
    'nemecko'                                  => 'de',
    'nepál'                                   => 'np',
    'neutralzone'                              => 'nt',
    'neznámyaleboneplatnýregión'            => 'zz',
    'niger'                                    => 'ne',
    'nigéria'                                 => 'ng',
    'nikaragua'                                => 'ni',
    'niue'                                     => 'nu',
    'norfolkovostrov'                          => 'nf',
    'northvietnam'                             => 'vd',
    'novákaledónia'                          => 'nc',
    'novýzéland'                             => 'nz',
    'nórsko'                                  => 'no',
    'omán'                                    => 'om',
    'ostrovman'                                => 'im',
    'pacificislandstrustterritory'             => 'pc',
    'pakistan'                                 => 'pk',
    'palau'                                    => 'pw',
    'palestínskeúzemie'                      => 'ps',
    'panama'                                   => 'pa',
    'panamacanalzone'                          => 'pz',
    'panenskéostrovyusa'                      => 'vi',
    'papuanováguinea'                         => 'pg',
    'paraguaj'                                 => 'py',
    'peoplesdemocraticrepublicofyemen'         => 'yd',
    'peru'                                     => 'pe',
    'pitcairnoveostrovy'                       => 'pn',
    'pobrežieslonoviny'                       => 'ci',
    'portoriko'                                => 'pr',
    'portugalsko'                              => 'pt',
    'poľsko'                                  => 'pl',
    'rakúsko'                                 => 'at',
    'reunion'                                  => 're',
    'rovníkováguinea'                        => 'gq',
    'rumunsko'                                 => 'ro',
    'ruskáfederácia'                         => 'ru',
    'rwanda'                                   => 'rw',
    'saintkittsanevis'                         => 'kn',
    'saintpierreamiquelon'                     => 'pm',
    'salvador'                                 => 'sv',
    'samoa'                                    => 'ws',
    'sanmaríno'                               => 'sm',
    'saudskáarábia'                          => 'sa',
    'senegal'                                  => 'sn',
    'severnémariány'                         => 'mp',
    'seychelskéostrovy'                       => 'sc',
    'sierraleone'                              => 'sl',
    'singapur'                                 => 'sg',
    'slovenskárepublika'                      => 'sk',
    'slovinsko'                                => 'si',
    'somálsko'                                => 'so',
    'spojenéarabskéemiráty'                 => 'ae',
    'spojenékráľovstvo'                     => 'gb',
    'spojenéštáty'                          => 'us',
    'srbsko'                                   => 'rs',
    'srbskoaČiernahora'                       => 'cs',
    'srílanka'                                => 'lk',
    'stredoafrickárepublika'                  => 'cf',
    'sudán'                                   => 'sd',
    'surinam'                                  => 'sr',
    'svazijsko'                                => 'sz',
    'svätáhelena'                            => 'sh',
    'svätálucia'                             => 'lc',
    'svätýbartolomej'                        => 'bl',
    'svätýmartin'                            => 'mf',
    'svätýtomášaprincoveostrovy'           => 'st',
    'svätývincentagrenadíny'                => 'vc',
    'sýrskaarabskárepublika'                 => 'sy',
    'tadžikistan'                             => 'tj',
    'tajwan'                                   => 'tw',
    'taliansko'                                => 'it',
    'tanzánia'                                => 'tz',
    'thajsko'                                  => 'th',
    'tichomorieostatné'                       => 'qo',
    'togo'                                     => 'tg',
    'tokelau'                                  => 'tk',
    'tonga'                                    => 'to',
    'trinidadatobago'                          => 'tt',
    'tunisko'                                  => 'tn',
    'turecko'                                  => 'tr',
    'turkménsko'                              => 'tm',
    'turksacaicos'                             => 'tc',
    'tuvalu'                                   => 'tv',
    "u\.s\.miscellaneouspacificislands"        => 'pu',
    'uganda'                                   => 'ug',
    'ukrajina'                                 => 'ua',
    'unionofsovietsocialistrepublics'          => 'su',
    'uruguaj'                                  => 'uy',
    'uzbekistan'                               => 'uz',
    'vanuatu'                                  => 'vu',
    'vatikán'                                 => 'va',
    'venezuela'                                => 've',
    'vianočnýostrov'                         => 'cx',
    'vietnam'                                  => 'vn',
    'východnýtimor'                          => 'tl',
    'wakeisland'                               => 'wk',
    'wallisafutuna'                            => 'wf',
    'zambia'                                   => 'zm',
    'zimbabwe'                                 => 'zw',
    'západnásahara'                          => 'eh',
    'Írsko'                                   => 'ie',
    'Čad'                                     => 'td',
    'Českárepublika'                         => 'cz',
    'Čiernahora'                              => 'me',
    'Čile'                                    => 'cl',
    'Čína'                                   => 'cn',
    'Šalamúnoveostrovy'                      => 'sb',
    'Španielsko'                              => 'es',
    'Špicbergyajanmayen'                      => 'sj',
    'Švajčiarsko'                            => 'ch',
    'Švédsko'                                => 'se',
);

1;

