package Locales::DB::Territory::it;

# Auto generated from CLDR

$Locales::DB::Territory::it::VERSION = '0.02';

$Locales::DB::Territory::it::cldr_version = '1.7.1';

%Locales::DB::Territory::it::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "Emirati\ Arabi\ Uniti",
    'af' => 'Afghanistan',
    'ag' => "Antigua\ e\ Barbuda",
    'ai' => 'Anguilla',
    'al' => 'Albania',
    'am' => 'Armenia',
    'an' => "Antille\ Olandesi",
    'ao' => 'Angola',
    'aq' => 'Antartide',
    'ar' => 'Argentina',
    'as' => "Samoa\ Americane",
    'at' => 'Austria',
    'au' => 'Australia',
    'aw' => 'Aruba',
    'ax' => "Isole\ Aland",
    'az' => 'Azerbaigian',
    'ba' => "Bosnia\ Erzegovina",
    'bb' => 'Barbados',
    'bd' => 'Bangladesh',
    'be' => 'Belgio',
    'bf' => "Burkina\ Faso",
    'bg' => 'Bulgaria',
    'bh' => 'Bahrein',
    'bi' => 'Burundi',
    'bj' => 'Benin',
    'bl' => "San\ Bartolomeo",
    'bm' => 'Bermuda',
    'bn' => 'Brunei',
    'bo' => 'Bolivia',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brasile',
    'bs' => 'Bahamas',
    'bt' => 'Bhutan',
    'bv' => "Isola\ Bouvet",
    'bw' => 'Botswana',
    'by' => 'Bielorussia',
    'bz' => 'Belize',
    'ca' => 'Canada',
    'cc' => "Isole\ Cocos",
    'cd' => "Repubblica\ Democratica\ del\ Congo",
    'cf' => "Repubblica\ Centrafricana",
    'cg' => 'Congo',
    'ch' => 'Svizzera',
    'ci' => "Costa\ d’Avorio",
    'ck' => "Isole\ Cook",
    'cl' => 'Cile',
    'cm' => 'Camerun',
    'cn' => 'Cina',
    'co' => 'Colombia',
    'cr' => "Costa\ Rica",
    'cs' => "Serbia\ e\ Montenegro",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Cuba',
    'cv' => "Capo\ Verde",
    'cx' => "Isola\ di\ Christmas",
    'cy' => 'Cipro',
    'cz' => "Repubblica\ Ceca",
    'dd' => "East\ Germany",
    'de' => 'Germania',
    'dj' => 'Gibuti',
    'dk' => 'Danimarca',
    'dm' => 'Dominica',
    'do' => "Repubblica\ Dominicana",
    'dz' => 'Algeria',
    'ec' => 'Ecuador',
    'ee' => 'Estonia',
    'eg' => 'Egitto',
    'eh' => "Sahara\ Occidentale",
    'er' => 'Eritrea',
    'es' => 'Spagna',
    'et' => 'Etiopia',
    'fi' => 'Finlandia',
    'fj' => 'Figi',
    'fk' => "Isole\ Falkland",
    'fm' => 'Micronesia',
    'fo' => "Isole\ Faroe",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Francia',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabon',
    'gb' => "Regno\ Unito",
    'gd' => 'Grenada',
    'ge' => 'Georgia',
    'gf' => "Guiana\ Francese",
    'gg' => 'Guernsey',
    'gh' => 'Ghana',
    'gi' => 'Gibilterra',
    'gl' => 'Groenlandia',
    'gm' => 'Gambia',
    'gn' => 'Guinea',
    'gp' => 'Guadalupa',
    'gq' => "Guinea\ Equatoriale",
    'gr' => 'Grecia',
    'gs' => "Georgia\ del\ Sud\ e\ Isole\ Sandwich\ del\ Sud",
    'gt' => 'Guatemala',
    'gu' => 'Guam',
    'gw' => "Guinea\-Bissau",
    'gy' => 'Guyana',
    'hk' => "Hong\ Kong",
    'hm' => "Isole\ Heard\ ed\ Isole\ McDonald",
    'hn' => 'Honduras',
    'hr' => 'Croazia',
    'ht' => 'Haiti',
    'hu' => 'Ungheria',
    'id' => 'Indonesia',
    'ie' => 'Irlanda',
    'il' => 'Israele',
    'im' => "Isola\ di\ Man",
    'in' => 'India',
    'io' => "Territorio\ Britannico\ dell’Oceano\ Indiano",
    'iq' => 'Iraq',
    'ir' => 'Iran',
    'is' => 'Islanda',
    'it' => 'Italia',
    'je' => 'Jersey',
    'jm' => 'Giamaica',
    'jo' => 'Giordania',
    'jp' => 'Giappone',
    'jt' => "Johnston\ Island",
    'ke' => 'Kenya',
    'kg' => 'Kirghizistan',
    'kh' => 'Cambogia',
    'ki' => 'Kiribati',
    'km' => 'Comore',
    'kn' => "Saint\ Kitts\ e\ Nevis",
    'kp' => "Corea\ del\ Nord",
    'kr' => "Corea\ del\ Sud",
    'kw' => 'Kuwait',
    'ky' => "Isole\ Cayman",
    'kz' => 'Kazakistan',
    'la' => 'Laos',
    'lb' => 'Libano',
    'lc' => "Saint\ Lucia",
    'li' => 'Liechtenstein',
    'lk' => "Sri\ Lanka",
    'lr' => 'Liberia',
    'ls' => 'Lesotho',
    'lt' => 'Lituania',
    'lu' => 'Lussemburgo',
    'lv' => 'Lettonia',
    'ly' => 'Libia',
    'ma' => 'Marocco',
    'mc' => 'Monaco',
    'md' => 'Moldavia',
    'me' => 'Montenegro',
    'mf' => "Saint\ Martin",
    'mg' => 'Madagascar',
    'mh' => "Isole\ Marshall",
    'mi' => "Midway\ Islands",
    'mk' => "Repubblica\ di\ Macedonia",
    'ml' => 'Mali',
    'mm' => 'Myanmar',
    'mn' => 'Mongolia',
    'mo' => 'Macao',
    'mp' => "Isole\ Marianne\ Settentrionali",
    'mq' => 'Martinica',
    'mr' => 'Mauritania',
    'ms' => 'Montserrat',
    'mt' => 'Malta',
    'mu' => 'Mauritius',
    'mv' => 'Maldive',
    'mw' => 'Malawi',
    'mx' => 'Messico',
    'my' => 'Malesia',
    'mz' => 'Mozambico',
    'na' => 'Namibia',
    'nc' => "Nuova\ Caledonia",
    'ne' => 'Niger',
    'nf' => "Isola\ Norfolk",
    'ng' => 'Nigeria',
    'ni' => 'Nicaragua',
    'nl' => "Paesi\ Bassi",
    'no' => 'Norvegia',
    'np' => 'Nepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "Nuova\ Zelanda",
    'om' => 'Oman',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Perù',
    'pf' => "Polinesia\ Francese",
    'pg' => "Papua\ Nuova\ Guinea",
    'ph' => 'Filippine',
    'pk' => 'Pakistan',
    'pl' => 'Polonia',
    'pm' => "Saint\ Pierre\ e\ Miquelon",
    'pn' => 'Pitcairn',
    'pr' => 'Portorico',
    'ps' => 'Palestina',
    'pt' => 'Portogallo',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paraguay',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Qatar',
    'qo' => "Oceania\ lontana",
    'qu' => "Unione\ Europea",
    're' => 'Réunion',
    'ro' => 'Romania',
    'rs' => 'Serbia',
    'ru' => "Federazione\ Russa",
    'rw' => 'Ruanda',
    'sa' => "Arabia\ Saudita",
    'sb' => "Isole\ Solomon",
    'sc' => 'Seychelles',
    'sd' => 'Sudan',
    'se' => 'Svezia',
    'sg' => 'Singapore',
    'sh' => 'Sant’Elena',
    'si' => 'Slovenia',
    'sj' => "Svalbard\ e\ Jan\ Mayen",
    'sk' => 'Slovacchia',
    'sl' => "Sierra\ Leone",
    'sm' => "San\ Marino",
    'sn' => 'Senegal',
    'so' => 'Somalia',
    'sr' => 'Suriname',
    'st' => "Sao\ Tomé\ e\ Príncipe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salvador",
    'sy' => 'Siria',
    'sz' => 'Swaziland',
    'tc' => "Isole\ Turks\ e\ Caicos",
    'td' => 'Ciad',
    'tf' => "Territori\ australi\ francesi",
    'tg' => 'Togo',
    'th' => 'Tailandia',
    'tj' => 'Tagikistan',
    'tk' => 'Tokelau',
    'tl' => "Timor\ Est",
    'tm' => 'Turkmenistan',
    'tn' => 'Tunisia',
    'to' => 'Tonga',
    'tr' => 'Turchia',
    'tt' => "Trinidad\ e\ Tobago",
    'tv' => 'Tuvalu',
    'tw' => 'Taiwan',
    'tz' => 'Tanzania',
    'ua' => 'Ucraina',
    'ug' => 'Uganda',
    'um' => "Isole\ Minori\ lontane\ dagli\ Stati\ Uniti",
    'us' => "Stati\ Uniti",
    'uy' => 'Uruguay',
    'uz' => 'Uzbekistan',
    'va' => 'Vaticano',
    'vc' => "Saint\ Vincent\ e\ Grenadines",
    'vd' => "North\ Vietnam",
    've' => 'Venezuela',
    'vg' => "Isole\ Vergini\ Britanniche",
    'vi' => "Isole\ Vergini\ Americane",
    'vn' => 'Vietnam',
    'vu' => 'Vanuatu',
    'wf' => "Wallis\ e\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Yemen',
    'yt' => 'Mayotte',
    'za' => 'Sudafrica',
    'zm' => 'Zambia',
    'zw' => 'Zimbabwe',
    'zz' => "regione\ non\ valida\ o\ sconosciuta",
);

%Locales::DB::Territory::it::name_to_code = (
    'afghanistan'                              => 'af',
    'albania'                                  => 'al',
    'algeria'                                  => 'dz',
    'andorra'                                  => 'ad',
    'angola'                                   => 'ao',
    'anguilla'                                 => 'ai',
    'antartide'                                => 'aq',
    'antiguaebarbuda'                          => 'ag',
    'antilleolandesi'                          => 'an',
    'arabiasaudita'                            => 'sa',
    'argentina'                                => 'ar',
    'armenia'                                  => 'am',
    'aruba'                                    => 'aw',
    'australia'                                => 'au',
    'austria'                                  => 'at',
    'azerbaigian'                              => 'az',
    'bahamas'                                  => 'bs',
    'bahrein'                                  => 'bh',
    'bangladesh'                               => 'bd',
    'barbados'                                 => 'bb',
    'belgio'                                   => 'be',
    'belize'                                   => 'bz',
    'benin'                                    => 'bj',
    'bermuda'                                  => 'bm',
    'bhutan'                                   => 'bt',
    'bielorussia'                              => 'by',
    'bolivia'                                  => 'bo',
    'bosniaerzegovina'                         => 'ba',
    'botswana'                                 => 'bw',
    'brasile'                                  => 'br',
    'britishantarcticterritory'                => 'bq',
    'brunei'                                   => 'bn',
    'bulgaria'                                 => 'bg',
    'burkinafaso'                              => 'bf',
    'burundi'                                  => 'bi',
    'cambogia'                                 => 'kh',
    'camerun'                                  => 'cm',
    'canada'                                   => 'ca',
    'cantonandenderburyislands'                => 'ct',
    'capoverde'                                => 'cv',
    'ciad'                                     => 'td',
    'cile'                                     => 'cl',
    'cina'                                     => 'cn',
    'cipro'                                    => 'cy',
    'colombia'                                 => 'co',
    'comore'                                   => 'km',
    'congo'                                    => 'cg',
    'coreadelnord'                             => 'kp',
    'coreadelsud'                              => 'kr',
    'costad’avorio'                          => 'ci',
    'costarica'                                => 'cr',
    'croazia'                                  => 'hr',
    'cuba'                                     => 'cu',
    'danimarca'                                => 'dk',
    'dominica'                                 => 'dm',
    'dronningmaudland'                         => 'nq',
    'eastgermany'                              => 'dd',
    'ecuador'                                  => 'ec',
    'egitto'                                   => 'eg',
    'elsalvador'                               => 'sv',
    'emiratiarabiuniti'                        => 'ae',
    'eritrea'                                  => 'er',
    'estonia'                                  => 'ee',
    'etiopia'                                  => 'et',
    'federazionerussa'                         => 'ru',
    'figi'                                     => 'fj',
    'filippine'                                => 'ph',
    'finlandia'                                => 'fi',
    'francia'                                  => 'fr',
    'frenchsouthernandantarcticterritories'    => 'fq',
    'gabon'                                    => 'ga',
    'gambia'                                   => 'gm',
    'georgia'                                  => 'ge',
    'georgiadelsudeisolesandwichdelsud'        => 'gs',
    'germania'                                 => 'de',
    'ghana'                                    => 'gh',
    'giamaica'                                 => 'jm',
    'giappone'                                 => 'jp',
    'gibilterra'                               => 'gi',
    'gibuti'                                   => 'dj',
    'giordania'                                => 'jo',
    'grecia'                                   => 'gr',
    'grenada'                                  => 'gd',
    'groenlandia'                              => 'gl',
    'guadalupa'                                => 'gp',
    'guam'                                     => 'gu',
    'guatemala'                                => 'gt',
    'guernsey'                                 => 'gg',
    'guianafrancese'                           => 'gf',
    'guinea'                                   => 'gn',
    'guineabissau'                             => 'gw',
    'guineaequatoriale'                        => 'gq',
    'guyana'                                   => 'gy',
    'haiti'                                    => 'ht',
    'honduras'                                 => 'hn',
    'hongkong'                                 => 'hk',
    'india'                                    => 'in',
    'indonesia'                                => 'id',
    'iran'                                     => 'ir',
    'iraq'                                     => 'iq',
    'irlanda'                                  => 'ie',
    'islanda'                                  => 'is',
    'isolabouvet'                              => 'bv',
    'isoladichristmas'                         => 'cx',
    'isoladiman'                               => 'im',
    'isolanorfolk'                             => 'nf',
    'isolealand'                               => 'ax',
    'isolecayman'                              => 'ky',
    'isolecocos'                               => 'cc',
    'isolecook'                                => 'ck',
    'isolefalkland'                            => 'fk',
    'isolefaroe'                               => 'fo',
    'isoleheardedisolemcdonald'                => 'hm',
    'isolemariannesettentrionali'              => 'mp',
    'isolemarshall'                            => 'mh',
    'isoleminorilontanedaglistatiuniti'        => 'um',
    'isolesolomon'                             => 'sb',
    'isoleturksecaicos'                        => 'tc',
    'isoleverginiamericane'                    => 'vi',
    'isoleverginibritanniche'                  => 'vg',
    'israele'                                  => 'il',
    'italia'                                   => 'it',
    'jersey'                                   => 'je',
    'johnstonisland'                           => 'jt',
    'kazakistan'                               => 'kz',
    'kenya'                                    => 'ke',
    'kirghizistan'                             => 'kg',
    'kiribati'                                 => 'ki',
    'kuwait'                                   => 'kw',
    'laos'                                     => 'la',
    'lesotho'                                  => 'ls',
    'lettonia'                                 => 'lv',
    'libano'                                   => 'lb',
    'liberia'                                  => 'lr',
    'libia'                                    => 'ly',
    'liechtenstein'                            => 'li',
    'lituania'                                 => 'lt',
    'lussemburgo'                              => 'lu',
    'macao'                                    => 'mo',
    'madagascar'                               => 'mg',
    'malawi'                                   => 'mw',
    'maldive'                                  => 'mv',
    'malesia'                                  => 'my',
    'mali'                                     => 'ml',
    'malta'                                    => 'mt',
    'marocco'                                  => 'ma',
    'martinica'                                => 'mq',
    'mauritania'                               => 'mr',
    'mauritius'                                => 'mu',
    'mayotte'                                  => 'yt',
    'messico'                                  => 'mx',
    'metropolitanfrance'                       => 'fx',
    'micronesia'                               => 'fm',
    'midwayislands'                            => 'mi',
    'moldavia'                                 => 'md',
    'monaco'                                   => 'mc',
    'mongolia'                                 => 'mn',
    'montenegro'                               => 'me',
    'montserrat'                               => 'ms',
    'mozambico'                                => 'mz',
    'myanmar'                                  => 'mm',
    'namibia'                                  => 'na',
    'nauru'                                    => 'nr',
    'nepal'                                    => 'np',
    'neutralzone'                              => 'nt',
    'nicaragua'                                => 'ni',
    'niger'                                    => 'ne',
    'nigeria'                                  => 'ng',
    'niue'                                     => 'nu',
    'northvietnam'                             => 'vd',
    'norvegia'                                 => 'no',
    'nuovacaledonia'                           => 'nc',
    'nuovazelanda'                             => 'nz',
    'oceanialontana'                           => 'qo',
    'oman'                                     => 'om',
    'pacificislandstrustterritory'             => 'pc',
    'paesibassi'                               => 'nl',
    'pakistan'                                 => 'pk',
    'palau'                                    => 'pw',
    'palestina'                                => 'ps',
    'panama'                                   => 'pa',
    'panamacanalzone'                          => 'pz',
    'papuanuovaguinea'                         => 'pg',
    'paraguay'                                 => 'py',
    'peoplesdemocraticrepublicofyemen'         => 'yd',
    'perù'                                    => 'pe',
    'pitcairn'                                 => 'pn',
    'polinesiafrancese'                        => 'pf',
    'polonia'                                  => 'pl',
    'portogallo'                               => 'pt',
    'portorico'                                => 'pr',
    'qatar'                                    => 'qa',
    'regionenonvalidaosconosciuta'             => 'zz',
    'regnounito'                               => 'gb',
    'repubblicaceca'                           => 'cz',
    'repubblicacentrafricana'                  => 'cf',
    'repubblicademocraticadelcongo'            => 'cd',
    'repubblicadimacedonia'                    => 'mk',
    'repubblicadominicana'                     => 'do',
    'romania'                                  => 'ro',
    'ruanda'                                   => 'rw',
    'réunion'                                 => 're',
    'saharaoccidentale'                        => 'eh',
    'saintkittsenevis'                         => 'kn',
    'saintlucia'                               => 'lc',
    'saintmartin'                              => 'mf',
    'saintpierreemiquelon'                     => 'pm',
    'saintvincentegrenadines'                  => 'vc',
    'samoa'                                    => 'ws',
    'samoaamericane'                           => 'as',
    'sanbartolomeo'                            => 'bl',
    'sanmarino'                                => 'sm',
    'sant’elena'                             => 'sh',
    'saotoméepríncipe'                       => 'st',
    'senegal'                                  => 'sn',
    'serbia'                                   => 'rs',
    'serbiaemontenegro'                        => 'cs',
    'seychelles'                               => 'sc',
    'sierraleone'                              => 'sl',
    'singapore'                                => 'sg',
    'siria'                                    => 'sy',
    'slovacchia'                               => 'sk',
    'slovenia'                                 => 'si',
    'somalia'                                  => 'so',
    'spagna'                                   => 'es',
    'srilanka'                                 => 'lk',
    'statiuniti'                               => 'us',
    'sudafrica'                                => 'za',
    'sudan'                                    => 'sd',
    'suriname'                                 => 'sr',
    'svalbardejanmayen'                        => 'sj',
    'svezia'                                   => 'se',
    'svizzera'                                 => 'ch',
    'swaziland'                                => 'sz',
    'tagikistan'                               => 'tj',
    'tailandia'                                => 'th',
    'taiwan'                                   => 'tw',
    'tanzania'                                 => 'tz',
    'territoriaustralifrancesi'                => 'tf',
    'territoriobritannicodell’oceanoindiano' => 'io',
    'timorest'                                 => 'tl',
    'togo'                                     => 'tg',
    'tokelau'                                  => 'tk',
    'tonga'                                    => 'to',
    'trinidadetobago'                          => 'tt',
    'tunisia'                                  => 'tn',
    'turchia'                                  => 'tr',
    'turkmenistan'                             => 'tm',
    'tuvalu'                                   => 'tv',
    "u\.s\.miscellaneouspacificislands"        => 'pu',
    'ucraina'                                  => 'ua',
    'uganda'                                   => 'ug',
    'ungheria'                                 => 'hu',
    'unioneeuropea'                            => 'qu',
    'unionofsovietsocialistrepublics'          => 'su',
    'uruguay'                                  => 'uy',
    'uzbekistan'                               => 'uz',
    'vanuatu'                                  => 'vu',
    'vaticano'                                 => 'va',
    'venezuela'                                => 've',
    'vietnam'                                  => 'vn',
    'wakeisland'                               => 'wk',
    'wallisefutuna'                            => 'wf',
    'yemen'                                    => 'ye',
    'zambia'                                   => 'zm',
    'zimbabwe'                                 => 'zw',
);

1;

