package Locales::DB::Territory::ur;

# Auto generated from CLDR

$Locales::DB::Territory::ur::VERSION = '0.02';

$Locales::DB::Territory::ur::cldr_version = '1.7.1';

%Locales::DB::Territory::ur::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "متحدہ\ عرب\ امارات",
    'af' => 'افغانستان',
    'ag' => "انٹیگوا\ اور\ باربودا",
    'ai' => 'Anguilla',
    'al' => 'البانیا',
    'am' => "آر\ مینیا",
    'an' => "نیدرلینڈز\ انٹیلیز",
    'ao' => 'انگولا',
    'aq' => "انٹار\ ٹکا",
    'ar' => 'ارجنٹینا',
    'as' => "امریکی\ ساموا",
    'at' => 'آسٹریا',
    'au' => 'آسٹریلیا',
    'aw' => 'Aruba',
    'ax' => "\Ã\land\ Islands",
    'az' => "آذر\ بائجان",
    'ba' => "بوسنیا\ ہرزگوینا",
    'bb' => 'Barbados',
    'bd' => "بنگلا\ دیش",
    'be' => 'بیلجئیم',
    'bf' => "برکینا\ فاسو",
    'bg' => 'بلغاریہ',
    'bh' => 'Bahrain',
    'bi' => 'برنڈی',
    'bj' => 'بینن',
    'bl' => "Saint\ Barth\Ã\©lemy",
    'bm' => 'Bermuda',
    'bn' => 'Brunei',
    'bo' => 'بولیویا',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'برازیل',
    'bs' => "باھا\ ماس",
    'bt' => 'بھوٹان',
    'bv' => "جزیرہ\ بووٹ",
    'bw' => 'بوٹسوانا',
    'by' => "بیلا\ رس",
    'bz' => 'Belize',
    'ca' => 'کینیڈا',
    'cc' => "جزائر\ کوکوز",
    'cd' => "کانگو،\ جمہوری\ ریاست",
    'cf' => "جمہوریہ\ وسطی\ افریقہ",
    'cg' => 'کانگو',
    'ch' => "سوئزر\ لینڈ",
    'ci' => "Ivory\ Coast",
    'ck' => "جزائر\ کُک",
    'cl' => 'چلی',
    'cm' => 'کیمرون',
    'cn' => 'چین',
    'co' => 'کولمبیا',
    'cr' => "Costa\ Rica",
    'cs' => "سربیا\ اور\ مانٹینیگرو",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'کیوبا',
    'cv' => "Cape\ Verde",
    'cx' => "جزیرہ\ کرسمس",
    'cy' => 'قبرص',
    'cz' => "جمہوریہ\ چیک",
    'dd' => "East\ Germany",
    'de' => 'جرمنی',
    'dj' => 'Djibouti',
    'dk' => 'ڈنمارک',
    'dm' => 'Dominica',
    'do' => "ڈومینیکن\ ریپبلک",
    'dz' => 'الجیریا',
    'ec' => 'ایکواڈور',
    'ee' => 'ایسٹونیا',
    'eg' => 'مصر',
    'eh' => "مغربی\ صحارا",
    'er' => 'اریٹیریا',
    'es' => 'سپین',
    'et' => 'ایتھوپیا',
    'fi' => "فن\ لینڈ",
    'fj' => 'Fiji',
    'fk' => "جزائر\ فاک\ لینڈ",
    'fm' => 'مائکرونیزیا',
    'fo' => 'جزائرفارو',
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'فرانس',
    'fx' => "Metropolitan\ France",
    'ga' => 'غیبون',
    'gb' => 'برطانیہ',
    'gd' => 'Grenada',
    'ge' => 'جارجیا',
    'gf' => "فرانسیسی\ گی\ آنا",
    'gg' => 'گرنزی',
    'gh' => 'گھانا',
    'gi' => 'Gibraltar',
    'gl' => "گرین\ لینڈ",
    'gm' => 'گیمبیا',
    'gn' => 'گنی',
    'gp' => 'Guadeloupe',
    'gq' => "استوائی\ گنی",
    'gr' => 'یونان',
    'gs' => "جنوبی\ جارجیا\ اور\ جزائر\ جنوبی\ سینڈوچ",
    'gt' => 'Guatemala',
    'gu' => 'Guam',
    'gw' => "گنی\ بسائو",
    'gy' => 'Guyana',
    'hk' => "Hong\ Kong",
    'hm' => "جزیرہ\ ہرڈ\ اور\ جزائر\ مکڈونلڈ",
    'hn' => 'ہونڈوراس',
    'hr' => 'کروشیا',
    'ht' => 'ہائٹی',
    'hu' => 'ہنگری',
    'id' => 'انڈونیشیا',
    'ie' => "آئر\ لینڈ",
    'il' => 'اسرائیل',
    'im' => "Isle\ of\ Man",
    'in' => 'بھارت',
    'io' => "بحرھند\ کا\ برٹش\ علاقہ",
    'iq' => 'عراق',
    'ir' => 'ایران',
    'is' => "آئس\ لینڈ",
    'it' => 'اٹلی',
    'je' => 'جرسی',
    'jm' => 'Jamaica',
    'jo' => 'اردن',
    'jp' => 'جاپان',
    'jt' => "Johnston\ Island",
    'ke' => 'کینیا',
    'kg' => 'کرغستان',
    'kh' => 'کمبوڈیا',
    'ki' => 'کِرباتی',
    'km' => 'کوموروس',
    'kn' => "سینٹ\ کٹس\ اور\ نیوس",
    'kp' => "شمالی\ کوریا",
    'kr' => "جنوبی\ کوریا",
    'kw' => 'Kuwait',
    'ky' => "جزائر\ کیمن",
    'kz' => 'قزاقستان',
    'la' => 'لاؤس',
    'lb' => 'لبنان',
    'lc' => "سینٹ\ لوسیا",
    'li' => 'لکٹنسٹائن',
    'lk' => "سری\ لنکا",
    'lr' => 'لائبیریا',
    'ls' => 'لیسوتھو',
    'lt' => 'لتھوانیا',
    'lu' => 'Luxembourg',
    'lv' => 'لٹوِیا',
    'ly' => 'لیبیا',
    'ma' => 'مراکش',
    'mc' => 'Monaco',
    'md' => 'مالدووا',
    'me' => 'Montenegro',
    'mf' => "Saint\ Martin",
    'mg' => 'مڈغاسکر',
    'mh' => "جزائر\ مارشل",
    'mi' => "Midway\ Islands",
    'mk' => 'مقدونیہ',
    'ml' => 'مالی',
    'mm' => 'میانمر',
    'mn' => 'منگولیا',
    'mo' => 'ماکاؤ',
    'mp' => "شمالی\ ماریاناجزائر",
    'mq' => 'Martinique',
    'mr' => 'موریطانیہ',
    'ms' => 'Montserrat',
    'mt' => 'Malta',
    'mu' => 'Mauritius',
    'mv' => 'Maldives',
    'mw' => 'ملاوی',
    'mx' => 'میکسیکو',
    'my' => 'ملائیشیا',
    'mz' => 'موزنبیق',
    'na' => 'نمیبیا',
    'nc' => "نیو\ کیلیڈونیا",
    'ne' => 'نائیجر',
    'nf' => "جزیرہ\ نارفولک",
    'ng' => 'نائیجیریا',
    'ni' => 'نکاراگوا',
    'nl' => 'نیدرلینڈ',
    'no' => 'ناروے',
    'np' => 'نیپال',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "نیوزی\ لینڈ",
    'om' => 'عمان',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'پیرو',
    'pf' => "فرانسیسی\ پولینیسیا",
    'pg' => "پاپوا\ نیو\ گنی",
    'ph' => 'فلپائن',
    'pk' => 'پاکستان',
    'pl' => 'پولینڈ',
    'pm' => "سینٹ\ پائرے\ اور\ میکویلون",
    'pn' => "Pitcairn\ Islands",
    'pr' => "Puerto\ Rico",
    'ps' => 'فلسطین',
    'pt' => 'پرتگال',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'پیراگوئے',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Qatar',
    'qo' => "Outlying\ Oceania",
    'qu' => "European\ Union",
    're' => "R\Ã\©union",
    'ro' => 'رومانیہ',
    'rs' => 'Serbia',
    'ru' => 'روس',
    'rw' => 'روانڈا',
    'sa' => "سعودی\ عرب",
    'sb' => 'جزائرسولمون',
    'sc' => "سے\ شلز",
    'sd' => 'سوڈان',
    'se' => 'سویڈن',
    'sg' => 'Singapore',
    'sh' => "سینٹ\ ھیلینا",
    'si' => 'سلوانیہ',
    'sj' => "Svalbard\ and\ Jan\ Mayen",
    'sk' => 'سلوواکیہ',
    'sl' => 'سیرالیون',
    'sm' => "سان\ میرینو",
    'sn' => 'سینیگال',
    'so' => 'صوپالیہ',
    'sr' => 'سورینام',
    'st' => "S\Ã\£o\ Tom\Ã\©\ and\ Pr\Ã\­ncipe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salvador",
    'sy' => 'سیریا',
    'sz' => "سوازی\ لینڈ",
    'tc' => "جزائر\ کیکس\ اور\ ترکیّہ",
    'td' => 'چاڈ',
    'tf' => "جنوبی\ فرانسیسی\ علاقہ\ جات",
    'tg' => 'ٹوگو',
    'th' => "تھائی\ لینڈ",
    'tj' => 'تاجکستان',
    'tk' => 'ٹوکیلاؤ',
    'tl' => "مشرقی\ تیمور",
    'tm' => 'ترکمانستان',
    'tn' => 'تیونس',
    'to' => 'تونگا',
    'tr' => 'ترکی',
    'tt' => "ٹرینیڈاڈ\ اور\ ٹوباگو",
    'tv' => 'ٹوالو',
    'tw' => 'تائیوان',
    'tz' => 'تنزانیہ',
    'ua' => 'یوکرائن',
    'ug' => 'یوگنڈا',
    'um' => "ریاست\ ہائے\ متحدہ\ اور\ بیرونی\ جزائر",
    'us' => "ریاست\ ہائے\ متحدہ\ امریکا",
    'uy' => 'ہوراگوئے',
    'uz' => 'ازبکستان',
    'va' => "ویٹیکن\ سٹی",
    'vc' => "سینٹ\ کیرن\ اور\ گریناڈائنز",
    'vd' => "North\ Vietnam",
    've' => 'وینزولا',
    'vg' => "جزائر\ ورجن،\ برٹش",
    'vi' => "جزائر\ ورجن،\ امریکہ",
    'vn' => "ویت\ نام",
    'vu' => 'وانواٹو',
    'wf' => "والس\ اور\ فتونہ",
    'wk' => "Wake\ Island",
    'ws' => 'ساموا',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'یمن',
    'yt' => 'Mayotte',
    'za' => "جنوبی\ افریقہ",
    'zm' => 'زیمبیا',
    'zw' => 'زمبابوے',
    'zz' => "Unknown\ or\ Invalid\ Region",
);

%Locales::DB::Territory::ur::name_to_code = (
    'andorra'                                                      => 'ad',
    'anguilla'                                                     => 'ai',
    'aruba'                                                        => 'aw',
    'bahrain'                                                      => 'bh',
    'barbados'                                                     => 'bb',
    'belize'                                                       => 'bz',
    'bermuda'                                                      => 'bm',
    'britishantarcticterritory'                                    => 'bq',
    'brunei'                                                       => 'bn',
    'cantonandenderburyislands'                                    => 'ct',
    'capeverde'                                                    => 'cv',
    'costarica'                                                    => 'cr',
    'djibouti'                                                     => 'dj',
    'dominica'                                                     => 'dm',
    'dronningmaudland'                                             => 'nq',
    'eastgermany'                                                  => 'dd',
    'elsalvador'                                                   => 'sv',
    'europeanunion'                                                => 'qu',
    'fiji'                                                         => 'fj',
    'frenchsouthernandantarcticterritories'                        => 'fq',
    'gibraltar'                                                    => 'gi',
    'grenada'                                                      => 'gd',
    'guadeloupe'                                                   => 'gp',
    'guam'                                                         => 'gu',
    'guatemala'                                                    => 'gt',
    'guyana'                                                       => 'gy',
    'hongkong'                                                     => 'hk',
    'isleofman'                                                    => 'im',
    'ivorycoast'                                                   => 'ci',
    'jamaica'                                                      => 'jm',
    'johnstonisland'                                               => 'jt',
    'kuwait'                                                       => 'kw',
    'luxembourg'                                                   => 'lu',
    'maldives'                                                     => 'mv',
    'malta'                                                        => 'mt',
    'martinique'                                                   => 'mq',
    'mauritius'                                                    => 'mu',
    'mayotte'                                                      => 'yt',
    'metropolitanfrance'                                           => 'fx',
    'midwayislands'                                                => 'mi',
    'monaco'                                                       => 'mc',
    'montenegro'                                                   => 'me',
    'montserrat'                                                   => 'ms',
    'nauru'                                                        => 'nr',
    'neutralzone'                                                  => 'nt',
    'niue'                                                         => 'nu',
    'northvietnam'                                                 => 'vd',
    'outlyingoceania'                                              => 'qo',
    'pacificislandstrustterritory'                                 => 'pc',
    'palau'                                                        => 'pw',
    'panama'                                                       => 'pa',
    'panamacanalzone'                                              => 'pz',
    'peoplesdemocraticrepublicofyemen'                             => 'yd',
    'pitcairnislands'                                              => 'pn',
    'puertorico'                                                   => 'pr',
    'qatar'                                                        => 'qa',
    "r\Ã\©union"                                                 => 're',
    "saintbarth\Ã\©lemy"                                         => 'bl',
    'saintmartin'                                                  => 'mf',
    'serbia'                                                       => 'rs',
    'singapore'                                                    => 'sg',
    'svalbardandjanmayen'                                          => 'sj',
    "s\Ã\£otom\Ã\©andpr\Ã\­ncipe"                            => 'st',
    "u\.s\.miscellaneouspacificislands"                            => 'pu',
    'unionofsovietsocialistrepublics'                              => 'su',
    'unknownorinvalidregion'                                       => 'zz',
    'wakeisland'                                                   => 'wk',
    "\Ã\landislands"                                            => 'ax',
    'آئرلینڈ'                                               => 'ie',
    'آئسلینڈ'                                               => 'is',
    'آذربائجان'                                           => 'az',
    'آرمینیا'                                               => 'am',
    'آسٹریا'                                                 => 'at',
    'آسٹریلیا'                                             => 'au',
    'ارجنٹینا'                                             => 'ar',
    'اردن'                                                     => 'jo',
    'اریٹیریا'                                             => 'er',
    'ازبکستان'                                             => 'uz',
    'استوائیگنی'                                         => 'gq',
    'اسرائیل'                                               => 'il',
    'افغانستان'                                           => 'af',
    'البانیا'                                               => 'al',
    'الجیریا'                                               => 'dz',
    'امریکیساموا'                                       => 'as',
    'انٹارٹکا'                                             => 'aq',
    'انٹیگوااورباربودا'                           => 'ag',
    'انڈونیشیا'                                           => 'id',
    'انگولا'                                                 => 'ao',
    'اٹلی'                                                     => 'it',
    'ایتھوپیا'                                             => 'et',
    'ایران'                                                   => 'ir',
    'ایسٹونیا'                                             => 'ee',
    'ایکواڈور'                                             => 'ec',
    'باھاماس'                                               => 'bs',
    'بحرھندکابرٹشعلاقہ'                           => 'io',
    'برازیل'                                                 => 'br',
    'برطانیہ'                                               => 'gb',
    'برنڈی'                                                   => 'bi',
    'برکینافاسو'                                         => 'bf',
    'بلغاریہ'                                               => 'bg',
    'بنگلادیش'                                             => 'bd',
    'بوسنیاہرزگوینا'                                 => 'ba',
    'بولیویا'                                               => 'bo',
    'بوٹسوانا'                                             => 'bw',
    'بھارت'                                                   => 'in',
    'بھوٹان'                                                 => 'bt',
    'بیلارس'                                                 => 'by',
    'بیلجئیم'                                               => 'be',
    'بینن'                                                     => 'bj',
    'تائیوان'                                               => 'tw',
    'تاجکستان'                                             => 'tj',
    'ترکمانستان'                                         => 'tm',
    'ترکی'                                                     => 'tr',
    'تنزانیہ'                                               => 'tz',
    'تونگا'                                                   => 'to',
    'تھائیلینڈ'                                           => 'th',
    'تیونس'                                                   => 'tn',
    'جارجیا'                                                 => 'ge',
    'جاپان'                                                   => 'jp',
    'جرسی'                                                     => 'je',
    'جرمنی'                                                   => 'de',
    'جزائرسولمون'                                       => 'sb',
    'جزائرفارو'                                           => 'fo',
    'جزائرفاکلینڈ'                                     => 'fk',
    'جزائرمارشل'                                         => 'mh',
    'جزائرورجن،امریکہ'                             => 'vi',
    'جزائرورجن،برٹش'                                 => 'vg',
    'جزائرکوکوز'                                         => 'cc',
    'جزائرکُک'                                             => 'ck',
    'جزائرکیمن'                                           => 'ky',
    'جزائرکیکساورترکیّہ'                         => 'tc',
    'جزیرہبووٹ'                                           => 'bv',
    'جزیرہنارفولک'                                     => 'nf',
    'جزیرہکرسمس'                                         => 'cx',
    'جزیرہہرڈاورجزائرمکڈونلڈ'               => 'hm',
    'جمہوریہوسطیافریقہ'                           => 'cf',
    'جمہوریہچیک'                                         => 'cz',
    'جنوبیافریقہ'                                       => 'za',
    'جنوبیجارجیااورجزائرجنوبیسینڈوچ' => 'gs',
    'جنوبیفرانسیسیعلاقہجات'                   => 'tf',
    'جنوبیکوریا'                                         => 'kr',
    'روانڈا'                                                 => 'rw',
    'روس'                                                       => 'ru',
    'رومانیہ'                                               => 'ro',
    'ریاستہائےمتحدہامریکا'                     => 'us',
    'ریاستہائےمتحدہاوربیرونیجزائر'     => 'um',
    'زمبابوے'                                               => 'zw',
    'زیمبیا'                                                 => 'zm',
    'ساموا'                                                   => 'ws',
    'سانمیرینو'                                           => 'sm',
    'سربیااورمانٹینیگرو'                         => 'cs',
    'سریلنکا'                                               => 'lk',
    'سعودیعرب'                                             => 'sa',
    'سلوانیہ'                                               => 'si',
    'سلوواکیہ'                                             => 'sk',
    'سوئزرلینڈ'                                           => 'ch',
    'سوازیلینڈ'                                           => 'sz',
    'سورینام'                                               => 'sr',
    'سوڈان'                                                   => 'sd',
    'سویڈن'                                                   => 'se',
    'سپین'                                                     => 'es',
    'سیرالیون'                                             => 'sl',
    'سیریا'                                                   => 'sy',
    'سینٹلوسیا'                                           => 'lc',
    'سینٹپائرےاورمیکویلون'                     => 'pm',
    'سینٹکٹساورنیوس'                                 => 'kn',
    'سینٹکیرناورگریناڈائنز'                   => 'vc',
    'سینٹھیلینا'                                         => 'sh',
    'سینیگال'                                               => 'sn',
    'سےشلز'                                                   => 'sc',
    'شمالیماریاناجزائر'                           => 'mp',
    'شمالیکوریا'                                         => 'kp',
    'صوپالیہ'                                               => 'so',
    'عراق'                                                     => 'iq',
    'عمان'                                                     => 'om',
    'غیبون'                                                   => 'ga',
    'فرانس'                                                   => 'fr',
    'فرانسیسیپولینیسیا'                           => 'pf',
    'فرانسیسیگیآنا'                                   => 'gf',
    'فلسطین'                                                 => 'ps',
    'فلپائن'                                                 => 'ph',
    'فنلینڈ'                                                 => 'fi',
    'قبرص'                                                     => 'cy',
    'قزاقستان'                                             => 'kz',
    'لاؤس'                                                     => 'la',
    'لائبیریا'                                             => 'lr',
    'لبنان'                                                   => 'lb',
    'لتھوانیا'                                             => 'lt',
    'لٹوِیا'                                                 => 'lv',
    'لکٹنسٹائن'                                           => 'li',
    'لیبیا'                                                   => 'ly',
    'لیسوتھو'                                               => 'ls',
    'مائکرونیزیا'                                       => 'fm',
    'مالدووا'                                               => 'md',
    'مالی'                                                     => 'ml',
    'ماکاؤ'                                                   => 'mo',
    'متحدہعربامارات'                                 => 'ae',
    'مراکش'                                                   => 'ma',
    'مشرقیتیمور'                                         => 'tl',
    'مصر'                                                       => 'eg',
    'مغربیصحارا'                                         => 'eh',
    'مقدونیہ'                                               => 'mk',
    'ملائیشیا'                                             => 'my',
    'ملاوی'                                                   => 'mw',
    'منگولیا'                                               => 'mn',
    'موریطانیہ'                                           => 'mr',
    'موزنبیق'                                               => 'mz',
    'مڈغاسکر'                                               => 'mg',
    'میانمر'                                                 => 'mm',
    'میکسیکو'                                               => 'mx',
    'نائیجر'                                                 => 'ne',
    'نائیجیریا'                                           => 'ng',
    'ناروے'                                                   => 'no',
    'نمیبیا'                                                 => 'na',
    'نکاراگوا'                                             => 'ni',
    'نیدرلینڈ'                                             => 'nl',
    'نیدرلینڈزانٹیلیز'                             => 'an',
    'نیوزیلینڈ'                                           => 'nz',
    'نیوکیلیڈونیا'                                     => 'nc',
    'نیپال'                                                   => 'np',
    'والساورفتونہ'                                     => 'wf',
    'وانواٹو'                                               => 'vu',
    'ویتنام'                                                 => 'vn',
    'وینزولا'                                               => 've',
    'ویٹیکنسٹی'                                           => 'va',
    'ٹرینیڈاڈاورٹوباگو'                           => 'tt',
    'ٹوالو'                                                   => 'tv',
    'ٹوکیلاؤ'                                               => 'tk',
    'ٹوگو'                                                     => 'tg',
    'پاپوانیوگنی'                                       => 'pg',
    'پاکستان'                                               => 'pk',
    'پرتگال'                                                 => 'pt',
    'پولینڈ'                                                 => 'pl',
    'پیراگوئے'                                             => 'py',
    'پیرو'                                                     => 'pe',
    'چاڈ'                                                       => 'td',
    'چلی'                                                       => 'cl',
    'چین'                                                       => 'cn',
    'ڈنمارک'                                                 => 'dk',
    'ڈومینیکنریپبلک'                                 => 'do',
    'کانگو'                                                   => 'cg',
    'کانگو،جمہوریریاست'                           => 'cd',
    'کرغستان'                                               => 'kg',
    'کروشیا'                                                 => 'hr',
    'کمبوڈیا'                                               => 'kh',
    'کولمبیا'                                               => 'co',
    'کوموروس'                                               => 'km',
    'کِرباتی'                                               => 'ki',
    'کیمرون'                                                 => 'cm',
    'کینیا'                                                   => 'ke',
    'کینیڈا'                                                 => 'ca',
    'کیوبا'                                                   => 'cu',
    'گرنزی'                                                   => 'gg',
    'گرینلینڈ'                                             => 'gl',
    'گنی'                                                       => 'gn',
    'گنیبسائو'                                             => 'gw',
    'گھانا'                                                   => 'gh',
    'گیمبیا'                                                 => 'gm',
    'ہائٹی'                                                   => 'ht',
    'ہنگری'                                                   => 'hu',
    'ہوراگوئے'                                             => 'uy',
    'ہونڈوراس'                                             => 'hn',
    'یمن'                                                       => 'ye',
    'یونان'                                                   => 'gr',
    'یوکرائن'                                               => 'ua',
    'یوگنڈا'                                                 => 'ug',
);

1;

