package Locales::DB::Territory::hr;

# Auto generated from CLDR

$Locales::DB::Territory::hr::VERSION = '0.02';

$Locales::DB::Territory::hr::cldr_version = '1.7.1';

%Locales::DB::Territory::hr::code_to_name = (
    'ad' => 'Andora',
    'ae' => "Ujedinjeni\ Arapski\ Emirati",
    'af' => 'Afganistan',
    'ag' => "Antigua\ i\ Barbuda",
    'ai' => 'Anguila',
    'al' => 'Albanija',
    'am' => 'Armenija',
    'an' => "Nizozemski\ Antili",
    'ao' => 'Angola',
    'aq' => 'Antarktik',
    'ar' => 'Argentina',
    'as' => "Američka\ Samoa",
    'at' => 'Austrija',
    'au' => 'Australija',
    'aw' => 'Aruba',
    'ax' => "Alandski\ otoci",
    'az' => 'Azerbajdžan',
    'ba' => "Bosna\ i\ Hercegovina",
    'bb' => 'Barbados',
    'bd' => 'Bangladeš',
    'be' => 'Belgija',
    'bf' => "Burkina\ Faso",
    'bg' => 'Bugarska',
    'bh' => 'Bahrein',
    'bi' => 'Burundi',
    'bj' => 'Benin',
    'bl' => "Sveti\ Bartolomej",
    'bm' => 'Bermuda',
    'bn' => 'Brunej',
    'bo' => 'Bolivija',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brazil',
    'bs' => 'Bahami',
    'bt' => 'Butan',
    'bv' => "Otok\ Bouvet",
    'bw' => 'Bocvana',
    'by' => 'Bjelorusija',
    'bz' => 'Belize',
    'ca' => 'Kanada',
    'cc' => "Kokosovi\ Otoci",
    'cd' => "Demokratska\ Republika\ Kongo",
    'cf' => "Srednjoafrička\ Republika",
    'cg' => 'Kongo',
    'ch' => 'Švicarska',
    'ci' => "Obala\ Bjelokosti",
    'ck' => "Kukovi\ Otoci",
    'cl' => 'Čile',
    'cm' => 'Kamerun',
    'cn' => 'Kina',
    'co' => 'Kolumbija',
    'cr' => 'Kostarika',
    'cs' => "Srbija\ i\ Crna\ Gora",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Kuba',
    'cv' => "Zeleni\ Rt",
    'cx' => "Božićni\ Otok",
    'cy' => 'Cipar',
    'cz' => "Češka\ Republika",
    'dd' => "East\ Germany",
    'de' => 'Njemačka',
    'dj' => 'Džibuti',
    'dk' => 'Danska',
    'dm' => 'Dominika',
    'do' => "Dominikanska\ Republika",
    'dz' => 'Alžir',
    'ec' => 'Ekvador',
    'ee' => 'Estonija',
    'eg' => 'Egipat',
    'eh' => "Zapadna\ Sahara",
    'er' => 'Eritreja',
    'es' => 'Španjolska',
    'et' => 'Etiopija',
    'fi' => 'Finska',
    'fj' => 'Fidži',
    'fk' => "Falklandski\ Otoci",
    'fm' => 'Mikronezija',
    'fo' => "Farski\ Otoci",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Francuska',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabon',
    'gb' => "Velika\ Britanija",
    'gd' => 'Grenada',
    'ge' => 'Gruzija',
    'gf' => "Francuska\ Gvajana",
    'gg' => 'Guernsey',
    'gh' => 'Gana',
    'gi' => 'Gibraltar',
    'gl' => 'Grenland',
    'gm' => 'Gambija',
    'gn' => 'Gvineja',
    'gp' => 'Guadeloupe',
    'gq' => "Ekvatorska\ Gvineja",
    'gr' => 'Grčka',
    'gs' => "Južna\ Gruzija\ i\ Južni\ Sendvič\ Otoci",
    'gt' => 'Gvatemala',
    'gu' => 'Guam',
    'gw' => "Gvineja\ Bisau",
    'gy' => 'Gvajana',
    'hk' => "Hong\ Kong",
    'hm' => "Otok\ Heard\ i\ Otoci\ McDonald",
    'hn' => 'Honduras',
    'hr' => 'Hrvatska',
    'ht' => 'Haiti',
    'hu' => 'Mađarska',
    'id' => 'Indonezija',
    'ie' => 'Irska',
    'il' => 'Izrael',
    'im' => "Otok\ Man",
    'in' => 'Indija',
    'io' => "Britanski\ Teritorij\ Indijskog\ Oceana",
    'iq' => 'Irak',
    'ir' => 'Iran',
    'is' => 'Island',
    'it' => 'Italija',
    'je' => 'Jersey',
    'jm' => 'Jamajka',
    'jo' => 'Jordan',
    'jp' => 'Japan',
    'jt' => "Johnston\ Island",
    'ke' => 'Kenija',
    'kg' => 'Kirgistan',
    'kh' => 'Kambodža',
    'ki' => 'Kiribati',
    'km' => 'Komori',
    'kn' => "Sveti\ Kristofor\ i\ Nevis",
    'kp' => "Koreja\,\ Sjeverna",
    'kr' => "Južna\ Koreja",
    'kw' => 'Kuvajt',
    'ky' => "Kajmanski\ Otoci",
    'kz' => 'Kazakstan',
    'la' => 'Laos',
    'lb' => 'Libanon',
    'lc' => "Sveta\ Lucija",
    'li' => 'Lihtenštajn',
    'lk' => "Šri\ Lanka",
    'lr' => 'Liberija',
    'ls' => 'Lesoto',
    'lt' => 'Litva',
    'lu' => 'Luksemburg',
    'lv' => 'Latvija',
    'ly' => "Libijska\ Arapska\ Džamahirija",
    'ma' => 'Maroko',
    'mc' => 'Monako',
    'md' => 'Moldavija',
    'me' => "Crna\ Gora",
    'mf' => "Sveti\ Martin",
    'mg' => 'Madagaskar',
    'mh' => "Maršalovi\ Otoci",
    'mi' => "Midway\ Islands",
    'mk' => "Bivša\ Jugoslavenska\ Republika\ Makedonija",
    'ml' => 'Mali',
    'mm' => 'Mijanma',
    'mn' => 'Mongolija',
    'mo' => 'Makao',
    'mp' => "Sjeverni\ Marijanski\ Otoci",
    'mq' => 'Martinik',
    'mr' => 'Mauritanija',
    'ms' => 'Montserat',
    'mt' => 'Malta',
    'mu' => 'Mauricijus',
    'mv' => 'Maldivi',
    'mw' => 'Malavi',
    'mx' => 'Meksiko',
    'my' => 'Malezija',
    'mz' => 'Mozambik',
    'na' => 'Namibija',
    'nc' => "Nova\ Kaledonija",
    'ne' => 'Niger',
    'nf' => "Otok\ Norfolk",
    'ng' => 'Nigerija',
    'ni' => 'Nikaragva',
    'nl' => 'Nizozemska',
    'no' => 'Norveška',
    'np' => 'Nepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "Novi\ Zeland",
    'om' => 'Oman',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Peru',
    'pf' => "Francuska\ Polinezija",
    'pg' => "Papua\ Nova\ Gvineja",
    'ph' => 'Filipini',
    'pk' => 'Pakistan',
    'pl' => 'Poljska',
    'pm' => "Sveti\ Petar\ i\ Miguel",
    'pn' => 'Pitcairn',
    'pr' => 'Portoriko',
    'ps' => "Palestinsko\ Područje",
    'pt' => 'Portugal',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paragvaj',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Katar',
    'qo' => "Ostala\ oceanija",
    'qu' => "Europska\ Unija",
    're' => 'Reunion',
    'ro' => 'Rumunjska',
    'rs' => 'Srbija',
    'ru' => 'Rusija',
    'rw' => 'Ruanda',
    'sa' => "Saudijska\ Arabija",
    'sb' => "Solomonski\ Otoci",
    'sc' => 'Sejšeli',
    'sd' => 'Sudan',
    'se' => 'Švedska',
    'sg' => 'Singapur',
    'sh' => "Sveta\ Helena",
    'si' => 'Slovenija',
    'sj' => "Svalbard\ i\ Jan\ Mayen",
    'sk' => 'Slovačka',
    'sl' => "Sijera\ Leone",
    'sm' => "San\ Marino",
    'sn' => 'Senegal',
    'so' => 'Somalija',
    'sr' => 'Surinam',
    'st' => "Sveti\ Toma\ i\ Prinsipe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salvador",
    'sy' => 'Sirija',
    'sz' => 'Svazi',
    'tc' => "Turkski\ i\ Kaikos\ Otoci",
    'td' => 'Čad',
    'tf' => "Francuski\ Južni\ Teritoriji",
    'tg' => 'Togo',
    'th' => 'Tajland',
    'tj' => 'Tadžikistan',
    'tk' => 'Tokelau',
    'tl' => "Istočni\ Timor",
    'tm' => 'Turkmenistan',
    'tn' => 'Tunis',
    'to' => 'Tonga',
    'tr' => 'Turska',
    'tt' => "Trinidad\ i\ Tobago",
    'tv' => 'Tuvalu',
    'tw' => 'Tajvan',
    'tz' => 'Tanzanija',
    'ua' => 'Ukrajina',
    'ug' => 'Uganda',
    'um' => "Ujedinjene\ Države\ Manjih\ Pacifičkih\ Otoka",
    'us' => "Sjedinjene\ Države",
    'uy' => 'Urugvaj',
    'uz' => 'Uzbekistan',
    'va' => "Grad\ Vatikan",
    'vc' => "Sveti\ Vincent\ i\ Grenadini",
    'vd' => "North\ Vietnam",
    've' => 'Venezuela',
    'vg' => "Britanski\ Djevičanski\ Otoci",
    'vi' => "Američki\ Djevičanski\ Otoci",
    'vn' => 'Vijetnam',
    'vu' => 'Vanuatu',
    'wf' => "Wallis\ i\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Jemen',
    'yt' => 'Majote',
    'za' => "Južnoafrička\ Republika",
    'zm' => 'Zambija',
    'zw' => 'Zimbabve',
    'zz' => "nepoznata\ ili\ nevažeća\ oblast",
);

%Locales::DB::Territory::hr::name_to_code = (
    'afganistan'                              => 'af',
    'alandskiotoci'                           => 'ax',
    'albanija'                                => 'al',
    'alžir'                                  => 'dz',
    'američkasamoa'                          => 'as',
    'američkidjevičanskiotoci'              => 'vi',
    'andora'                                  => 'ad',
    'angola'                                  => 'ao',
    'anguila'                                 => 'ai',
    'antarktik'                               => 'aq',
    'antiguaibarbuda'                         => 'ag',
    'argentina'                               => 'ar',
    'armenija'                                => 'am',
    'aruba'                                   => 'aw',
    'australija'                              => 'au',
    'austrija'                                => 'at',
    'azerbajdžan'                            => 'az',
    'bahami'                                  => 'bs',
    'bahrein'                                 => 'bh',
    'bangladeš'                              => 'bd',
    'barbados'                                => 'bb',
    'belgija'                                 => 'be',
    'belize'                                  => 'bz',
    'benin'                                   => 'bj',
    'bermuda'                                 => 'bm',
    'bivšajugoslavenskarepublikamakedonija'  => 'mk',
    'bjelorusija'                             => 'by',
    'bocvana'                                 => 'bw',
    'bolivija'                                => 'bo',
    'bosnaihercegovina'                       => 'ba',
    'božićniotok'                           => 'cx',
    'brazil'                                  => 'br',
    'britanskidjevičanskiotoci'              => 'vg',
    'britanskiteritorijindijskogoceana'       => 'io',
    'britishantarcticterritory'               => 'bq',
    'brunej'                                  => 'bn',
    'bugarska'                                => 'bg',
    'burkinafaso'                             => 'bf',
    'burundi'                                 => 'bi',
    'butan'                                   => 'bt',
    'cantonandenderburyislands'               => 'ct',
    'cipar'                                   => 'cy',
    'crnagora'                                => 'me',
    'danska'                                  => 'dk',
    'demokratskarepublikakongo'               => 'cd',
    'dominika'                                => 'dm',
    'dominikanskarepublika'                   => 'do',
    'dronningmaudland'                        => 'nq',
    'džibuti'                                => 'dj',
    'eastgermany'                             => 'dd',
    'egipat'                                  => 'eg',
    'ekvador'                                 => 'ec',
    'ekvatorskagvineja'                       => 'gq',
    'elsalvador'                              => 'sv',
    'eritreja'                                => 'er',
    'estonija'                                => 'ee',
    'etiopija'                                => 'et',
    'europskaunija'                           => 'qu',
    'falklandskiotoci'                        => 'fk',
    'farskiotoci'                             => 'fo',
    'fidži'                                  => 'fj',
    'filipini'                                => 'ph',
    'finska'                                  => 'fi',
    'francuska'                               => 'fr',
    'francuskagvajana'                        => 'gf',
    'francuskapolinezija'                     => 'pf',
    'francuskijužniteritoriji'               => 'tf',
    'frenchsouthernandantarcticterritories'   => 'fq',
    'gabon'                                   => 'ga',
    'gambija'                                 => 'gm',
    'gana'                                    => 'gh',
    'gibraltar'                               => 'gi',
    'gradvatikan'                             => 'va',
    'grenada'                                 => 'gd',
    'grenland'                                => 'gl',
    'gruzija'                                 => 'ge',
    'grčka'                                  => 'gr',
    'guadeloupe'                              => 'gp',
    'guam'                                    => 'gu',
    'guernsey'                                => 'gg',
    'gvajana'                                 => 'gy',
    'gvatemala'                               => 'gt',
    'gvineja'                                 => 'gn',
    'gvinejabisau'                            => 'gw',
    'haiti'                                   => 'ht',
    'honduras'                                => 'hn',
    'hongkong'                                => 'hk',
    'hrvatska'                                => 'hr',
    'indija'                                  => 'in',
    'indonezija'                              => 'id',
    'irak'                                    => 'iq',
    'iran'                                    => 'ir',
    'irska'                                   => 'ie',
    'island'                                  => 'is',
    'istočnitimor'                           => 'tl',
    'italija'                                 => 'it',
    'izrael'                                  => 'il',
    'jamajka'                                 => 'jm',
    'japan'                                   => 'jp',
    'jemen'                                   => 'ye',
    'jersey'                                  => 'je',
    'johnstonisland'                          => 'jt',
    'jordan'                                  => 'jo',
    'južnagruzijaijužnisendvičotoci'       => 'gs',
    'južnakoreja'                            => 'kr',
    'južnoafričkarepublika'                 => 'za',
    'kajmanskiotoci'                          => 'ky',
    'kambodža'                               => 'kh',
    'kamerun'                                 => 'cm',
    'kanada'                                  => 'ca',
    'katar'                                   => 'qa',
    'kazakstan'                               => 'kz',
    'kenija'                                  => 'ke',
    'kina'                                    => 'cn',
    'kirgistan'                               => 'kg',
    'kiribati'                                => 'ki',
    'kokosoviotoci'                           => 'cc',
    'kolumbija'                               => 'co',
    'komori'                                  => 'km',
    'kongo'                                   => 'cg',
    "koreja\,sjeverna"                        => 'kp',
    'kostarika'                               => 'cr',
    'kuba'                                    => 'cu',
    'kukoviotoci'                             => 'ck',
    'kuvajt'                                  => 'kw',
    'laos'                                    => 'la',
    'latvija'                                 => 'lv',
    'lesoto'                                  => 'ls',
    'libanon'                                 => 'lb',
    'liberija'                                => 'lr',
    'libijskaarapskadžamahirija'             => 'ly',
    'lihtenštajn'                            => 'li',
    'litva'                                   => 'lt',
    'luksemburg'                              => 'lu',
    'madagaskar'                              => 'mg',
    'majote'                                  => 'yt',
    'makao'                                   => 'mo',
    'malavi'                                  => 'mw',
    'maldivi'                                 => 'mv',
    'malezija'                                => 'my',
    'mali'                                    => 'ml',
    'malta'                                   => 'mt',
    'maroko'                                  => 'ma',
    'martinik'                                => 'mq',
    'maršaloviotoci'                         => 'mh',
    'mauricijus'                              => 'mu',
    'mauritanija'                             => 'mr',
    'mađarska'                               => 'hu',
    'meksiko'                                 => 'mx',
    'metropolitanfrance'                      => 'fx',
    'midwayislands'                           => 'mi',
    'mijanma'                                 => 'mm',
    'mikronezija'                             => 'fm',
    'moldavija'                               => 'md',
    'monako'                                  => 'mc',
    'mongolija'                               => 'mn',
    'montserat'                               => 'ms',
    'mozambik'                                => 'mz',
    'namibija'                                => 'na',
    'nauru'                                   => 'nr',
    'nepal'                                   => 'np',
    'nepoznatailinevažećaoblast'            => 'zz',
    'neutralzone'                             => 'nt',
    'niger'                                   => 'ne',
    'nigerija'                                => 'ng',
    'nikaragva'                               => 'ni',
    'niue'                                    => 'nu',
    'nizozemska'                              => 'nl',
    'nizozemskiantili'                        => 'an',
    'njemačka'                               => 'de',
    'northvietnam'                            => 'vd',
    'norveška'                               => 'no',
    'novakaledonija'                          => 'nc',
    'novizeland'                              => 'nz',
    'obalabjelokosti'                         => 'ci',
    'oman'                                    => 'om',
    'ostalaoceanija'                          => 'qo',
    'otokbouvet'                              => 'bv',
    'otokheardiotocimcdonald'                 => 'hm',
    'otokman'                                 => 'im',
    'otoknorfolk'                             => 'nf',
    'pacificislandstrustterritory'            => 'pc',
    'pakistan'                                => 'pk',
    'palau'                                   => 'pw',
    'palestinskopodručje'                    => 'ps',
    'panama'                                  => 'pa',
    'panamacanalzone'                         => 'pz',
    'papuanovagvineja'                        => 'pg',
    'paragvaj'                                => 'py',
    'peoplesdemocraticrepublicofyemen'        => 'yd',
    'peru'                                    => 'pe',
    'pitcairn'                                => 'pn',
    'poljska'                                 => 'pl',
    'portoriko'                               => 'pr',
    'portugal'                                => 'pt',
    'reunion'                                 => 're',
    'ruanda'                                  => 'rw',
    'rumunjska'                               => 'ro',
    'rusija'                                  => 'ru',
    'samoa'                                   => 'ws',
    'sanmarino'                               => 'sm',
    'saudijskaarabija'                        => 'sa',
    'sejšeli'                                => 'sc',
    'senegal'                                 => 'sn',
    'sijeraleone'                             => 'sl',
    'singapur'                                => 'sg',
    'sirija'                                  => 'sy',
    'sjedinjenedržave'                       => 'us',
    'sjevernimarijanskiotoci'                 => 'mp',
    'slovačka'                               => 'sk',
    'slovenija'                               => 'si',
    'solomonskiotoci'                         => 'sb',
    'somalija'                                => 'so',
    'srbija'                                  => 'rs',
    'srbijaicrnagora'                         => 'cs',
    'srednjoafričkarepublika'                => 'cf',
    'sudan'                                   => 'sd',
    'surinam'                                 => 'sr',
    'svalbardijanmayen'                       => 'sj',
    'svazi'                                   => 'sz',
    'svetahelena'                             => 'sh',
    'svetalucija'                             => 'lc',
    'svetibartolomej'                         => 'bl',
    'svetikristoforinevis'                    => 'kn',
    'svetimartin'                             => 'mf',
    'svetipetarimiguel'                       => 'pm',
    'svetitomaiprinsipe'                      => 'st',
    'svetivincentigrenadini'                  => 'vc',
    'tadžikistan'                            => 'tj',
    'tajland'                                 => 'th',
    'tajvan'                                  => 'tw',
    'tanzanija'                               => 'tz',
    'togo'                                    => 'tg',
    'tokelau'                                 => 'tk',
    'tonga'                                   => 'to',
    'trinidaditobago'                         => 'tt',
    'tunis'                                   => 'tn',
    'turkmenistan'                            => 'tm',
    'turkskiikaikosotoci'                     => 'tc',
    'turska'                                  => 'tr',
    'tuvalu'                                  => 'tv',
    "u\.s\.miscellaneouspacificislands"       => 'pu',
    'uganda'                                  => 'ug',
    'ujedinjenedržavemanjihpacifičkihotoka' => 'um',
    'ujedinjeniarapskiemirati'                => 'ae',
    'ukrajina'                                => 'ua',
    'unionofsovietsocialistrepublics'         => 'su',
    'urugvaj'                                 => 'uy',
    'uzbekistan'                              => 'uz',
    'vanuatu'                                 => 'vu',
    'velikabritanija'                         => 'gb',
    'venezuela'                               => 've',
    'vijetnam'                                => 'vn',
    'wakeisland'                              => 'wk',
    'wallisifutuna'                           => 'wf',
    'zambija'                                 => 'zm',
    'zapadnasahara'                           => 'eh',
    'zelenirt'                                => 'cv',
    'zimbabve'                                => 'zw',
    'Čad'                                    => 'td',
    'Češkarepublika'                        => 'cz',
    'Čile'                                   => 'cl',
    'Španjolska'                             => 'es',
    'Šrilanka'                               => 'lk',
    'Švedska'                                => 'se',
    'Švicarska'                              => 'ch',
);

1;

