package Locales::DB::Territory::si;

# Auto generated from CLDR

$Locales::DB::Territory::si::VERSION = '0.02';

$Locales::DB::Territory::si::cldr_version = '1.7.1';

%Locales::DB::Territory::si::code_to_name = (
    'ad'      => 'Andorra',
    'ae'      => "United\ Arab\ Emirates",
    'af'      => 'Afghanistan',
    'ag'      => "Antigua\ and\ Barbuda",
    'ai'      => 'Anguilla',
    'al'      => 'Albania',
    'am'      => 'Armenia',
    'an'      => "Netherlands\ Antilles",
    'ao'      => 'Angola',
    'aq'      => 'Antarctica',
    'ar'      => 'Argentina',
    'as'      => "American\ Samoa",
    'at'      => 'Austria',
    'au'      => 'Australia',
    'aw'      => 'Aruba',
    'ax'      => "\Ã\land\ Islands",
    'az'      => 'Azerbaijan',
    'ba'      => "Bosnia\ and\ Herzegovina",
    'bb'      => 'Barbados',
    'bd'      => 'Bangladesh',
    'be'      => 'Belgium',
    'bf'      => "Burkina\ Faso",
    'bg'      => 'Bulgaria',
    'bh'      => 'Bahrain',
    'bi'      => 'Burundi',
    'bj'      => 'Benin',
    'bl'      => "Saint\ Barth\Ã\©lemy",
    'bm'      => 'Bermuda',
    'bn'      => 'Brunei',
    'bo'      => 'Bolivia',
    'bq'      => "British\ Antarctic\ Territory",
    'br'      => 'Brazil',
    'bs'      => 'Bahamas',
    'bt'      => 'Bhutan',
    'bv'      => "Bouvet\ Island",
    'bw'      => 'Botswana',
    'by'      => 'Belarus',
    'bz'      => 'Belize',
    'ca'      => 'Canada',
    'cc'      => "Cocos\ \[Keeling\]\ Islands",
    'cd'      => "Congo\ \[DRC\]",
    'cf'      => "Central\ African\ Republic",
    'cg'      => "Congo\ \[Republic\]",
    'ch'      => 'Switzerland',
    'ci'      => "Ivory\ Coast",
    'ck'      => "Cook\ Islands",
    'cl'      => 'Chile',
    'cm'      => 'Cameroon',
    'cn'      => 'China',
    'co'      => 'Colombia',
    'content' => undef,
    'cr'      => "Costa\ Rica",
    'cs'      => "Serbia\ and\ Montenegro",
    'ct'      => "Canton\ and\ Enderbury\ Islands",
    'cu'      => 'Cuba',
    'cv'      => "Cape\ Verde",
    'cx'      => "Christmas\ Island",
    'cy'      => 'Cyprus',
    'cz'      => "Czech\ Republic",
    'dd'      => "East\ Germany",
    'de'      => 'Germany',
    'dj'      => 'Djibouti',
    'dk'      => 'Denmark',
    'dm'      => 'Dominica',
    'do'      => "Dominican\ Republic",
    'dz'      => 'Algeria',
    'ec'      => 'Ecuador',
    'ee'      => 'Estonia',
    'eg'      => 'Egypt',
    'eh'      => "Western\ Sahara",
    'er'      => 'Eritrea',
    'es'      => 'Spain',
    'et'      => 'Ethiopia',
    'fi'      => 'Finland',
    'fj'      => 'Fiji',
    'fk'      => "Falkland\ Islands\ \[Islas\ Malvinas\]",
    'fm'      => 'Micronesia',
    'fo'      => "Faroe\ Islands",
    'fq'      => "French\ Southern\ and\ Antarctic\ Territories",
    'fr'      => 'France',
    'fx'      => "Metropolitan\ France",
    'ga'      => 'Gabon',
    'gb'      => "United\ Kingdom",
    'gd'      => 'Grenada',
    'ge'      => 'Georgia',
    'gf'      => "French\ Guiana",
    'gg'      => 'Guernsey',
    'gh'      => 'Ghana',
    'gi'      => 'Gibraltar',
    'gl'      => 'Greenland',
    'gm'      => 'Gambia',
    'gn'      => 'Guinea',
    'gp'      => 'Guadeloupe',
    'gq'      => "Equatorial\ Guinea",
    'gr'      => 'Greece',
    'gs'      => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt'      => 'Guatemala',
    'gu'      => 'Guam',
    'gw'      => "Guinea\-Bissau",
    'gy'      => 'Guyana',
    'hk'      => "Hong\ Kong",
    'hm'      => "Heard\ Island\ and\ McDonald\ Islands",
    'hn'      => 'Honduras',
    'hr'      => 'Croatia',
    'ht'      => 'Haiti',
    'hu'      => 'Hungary',
    'id'      => 'Indonesia',
    'ie'      => 'Ireland',
    'il'      => 'Israel',
    'im'      => "Isle\ of\ Man",
    'in'      => 'India',
    'io'      => "British\ Indian\ Ocean\ Territory",
    'iq'      => 'Iraq',
    'ir'      => 'Iran',
    'is'      => 'Iceland',
    'it'      => 'Italy',
    'je'      => 'Jersey',
    'jm'      => 'Jamaica',
    'jo'      => 'Jordan',
    'jp'      => 'Japan',
    'jt'      => "Johnston\ Island",
    'ke'      => 'Kenya',
    'kg'      => 'Kyrgyzstan',
    'kh'      => 'Cambodia',
    'ki'      => 'Kiribati',
    'km'      => 'Comoros',
    'kn'      => "Saint\ Kitts\ and\ Nevis",
    'kp'      => "North\ Korea",
    'kr'      => "South\ Korea",
    'kw'      => 'Kuwait',
    'ky'      => "Cayman\ Islands",
    'kz'      => 'Kazakhstan',
    'la'      => 'Laos',
    'lb'      => 'Lebanon',
    'lc'      => "Saint\ Lucia",
    'li'      => 'Liechtenstein',
    'lk'      => "Sri\ Lanka",
    'lr'      => 'Liberia',
    'ls'      => 'Lesotho',
    'lt'      => 'Lithuania',
    'lu'      => 'Luxembourg',
    'lv'      => 'Latvia',
    'ly'      => 'Libya',
    'ma'      => 'Morocco',
    'mc'      => 'Monaco',
    'md'      => 'Moldova',
    'me'      => 'Montenegro',
    'mf'      => "Saint\ Martin",
    'mg'      => 'Madagascar',
    'mh'      => "Marshall\ Islands",
    'mi'      => "Midway\ Islands",
    'mk'      => "Macedonia\ \[FYROM\]",
    'ml'      => 'Mali',
    'mm'      => "Myanmar\ \[Burma\]",
    'mn'      => 'Mongolia',
    'mo'      => 'Macau',
    'mp'      => "Northern\ Mariana\ Islands",
    'mq'      => 'Martinique',
    'mr'      => 'Mauritania',
    'ms'      => 'Montserrat',
    'mt'      => 'Malta',
    'mu'      => 'Mauritius',
    'mv'      => 'Maldives',
    'mw'      => 'Malawi',
    'mx'      => 'Mexico',
    'my'      => 'Malaysia',
    'mz'      => 'Mozambique',
    'na'      => 'Namibia',
    'nc'      => "New\ Caledonia",
    'ne'      => 'Niger',
    'nf'      => "Norfolk\ Island",
    'ng'      => 'Nigeria',
    'ni'      => 'Nicaragua',
    'nl'      => 'Netherlands',
    'no'      => 'Norway',
    'np'      => 'Nepal',
    'nq'      => "Dronning\ Maud\ Land",
    'nr'      => 'Nauru',
    'nt'      => "Neutral\ Zone",
    'nu'      => 'Niue',
    'nz'      => "New\ Zealand",
    'om'      => 'Oman',
    'pa'      => 'Panama',
    'pc'      => "Pacific\ Islands\ Trust\ Territory",
    'pe'      => 'Peru',
    'pf'      => "French\ Polynesia",
    'pg'      => "Papua\ New\ Guinea",
    'ph'      => 'Philippines',
    'pk'      => 'Pakistan',
    'pl'      => 'Poland',
    'pm'      => "Saint\ Pierre\ and\ Miquelon",
    'pn'      => "Pitcairn\ Islands",
    'pr'      => "Puerto\ Rico",
    'ps'      => "Palestinian\ Territories",
    'pt'      => 'Portugal',
    'pu'      => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw'      => 'Palau',
    'py'      => 'Paraguay',
    'pz'      => "Panama\ Canal\ Zone",
    'qa'      => 'Qatar',
    'qo'      => "Outlying\ Oceania",
    'qu'      => "European\ Union",
    're'      => "R\Ã\©union",
    'ro'      => 'Romania',
    'rs'      => 'Serbia',
    'ru'      => 'Russia',
    'rw'      => 'Rwanda',
    'sa'      => "Saudi\ Arabia",
    'sb'      => "Solomon\ Islands",
    'sc'      => 'Seychelles',
    'sd'      => 'Sudan',
    'se'      => 'Sweden',
    'sg'      => 'Singapore',
    'sh'      => "Saint\ Helena",
    'si'      => 'Slovenia',
    'sj'      => "Svalbard\ and\ Jan\ Mayen",
    'sk'      => 'Slovakia',
    'sl'      => "Sierra\ Leone",
    'sm'      => "San\ Marino",
    'sn'      => 'Senegal',
    'so'      => 'Somalia',
    'sr'      => 'Suriname',
    'st'      => "S\Ã\£o\ Tom\Ã\©\ and\ Pr\Ã\­ncipe",
    'su'      => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv'      => "El\ Salvador",
    'sy'      => 'Syria',
    'sz'      => 'Swaziland',
    'tc'      => "Turks\ and\ Caicos\ Islands",
    'td'      => 'Chad',
    'tf'      => "French\ Southern\ Territories",
    'tg'      => 'Togo',
    'th'      => 'Thailand',
    'tj'      => 'Tajikistan',
    'tk'      => 'Tokelau',
    'tl'      => "East\ Timor",
    'tm'      => 'Turkmenistan',
    'tn'      => 'Tunisia',
    'to'      => 'Tonga',
    'tr'      => 'Turkey',
    'tt'      => "Trinidad\ and\ Tobago",
    'tv'      => 'Tuvalu',
    'tw'      => 'Taiwan',
    'type'    => undef,
    'tz'      => 'Tanzania',
    'ua'      => 'Ukraine',
    'ug'      => 'Uganda',
    'um'      => "U\.S\.\ Minor\ Outlying\ Islands",
    'us'      => "United\ States",
    'uy'      => 'Uruguay',
    'uz'      => 'Uzbekistan',
    'va'      => "Vatican\ City",
    'vc'      => "Saint\ Vincent\ and\ the\ Grenadines",
    'vd'      => "North\ Vietnam",
    've'      => 'Venezuela',
    'vg'      => "British\ Virgin\ Islands",
    'vi'      => "U\.S\.\ Virgin\ Islands",
    'vn'      => 'Vietnam',
    'vu'      => 'Vanuatu',
    'wf'      => "Wallis\ and\ Futuna",
    'wk'      => "Wake\ Island",
    'ws'      => 'Samoa',
    'yd'      => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye'      => 'Yemen',
    'yt'      => 'Mayotte',
    'za'      => "South\ Africa",
    'zm'      => 'Zambia',
    'zw'      => 'Zimbabwe',
    'zz'      => "Unknown\ or\ Invalid\ Region",
);

%Locales::DB::Territory::si::name_to_code = (
    ''                                       => 'type',
    'afghanistan'                            => 'af',
    'albania'                                => 'al',
    'algeria'                                => 'dz',
    'americansamoa'                          => 'as',
    'andorra'                                => 'ad',
    'angola'                                 => 'ao',
    'anguilla'                               => 'ai',
    'antarctica'                             => 'aq',
    'antiguaandbarbuda'                      => 'ag',
    'argentina'                              => 'ar',
    'armenia'                                => 'am',
    'aruba'                                  => 'aw',
    'australia'                              => 'au',
    'austria'                                => 'at',
    'azerbaijan'                             => 'az',
    'bahamas'                                => 'bs',
    'bahrain'                                => 'bh',
    'bangladesh'                             => 'bd',
    'barbados'                               => 'bb',
    'belarus'                                => 'by',
    'belgium'                                => 'be',
    'belize'                                 => 'bz',
    'benin'                                  => 'bj',
    'bermuda'                                => 'bm',
    'bhutan'                                 => 'bt',
    'bolivia'                                => 'bo',
    'bosniaandherzegovina'                   => 'ba',
    'botswana'                               => 'bw',
    'bouvetisland'                           => 'bv',
    'brazil'                                 => 'br',
    'britishantarcticterritory'              => 'bq',
    'britishindianoceanterritory'            => 'io',
    'britishvirginislands'                   => 'vg',
    'brunei'                                 => 'bn',
    'bulgaria'                               => 'bg',
    'burkinafaso'                            => 'bf',
    'burundi'                                => 'bi',
    'cambodia'                               => 'kh',
    'cameroon'                               => 'cm',
    'canada'                                 => 'ca',
    'cantonandenderburyislands'              => 'ct',
    'capeverde'                              => 'cv',
    'caymanislands'                          => 'ky',
    'centralafricanrepublic'                 => 'cf',
    'chad'                                   => 'td',
    'chile'                                  => 'cl',
    'china'                                  => 'cn',
    'christmasisland'                        => 'cx',
    'cocoskeelingislands'                    => 'cc',
    'colombia'                               => 'co',
    'comoros'                                => 'km',
    'congodrc'                               => 'cd',
    'congorepublic'                          => 'cg',
    'cookislands'                            => 'ck',
    'costarica'                              => 'cr',
    'croatia'                                => 'hr',
    'cuba'                                   => 'cu',
    'cyprus'                                 => 'cy',
    'czechrepublic'                          => 'cz',
    'denmark'                                => 'dk',
    'djibouti'                               => 'dj',
    'dominica'                               => 'dm',
    'dominicanrepublic'                      => 'do',
    'dronningmaudland'                       => 'nq',
    'eastgermany'                            => 'dd',
    'easttimor'                              => 'tl',
    'ecuador'                                => 'ec',
    'egypt'                                  => 'eg',
    'elsalvador'                             => 'sv',
    'equatorialguinea'                       => 'gq',
    'eritrea'                                => 'er',
    'estonia'                                => 'ee',
    'ethiopia'                               => 'et',
    'europeanunion'                          => 'qu',
    'falklandislandsislasmalvinas'           => 'fk',
    'faroeislands'                           => 'fo',
    'fiji'                                   => 'fj',
    'finland'                                => 'fi',
    'france'                                 => 'fr',
    'frenchguiana'                           => 'gf',
    'frenchpolynesia'                        => 'pf',
    'frenchsouthernandantarcticterritories'  => 'fq',
    'frenchsouthernterritories'              => 'tf',
    'gabon'                                  => 'ga',
    'gambia'                                 => 'gm',
    'georgia'                                => 'ge',
    'germany'                                => 'de',
    'ghana'                                  => 'gh',
    'gibraltar'                              => 'gi',
    'greece'                                 => 'gr',
    'greenland'                              => 'gl',
    'grenada'                                => 'gd',
    'guadeloupe'                             => 'gp',
    'guam'                                   => 'gu',
    'guatemala'                              => 'gt',
    'guernsey'                               => 'gg',
    'guinea'                                 => 'gn',
    'guineabissau'                           => 'gw',
    'guyana'                                 => 'gy',
    'haiti'                                  => 'ht',
    'heardislandandmcdonaldislands'          => 'hm',
    'honduras'                               => 'hn',
    'hongkong'                               => 'hk',
    'hungary'                                => 'hu',
    'iceland'                                => 'is',
    'india'                                  => 'in',
    'indonesia'                              => 'id',
    'iran'                                   => 'ir',
    'iraq'                                   => 'iq',
    'ireland'                                => 'ie',
    'isleofman'                              => 'im',
    'israel'                                 => 'il',
    'italy'                                  => 'it',
    'ivorycoast'                             => 'ci',
    'jamaica'                                => 'jm',
    'japan'                                  => 'jp',
    'jersey'                                 => 'je',
    'johnstonisland'                         => 'jt',
    'jordan'                                 => 'jo',
    'kazakhstan'                             => 'kz',
    'kenya'                                  => 'ke',
    'kiribati'                               => 'ki',
    'kuwait'                                 => 'kw',
    'kyrgyzstan'                             => 'kg',
    'laos'                                   => 'la',
    'latvia'                                 => 'lv',
    'lebanon'                                => 'lb',
    'lesotho'                                => 'ls',
    'liberia'                                => 'lr',
    'libya'                                  => 'ly',
    'liechtenstein'                          => 'li',
    'lithuania'                              => 'lt',
    'luxembourg'                             => 'lu',
    'macau'                                  => 'mo',
    'macedoniafyrom'                         => 'mk',
    'madagascar'                             => 'mg',
    'malawi'                                 => 'mw',
    'malaysia'                               => 'my',
    'maldives'                               => 'mv',
    'mali'                                   => 'ml',
    'malta'                                  => 'mt',
    'marshallislands'                        => 'mh',
    'martinique'                             => 'mq',
    'mauritania'                             => 'mr',
    'mauritius'                              => 'mu',
    'mayotte'                                => 'yt',
    'metropolitanfrance'                     => 'fx',
    'mexico'                                 => 'mx',
    'micronesia'                             => 'fm',
    'midwayislands'                          => 'mi',
    'moldova'                                => 'md',
    'monaco'                                 => 'mc',
    'mongolia'                               => 'mn',
    'montenegro'                             => 'me',
    'montserrat'                             => 'ms',
    'morocco'                                => 'ma',
    'mozambique'                             => 'mz',
    'myanmarburma'                           => 'mm',
    'namibia'                                => 'na',
    'nauru'                                  => 'nr',
    'nepal'                                  => 'np',
    'netherlands'                            => 'nl',
    'netherlandsantilles'                    => 'an',
    'neutralzone'                            => 'nt',
    'newcaledonia'                           => 'nc',
    'newzealand'                             => 'nz',
    'nicaragua'                              => 'ni',
    'niger'                                  => 'ne',
    'nigeria'                                => 'ng',
    'niue'                                   => 'nu',
    'norfolkisland'                          => 'nf',
    'northernmarianaislands'                 => 'mp',
    'northkorea'                             => 'kp',
    'northvietnam'                           => 'vd',
    'norway'                                 => 'no',
    'oman'                                   => 'om',
    'outlyingoceania'                        => 'qo',
    'pacificislandstrustterritory'           => 'pc',
    'pakistan'                               => 'pk',
    'palau'                                  => 'pw',
    'palestinianterritories'                 => 'ps',
    'panama'                                 => 'pa',
    'panamacanalzone'                        => 'pz',
    'papuanewguinea'                         => 'pg',
    'paraguay'                               => 'py',
    'peoplesdemocraticrepublicofyemen'       => 'yd',
    'peru'                                   => 'pe',
    'philippines'                            => 'ph',
    'pitcairnislands'                        => 'pn',
    'poland'                                 => 'pl',
    'portugal'                               => 'pt',
    'puertorico'                             => 'pr',
    'qatar'                                  => 'qa',
    'romania'                                => 'ro',
    'russia'                                 => 'ru',
    'rwanda'                                 => 'rw',
    "r\Ã\©union"                           => 're',
    "saintbarth\Ã\©lemy"                   => 'bl',
    'sainthelena'                            => 'sh',
    'saintkittsandnevis'                     => 'kn',
    'saintlucia'                             => 'lc',
    'saintmartin'                            => 'mf',
    'saintpierreandmiquelon'                 => 'pm',
    'saintvincentandthegrenadines'           => 'vc',
    'samoa'                                  => 'ws',
    'sanmarino'                              => 'sm',
    'saudiarabia'                            => 'sa',
    'senegal'                                => 'sn',
    'serbia'                                 => 'rs',
    'serbiaandmontenegro'                    => 'cs',
    'seychelles'                             => 'sc',
    'sierraleone'                            => 'sl',
    'singapore'                              => 'sg',
    'slovakia'                               => 'sk',
    'slovenia'                               => 'si',
    'solomonislands'                         => 'sb',
    'somalia'                                => 'so',
    'southafrica'                            => 'za',
    'southgeorgiaandthesouthsandwichislands' => 'gs',
    'southkorea'                             => 'kr',
    'spain'                                  => 'es',
    'srilanka'                               => 'lk',
    'sudan'                                  => 'sd',
    'suriname'                               => 'sr',
    'svalbardandjanmayen'                    => 'sj',
    'swaziland'                              => 'sz',
    'sweden'                                 => 'se',
    'switzerland'                            => 'ch',
    'syria'                                  => 'sy',
    "s\Ã\£otom\Ã\©andpr\Ã\­ncipe"      => 'st',
    'taiwan'                                 => 'tw',
    'tajikistan'                             => 'tj',
    'tanzania'                               => 'tz',
    'thailand'                               => 'th',
    'togo'                                   => 'tg',
    'tokelau'                                => 'tk',
    'tonga'                                  => 'to',
    'trinidadandtobago'                      => 'tt',
    'tunisia'                                => 'tn',
    'turkey'                                 => 'tr',
    'turkmenistan'                           => 'tm',
    'turksandcaicosislands'                  => 'tc',
    'tuvalu'                                 => 'tv',
    "u\.s\.minoroutlyingislands"             => 'um',
    "u\.s\.miscellaneouspacificislands"      => 'pu',
    "u\.s\.virginislands"                    => 'vi',
    'uganda'                                 => 'ug',
    'ukraine'                                => 'ua',
    'unionofsovietsocialistrepublics'        => 'su',
    'unitedarabemirates'                     => 'ae',
    'unitedkingdom'                          => 'gb',
    'unitedstates'                           => 'us',
    'unknownorinvalidregion'                 => 'zz',
    'uruguay'                                => 'uy',
    'uzbekistan'                             => 'uz',
    'vanuatu'                                => 'vu',
    'vaticancity'                            => 'va',
    'venezuela'                              => 've',
    'vietnam'                                => 'vn',
    'wakeisland'                             => 'wk',
    'wallisandfutuna'                        => 'wf',
    'westernsahara'                          => 'eh',
    'yemen'                                  => 'ye',
    'zambia'                                 => 'zm',
    'zimbabwe'                               => 'zw',
    "\Ã\landislands"                      => 'ax',
);

1;

