package Locales::DB::Territory::pl;

# Auto generated from CLDR

$Locales::DB::Territory::pl::VERSION = '0.02';

$Locales::DB::Territory::pl::cldr_version = '1.7.1';

%Locales::DB::Territory::pl::code_to_name = (
    'ad' => 'Andora',
    'ae' => "Zjednoczone\ Emiraty\ Arabskie",
    'af' => 'Afganistan',
    'ag' => "Antigua\ i\ Barbuda",
    'ai' => 'Anguilla',
    'al' => 'Albania',
    'am' => 'Armenia',
    'an' => "Antyle\ Holenderskie",
    'ao' => 'Angola',
    'aq' => 'Antarktyka',
    'ar' => 'Argentyna',
    'as' => "Samoa\ Amerykańskie",
    'at' => 'Austria',
    'au' => 'Australia',
    'aw' => 'Aruba',
    'ax' => "Wyspy\ Alandzkie",
    'az' => 'Azerbejdżan',
    'ba' => "Bośnia\ i\ Hercegowina",
    'bb' => 'Barbados',
    'bd' => 'Bangladesz',
    'be' => 'Belgia',
    'bf' => "Burkina\ Faso",
    'bg' => 'Bułgaria',
    'bh' => 'Bahrajn',
    'bi' => 'Burundi',
    'bj' => 'Benin',
    'bl' => "Saint\ Barthélemy",
    'bm' => 'Bermudy',
    'bn' => "Brunei\ Darussalam",
    'bo' => 'Boliwia',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brazylia',
    'bs' => 'Bahamy',
    'bt' => 'Bhutan',
    'bv' => "Wyspa\ Bouveta",
    'bw' => 'Botswana',
    'by' => 'Białoruś',
    'bz' => 'Belize',
    'ca' => 'Kanada',
    'cc' => "Wyspy\ Kokosowe",
    'cd' => "Demokratyczna\ Republika\ Konga",
    'cf' => "Republika\ Środkowoafrykańska",
    'cg' => 'Kongo',
    'ch' => 'Szwajcaria',
    'ci' => "Wybrzeże\ Kości\ Słoniowej",
    'ck' => "Wyspy\ Cooka",
    'cl' => 'Chile',
    'cm' => 'Kamerun',
    'cn' => 'Chiny',
    'co' => 'Kolumbia',
    'cr' => 'Kostaryka',
    'cs' => "Serbia\ i\ Czarnogóra",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Kuba',
    'cv' => "Republika\ Zielonego\ Przylądka",
    'cx' => "Wyspa\ Bożego\ Narodzenia",
    'cy' => 'Cypr',
    'cz' => 'Czechy',
    'dd' => "East\ Germany",
    'de' => 'Niemcy',
    'dj' => 'Dżibuti',
    'dk' => 'Dania',
    'dm' => 'Dominika',
    'do' => "Republika\ Dominikańska",
    'dz' => 'Algieria',
    'ec' => 'Ekwador',
    'ee' => 'Estonia',
    'eg' => 'Egipt',
    'eh' => "Sahara\ Zachodnia",
    'er' => 'Erytrea',
    'es' => 'Hiszpania',
    'et' => 'Etiopia',
    'fi' => 'Finlandia',
    'fj' => 'Fidżi',
    'fk' => 'Falklandy',
    'fm' => "Federalne\ Stany\ Mikronezji",
    'fo' => "Wyspy\ Owcze",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Francja',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabon',
    'gb' => "Wielka\ Brytania",
    'gd' => 'Grenada',
    'ge' => 'Gruzja',
    'gf' => "Gujana\ Francuska",
    'gg' => "Wyspa\ Guernsey",
    'gh' => 'Ghana',
    'gi' => 'Gibraltar',
    'gl' => 'Grenlandia',
    'gm' => 'Gambia',
    'gn' => 'Gwinea',
    'gp' => 'Gwadelupa',
    'gq' => "Gwinea\ Równikowa",
    'gr' => 'Grecja',
    'gs' => "Georgia\ Południowa\ i\ Sandwich\ Południowy",
    'gt' => 'Gwatemala',
    'gu' => 'Guam',
    'gw' => "Gwinea\ Bissau",
    'gy' => 'Gujana',
    'hk' => 'Hongkong',
    'hm' => "Wyspy\ Heard\ i\ McDonalda",
    'hn' => 'Honduras',
    'hr' => 'Chorwacja',
    'ht' => 'Haiti',
    'hu' => 'Węgry',
    'id' => 'Indonezja',
    'ie' => 'Irlandia',
    'il' => 'Izrael',
    'im' => "Wyspa\ Man",
    'in' => 'Indie',
    'io' => "Terytorium\ Brytyjskie\ Oceanu\ Indyjskiego",
    'iq' => 'Irak',
    'ir' => 'Iran',
    'is' => 'Islandia',
    'it' => 'Włochy',
    'je' => "Wyspa\ Jersey",
    'jm' => 'Jamajka',
    'jo' => 'Jordania',
    'jp' => 'Japonia',
    'jt' => "Johnston\ Island",
    'ke' => 'Kenia',
    'kg' => 'Kirgistan',
    'kh' => 'Kambodża',
    'ki' => 'Kiribati',
    'km' => 'Komory',
    'kn' => "Saint\ Kitts\ i\ Nevis",
    'kp' => "Korea\ Północna",
    'kr' => "Korea\ Południowa",
    'kw' => 'Kuwejt',
    'ky' => 'Kajmany',
    'kz' => 'Kazachstan',
    'la' => 'Laos',
    'lb' => 'Liban',
    'lc' => "Saint\ Lucia",
    'li' => 'Liechtenstein',
    'lk' => "Sri\ Lanka",
    'lr' => 'Liberia',
    'ls' => 'Lesotho',
    'lt' => 'Litwa',
    'lu' => 'Luksemburg',
    'lv' => 'Łotwa',
    'ly' => 'Libia',
    'ma' => 'Maroko',
    'mc' => 'Monako',
    'md' => 'Mołdawia',
    'me' => 'Czarnogóra',
    'mf' => "Sint\ Maarten",
    'mg' => 'Madagaskar',
    'mh' => "Wyspy\ Marshalla",
    'mi' => "Midway\ Islands",
    'mk' => 'Macedonia',
    'ml' => 'Mali',
    'mm' => 'Birma',
    'mn' => 'Mongolia',
    'mo' => 'Makau',
    'mp' => "Mariany\ Północne",
    'mq' => 'Martynika',
    'mr' => 'Mauretania',
    'ms' => 'Montserrat',
    'mt' => 'Malta',
    'mu' => 'Mauritius',
    'mv' => 'Malediwy',
    'mw' => 'Malawi',
    'mx' => 'Meksyk',
    'my' => 'Malezja',
    'mz' => 'Mozambik',
    'na' => 'Namibia',
    'nc' => "Nowa\ Kaledonia",
    'ne' => 'Niger',
    'nf' => 'Norfolk',
    'ng' => 'Nigeria',
    'ni' => 'Nikaragua',
    'nl' => 'Holandia',
    'no' => 'Norwegia',
    'np' => 'Nepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "Nowa\ Zelandia",
    'om' => 'Oman',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Peru',
    'pf' => "Polinezja\ Francuska",
    'pg' => "Papua\ Nowa\ Gwinea",
    'ph' => 'Filipiny',
    'pk' => 'Pakistan',
    'pl' => 'Polska',
    'pm' => "Saint\-Pierre\ i\ Miquelon",
    'pn' => 'Pitcairn',
    'pr' => 'Portoryko',
    'ps' => "Terytoria\ Palestyńskie",
    'pt' => 'Portugalia',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paragwaj',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Katar',
    'qo' => "Oceania\ inne",
    'qu' => "Unia\ Europejska",
    're' => 'Reunion',
    'ro' => 'Rumunia',
    'rs' => 'Serbia',
    'ru' => 'Rosja',
    'rw' => 'Rwanda',
    'sa' => "Arabia\ Saudyjska",
    'sb' => "Wyspy\ Salomona",
    'sc' => 'Seszele',
    'sd' => 'Sudan',
    'se' => 'Szwecja',
    'sg' => 'Singapur',
    'sh' => "Wyspa\ Świętej\ Heleny",
    'si' => 'Słowenia',
    'sj' => "Svalbard\ i\ Jan\ Mayen",
    'sk' => 'Słowacja',
    'sl' => "Sierra\ Leone",
    'sm' => "San\ Marino",
    'sn' => 'Senegal',
    'so' => 'Somalia',
    'sr' => 'Surinam',
    'st' => "Wyspy\ Świętego\ Tomasza\ i\ Książęca",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => 'Salwador',
    'sy' => 'Syria',
    'sz' => 'Suazi',
    'tc' => "Turks\ i\ Caicos",
    'td' => 'Czad',
    'tf' => "Francuskie\ Terytoria\ Południowe",
    'tg' => 'Togo',
    'th' => 'Tajlandia',
    'tj' => 'Tadżykistan',
    'tk' => 'Tokelau',
    'tl' => "Timor\ Wschodni",
    'tm' => 'Turkmenistan',
    'tn' => 'Tunezja',
    'to' => 'Tonga',
    'tr' => 'Turcja',
    'tt' => "Trynidad\ i\ Tobago",
    'tv' => 'Tuvalu',
    'tw' => 'Tajwan',
    'tz' => 'Tanzania',
    'ua' => 'Ukraina',
    'ug' => 'Uganda',
    'um' => "Dalekie\ Wyspy\ Mniejsze\ Stanów\ Zjednoczonych",
    'us' => "Stany\ Zjednoczone",
    'uy' => 'Urugwaj',
    'uz' => 'Uzbekistan',
    'va' => 'Watykan',
    'vc' => "Saint\ Vincent\ i\ Grenadyny",
    'vd' => "North\ Vietnam",
    've' => 'Wenezuela',
    'vg' => "Brytyjskie\ Wyspy\ Dziewicze",
    'vi' => "Wyspy\ Dziewicze\ Stanów\ Zjednoczonych",
    'vn' => 'Wietnam',
    'vu' => 'Vanuatu',
    'wf' => "Wallis\ i\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Jemen',
    'yt' => 'Majotta',
    'za' => "Republika\ Południowej\ Afryki",
    'zm' => 'Zambia',
    'zw' => 'Zimbabwe',
    'zz' => "Nieznany\ lub\ nieprawidłowy\ region",
);

%Locales::DB::Territory::pl::name_to_code = (
    'afganistan'                               => 'af',
    'albania'                                  => 'al',
    'algieria'                                 => 'dz',
    'andora'                                   => 'ad',
    'angola'                                   => 'ao',
    'anguilla'                                 => 'ai',
    'antarktyka'                               => 'aq',
    'antiguaibarbuda'                          => 'ag',
    'antyleholenderskie'                       => 'an',
    'arabiasaudyjska'                          => 'sa',
    'argentyna'                                => 'ar',
    'armenia'                                  => 'am',
    'aruba'                                    => 'aw',
    'australia'                                => 'au',
    'austria'                                  => 'at',
    'azerbejdżan'                             => 'az',
    'bahamy'                                   => 'bs',
    'bahrajn'                                  => 'bh',
    'bangladesz'                               => 'bd',
    'barbados'                                 => 'bb',
    'belgia'                                   => 'be',
    'belize'                                   => 'bz',
    'benin'                                    => 'bj',
    'bermudy'                                  => 'bm',
    'bhutan'                                   => 'bt',
    'białoruś'                               => 'by',
    'birma'                                    => 'mm',
    'boliwia'                                  => 'bo',
    'botswana'                                 => 'bw',
    'bośniaihercegowina'                      => 'ba',
    'brazylia'                                 => 'br',
    'britishantarcticterritory'                => 'bq',
    'bruneidarussalam'                         => 'bn',
    'brytyjskiewyspydziewicze'                 => 'vg',
    'burkinafaso'                              => 'bf',
    'burundi'                                  => 'bi',
    'bułgaria'                                => 'bg',
    'cantonandenderburyislands'                => 'ct',
    'chile'                                    => 'cl',
    'chiny'                                    => 'cn',
    'chorwacja'                                => 'hr',
    'cypr'                                     => 'cy',
    'czad'                                     => 'td',
    'czarnogóra'                              => 'me',
    'czechy'                                   => 'cz',
    'dalekiewyspymniejszestanówzjednoczonych' => 'um',
    'dania'                                    => 'dk',
    'demokratycznarepublikakonga'              => 'cd',
    'dominika'                                 => 'dm',
    'dronningmaudland'                         => 'nq',
    'dżibuti'                                 => 'dj',
    'eastgermany'                              => 'dd',
    'egipt'                                    => 'eg',
    'ekwador'                                  => 'ec',
    'erytrea'                                  => 'er',
    'estonia'                                  => 'ee',
    'etiopia'                                  => 'et',
    'falklandy'                                => 'fk',
    'federalnestanymikronezji'                 => 'fm',
    'fidżi'                                   => 'fj',
    'filipiny'                                 => 'ph',
    'finlandia'                                => 'fi',
    'francja'                                  => 'fr',
    'francuskieterytoriapołudniowe'           => 'tf',
    'frenchsouthernandantarcticterritories'    => 'fq',
    'gabon'                                    => 'ga',
    'gambia'                                   => 'gm',
    'georgiapołudniowaisandwichpołudniowy'   => 'gs',
    'ghana'                                    => 'gh',
    'gibraltar'                                => 'gi',
    'grecja'                                   => 'gr',
    'grenada'                                  => 'gd',
    'grenlandia'                               => 'gl',
    'gruzja'                                   => 'ge',
    'guam'                                     => 'gu',
    'gujana'                                   => 'gy',
    'gujanafrancuska'                          => 'gf',
    'gwadelupa'                                => 'gp',
    'gwatemala'                                => 'gt',
    'gwinea'                                   => 'gn',
    'gwineabissau'                             => 'gw',
    'gwinearównikowa'                         => 'gq',
    'haiti'                                    => 'ht',
    'hiszpania'                                => 'es',
    'holandia'                                 => 'nl',
    'honduras'                                 => 'hn',
    'hongkong'                                 => 'hk',
    'indie'                                    => 'in',
    'indonezja'                                => 'id',
    'irak'                                     => 'iq',
    'iran'                                     => 'ir',
    'irlandia'                                 => 'ie',
    'islandia'                                 => 'is',
    'izrael'                                   => 'il',
    'jamajka'                                  => 'jm',
    'japonia'                                  => 'jp',
    'jemen'                                    => 'ye',
    'johnstonisland'                           => 'jt',
    'jordania'                                 => 'jo',
    'kajmany'                                  => 'ky',
    'kambodża'                                => 'kh',
    'kamerun'                                  => 'cm',
    'kanada'                                   => 'ca',
    'katar'                                    => 'qa',
    'kazachstan'                               => 'kz',
    'kenia'                                    => 'ke',
    'kirgistan'                                => 'kg',
    'kiribati'                                 => 'ki',
    'kolumbia'                                 => 'co',
    'komory'                                   => 'km',
    'kongo'                                    => 'cg',
    'koreapołudniowa'                         => 'kr',
    'koreapółnocna'                          => 'kp',
    'kostaryka'                                => 'cr',
    'kuba'                                     => 'cu',
    'kuwejt'                                   => 'kw',
    'laos'                                     => 'la',
    'lesotho'                                  => 'ls',
    'liban'                                    => 'lb',
    'liberia'                                  => 'lr',
    'libia'                                    => 'ly',
    'liechtenstein'                            => 'li',
    'litwa'                                    => 'lt',
    'luksemburg'                               => 'lu',
    'macedonia'                                => 'mk',
    'madagaskar'                               => 'mg',
    'majotta'                                  => 'yt',
    'makau'                                    => 'mo',
    'malawi'                                   => 'mw',
    'malediwy'                                 => 'mv',
    'malezja'                                  => 'my',
    'mali'                                     => 'ml',
    'malta'                                    => 'mt',
    'marianypółnocne'                        => 'mp',
    'maroko'                                   => 'ma',
    'martynika'                                => 'mq',
    'mauretania'                               => 'mr',
    'mauritius'                                => 'mu',
    'meksyk'                                   => 'mx',
    'metropolitanfrance'                       => 'fx',
    'midwayislands'                            => 'mi',
    'monako'                                   => 'mc',
    'mongolia'                                 => 'mn',
    'montserrat'                               => 'ms',
    'mozambik'                                 => 'mz',
    'mołdawia'                                => 'md',
    'namibia'                                  => 'na',
    'nauru'                                    => 'nr',
    'nepal'                                    => 'np',
    'neutralzone'                              => 'nt',
    'niemcy'                                   => 'de',
    'nieznanylubnieprawidłowyregion'          => 'zz',
    'niger'                                    => 'ne',
    'nigeria'                                  => 'ng',
    'nikaragua'                                => 'ni',
    'niue'                                     => 'nu',
    'norfolk'                                  => 'nf',
    'northvietnam'                             => 'vd',
    'norwegia'                                 => 'no',
    'nowakaledonia'                            => 'nc',
    'nowazelandia'                             => 'nz',
    'oceaniainne'                              => 'qo',
    'oman'                                     => 'om',
    'pacificislandstrustterritory'             => 'pc',
    'pakistan'                                 => 'pk',
    'palau'                                    => 'pw',
    'panama'                                   => 'pa',
    'panamacanalzone'                          => 'pz',
    'papuanowagwinea'                          => 'pg',
    'paragwaj'                                 => 'py',
    'peoplesdemocraticrepublicofyemen'         => 'yd',
    'peru'                                     => 'pe',
    'pitcairn'                                 => 'pn',
    'polinezjafrancuska'                       => 'pf',
    'polska'                                   => 'pl',
    'portoryko'                                => 'pr',
    'portugalia'                               => 'pt',
    'republikadominikańska'                   => 'do',
    'republikapołudniowejafryki'              => 'za',
    'republikazielonegoprzylądka'             => 'cv',
    'republikaŚrodkowoafrykańska'            => 'cf',
    'reunion'                                  => 're',
    'rosja'                                    => 'ru',
    'rumunia'                                  => 'ro',
    'rwanda'                                   => 'rw',
    'saharazachodnia'                          => 'eh',
    'saintbarthélemy'                         => 'bl',
    'saintkittsinevis'                         => 'kn',
    'saintlucia'                               => 'lc',
    'saintpierreimiquelon'                     => 'pm',
    'saintvincentigrenadyny'                   => 'vc',
    'salwador'                                 => 'sv',
    'samoa'                                    => 'ws',
    'samoaamerykańskie'                       => 'as',
    'sanmarino'                                => 'sm',
    'senegal'                                  => 'sn',
    'serbia'                                   => 'rs',
    'serbiaiczarnogóra'                       => 'cs',
    'seszele'                                  => 'sc',
    'sierraleone'                              => 'sl',
    'singapur'                                 => 'sg',
    'sintmaarten'                              => 'mf',
    'somalia'                                  => 'so',
    'srilanka'                                 => 'lk',
    'stanyzjednoczone'                         => 'us',
    'suazi'                                    => 'sz',
    'sudan'                                    => 'sd',
    'surinam'                                  => 'sr',
    'svalbardijanmayen'                        => 'sj',
    'syria'                                    => 'sy',
    'szwajcaria'                               => 'ch',
    'szwecja'                                  => 'se',
    'słowacja'                                => 'sk',
    'słowenia'                                => 'si',
    'tadżykistan'                             => 'tj',
    'tajlandia'                                => 'th',
    'tajwan'                                   => 'tw',
    'tanzania'                                 => 'tz',
    'terytoriapalestyńskie'                   => 'ps',
    'terytoriumbrytyjskieoceanuindyjskiego'    => 'io',
    'timorwschodni'                            => 'tl',
    'togo'                                     => 'tg',
    'tokelau'                                  => 'tk',
    'tonga'                                    => 'to',
    'trynidaditobago'                          => 'tt',
    'tunezja'                                  => 'tn',
    'turcja'                                   => 'tr',
    'turkmenistan'                             => 'tm',
    'turksicaicos'                             => 'tc',
    'tuvalu'                                   => 'tv',
    "u\.s\.miscellaneouspacificislands"        => 'pu',
    'uganda'                                   => 'ug',
    'ukraina'                                  => 'ua',
    'uniaeuropejska'                           => 'qu',
    'unionofsovietsocialistrepublics'          => 'su',
    'urugwaj'                                  => 'uy',
    'uzbekistan'                               => 'uz',
    'vanuatu'                                  => 'vu',
    'wakeisland'                               => 'wk',
    'wallisifutuna'                            => 'wf',
    'watykan'                                  => 'va',
    'wenezuela'                                => 've',
    'wielkabrytania'                           => 'gb',
    'wietnam'                                  => 'vn',
    'wybrzeżekościsłoniowej'                => 'ci',
    'wyspabouveta'                             => 'bv',
    'wyspabożegonarodzenia'                   => 'cx',
    'wyspaguernsey'                            => 'gg',
    'wyspajersey'                              => 'je',
    'wyspaman'                                 => 'im',
    'wyspaŚwiętejheleny'                     => 'sh',
    'wyspyalandzkie'                           => 'ax',
    'wyspycooka'                               => 'ck',
    'wyspydziewiczestanówzjednoczonych'       => 'vi',
    'wyspyheardimcdonalda'                     => 'hm',
    'wyspykokosowe'                            => 'cc',
    'wyspymarshalla'                           => 'mh',
    'wyspyowcze'                               => 'fo',
    'wyspysalomona'                            => 'sb',
    'wyspyŚwiętegotomaszaiksiążęca'       => 'st',
    'węgry'                                   => 'hu',
    'włochy'                                  => 'it',
    'zambia'                                   => 'zm',
    'zimbabwe'                                 => 'zw',
    'zjednoczoneemiratyarabskie'               => 'ae',
    'Łotwa'                                   => 'lv',
);

1;

