package Locales::DB::Territory::sl;

# Auto generated from CLDR

$Locales::DB::Territory::sl::VERSION = '0.02';

$Locales::DB::Territory::sl::cldr_version = '1.7.1';

%Locales::DB::Territory::sl::code_to_name = (
    'ad' => 'Andora',
    'ae' => "Združeni\ arabski\ emirati",
    'af' => 'Afganistan',
    'ag' => "Antigva\ in\ Barbuda",
    'ai' => 'Angvila',
    'al' => 'Albanija',
    'am' => 'Armenija',
    'an' => "Nizozemski\ Antili",
    'ao' => 'Angola',
    'aq' => 'Antarktika',
    'ar' => 'Argentina',
    'as' => "Ameriška\ Samoa",
    'at' => 'Avstrija',
    'au' => 'Avstralija',
    'aw' => 'Aruba',
    'ax' => "Alandsko\ otočje",
    'az' => 'Azerbajdžan',
    'ba' => "Bosna\ in\ Hercegovina",
    'bb' => 'Barbados',
    'bd' => 'Bangladeš',
    'be' => 'Belgija',
    'bf' => "Burkina\ Faso",
    'bg' => 'Bolgarija',
    'bh' => 'Bahrajn',
    'bi' => 'Burundi',
    'bj' => 'Benin',
    'bl' => "Saint\ Barthelemy",
    'bm' => 'Bermudi',
    'bn' => 'Brunej',
    'bo' => 'Bolivija',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brazilija',
    'bs' => 'Bahami',
    'bt' => 'Butan',
    'bv' => "Bouvetov\ otok",
    'bw' => 'Bocvana',
    'by' => 'Belorusija',
    'bz' => 'Belize',
    'ca' => 'Kanada',
    'cc' => "Kokosovi\ otoki",
    'cd' => "Demokratična\ republika\ Kongo",
    'cf' => "Centralnoafriška\ republika",
    'cg' => 'Kongo',
    'ch' => 'Švica',
    'ci' => "Slonokoščena\ obala",
    'ck' => "Cookovo\ otočje",
    'cl' => 'Čile',
    'cm' => 'Kamerun',
    'cn' => 'Kitajska',
    'co' => 'Kolumbija',
    'cr' => 'Kostarika',
    'cs' => "Srbija\ in\ Črna\ gora",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Kuba',
    'cv' => "Zelenortski\ otoki",
    'cx' => "Božični\ otok",
    'cy' => 'Ciper',
    'cz' => 'Češka',
    'dd' => "East\ Germany",
    'de' => 'Nemčija',
    'dj' => 'Džibuti',
    'dk' => 'Danska',
    'dm' => 'Dominika',
    'do' => "Dominikanska\ republika",
    'dz' => 'Alžirija',
    'ec' => 'Ekvador',
    'ee' => 'Estonija',
    'eg' => 'Egipt',
    'eh' => "Zahodna\ Sahara",
    'er' => 'Eritreja',
    'es' => 'Španija',
    'et' => 'Etiopija',
    'fi' => 'Finska',
    'fj' => 'Fidži',
    'fk' => "Falklandski\ otoki",
    'fm' => 'Mikronezija',
    'fo' => "Ferski\ otoki",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Francija',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabon',
    'gb' => "Velika\ Britanija",
    'gd' => 'Grenada',
    'ge' => 'Gruzija',
    'gf' => "Francoska\ Gvajana",
    'gg' => 'Guernsey',
    'gh' => 'Gana',
    'gi' => 'Gibraltar',
    'gl' => 'Grenlandija',
    'gm' => 'Gambija',
    'gn' => 'Gvineja',
    'gp' => 'Gvadalupe',
    'gq' => "Ekvatorialna\ Gvineja",
    'gr' => 'Grčija',
    'gs' => "Južna\ Georgia\ in\ Južni\ Sandwichevi\ otoki",
    'gt' => 'Gvatemala',
    'gu' => 'Guam',
    'gw' => "Gvineja\ Bissau",
    'gy' => 'Gvajana',
    'hk' => "Posebno\ administrativno\ območje\ LR\ Kitajske\ Hong\ Kong",
    'hm' => "Otok\ Heard\ in\ otočje\ McDonald",
    'hn' => 'Honduras',
    'hr' => 'Hrvaška',
    'ht' => 'Haiti',
    'hu' => 'Madžarska',
    'id' => 'Indonezija',
    'ie' => 'Irska',
    'il' => 'Izrael',
    'im' => "Otok\ Man",
    'in' => 'Indija',
    'io' => "Britansko\ ozemlje\ v\ Indijskem\ oceanu",
    'iq' => 'Irak',
    'ir' => 'Iran',
    'is' => 'Islandija',
    'it' => 'Italija',
    'je' => 'Jersey',
    'jm' => 'Jamajka',
    'jo' => 'Jordanija',
    'jp' => 'Japonska',
    'jt' => "Johnston\ Island",
    'ke' => 'Kenija',
    'kg' => 'Kirgizistan',
    'kh' => 'Kambodža',
    'ki' => 'Kiribati',
    'km' => 'Komori',
    'kn' => "Saint\ Kitts\ in\ Nevis",
    'kp' => "Severna\ Koreja",
    'kr' => "Južna\ Koreja",
    'kw' => 'Kuvajt',
    'ky' => "Kajmanski\ otoki",
    'kz' => 'Kazahstan',
    'la' => 'Laos',
    'lb' => 'Libanon',
    'lc' => "Saint\ Lucia",
    'li' => 'Lihtenštajn',
    'lk' => 'Šrilanka',
    'lr' => 'Liberija',
    'ls' => 'Lesoto',
    'lt' => 'Litva',
    'lu' => 'Luksemburg',
    'lv' => 'Latvija',
    'ly' => 'Libija',
    'ma' => 'Maroko',
    'mc' => 'Monako',
    'md' => 'Moldavija',
    'me' => "Črna\ gora",
    'mf' => "Saint\ Martin",
    'mg' => 'Madagaskar',
    'mh' => "Marshallovi\ otoki",
    'mi' => "Midway\ Islands",
    'mk' => 'Makedonija',
    'ml' => 'Mali',
    'mm' => 'Mjanmar',
    'mn' => 'Mongolija',
    'mo' => "Posebno\ administrativno\ območje\ LR\ Kitajske\ Macao",
    'mp' => "Severni\ Marianski\ otoki",
    'mq' => 'Martinik',
    'mr' => 'Mavretanija',
    'ms' => 'Montserrat',
    'mt' => 'Malta',
    'mu' => 'Mauritius',
    'mv' => 'Maldivi',
    'mw' => 'Malavi',
    'mx' => 'Mehika',
    'my' => 'Malezija',
    'mz' => 'Mozambik',
    'na' => 'Namibija',
    'nc' => "Nova\ Kaledonija",
    'ne' => 'Niger',
    'nf' => "Norfolški\ otok",
    'ng' => 'Nigerija',
    'ni' => 'Nikaragva',
    'nl' => 'Nizozemska',
    'no' => 'Norveška',
    'np' => 'Nepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "Nova\ Zelandija",
    'om' => 'Oman',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Peru',
    'pf' => "Francoska\ Polinezija",
    'pg' => "Papua\ Nova\ Gvineja",
    'ph' => 'Filipini',
    'pk' => 'Pakistan',
    'pl' => 'Poljska',
    'pm' => "Saint\ Pierre\ in\ Miquelon",
    'pn' => 'Pitcairn',
    'pr' => 'Portoriko',
    'ps' => "Palestinsko\ ozemlje",
    'pt' => 'Portugalska',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paragvaj',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Katar',
    'qo' => "Ostala\ oceanija",
    'qu' => "Evropska\ unija",
    're' => 'Reunion',
    'ro' => 'Romunija',
    'rs' => 'Srbija',
    'ru' => 'Rusija',
    'rw' => 'Ruanda',
    'sa' => "Saudova\ Arabija",
    'sb' => "Salomonovi\ otoki",
    'sc' => 'Sejšeli',
    'sd' => 'Sudan',
    'se' => 'Švedska',
    'sg' => 'Singapur',
    'sh' => "Sveta\ Helena",
    'si' => 'Slovenija',
    'sj' => "Svalbard\ in\ Jan\ Mayen",
    'sk' => 'Slovaška',
    'sl' => "Sierra\ Leone",
    'sm' => "San\ Marino",
    'sn' => 'Senegal',
    'so' => 'Somalija',
    'sr' => 'Surinam',
    'st' => "Sao\ Tome\ in\ Principe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => 'Salvador',
    'sy' => 'Sirija',
    'sz' => 'Svazi',
    'tc' => "Otočji\ Turks\ in\ Caicos",
    'td' => 'Čad',
    'tf' => "Francosko\ južno\ ozemlje",
    'tg' => 'Togo',
    'th' => 'Tajska',
    'tj' => 'Tadžikistan',
    'tk' => 'Tokelau',
    'tl' => "Vzhodni\ Timor",
    'tm' => 'Turkmenistan',
    'tn' => 'Tunizija',
    'to' => 'Tonga',
    'tr' => 'Turčija',
    'tt' => "Trinidad\ in\ Tobago",
    'tv' => 'Tuvalu',
    'tw' => 'Tajvan',
    'tz' => 'Tanzanija',
    'ua' => 'Ukrajina',
    'ug' => 'Uganda',
    'um' => "Druga\ ameriška\ ozemlja\ v\ Tihem\ oceanu",
    'us' => "Združene\ države\ Amerike",
    'uy' => 'Urugvaj',
    'uz' => 'Uzbekistan',
    'va' => 'Vatikan',
    'vc' => "Saint\ Vincent\ in\ Grenadine",
    'vd' => "North\ Vietnam",
    've' => 'Venezuela',
    'vg' => "Britanski\ Deviški\ otoki",
    'vi' => "Ameriški\ Deviški\ otoki",
    'vn' => 'Vietnam',
    'vu' => 'Vanuatu',
    'wf' => "Wallis\ in\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Jemen',
    'yt' => 'Mayotte',
    'za' => "Južnoafriška\ republika",
    'zm' => 'Zambija',
    'zw' => 'Zimbabve',
    'zz' => "Neznano\ ali\ neveljavno\ območje",
);

%Locales::DB::Territory::sl::name_to_code = (
    'afganistan'                                       => 'af',
    'alandskootočje'                                  => 'ax',
    'albanija'                                         => 'al',
    'alžirija'                                        => 'dz',
    'ameriškasamoa'                                   => 'as',
    'ameriškideviškiotoki'                           => 'vi',
    'andora'                                           => 'ad',
    'angola'                                           => 'ao',
    'angvila'                                          => 'ai',
    'antarktika'                                       => 'aq',
    'antigvainbarbuda'                                 => 'ag',
    'argentina'                                        => 'ar',
    'armenija'                                         => 'am',
    'aruba'                                            => 'aw',
    'avstralija'                                       => 'au',
    'avstrija'                                         => 'at',
    'azerbajdžan'                                     => 'az',
    'bahami'                                           => 'bs',
    'bahrajn'                                          => 'bh',
    'bangladeš'                                       => 'bd',
    'barbados'                                         => 'bb',
    'belgija'                                          => 'be',
    'belize'                                           => 'bz',
    'belorusija'                                       => 'by',
    'benin'                                            => 'bj',
    'bermudi'                                          => 'bm',
    'bocvana'                                          => 'bw',
    'bolgarija'                                        => 'bg',
    'bolivija'                                         => 'bo',
    'bosnainhercegovina'                               => 'ba',
    'bouvetovotok'                                     => 'bv',
    'božičniotok'                                    => 'cx',
    'brazilija'                                        => 'br',
    'britanskideviškiotoki'                           => 'vg',
    'britanskoozemljevindijskemoceanu'                 => 'io',
    'britishantarcticterritory'                        => 'bq',
    'brunej'                                           => 'bn',
    'burkinafaso'                                      => 'bf',
    'burundi'                                          => 'bi',
    'butan'                                            => 'bt',
    'cantonandenderburyislands'                        => 'ct',
    'centralnoafriškarepublika'                       => 'cf',
    'ciper'                                            => 'cy',
    'cookovootočje'                                   => 'ck',
    'danska'                                           => 'dk',
    'demokratičnarepublikakongo'                      => 'cd',
    'dominika'                                         => 'dm',
    'dominikanskarepublika'                            => 'do',
    'dronningmaudland'                                 => 'nq',
    'drugaameriškaozemljavtihemoceanu'                => 'um',
    'džibuti'                                         => 'dj',
    'eastgermany'                                      => 'dd',
    'egipt'                                            => 'eg',
    'ekvador'                                          => 'ec',
    'ekvatorialnagvineja'                              => 'gq',
    'eritreja'                                         => 'er',
    'estonija'                                         => 'ee',
    'etiopija'                                         => 'et',
    'evropskaunija'                                    => 'qu',
    'falklandskiotoki'                                 => 'fk',
    'ferskiotoki'                                      => 'fo',
    'fidži'                                           => 'fj',
    'filipini'                                         => 'ph',
    'finska'                                           => 'fi',
    'francija'                                         => 'fr',
    'francoskagvajana'                                 => 'gf',
    'francoskapolinezija'                              => 'pf',
    'francoskojužnoozemlje'                           => 'tf',
    'frenchsouthernandantarcticterritories'            => 'fq',
    'gabon'                                            => 'ga',
    'gambija'                                          => 'gm',
    'gana'                                             => 'gh',
    'gibraltar'                                        => 'gi',
    'grenada'                                          => 'gd',
    'grenlandija'                                      => 'gl',
    'gruzija'                                          => 'ge',
    'grčija'                                          => 'gr',
    'guam'                                             => 'gu',
    'guernsey'                                         => 'gg',
    'gvadalupe'                                        => 'gp',
    'gvajana'                                          => 'gy',
    'gvatemala'                                        => 'gt',
    'gvineja'                                          => 'gn',
    'gvinejabissau'                                    => 'gw',
    'haiti'                                            => 'ht',
    'honduras'                                         => 'hn',
    'hrvaška'                                         => 'hr',
    'indija'                                           => 'in',
    'indonezija'                                       => 'id',
    'irak'                                             => 'iq',
    'iran'                                             => 'ir',
    'irska'                                            => 'ie',
    'islandija'                                        => 'is',
    'italija'                                          => 'it',
    'izrael'                                           => 'il',
    'jamajka'                                          => 'jm',
    'japonska'                                         => 'jp',
    'jemen'                                            => 'ye',
    'jersey'                                           => 'je',
    'johnstonisland'                                   => 'jt',
    'jordanija'                                        => 'jo',
    'južnageorgiainjužnisandwicheviotoki'            => 'gs',
    'južnakoreja'                                     => 'kr',
    'južnoafriškarepublika'                          => 'za',
    'kajmanskiotoki'                                   => 'ky',
    'kambodža'                                        => 'kh',
    'kamerun'                                          => 'cm',
    'kanada'                                           => 'ca',
    'katar'                                            => 'qa',
    'kazahstan'                                        => 'kz',
    'kenija'                                           => 'ke',
    'kirgizistan'                                      => 'kg',
    'kiribati'                                         => 'ki',
    'kitajska'                                         => 'cn',
    'kokosoviotoki'                                    => 'cc',
    'kolumbija'                                        => 'co',
    'komori'                                           => 'km',
    'kongo'                                            => 'cg',
    'kostarika'                                        => 'cr',
    'kuba'                                             => 'cu',
    'kuvajt'                                           => 'kw',
    'laos'                                             => 'la',
    'latvija'                                          => 'lv',
    'lesoto'                                           => 'ls',
    'libanon'                                          => 'lb',
    'liberija'                                         => 'lr',
    'libija'                                           => 'ly',
    'lihtenštajn'                                     => 'li',
    'litva'                                            => 'lt',
    'luksemburg'                                       => 'lu',
    'madagaskar'                                       => 'mg',
    'madžarska'                                       => 'hu',
    'makedonija'                                       => 'mk',
    'malavi'                                           => 'mw',
    'maldivi'                                          => 'mv',
    'malezija'                                         => 'my',
    'mali'                                             => 'ml',
    'malta'                                            => 'mt',
    'maroko'                                           => 'ma',
    'marshalloviotoki'                                 => 'mh',
    'martinik'                                         => 'mq',
    'mauritius'                                        => 'mu',
    'mavretanija'                                      => 'mr',
    'mayotte'                                          => 'yt',
    'mehika'                                           => 'mx',
    'metropolitanfrance'                               => 'fx',
    'midwayislands'                                    => 'mi',
    'mikronezija'                                      => 'fm',
    'mjanmar'                                          => 'mm',
    'moldavija'                                        => 'md',
    'monako'                                           => 'mc',
    'mongolija'                                        => 'mn',
    'montserrat'                                       => 'ms',
    'mozambik'                                         => 'mz',
    'namibija'                                         => 'na',
    'nauru'                                            => 'nr',
    'nemčija'                                         => 'de',
    'nepal'                                            => 'np',
    'neutralzone'                                      => 'nt',
    'neznanoalineveljavnoobmočje'                     => 'zz',
    'niger'                                            => 'ne',
    'nigerija'                                         => 'ng',
    'nikaragva'                                        => 'ni',
    'niue'                                             => 'nu',
    'nizozemska'                                       => 'nl',
    'nizozemskiantili'                                 => 'an',
    'norfolškiotok'                                   => 'nf',
    'northvietnam'                                     => 'vd',
    'norveška'                                        => 'no',
    'novakaledonija'                                   => 'nc',
    'novazelandija'                                    => 'nz',
    'oman'                                             => 'om',
    'ostalaoceanija'                                   => 'qo',
    'otokheardinotočjemcdonald'                       => 'hm',
    'otokman'                                          => 'im',
    'otočjiturksincaicos'                             => 'tc',
    'pacificislandstrustterritory'                     => 'pc',
    'pakistan'                                         => 'pk',
    'palau'                                            => 'pw',
    'palestinskoozemlje'                               => 'ps',
    'panama'                                           => 'pa',
    'panamacanalzone'                                  => 'pz',
    'papuanovagvineja'                                 => 'pg',
    'paragvaj'                                         => 'py',
    'peoplesdemocraticrepublicofyemen'                 => 'yd',
    'peru'                                             => 'pe',
    'pitcairn'                                         => 'pn',
    'poljska'                                          => 'pl',
    'portoriko'                                        => 'pr',
    'portugalska'                                      => 'pt',
    'posebnoadministrativnoobmočjelrkitajskehongkong' => 'hk',
    'posebnoadministrativnoobmočjelrkitajskemacao'    => 'mo',
    'reunion'                                          => 're',
    'romunija'                                         => 'ro',
    'ruanda'                                           => 'rw',
    'rusija'                                           => 'ru',
    'saintbarthelemy'                                  => 'bl',
    'saintkittsinnevis'                                => 'kn',
    'saintlucia'                                       => 'lc',
    'saintmartin'                                      => 'mf',
    'saintpierreinmiquelon'                            => 'pm',
    'saintvincentingrenadine'                          => 'vc',
    'salomonoviotoki'                                  => 'sb',
    'salvador'                                         => 'sv',
    'samoa'                                            => 'ws',
    'sanmarino'                                        => 'sm',
    'saotomeinprincipe'                                => 'st',
    'saudovaarabija'                                   => 'sa',
    'sejšeli'                                         => 'sc',
    'senegal'                                          => 'sn',
    'severnakoreja'                                    => 'kp',
    'severnimarianskiotoki'                            => 'mp',
    'sierraleone'                                      => 'sl',
    'singapur'                                         => 'sg',
    'sirija'                                           => 'sy',
    'slonokoščenaobala'                              => 'ci',
    'slovaška'                                        => 'sk',
    'slovenija'                                        => 'si',
    'somalija'                                         => 'so',
    'srbija'                                           => 'rs',
    'srbijainČrnagora'                                => 'cs',
    'sudan'                                            => 'sd',
    'surinam'                                          => 'sr',
    'svalbardinjanmayen'                               => 'sj',
    'svazi'                                            => 'sz',
    'svetahelena'                                      => 'sh',
    'tadžikistan'                                     => 'tj',
    'tajska'                                           => 'th',
    'tajvan'                                           => 'tw',
    'tanzanija'                                        => 'tz',
    'togo'                                             => 'tg',
    'tokelau'                                          => 'tk',
    'tonga'                                            => 'to',
    'trinidadintobago'                                 => 'tt',
    'tunizija'                                         => 'tn',
    'turkmenistan'                                     => 'tm',
    'turčija'                                         => 'tr',
    'tuvalu'                                           => 'tv',
    "u\.s\.miscellaneouspacificislands"                => 'pu',
    'uganda'                                           => 'ug',
    'ukrajina'                                         => 'ua',
    'unionofsovietsocialistrepublics'                  => 'su',
    'urugvaj'                                          => 'uy',
    'uzbekistan'                                       => 'uz',
    'vanuatu'                                          => 'vu',
    'vatikan'                                          => 'va',
    'velikabritanija'                                  => 'gb',
    'venezuela'                                        => 've',
    'vietnam'                                          => 'vn',
    'vzhodnitimor'                                     => 'tl',
    'wakeisland'                                       => 'wk',
    'wallisinfutuna'                                   => 'wf',
    'zahodnasahara'                                    => 'eh',
    'zambija'                                          => 'zm',
    'združenedržaveamerike'                          => 'us',
    'združeniarabskiemirati'                          => 'ae',
    'zelenortskiotoki'                                 => 'cv',
    'zimbabve'                                         => 'zw',
    'Čad'                                             => 'td',
    'Češka'                                          => 'cz',
    'Čile'                                            => 'cl',
    'Črnagora'                                        => 'me',
    'Španija'                                         => 'es',
    'Šrilanka'                                        => 'lk',
    'Švedska'                                         => 'se',
    'Švica'                                           => 'ch',
);

1;

