package Locales::DB::Territory::ga;

# Auto generated from CLDR

$Locales::DB::Territory::ga::VERSION = '0.02';

$Locales::DB::Territory::ga::cldr_version = '1.7.1';

%Locales::DB::Territory::ga::code_to_name = (
    'ad' => 'Andóra',
    'ae' => "Aontas\ na\ nÉimíríochtaí\ Arabacha",
    'af' => "An\ Afganastáin",
    'ag' => "Aintíge\ agus\ Barbúda",
    'ai' => 'Anguilla',
    'al' => "An\ Albáin",
    'am' => "An\ Airméin",
    'an' => "Antillí\ na\ hÍsiltíre",
    'ao' => 'Angóla',
    'aq' => "An\ Antartaice",
    'ar' => "An\ Airgintín",
    'as' => "Samó\ Meiriceánach",
    'at' => "An\ Ostair",
    'au' => "An\ Astráil",
    'aw' => 'Arúba',
    'ax' => "Oileáin\ Alaind",
    'az' => "An\ Asarbaiseáin",
    'ba' => "An\ Bhoisnia\ agus\ Heirseagóvéin",
    'bb' => 'Barbadós',
    'bd' => "An\ Bhanglaidéis",
    'be' => "An\ Bheilg",
    'bf' => "Buircíne\ Fasó",
    'bg' => "An\ Bhulgáir",
    'bh' => 'Bairéin',
    'bi' => "An\ Bhurúin",
    'bj' => 'Beinin',
    'bl' => "Saint\ Barth\Ã\©lemy",
    'bm' => 'Beirmiúda',
    'bn' => 'Brúiné',
    'bo' => "An\ Bholaiv",
    'bq' => "British\ Antarctic\ Territory",
    'br' => "An\ Bhrasaíl",
    'bs' => "Na\ Bahámaí",
    'bt' => "An\ Bhútáin",
    'bv' => "Oileán\ Bouvet",
    'bw' => "An\ Bhotsuáin",
    'by' => "An\ Bhealarúis",
    'bz' => "An\ Bheilís",
    'ca' => 'Ceanada',
    'cc' => "Oileáin\ na\ gCócónna",
    'cd' => "Poblacht\ Dhaonlathach\ an\ Chongó",
    'cf' => "Poblacht\ na\ hAfraice\ Láir",
    'cg' => "An\ Congó",
    'ch' => "An\ Eilvéis",
    'ci' => "An\ Cósta\ Eabhair",
    'ck' => "Oileáin\ Cook",
    'cl' => "An\ tSile",
    'cm' => 'Camarún',
    'cn' => "An\ tSín",
    'co' => "An\ Cholóim",
    'cr' => "Cósta\ Ríce",
    'cs' => "An\ tSeirbia\ agus\ Montainéagró",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Cúba',
    'cv' => "An\ Rinn\ Ghlas",
    'cx' => "Oileán\ na\ Nollag",
    'cy' => "An\ Chipir",
    'cz' => "Poblacht\ na\ Seice",
    'dd' => "East\ Germany",
    'de' => "An\ Ghearmáin",
    'dj' => 'Djibouti',
    'dk' => "An\ Danmhairg",
    'dm' => 'Doiminice',
    'do' => "An\ Phoblacht\ Dhoiminiceach",
    'dz' => "An\ Ailgéir",
    'ec' => 'Eacuadór',
    'ee' => "An\ Eastóin",
    'eg' => "An\ Éigipt",
    'eh' => "An\ Sahára\ Thiar",
    'er' => "An\ Eiritré",
    'es' => "An\ Spáinn",
    'et' => "An\ Aetóip",
    'fi' => "An\ Fhionlainn",
    'fj' => 'Fidsí',
    'fk' => "Oileáin\ Fháclainne",
    'fm' => "An\ Mhicrinéis",
    'fo' => "Oileáin\ Fharó",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => "An\ Fhrainc",
    'fx' => "Metropolitan\ France",
    'ga' => "An\ Ghabúin",
    'gb' => "An\ Ríocht\ Aontaithe",
    'gd' => 'Grenada',
    'ge' => "An\ tSeoirsia",
    'gf' => "An\ Ghuáin\ Fhrancach",
    'gg' => 'Geansaí',
    'gh' => 'Gána',
    'gi' => 'Giobráltar',
    'gl' => "An\ Ghraonlainn",
    'gm' => "An\ Ghaimbia",
    'gn' => "An\ Ghuine",
    'gp' => 'Guadalúip',
    'gq' => "An\ Ghuine\ Mheánchriosach",
    'gr' => "An\ Ghréig",
    'gs' => "An\ tSeoirsia\ Theas\ agus\ Oileáin\ Sandwich\ Theas",
    'gt' => 'Guatamala',
    'gu' => 'Guam',
    'gw' => "An\ Ghuine\-Bhissau",
    'gy' => "An\ Ghuáin",
    'hk' => "Hong\ Cong",
    'hm' => "Oileán\ Heard\ agus\ Oileáin\ McDonald",
    'hn' => 'Hondúras',
    'hr' => "An\ Chróit",
    'ht' => 'Háití',
    'hu' => "An\ Ungáir",
    'id' => "An\ Indinéis",
    'ie' => 'Éire',
    'il' => 'Iosrael',
    'im' => "Oileán\ Mhanann",
    'in' => "An\ India",
    'io' => "Críocha\ Briotanacha\ an\ Aigéin\ Indiagh",
    'iq' => "An\ Iaráic",
    'ir' => "An\ Iaráin",
    'is' => "An\ Íoslainn",
    'it' => "An\ Iodáil",
    'je' => 'Geirsí',
    'jm' => 'Iamáice',
    'jo' => "An\ Iordáin",
    'jp' => "An\ tSeapáin",
    'jt' => "Johnston\ Island",
    'ke' => "An\ Chéinia",
    'kg' => "An\ Chirgeastáin",
    'kh' => "An\ Chambóid",
    'ki' => 'Ciribeas',
    'km' => "Oileáin\ Chomóra",
    'kn' => "Saint\ Kitts\ agus\ Nevis",
    'kp' => "An\ Chóiré\ Thuaidh",
    'kr' => "An\ Chóiré\ Theas",
    'kw' => 'Cuáit',
    'ky' => "Oileáin\ na\ gCadhman",
    'kz' => "An\ Chasacstáin",
    'la' => 'Laos',
    'lb' => "An\ Liobáin",
    'lc' => "San\ Lúisia",
    'li' => 'Lichtinstéin',
    'lk' => "Srí\ Lanca",
    'lr' => "An\ Libéir",
    'ls' => 'Leosóta',
    'lt' => "An\ Liotuáin",
    'lu' => 'Lucsamburg',
    'lv' => "An\ Laitvia",
    'ly' => "An\ Libia",
    'ma' => 'Maracó',
    'mc' => 'Monacó',
    'md' => "An\ Mholdóiv",
    'me' => 'Montainéagró',
    'mf' => "Saint\ Martin",
    'mg' => 'Madagascar',
    'mh' => "Oileáin\ Marshall",
    'mi' => "Midway\ Islands",
    'mk' => "An\ Mhacadóin",
    'ml' => 'Mailí',
    'mm' => 'Maenmar',
    'mn' => "An\ Mhongóil",
    'mo' => 'Macáó',
    'mp' => "Oileáin\ Mariana\ Thuaidh",
    'mq' => 'Martainíc',
    'mr' => "An\ Mharatáin",
    'ms' => 'Montsarat',
    'mt' => 'Málta',
    'mu' => "Oileán\ Mhuirís",
    'mv' => "Na\ Maildiví",
    'mw' => "An\ Mhaláiv",
    'mx' => 'Meicsiceo',
    'my' => "An\ Mhalaeisia",
    'mz' => 'Mósaimbíc',
    'na' => "An\ Namaib",
    'nc' => "An\ Nua\-Chaladóin",
    'ne' => "An\ Nígir",
    'nf' => "Oileán\ Norfolk",
    'ng' => "An\ Nigéir",
    'ni' => 'Nicearagua',
    'nl' => "An\ Ísiltír",
    'no' => "An\ Iorua",
    'np' => 'Neipeal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nárú',
    'nt' => "Neutral\ Zone",
    'nu' => 'Nívé',
    'nz' => "An\ Nua\-Shéalainn",
    'om' => 'Óman',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Peiriú',
    'pf' => "An\ Pholainéis\ Fhrancach",
    'pg' => "Nua\-Ghuine\ Phapua",
    'ph' => "Na\ hOileáin\ Fhilipíneacha",
    'pk' => "An\ Phacastáin",
    'pl' => "An\ Pholainn",
    'pm' => "Saint\ Pierre\ agus\ Miquelon",
    'pn' => 'Pitcairn',
    'pr' => "Portó\ Ríce",
    'ps' => "Na\ Críocha\ Pailistíneacha",
    'pt' => "An\ Phortaingéil",
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paragua',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Catar',
    'qo' => "An\ Aigéine\ Imeallach",
    'qu' => "An\ tAontas\ Eorpach",
    're' => 'Réunion',
    'ro' => "An\ Rómáin",
    'rs' => "An\ tSeirbia",
    'ru' => "Cónaidhm\ na\ Rúise",
    'rw' => 'Ruanda',
    'sa' => "An\ Araib\ Shádach",
    'sb' => "Oileáin\ Sholaimh",
    'sc' => "Na\ Séiséil",
    'sd' => "An\ tSúdáin",
    'se' => "An\ tSualainn",
    'sg' => 'Singeapór',
    'sh' => "San\ Héilin",
    'si' => "An\ tSlóvéin",
    'sj' => "Svalbard\ agus\ Jan\ Mayen",
    'sk' => "An\ tSlóvaic",
    'sl' => "Siarra\ Leon",
    'sm' => "San\ Mairíne",
    'sn' => "An\ tSeineagáil",
    'so' => "An\ tSomáil",
    'sr' => 'Suranam',
    'st' => "Sao\ Tome\ agus\ Principe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "An\ tSalvadóir",
    'sy' => "An\ tSiria",
    'sz' => "An\ tSuasalainn",
    'tc' => "Oileáin\ Turks\ agus\ Caicos",
    'td' => 'Sead',
    'tf' => "Críocha\ Deisceartacha\ na\ Fraince",
    'tg' => 'Tóga',
    'th' => "An\ Téalainn",
    'tj' => "An\ Táidsíceastáin",
    'tk' => 'Tócalá',
    'tl' => "Tíomór\ Thoir",
    'tm' => "An\ Tuircméanastáin",
    'tn' => "An\ Túinéis",
    'to' => 'Tonga',
    'tr' => "An\ Tuirc",
    'tt' => "Oileáin\ na\ Tríonóide\ agus\ Tobága",
    'tv' => 'Túválú',
    'tw' => "An\ Téaváin",
    'tz' => "An\ Tansáin",
    'ua' => "An\ Úcráin",
    'ug' => 'Úganda',
    'um' => "Mion\-Oileáin\ Imeallacha\ S\.A\.M\.",
    'us' => "Stáit\ Aontaithe\ Mheiriceá",
    'uy' => 'Urugua',
    'uz' => 'Úisbéiceastáin',
    'va' => "An\ Vatacáin",
    'vc' => "Saint\ Vincent\ agus\ na\ Grenadines",
    'vd' => "North\ Vietnam",
    've' => 'Veiniséala',
    'vg' => "Oileáin\ Bhriotanacha\ na\ Maighdean",
    'vi' => "Oileáin\ na\ Maighdean\ S\.A\.M\.",
    'vn' => "Vít\ Neam",
    'vu' => 'Vanuatú',
    'wf' => "Oileáin\ Vailís\ agus\ Futúna",
    'wk' => "Wake\ Island",
    'ws' => 'Samó',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Éimin',
    'yt' => 'Mayotte',
    'za' => "An\ Afraic\ Theas",
    'zm' => "An\ tSaimbia",
    'zw' => "An\ tSiombáib",
    'zz' => "Réigiún\ Anaithnid\ nó\ Neamhbhailí",
);

%Locales::DB::Territory::ga::name_to_code = (
    'aintígeagusbarbúda'                      => 'ag',
    'anaetóip'                                 => 'et',
    'anafganastáin'                            => 'af',
    'anafraictheas'                             => 'za',
    'anaigéineimeallach'                       => 'qo',
    'anailgéir'                                => 'dz',
    'anairgintín'                              => 'ar',
    'anairméin'                                => 'am',
    'analbáin'                                 => 'al',
    'anantartaice'                              => 'aq',
    'anaraibshádach'                           => 'sa',
    'anasarbaiseáin'                           => 'az',
    'anastráil'                                => 'au',
    'anbhanglaidéis'                           => 'bd',
    'anbhealarúis'                             => 'by',
    'anbheilg'                                  => 'be',
    'anbheilís'                                => 'bz',
    'anbhoisniaagusheirseagóvéin'             => 'ba',
    'anbholaiv'                                 => 'bo',
    'anbhotsuáin'                              => 'bw',
    'anbhrasaíl'                               => 'br',
    'anbhulgáir'                               => 'bg',
    'anbhurúin'                                => 'bi',
    'anbhútáin'                               => 'bt',
    'anchambóid'                               => 'kh',
    'anchasacstáin'                            => 'kz',
    'anchipir'                                  => 'cy',
    'anchirgeastáin'                           => 'kg',
    'ancholóim'                                => 'co',
    'anchróit'                                 => 'hr',
    'anchéinia'                                => 'ke',
    'anchóirétheas'                           => 'kr',
    'anchóiréthuaidh'                         => 'kp',
    'ancongó'                                  => 'cg',
    'ancóstaeabhair'                           => 'ci',
    'andanmhairg'                               => 'dk',
    'andóra'                                   => 'ad',
    'aneastóin'                                => 'ee',
    'aneilvéis'                                => 'ch',
    'aneiritré'                                => 'er',
    'anfhionlainn'                              => 'fi',
    'anfhrainc'                                 => 'fr',
    'anghabúin'                                => 'ga',
    'anghaimbia'                                => 'gm',
    'anghearmáin'                              => 'de',
    'anghraonlainn'                             => 'gl',
    'anghréig'                                 => 'gr',
    'anghuine'                                  => 'gn',
    'anghuinebhissau'                           => 'gw',
    'anghuinemheánchriosach'                   => 'gq',
    'anghuáin'                                 => 'gy',
    'anghuáinfhrancach'                        => 'gf',
    'anguilla'                                  => 'ai',
    'angóla'                                   => 'ao',
    'aniaráic'                                 => 'iq',
    'aniaráin'                                 => 'ir',
    'anindia'                                   => 'in',
    'anindinéis'                               => 'id',
    'aniodáil'                                 => 'it',
    'aniordáin'                                => 'jo',
    'aniorua'                                   => 'no',
    'anlaitvia'                                 => 'lv',
    'anlibia'                                   => 'ly',
    'anlibéir'                                 => 'lr',
    'anliobáin'                                => 'lb',
    'anliotuáin'                               => 'lt',
    'anmhacadóin'                              => 'mk',
    'anmhalaeisia'                              => 'my',
    'anmhaláiv'                                => 'mw',
    'anmharatáin'                              => 'mr',
    'anmhicrinéis'                             => 'fm',
    'anmholdóiv'                               => 'md',
    'anmhongóil'                               => 'mn',
    'annamaib'                                  => 'na',
    'annigéir'                                 => 'ng',
    'annuachaladóin'                           => 'nc',
    'annuashéalainn'                           => 'nz',
    'annígir'                                  => 'ne',
    'anostair'                                  => 'at',
    'anphacastáin'                             => 'pk',
    'anphoblachtdhoiminiceach'                  => 'do',
    'anpholainn'                                => 'pl',
    'anpholainéisfhrancach'                    => 'pf',
    'anphortaingéil'                           => 'pt',
    'anrinnghlas'                               => 'cv',
    'anríochtaontaithe'                        => 'gb',
    'anrómáin'                                => 'ro',
    'ansahárathiar'                            => 'eh',
    'anspáinn'                                 => 'es',
    'antansáin'                                => 'tz',
    'antaontaseorpach'                          => 'qu',
    'antillínahÍsiltíre'                     => 'an',
    'antsaimbia'                                => 'zm',
    'antsalvadóir'                             => 'sv',
    'antseapáin'                               => 'jp',
    'antseineagáil'                            => 'sn',
    'antseirbia'                                => 'rs',
    'antseirbiaagusmontainéagró'              => 'cs',
    'antseoirsia'                               => 'ge',
    'antseoirsiatheasagusoileáinsandwichtheas' => 'gs',
    'antsile'                                   => 'cl',
    'antsiombáib'                              => 'zw',
    'antsiria'                                  => 'sy',
    'antslóvaic'                               => 'sk',
    'antslóvéin'                              => 'si',
    'antsomáil'                                => 'so',
    'antsualainn'                               => 'se',
    'antsuasalainn'                             => 'sz',
    'antsín'                                   => 'cn',
    'antsúdáin'                               => 'sd',
    'antuirc'                                   => 'tr',
    'antuircméanastáin'                       => 'tm',
    'antáidsíceastáin'                       => 'tj',
    'antéalainn'                               => 'th',
    'antéaváin'                               => 'tw',
    'antúinéis'                               => 'tn',
    'anungáir'                                 => 'hu',
    'anvatacáin'                               => 'va',
    'anÉigipt'                                 => 'eg',
    'anÍoslainn'                               => 'is',
    'anÍsiltír'                               => 'nl',
    'anÚcráin'                                => 'ua',
    'aontasnanÉimíríochtaíarabacha'         => 'ae',
    'arúba'                                    => 'aw',
    'bairéin'                                  => 'bh',
    'barbadós'                                 => 'bb',
    'beinin'                                    => 'bj',
    'beirmiúda'                                => 'bm',
    'britishantarcticterritory'                 => 'bq',
    'brúiné'                                  => 'bn',
    'buircínefasó'                            => 'bf',
    'camarún'                                  => 'cm',
    'cantonandenderburyislands'                 => 'ct',
    'catar'                                     => 'qa',
    'ceanada'                                   => 'ca',
    'ciribeas'                                  => 'ki',
    'críochabriotanachaanaigéinindiagh'       => 'io',
    'críochadeisceartachanafraince'            => 'tf',
    'cuáit'                                    => 'kw',
    'cónaidhmnarúise'                         => 'ru',
    'cóstaríce'                               => 'cr',
    'cúba'                                     => 'cu',
    'djibouti'                                  => 'dj',
    'doiminice'                                 => 'dm',
    'dronningmaudland'                          => 'nq',
    'eacuadór'                                 => 'ec',
    'eastgermany'                               => 'dd',
    'fidsí'                                    => 'fj',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'geansaí'                                  => 'gg',
    'geirsí'                                   => 'je',
    'giobráltar'                               => 'gi',
    'grenada'                                   => 'gd',
    'guadalúip'                                => 'gp',
    'guam'                                      => 'gu',
    'guatamala'                                 => 'gt',
    'gána'                                     => 'gh',
    'hondúras'                                 => 'hn',
    'hongcong'                                  => 'hk',
    'háití'                                   => 'ht',
    'iamáice'                                  => 'jm',
    'iosrael'                                   => 'il',
    'johnstonisland'                            => 'jt',
    'laos'                                      => 'la',
    'leosóta'                                  => 'ls',
    'lichtinstéin'                             => 'li',
    'lucsamburg'                                => 'lu',
    'macáó'                                   => 'mo',
    'madagascar'                                => 'mg',
    'maenmar'                                   => 'mm',
    'mailí'                                    => 'ml',
    'maracó'                                   => 'ma',
    'martainíc'                                => 'mq',
    'mayotte'                                   => 'yt',
    'meicsiceo'                                 => 'mx',
    'metropolitanfrance'                        => 'fx',
    'midwayislands'                             => 'mi',
    "mionoileáinimeallachas\.a\.m\."           => 'um',
    'monacó'                                   => 'mc',
    'montainéagró'                            => 'me',
    'montsarat'                                 => 'ms',
    'málta'                                    => 'mt',
    'mósaimbíc'                               => 'mz',
    'nabahámaí'                               => 'bs',
    'nacríochapailistíneacha'                 => 'ps',
    'nahoileáinfhilipíneacha'                 => 'ph',
    'namaildiví'                               => 'mv',
    'naséiséil'                               => 'sc',
    'neipeal'                                   => 'np',
    'neutralzone'                               => 'nt',
    'nicearagua'                                => 'ni',
    'northvietnam'                              => 'vd',
    'nuaghuinephapua'                           => 'pg',
    'nárú'                                    => 'nr',
    'nívé'                                    => 'nu',
    'oileáinalaind'                            => 'ax',
    'oileáinbhriotanachanamaighdean'           => 'vg',
    'oileáinchomóra'                          => 'km',
    'oileáincook'                              => 'ck',
    'oileáinfharó'                            => 'fo',
    'oileáinfháclainne'                       => 'fk',
    'oileáinmarianathuaidh'                    => 'mp',
    'oileáinmarshall'                          => 'mh',
    'oileáinnagcadhman'                        => 'ky',
    'oileáinnagcócónna'                      => 'cc',
    "oileáinnamaighdeans\.a\.m\."              => 'vi',
    'oileáinnatríonóideagustobága'          => 'tt',
    'oileáinsholaimh'                          => 'sb',
    'oileáinturksaguscaicos'                   => 'tc',
    'oileáinvailísagusfutúna'                => 'wf',
    'oileánbouvet'                             => 'bv',
    'oileánheardagusoileáinmcdonald'          => 'hm',
    'oileánmhanann'                            => 'im',
    'oileánmhuirís'                           => 'mu',
    'oileánnanollag'                           => 'cx',
    'oileánnorfolk'                            => 'nf',
    'pacificislandstrustterritory'              => 'pc',
    'palau'                                     => 'pw',
    'panama'                                    => 'pa',
    'panamacanalzone'                           => 'pz',
    'paragua'                                   => 'py',
    'peiriú'                                   => 'pe',
    'peoplesdemocraticrepublicofyemen'          => 'yd',
    'pitcairn'                                  => 'pn',
    'poblachtdhaonlathachanchongó'             => 'cd',
    'poblachtnahafraiceláir'                   => 'cf',
    'poblachtnaseice'                           => 'cz',
    'portóríce'                               => 'pr',
    'ruanda'                                    => 'rw',
    'réigiúnanaithnidnóneamhbhailí'         => 'zz',
    'réunion'                                  => 're',
    "saintbarth\Ã\©lemy"                      => 'bl',
    'saintkittsagusnevis'                       => 'kn',
    'saintmartin'                               => 'mf',
    'saintpierreagusmiquelon'                   => 'pm',
    'saintvincentagusnagrenadines'              => 'vc',
    'samó'                                     => 'ws',
    'samómeiriceánach'                        => 'as',
    'sanhéilin'                                => 'sh',
    'sanlúisia'                                => 'lc',
    'sanmairíne'                               => 'sm',
    'saotomeagusprincipe'                       => 'st',
    'sead'                                      => 'td',
    'siarraleon'                                => 'sl',
    'singeapór'                                => 'sg',
    'srílanca'                                 => 'lk',
    'stáitaontaithemheiriceá'                 => 'us',
    'suranam'                                   => 'sr',
    'svalbardagusjanmayen'                      => 'sj',
    'tonga'                                     => 'to',
    'tíomórthoir'                             => 'tl',
    'tócalá'                                  => 'tk',
    'tóga'                                     => 'tg',
    'túválú'                                 => 'tv',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'unionofsovietsocialistrepublics'           => 'su',
    'urugua'                                    => 'uy',
    'vanuatú'                                  => 'vu',
    'veiniséala'                               => 've',
    'vítneam'                                  => 'vn',
    'wakeisland'                                => 'wk',
    'Éimin'                                    => 'ye',
    'Éire'                                     => 'ie',
    'Óman'                                     => 'om',
    'Úganda'                                   => 'ug',
    'Úisbéiceastáin'                         => 'uz',
);

1;

