package Locales::DB::Territory::hu;

# Auto generated from CLDR

$Locales::DB::Territory::hu::VERSION = '0.02';

$Locales::DB::Territory::hu::cldr_version = '1.7.1';

%Locales::DB::Territory::hu::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "Egyesült\ Arab\ Emirátus",
    'af' => 'Afganisztán',
    'ag' => "Antigua\ és\ Barbuda",
    'ai' => 'Anguilla',
    'al' => 'Albánia',
    'am' => 'Örményország',
    'an' => "Holland\ Antillák",
    'ao' => 'Angola',
    'aq' => 'Antarktisz',
    'ar' => 'Argentína',
    'as' => "Amerikai\ Szamoa",
    'at' => 'Ausztria',
    'au' => 'Ausztrália',
    'aw' => 'Aruba',
    'ax' => "Aland\-szigetek",
    'az' => 'Azerbajdzsán',
    'ba' => "Bosznia\-Hercegovina",
    'bb' => 'Barbados',
    'bd' => 'Banglades',
    'be' => 'Belgium',
    'bf' => "Burkina\ Faso",
    'bg' => 'Bulgária',
    'bh' => 'Bahrein',
    'bi' => 'Burundi',
    'bj' => 'Benin',
    'bl' => "Saint\ Barthélemy",
    'bm' => 'Bermuda',
    'bn' => 'Brunei',
    'bo' => 'Bolívia',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brazília',
    'bs' => 'Bahamák',
    'bt' => 'Bhután',
    'bv' => "Bouvet\-sziget",
    'bw' => 'Botswana',
    'by' => 'Fehéroroszország',
    'bz' => 'Belize',
    'ca' => 'Kanada',
    'cc' => "Kókusz\-szigetek",
    'cd' => "Kongó\ \-\ Kinshasa",
    'cf' => "Közép\-afrikai\ Köztársaság",
    'cg' => 'Kongó',
    'ch' => 'Svájc',
    'ci' => 'Elefántcsontpart',
    'ck' => "Cook\-szigetek",
    'cl' => 'Chile',
    'cm' => 'Kamerun',
    'cn' => 'Kína',
    'co' => 'Kolumbia',
    'cr' => "Costa\ Rica",
    'cs' => "Szerbia\ és\ Montenegró",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Kuba',
    'cv' => "Zöld\-foki\ Köztársaság",
    'cx' => "Karácsony\-szigetek",
    'cy' => 'Ciprus',
    'cz' => 'Csehország',
    'dd' => "East\ Germany",
    'de' => 'Németország',
    'dj' => 'Dzsibuti',
    'dk' => 'Dánia',
    'dm' => 'Dominika',
    'do' => "Dominikai\ Köztársaság",
    'dz' => 'Algéria',
    'ec' => 'Ecuador',
    'ee' => 'Észtország',
    'eg' => 'Egyiptom',
    'eh' => "Nyugat\-Szahara",
    'er' => 'Eritrea',
    'es' => 'Spanyolország',
    'et' => 'Etiópia',
    'fi' => 'Finnország',
    'fj' => 'Fidzsi',
    'fk' => "Falkland\-szigetek",
    'fm' => 'Mikronézia',
    'fo' => "Feröer\-szigetek",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Franciaország',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabon',
    'gb' => "Egyesült\ Királyság",
    'gd' => 'Grenada',
    'ge' => 'Grúzia',
    'gf' => "Francia\ Guyana",
    'gg' => 'Guernsey',
    'gh' => 'Ghána',
    'gi' => 'Gibraltár',
    'gl' => 'Grönland',
    'gm' => 'Gambia',
    'gn' => 'Guinea',
    'gp' => 'Guadeloupe',
    'gq' => "Egyenlítői\-Guinea",
    'gr' => 'Görögország',
    'gs' => "Dél\ Grúzia\ és\ a\ Déli\ Szendvics\-szigetek",
    'gt' => 'Guatemala',
    'gu' => 'Guam',
    'gw' => "Guinea\-Bissau",
    'gy' => 'Guyana',
    'hk' => 'Hongkong',
    'hm' => "Heard\ és\ McDonald\ Szigetek",
    'hn' => 'Honduras',
    'hr' => 'Horvátország',
    'ht' => 'Haiti',
    'hu' => 'Magyarország',
    'id' => 'Indonézia',
    'ie' => 'Írország',
    'il' => 'Izrael',
    'im' => "Man\-sziget",
    'in' => 'India',
    'io' => "Brit\ Indiai\ Oceán",
    'iq' => 'Irak',
    'ir' => 'Irán',
    'is' => 'Izland',
    'it' => 'Olaszország',
    'je' => 'Jersey',
    'jm' => 'Jamaica',
    'jo' => 'Jordánia',
    'jp' => 'Japán',
    'jt' => "Johnston\ Island",
    'ke' => 'Kenya',
    'kg' => 'Kirgizisztán',
    'kh' => 'Kambodzsa',
    'ki' => 'Kiribati',
    'km' => "Comore\-szigetek",
    'kn' => "Saint\ Kitts\ és\ Nevis",
    'kp' => "Észak\-Korea",
    'kr' => "Dél\-Korea",
    'kw' => 'Kuvait',
    'ky' => "Kajmán\-szigetek",
    'kz' => 'Kazahsztán',
    'la' => 'Laosz',
    'lb' => 'Libanon',
    'lc' => "Santa\ Lucia",
    'li' => 'Liechtenstein',
    'lk' => "Srí\ Lanka",
    'lr' => 'Libéria',
    'ls' => 'Lesotho',
    'lt' => 'Litvánia',
    'lu' => 'Luxemburg',
    'lv' => 'Lettország',
    'ly' => 'Líbia',
    'ma' => 'Marokkó',
    'mc' => 'Monaco',
    'md' => 'Moldova',
    'me' => 'Montenegró',
    'mf' => "Saint\ Martin",
    'mg' => 'Madagaszkár',
    'mh' => "Marshall\-szigetek",
    'mi' => "Midway\ Islands",
    'mk' => 'Macedónia',
    'ml' => 'Mali',
    'mm' => 'Mianmar',
    'mn' => 'Mongólia',
    'mo' => 'Makaó',
    'mp' => "Északi\ Mariana\-szigetek",
    'mq' => 'Martinique',
    'mr' => 'Mauritánia',
    'ms' => 'Montserrat',
    'mt' => 'Málta',
    'mu' => 'Mauritius',
    'mv' => "Maldív\-szigetek",
    'mw' => 'Malawi',
    'mx' => 'Mexikó',
    'my' => 'Malajzia',
    'mz' => 'Mozambik',
    'na' => 'Namíbia',
    'nc' => "Új\-Kaledónia",
    'ne' => 'Niger',
    'nf' => "Norfolk\-sziget",
    'ng' => 'Nigéria',
    'ni' => 'Nicaragua',
    'nl' => 'Hollandia',
    'no' => 'Norvégia',
    'np' => 'Nepál',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "Új\-Zéland",
    'om' => 'Omán',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Peru',
    'pf' => "Francia\ Polinézia",
    'pg' => "Pápua\ Új\-Guinea",
    'ph' => "Fülöp\-szigetek",
    'pk' => 'Pakisztán',
    'pl' => 'Lengyelország',
    'pm' => "Saint\ Pierre\ és\ Miquelon",
    'pn' => "Pitcairn\-sziget",
    'pr' => "Puerto\ Rico",
    'ps' => "Palesztin\ Terület",
    'pt' => 'Portugália',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paraguay',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Katar',
    'qo' => "Külső\-Óceánia",
    'qu' => "Európai\ Unió",
    're' => 'Reunion',
    'ro' => 'Románia',
    'rs' => 'Szerbia',
    'ru' => 'Oroszország',
    'rw' => 'Ruanda',
    'sa' => "Szaúd\-Arábia",
    'sb' => "Salamon\-szigetek",
    'sc' => "Seychelle\-szigetek",
    'sd' => 'Szudán',
    'se' => 'Svédország',
    'sg' => 'Szingapúr',
    'sh' => "Szent\ Helena",
    'si' => 'Szlovénia',
    'sj' => "Svalbard\ és\ Jan\ Mayen",
    'sk' => 'Szlovákia',
    'sl' => "Sierra\ Leone",
    'sm' => "San\ Marino",
    'sn' => 'Szenegál',
    'so' => 'Szomália',
    'sr' => 'Suriname',
    'st' => "Sao\ Tomé\ és\ Príncipe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => 'Salvador',
    'sy' => 'Szíria',
    'sz' => 'Szváziföld',
    'tc' => "Turks\-\ és\ Caicos\-szigetek",
    'td' => 'Csád',
    'tf' => "Francia\ Déli\ Területek",
    'tg' => 'Togo',
    'th' => 'Thaiföld',
    'tj' => 'Tadzsikisztán',
    'tk' => 'Tokelau',
    'tl' => "Kelet\-Timor",
    'tm' => 'Türkmenisztán',
    'tn' => 'Tunézia',
    'to' => 'Tonga',
    'tr' => 'Törökország',
    'tt' => "Trinidad\ és\ Tobago",
    'tv' => 'Tuvalu',
    'tw' => 'Tajvan',
    'tz' => 'Tanzánia',
    'ua' => 'Ukrajna',
    'ug' => 'Uganda',
    'um' => "Amerikai\ Csendes\-óceáni\ Szigetek",
    'us' => "Egyesült\ Államok",
    'uy' => 'Uruguay',
    'uz' => 'Üzbegisztán',
    'va' => 'Vatikán',
    'vc' => "Saint\ Vincent\ és\ Grenadines",
    'vd' => "North\ Vietnam",
    've' => 'Venezuela',
    'vg' => "Brit\ Virgin\-szigetek",
    'vi' => "Amerikai\ Virgin\-szigetek",
    'vn' => 'Vietnam',
    'vu' => 'Vanuatu',
    'wf' => "Wallis\ és\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Szamoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Jemen',
    'yt' => 'Mayotte',
    'za' => "Dél\-Afrika",
    'zm' => 'Zambia',
    'zw' => 'Zimbabwe',
    'zz' => "Ismeretlen\ vagy\ érvénytelen\ körzet",
);

%Locales::DB::Territory::hu::name_to_code = (
    'afganisztán'                          => 'af',
    'alandszigetek'                         => 'ax',
    'albánia'                              => 'al',
    'algéria'                              => 'dz',
    'amerikaicsendesóceániszigetek'       => 'um',
    'amerikaiszamoa'                        => 'as',
    'amerikaivirginszigetek'                => 'vi',
    'andorra'                               => 'ad',
    'angola'                                => 'ao',
    'anguilla'                              => 'ai',
    'antarktisz'                            => 'aq',
    'antiguaésbarbuda'                     => 'ag',
    'argentína'                            => 'ar',
    'aruba'                                 => 'aw',
    'ausztria'                              => 'at',
    'ausztrália'                           => 'au',
    'azerbajdzsán'                         => 'az',
    'bahamák'                              => 'bs',
    'bahrein'                               => 'bh',
    'banglades'                             => 'bd',
    'barbados'                              => 'bb',
    'belgium'                               => 'be',
    'belize'                                => 'bz',
    'benin'                                 => 'bj',
    'bermuda'                               => 'bm',
    'bhután'                               => 'bt',
    'bolívia'                              => 'bo',
    'boszniahercegovina'                    => 'ba',
    'botswana'                              => 'bw',
    'bouvetsziget'                          => 'bv',
    'brazília'                             => 'br',
    'britindiaioceán'                      => 'io',
    'britishantarcticterritory'             => 'bq',
    'britvirginszigetek'                    => 'vg',
    'brunei'                                => 'bn',
    'bulgária'                             => 'bg',
    'burkinafaso'                           => 'bf',
    'burundi'                               => 'bi',
    'cantonandenderburyislands'             => 'ct',
    'chile'                                 => 'cl',
    'ciprus'                                => 'cy',
    'comoreszigetek'                        => 'km',
    'cookszigetek'                          => 'ck',
    'costarica'                             => 'cr',
    'csehország'                           => 'cz',
    'csád'                                 => 'td',
    'dominika'                              => 'dm',
    'dominikaiköztársaság'               => 'do',
    'dronningmaudland'                      => 'nq',
    'dzsibuti'                              => 'dj',
    'dánia'                                => 'dk',
    'délafrika'                            => 'za',
    'délgrúziaésadéliszendvicsszigetek' => 'gs',
    'délkorea'                             => 'kr',
    'eastgermany'                           => 'dd',
    'ecuador'                               => 'ec',
    'egyenlítőiguinea'                    => 'gq',
    'egyesültarabemirátus'                => 'ae',
    'egyesültkirályság'                  => 'gb',
    'egyesültÁllamok'                     => 'us',
    'egyiptom'                              => 'eg',
    'elefántcsontpart'                     => 'ci',
    'eritrea'                               => 'er',
    'etiópia'                              => 'et',
    'európaiunió'                         => 'qu',
    'falklandszigetek'                      => 'fk',
    'fehéroroszország'                    => 'by',
    'feröerszigetek'                       => 'fo',
    'fidzsi'                                => 'fj',
    'finnország'                           => 'fi',
    'franciadéliterületek'                => 'tf',
    'franciaguyana'                         => 'gf',
    'franciaország'                        => 'fr',
    'franciapolinézia'                     => 'pf',
    'frenchsouthernandantarcticterritories' => 'fq',
    'fülöpszigetek'                       => 'ph',
    'gabon'                                 => 'ga',
    'gambia'                                => 'gm',
    'ghána'                                => 'gh',
    'gibraltár'                            => 'gi',
    'grenada'                               => 'gd',
    'grönland'                             => 'gl',
    'grúzia'                               => 'ge',
    'guadeloupe'                            => 'gp',
    'guam'                                  => 'gu',
    'guatemala'                             => 'gt',
    'guernsey'                              => 'gg',
    'guinea'                                => 'gn',
    'guineabissau'                          => 'gw',
    'guyana'                                => 'gy',
    'görögország'                        => 'gr',
    'haiti'                                 => 'ht',
    'heardésmcdonaldszigetek'              => 'hm',
    'hollandantillák'                      => 'an',
    'hollandia'                             => 'nl',
    'honduras'                              => 'hn',
    'hongkong'                              => 'hk',
    'horvátország'                        => 'hr',
    'india'                                 => 'in',
    'indonézia'                            => 'id',
    'irak'                                  => 'iq',
    'irán'                                 => 'ir',
    'ismeretlenvagyérvénytelenkörzet'    => 'zz',
    'izland'                                => 'is',
    'izrael'                                => 'il',
    'jamaica'                               => 'jm',
    'japán'                                => 'jp',
    'jemen'                                 => 'ye',
    'jersey'                                => 'je',
    'johnstonisland'                        => 'jt',
    'jordánia'                             => 'jo',
    'kajmánszigetek'                       => 'ky',
    'kambodzsa'                             => 'kh',
    'kamerun'                               => 'cm',
    'kanada'                                => 'ca',
    'karácsonyszigetek'                    => 'cx',
    'katar'                                 => 'qa',
    'kazahsztán'                           => 'kz',
    'kelettimor'                            => 'tl',
    'kenya'                                 => 'ke',
    'kirgizisztán'                         => 'kg',
    'kiribati'                              => 'ki',
    'kolumbia'                              => 'co',
    'kongó'                                => 'cg',
    'kongókinshasa'                        => 'cd',
    'kuba'                                  => 'cu',
    'kuvait'                                => 'kw',
    'kína'                                 => 'cn',
    'kókuszszigetek'                       => 'cc',
    'középafrikaiköztársaság'          => 'cf',
    'külsőÓceánia'                      => 'qo',
    'laosz'                                 => 'la',
    'lengyelország'                        => 'pl',
    'lesotho'                               => 'ls',
    'lettország'                           => 'lv',
    'libanon'                               => 'lb',
    'libéria'                              => 'lr',
    'liechtenstein'                         => 'li',
    'litvánia'                             => 'lt',
    'luxemburg'                             => 'lu',
    'líbia'                                => 'ly',
    'macedónia'                            => 'mk',
    'madagaszkár'                          => 'mg',
    'magyarország'                         => 'hu',
    'makaó'                                => 'mo',
    'malajzia'                              => 'my',
    'malawi'                                => 'mw',
    'maldívszigetek'                       => 'mv',
    'mali'                                  => 'ml',
    'mansziget'                             => 'im',
    'marokkó'                              => 'ma',
    'marshallszigetek'                      => 'mh',
    'martinique'                            => 'mq',
    'mauritius'                             => 'mu',
    'mauritánia'                           => 'mr',
    'mayotte'                               => 'yt',
    'metropolitanfrance'                    => 'fx',
    'mexikó'                               => 'mx',
    'mianmar'                               => 'mm',
    'midwayislands'                         => 'mi',
    'mikronézia'                           => 'fm',
    'moldova'                               => 'md',
    'monaco'                                => 'mc',
    'mongólia'                             => 'mn',
    'montenegró'                           => 'me',
    'montserrat'                            => 'ms',
    'mozambik'                              => 'mz',
    'málta'                                => 'mt',
    'namíbia'                              => 'na',
    'nauru'                                 => 'nr',
    'nepál'                                => 'np',
    'neutralzone'                           => 'nt',
    'nicaragua'                             => 'ni',
    'niger'                                 => 'ne',
    'nigéria'                              => 'ng',
    'niue'                                  => 'nu',
    'norfolksziget'                         => 'nf',
    'northvietnam'                          => 'vd',
    'norvégia'                             => 'no',
    'nyugatszahara'                         => 'eh',
    'németország'                         => 'de',
    'olaszország'                          => 'it',
    'omán'                                 => 'om',
    'oroszország'                          => 'ru',
    'pacificislandstrustterritory'          => 'pc',
    'pakisztán'                            => 'pk',
    'palau'                                 => 'pw',
    'palesztinterület'                     => 'ps',
    'panama'                                => 'pa',
    'panamacanalzone'                       => 'pz',
    'paraguay'                              => 'py',
    'peoplesdemocraticrepublicofyemen'      => 'yd',
    'peru'                                  => 'pe',
    'pitcairnsziget'                        => 'pn',
    'portugália'                           => 'pt',
    'puertorico'                            => 'pr',
    'pápuaÚjguinea'                       => 'pg',
    'reunion'                               => 're',
    'románia'                              => 'ro',
    'ruanda'                                => 'rw',
    'saintbarthélemy'                      => 'bl',
    'saintkittsésnevis'                    => 'kn',
    'saintmartin'                           => 'mf',
    'saintpierreésmiquelon'                => 'pm',
    'saintvincentésgrenadines'             => 'vc',
    'salamonszigetek'                       => 'sb',
    'salvador'                              => 'sv',
    'sanmarino'                             => 'sm',
    'santalucia'                            => 'lc',
    'saotomééspríncipe'                  => 'st',
    'seychelleszigetek'                     => 'sc',
    'sierraleone'                           => 'sl',
    'spanyolország'                        => 'es',
    'srílanka'                             => 'lk',
    'suriname'                              => 'sr',
    'svalbardésjanmayen'                   => 'sj',
    'svájc'                                => 'ch',
    'svédország'                          => 'se',
    'szamoa'                                => 'ws',
    'szaúdarábia'                         => 'sa',
    'szenegál'                             => 'sn',
    'szenthelena'                           => 'sh',
    'szerbia'                               => 'rs',
    'szerbiaésmontenegró'                 => 'cs',
    'szingapúr'                            => 'sg',
    'szlovákia'                            => 'sk',
    'szlovénia'                            => 'si',
    'szomália'                             => 'so',
    'szudán'                               => 'sd',
    'szváziföld'                          => 'sz',
    'szíria'                               => 'sy',
    'tadzsikisztán'                        => 'tj',
    'tajvan'                                => 'tw',
    'tanzánia'                             => 'tz',
    'thaiföld'                             => 'th',
    'togo'                                  => 'tg',
    'tokelau'                               => 'tk',
    'tonga'                                 => 'to',
    'trinidadéstobago'                     => 'tt',
    'tunézia'                              => 'tn',
    'turkséscaicosszigetek'                => 'tc',
    'tuvalu'                                => 'tv',
    'törökország'                        => 'tr',
    'türkmenisztán'                       => 'tm',
    "u\.s\.miscellaneouspacificislands"     => 'pu',
    'uganda'                                => 'ug',
    'ukrajna'                               => 'ua',
    'unionofsovietsocialistrepublics'       => 'su',
    'uruguay'                               => 'uy',
    'vanuatu'                               => 'vu',
    'vatikán'                              => 'va',
    'venezuela'                             => 've',
    'vietnam'                               => 'vn',
    'wakeisland'                            => 'wk',
    'wallisésfutuna'                       => 'wf',
    'zambia'                                => 'zm',
    'zimbabwe'                              => 'zw',
    'zöldfokiköztársaság'               => 'cv',
    'Északimarianaszigetek'                => 'mp',
    'Északkorea'                           => 'kp',
    'Észtország'                          => 'ee',
    'Írország'                            => 'ie',
    'Örményország'                       => 'am',
    'Újkaledónia'                         => 'nc',
    'Újzéland'                            => 'nz',
    'Üzbegisztán'                         => 'uz',
);

1;

