package Locales::DB::Territory::tr;

# Auto generated from CLDR

$Locales::DB::Territory::tr::VERSION = '0.02';

$Locales::DB::Territory::tr::cldr_version = '1.7.1';

%Locales::DB::Territory::tr::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "Birleşik\ Arap\ Emirlikleri",
    'af' => 'Afganistan',
    'ag' => "Antigua\ ve\ Barbuda",
    'ai' => 'Anguilla',
    'al' => 'Arnavutluk',
    'am' => 'Ermenistan',
    'an' => "Hollanda\ Antilleri",
    'ao' => 'Angola',
    'aq' => 'Antarktika',
    'ar' => 'Arjantin',
    'as' => "Amerikan\ Samoası",
    'at' => 'Avusturya',
    'au' => 'Avustralya',
    'aw' => 'Aruba',
    'ax' => "Aland\ Adaları",
    'az' => 'Azerbaycan',
    'ba' => "Bosna\ Hersek",
    'bb' => 'Barbados',
    'bd' => 'Bangladeş',
    'be' => 'Belçika',
    'bf' => "Burkina\ Faso",
    'bg' => 'Bulgaristan',
    'bh' => 'Bahreyn',
    'bi' => 'Burundi',
    'bj' => 'Benin',
    'bl' => "Saint\ Barthelemy",
    'bm' => 'Bermuda',
    'bn' => 'Brunei',
    'bo' => 'Bolivya',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brezilya',
    'bs' => 'Bahamalar',
    'bt' => 'Bhutan',
    'bv' => "Bouvet\ Adası",
    'bw' => 'Botsvana',
    'by' => "Beyaz\ Rusya",
    'bz' => 'Belize',
    'ca' => 'Kanada',
    'cc' => "Cocos\ Adaları",
    'cd' => "Kongo\ \-\ Kinşasa",
    'cf' => "Orta\ Afrika\ Cumhuriyeti",
    'cg' => "Kongo\ \-\ Brazavil",
    'ch' => 'İsviçre',
    'ci' => "Fildişi\ Sahili",
    'ck' => "Cook\ Adaları",
    'cl' => 'Şili',
    'cm' => 'Kamerun',
    'cn' => 'Çin',
    'co' => 'Kolombiya',
    'cr' => "Kosta\ Rika",
    'cs' => "Sırbistan\-Karadağ",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Küba',
    'cv' => "Cape\ Verde",
    'cx' => "Christmas\ Adası",
    'cy' => "Güney\ Kıbrıs\ Rum\ Kesimi",
    'cz' => "Çek\ Cumhuriyeti",
    'dd' => "East\ Germany",
    'de' => 'Almanya',
    'dj' => 'Cibuti',
    'dk' => 'Danimarka',
    'dm' => 'Dominika',
    'do' => "Dominik\ Cumhuriyeti",
    'dz' => 'Cezayir',
    'ec' => 'Ekvador',
    'ee' => 'Estonya',
    'eg' => 'Mısır',
    'eh' => "Batı\ Sahara",
    'er' => 'Eritre',
    'es' => 'İspanya',
    'et' => 'Etiyopya',
    'fi' => 'Finlandiya',
    'fj' => 'Fiji',
    'fk' => "Falkland\ Adaları",
    'fm' => "Mikronezya\ Federal\ Eyaletleri",
    'fo' => "Faroe\ Adaları",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Fransa',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabon',
    'gb' => "Birleşik\ Krallık",
    'gd' => 'Grenada',
    'ge' => 'Gürcistan',
    'gf' => "Fransız\ Guyanası",
    'gg' => 'Guernsey',
    'gh' => 'Gana',
    'gi' => 'Cebelitarık',
    'gl' => 'Grönland',
    'gm' => 'Gambiya',
    'gn' => 'Gine',
    'gp' => 'Guadeloupe',
    'gq' => "Ekvator\ Ginesi",
    'gr' => 'Yunanistan',
    'gs' => "Güney\ Georgia\ ve\ Güney\ Sandwich\ Adaları",
    'gt' => 'Guatemala',
    'gu' => 'Guam',
    'gw' => "Gine\-Bissau",
    'gy' => 'Guyana',
    'hk' => "Hong\ Kong",
    'hm' => "Heard\ Adası\ ve\ McDonald\ Adaları",
    'hn' => 'Honduras',
    'hr' => 'Hırvatistan',
    'ht' => 'Haiti',
    'hu' => 'Macaristan',
    'id' => 'Endonezya',
    'ie' => 'İrlanda',
    'il' => 'İsrail',
    'im' => "Man\ Adası",
    'in' => 'Hindistan',
    'io' => "Hint\ Okyanusu\ İngiliz\ Bölgesi",
    'iq' => 'Irak',
    'ir' => 'İran',
    'is' => 'İzlanda',
    'it' => 'İtalya',
    'je' => 'Jersey',
    'jm' => 'Jamaika',
    'jo' => 'Ürdün',
    'jp' => 'Japonya',
    'jt' => "Johnston\ Island",
    'ke' => 'Kenya',
    'kg' => 'Kırgızistan',
    'kh' => 'Kamboçya',
    'ki' => 'Kiribati',
    'km' => 'Komorlar',
    'kn' => "Saint\ Kitts\ ve\ Nevis",
    'kp' => "Kuzey\ Kore",
    'kr' => "Güney\ Kore",
    'kw' => 'Kuveyt',
    'ky' => "Cayman\ Adaları",
    'kz' => 'Kazakistan',
    'la' => 'Laos',
    'lb' => 'Lübnan',
    'lc' => "Saint\ Lucia",
    'li' => 'Liechtenstein',
    'lk' => "Sri\ Lanka",
    'lr' => 'Liberya',
    'ls' => 'Lesotho',
    'lt' => 'Litvanya',
    'lu' => 'Lüksemburg',
    'lv' => 'Letonya',
    'ly' => 'Libya',
    'ma' => 'Fas',
    'mc' => 'Monako',
    'md' => 'Moldova',
    'me' => 'Karadağ',
    'mf' => "Saint\ Martin",
    'mg' => 'Madagaskar',
    'mh' => "Marshall\ Adaları",
    'mi' => "Midway\ Islands",
    'mk' => 'Makedonya',
    'ml' => 'Mali',
    'mm' => 'Myanmar',
    'mn' => 'Moğolistan',
    'mo' => 'Makao',
    'mp' => "Kuzey\ Mariana\ Adaları",
    'mq' => 'Martinik',
    'mr' => 'Moritanya',
    'ms' => 'Montserrat',
    'mt' => 'Malta',
    'mu' => 'Mauritius',
    'mv' => 'Maldivler',
    'mw' => 'Malavi',
    'mx' => 'Meksika',
    'my' => 'Malezya',
    'mz' => 'Mozambik',
    'na' => 'Namibya',
    'nc' => "Yeni\ Kaledonya",
    'ne' => 'Nijer',
    'nf' => "Norfolk\ Adası",
    'ng' => 'Nijerya',
    'ni' => 'Nikaragua',
    'nl' => 'Hollanda',
    'no' => 'Norveç',
    'np' => 'Nepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "Yeni\ Zelanda",
    'om' => 'Umman',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Peru',
    'pf' => "Fransız\ Polinezyası",
    'pg' => "Papua\ Yeni\ Gine",
    'ph' => 'Filipinler',
    'pk' => 'Pakistan',
    'pl' => 'Polonya',
    'pm' => "Saint\ Pierre\ ve\ Miquelon",
    'pn' => 'Pitcairn',
    'pr' => "Porto\ Riko",
    'ps' => "Filistin\ Bölgesi",
    'pt' => 'Portekiz',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paraguay',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Katar',
    'qo' => "Uzak\ Okyanusya",
    'qu' => "Avrupa\ Birliği",
    're' => 'Reunion',
    'ro' => 'Romanya',
    'rs' => 'Sırbistan',
    'ru' => "Rusya\ Federasyonu",
    'rw' => 'Ruanda',
    'sa' => "Suudi\ Arabistan",
    'sb' => "Solomon\ Adaları",
    'sc' => "Seyşel\ Adaları",
    'sd' => 'Sudan',
    'se' => 'İsveç',
    'sg' => 'Singapur',
    'sh' => "Saint\ Helena",
    'si' => 'Slovenya',
    'sj' => "Svalbard\ ve\ Jan\ Mayen",
    'sk' => 'Slovakya',
    'sl' => "Sierra\ Leone",
    'sm' => "San\ Marino",
    'sn' => 'Senegal',
    'so' => 'Somali',
    'sr' => 'Surinam',
    'st' => "Sao\ Tome\ ve\ Principe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salvador",
    'sy' => 'Suriye',
    'sz' => 'Svaziland',
    'tc' => "Turks\ ve\ Caicos\ Adaları",
    'td' => 'Çad',
    'tf' => "Fransız\ Güney\ Bölgeleri",
    'tg' => 'Togo',
    'th' => 'Tayland',
    'tj' => 'Tacikistan',
    'tk' => 'Tokelau',
    'tl' => "Doğu\ Timor",
    'tm' => 'Türkmenistan',
    'tn' => 'Tunus',
    'to' => 'Tonga',
    'tr' => 'Türkiye',
    'tt' => "Trinidad\ ve\ Tobago",
    'tv' => 'Tuvalu',
    'tw' => 'Tayvan',
    'tz' => 'Tanzanya',
    'ua' => 'Ukrayna',
    'ug' => 'Uganda',
    'um' => "Amerika\ Birleşik\ Devletleri\ Küçük\ Dış\ Adaları",
    'us' => "Amerika\ Birleşik\ Devletleri",
    'uy' => 'Uruguay',
    'uz' => 'Özbekistan',
    'va' => 'Vatikan',
    'vc' => "Saint\ Vincent\ ve\ Grenadinler",
    'vd' => "North\ Vietnam",
    've' => 'Venezuela',
    'vg' => "İngiliz\ Virgin\ Adaları",
    'vi' => "ABD\ Virgin\ Adaları",
    'vn' => 'Vietnam',
    'vu' => 'Vanuatu',
    'wf' => "Wallis\ ve\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Yemen',
    'yt' => 'Mayotte',
    'za' => "Güney\ Afrika",
    'zm' => 'Zambiya',
    'zw' => 'Zimbabve',
    'zz' => "Bilinmeyen\ veya\ Geçersiz\ Bölge",
);

%Locales::DB::Territory::tr::name_to_code = (
    'abdvirginadaları'                               => 'vi',
    'afganistan'                                      => 'af',
    'alandadaları'                                   => 'ax',
    'almanya'                                         => 'de',
    'amerikabirleşikdevletleri'                      => 'us',
    'amerikabirleşikdevletleriküçükdışadaları' => 'um',
    'amerikansamoası'                                => 'as',
    'andorra'                                         => 'ad',
    'angola'                                          => 'ao',
    'anguilla'                                        => 'ai',
    'antarktika'                                      => 'aq',
    'antiguavebarbuda'                                => 'ag',
    'arjantin'                                        => 'ar',
    'arnavutluk'                                      => 'al',
    'aruba'                                           => 'aw',
    'avrupabirliği'                                  => 'qu',
    'avustralya'                                      => 'au',
    'avusturya'                                       => 'at',
    'azerbaycan'                                      => 'az',
    'bahamalar'                                       => 'bs',
    'bahreyn'                                         => 'bh',
    'bangladeş'                                      => 'bd',
    'barbados'                                        => 'bb',
    'batısahara'                                     => 'eh',
    'belize'                                          => 'bz',
    'belçika'                                        => 'be',
    'benin'                                           => 'bj',
    'bermuda'                                         => 'bm',
    'beyazrusya'                                      => 'by',
    'bhutan'                                          => 'bt',
    'bilinmeyenveyageçersizbölge'                   => 'zz',
    'birleşikarapemirlikleri'                        => 'ae',
    'birleşikkrallık'                               => 'gb',
    'bolivya'                                         => 'bo',
    'bosnahersek'                                     => 'ba',
    'botsvana'                                        => 'bw',
    'bouvetadası'                                    => 'bv',
    'brezilya'                                        => 'br',
    'britishantarcticterritory'                       => 'bq',
    'brunei'                                          => 'bn',
    'bulgaristan'                                     => 'bg',
    'burkinafaso'                                     => 'bf',
    'burundi'                                         => 'bi',
    'cantonandenderburyislands'                       => 'ct',
    'capeverde'                                       => 'cv',
    'caymanadaları'                                  => 'ky',
    'cebelitarık'                                    => 'gi',
    'cezayir'                                         => 'dz',
    'christmasadası'                                 => 'cx',
    'cibuti'                                          => 'dj',
    'cocosadaları'                                   => 'cc',
    'cookadaları'                                    => 'ck',
    'danimarka'                                       => 'dk',
    'dominika'                                        => 'dm',
    'dominikcumhuriyeti'                              => 'do',
    'doğutimor'                                      => 'tl',
    'dronningmaudland'                                => 'nq',
    'eastgermany'                                     => 'dd',
    'ekvador'                                         => 'ec',
    'ekvatorginesi'                                   => 'gq',
    'elsalvador'                                      => 'sv',
    'endonezya'                                       => 'id',
    'eritre'                                          => 'er',
    'ermenistan'                                      => 'am',
    'estonya'                                         => 'ee',
    'etiyopya'                                        => 'et',
    'falklandadaları'                                => 'fk',
    'faroeadaları'                                   => 'fo',
    'fas'                                             => 'ma',
    'fiji'                                            => 'fj',
    'fildişisahili'                                  => 'ci',
    'filipinler'                                      => 'ph',
    'filistinbölgesi'                                => 'ps',
    'finlandiya'                                      => 'fi',
    'fransa'                                          => 'fr',
    'fransızguyanası'                               => 'gf',
    'fransızgüneybölgeleri'                        => 'tf',
    'fransızpolinezyası'                            => 'pf',
    'frenchsouthernandantarcticterritories'           => 'fq',
    'gabon'                                           => 'ga',
    'gambiya'                                         => 'gm',
    'gana'                                            => 'gh',
    'gine'                                            => 'gn',
    'ginebissau'                                      => 'gw',
    'grenada'                                         => 'gd',
    'grönland'                                       => 'gl',
    'guadeloupe'                                      => 'gp',
    'guam'                                            => 'gu',
    'guatemala'                                       => 'gt',
    'guernsey'                                        => 'gg',
    'guyana'                                          => 'gy',
    'güneyafrika'                                    => 'za',
    'güneygeorgiavegüneysandwichadaları'           => 'gs',
    'güneykore'                                      => 'kr',
    'güneykıbrısrumkesimi'                         => 'cy',
    'gürcistan'                                      => 'ge',
    'haiti'                                           => 'ht',
    'heardadasıvemcdonaldadaları'                   => 'hm',
    'hindistan'                                       => 'in',
    'hintokyanusuİngilizbölgesi'                    => 'io',
    'hollanda'                                        => 'nl',
    'hollandaantilleri'                               => 'an',
    'honduras'                                        => 'hn',
    'hongkong'                                        => 'hk',
    'hırvatistan'                                    => 'hr',
    'irak'                                            => 'iq',
    'jamaika'                                         => 'jm',
    'japonya'                                         => 'jp',
    'jersey'                                          => 'je',
    'johnstonisland'                                  => 'jt',
    'kamboçya'                                       => 'kh',
    'kamerun'                                         => 'cm',
    'kanada'                                          => 'ca',
    'karadağ'                                        => 'me',
    'katar'                                           => 'qa',
    'kazakistan'                                      => 'kz',
    'kenya'                                           => 'ke',
    'kiribati'                                        => 'ki',
    'kolombiya'                                       => 'co',
    'komorlar'                                        => 'km',
    'kongobrazavil'                                   => 'cg',
    'kongokinşasa'                                   => 'cd',
    'kostarika'                                       => 'cr',
    'kuveyt'                                          => 'kw',
    'kuzeykore'                                       => 'kp',
    'kuzeymarianaadaları'                            => 'mp',
    'küba'                                           => 'cu',
    'kırgızistan'                                   => 'kg',
    'laos'                                            => 'la',
    'lesotho'                                         => 'ls',
    'letonya'                                         => 'lv',
    'liberya'                                         => 'lr',
    'libya'                                           => 'ly',
    'liechtenstein'                                   => 'li',
    'litvanya'                                        => 'lt',
    'lübnan'                                         => 'lb',
    'lüksemburg'                                     => 'lu',
    'macaristan'                                      => 'hu',
    'madagaskar'                                      => 'mg',
    'makao'                                           => 'mo',
    'makedonya'                                       => 'mk',
    'malavi'                                          => 'mw',
    'maldivler'                                       => 'mv',
    'malezya'                                         => 'my',
    'mali'                                            => 'ml',
    'malta'                                           => 'mt',
    'manadası'                                       => 'im',
    'marshalladaları'                                => 'mh',
    'martinik'                                        => 'mq',
    'mauritius'                                       => 'mu',
    'mayotte'                                         => 'yt',
    'meksika'                                         => 'mx',
    'metropolitanfrance'                              => 'fx',
    'midwayislands'                                   => 'mi',
    'mikronezyafederaleyaletleri'                     => 'fm',
    'moldova'                                         => 'md',
    'monako'                                          => 'mc',
    'montserrat'                                      => 'ms',
    'moritanya'                                       => 'mr',
    'mozambik'                                        => 'mz',
    'moğolistan'                                     => 'mn',
    'myanmar'                                         => 'mm',
    'mısır'                                         => 'eg',
    'namibya'                                         => 'na',
    'nauru'                                           => 'nr',
    'nepal'                                           => 'np',
    'neutralzone'                                     => 'nt',
    'nijer'                                           => 'ne',
    'nijerya'                                         => 'ng',
    'nikaragua'                                       => 'ni',
    'niue'                                            => 'nu',
    'norfolkadası'                                   => 'nf',
    'northvietnam'                                    => 'vd',
    'norveç'                                         => 'no',
    'ortaafrikacumhuriyeti'                           => 'cf',
    'pacificislandstrustterritory'                    => 'pc',
    'pakistan'                                        => 'pk',
    'palau'                                           => 'pw',
    'panama'                                          => 'pa',
    'panamacanalzone'                                 => 'pz',
    'papuayenigine'                                   => 'pg',
    'paraguay'                                        => 'py',
    'peoplesdemocraticrepublicofyemen'                => 'yd',
    'peru'                                            => 'pe',
    'pitcairn'                                        => 'pn',
    'polonya'                                         => 'pl',
    'portekiz'                                        => 'pt',
    'portoriko'                                       => 'pr',
    'reunion'                                         => 're',
    'romanya'                                         => 'ro',
    'ruanda'                                          => 'rw',
    'rusyafederasyonu'                                => 'ru',
    'saintbarthelemy'                                 => 'bl',
    'sainthelena'                                     => 'sh',
    'saintkittsvenevis'                               => 'kn',
    'saintlucia'                                      => 'lc',
    'saintmartin'                                     => 'mf',
    'saintpierrevemiquelon'                           => 'pm',
    'saintvincentvegrenadinler'                       => 'vc',
    'samoa'                                           => 'ws',
    'sanmarino'                                       => 'sm',
    'saotomeveprincipe'                               => 'st',
    'senegal'                                         => 'sn',
    'seyşeladaları'                                 => 'sc',
    'sierraleone'                                     => 'sl',
    'singapur'                                        => 'sg',
    'slovakya'                                        => 'sk',
    'slovenya'                                        => 'si',
    'solomonadaları'                                 => 'sb',
    'somali'                                          => 'so',
    'srilanka'                                        => 'lk',
    'sudan'                                           => 'sd',
    'surinam'                                         => 'sr',
    'suriye'                                          => 'sy',
    'suudiarabistan'                                  => 'sa',
    'svalbardvejanmayen'                              => 'sj',
    'svaziland'                                       => 'sz',
    'sırbistan'                                      => 'rs',
    'sırbistankaradağ'                              => 'cs',
    'tacikistan'                                      => 'tj',
    'tanzanya'                                        => 'tz',
    'tayland'                                         => 'th',
    'tayvan'                                          => 'tw',
    'togo'                                            => 'tg',
    'tokelau'                                         => 'tk',
    'tonga'                                           => 'to',
    'trinidadvetobago'                                => 'tt',
    'tunus'                                           => 'tn',
    'turksvecaicosadaları'                           => 'tc',
    'tuvalu'                                          => 'tv',
    'türkiye'                                        => 'tr',
    'türkmenistan'                                   => 'tm',
    "u\.s\.miscellaneouspacificislands"               => 'pu',
    'uganda'                                          => 'ug',
    'ukrayna'                                         => 'ua',
    'umman'                                           => 'om',
    'unionofsovietsocialistrepublics'                 => 'su',
    'uruguay'                                         => 'uy',
    'uzakokyanusya'                                   => 'qo',
    'vanuatu'                                         => 'vu',
    'vatikan'                                         => 'va',
    'venezuela'                                       => 've',
    'vietnam'                                         => 'vn',
    'wakeisland'                                      => 'wk',
    'wallisvefutuna'                                  => 'wf',
    'yemen'                                           => 'ye',
    'yenikaledonya'                                   => 'nc',
    'yenizelanda'                                     => 'nz',
    'yunanistan'                                      => 'gr',
    'zambiya'                                         => 'zm',
    'zimbabve'                                        => 'zw',
    'Çad'                                            => 'td',
    'Çekcumhuriyeti'                                 => 'cz',
    'Çin'                                            => 'cn',
    'Özbekistan'                                     => 'uz',
    'Ürdün'                                         => 'jo',
    'İngilizvirginadaları'                          => 'vg',
    'İran'                                           => 'ir',
    'İrlanda'                                        => 'ie',
    'İspanya'                                        => 'es',
    'İsrail'                                         => 'il',
    'İsveç'                                         => 'se',
    'İsviçre'                                       => 'ch',
    'İtalya'                                         => 'it',
    'İzlanda'                                        => 'is',
    'Şili'                                           => 'cl',
);

1;

