package Locales::DB::Territory::ca;

# Auto generated from CLDR

$Locales::DB::Territory::ca::VERSION = '0.02';

$Locales::DB::Territory::ca::cldr_version = '1.7.1';

%Locales::DB::Territory::ca::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "Unió\ dels\ Emirats\ Àrabs",
    'af' => 'Afganistan',
    'ag' => "Antigua\ i\ Barbuda",
    'ai' => 'Anguilla',
    'al' => 'Albània',
    'am' => 'Armènia',
    'an' => "Antilles\ Neerlandeses",
    'ao' => 'Angola',
    'aq' => 'Antàrtida',
    'ar' => 'Argentina',
    'as' => "Samoa\ Americana",
    'at' => 'Àustria',
    'au' => 'Austràlia',
    'aw' => 'Aruba',
    'ax' => "Illes\ Aland",
    'az' => 'Azerbaidjan',
    'ba' => "Bòsnia\ i\ Hercegovina",
    'bb' => 'Barbados',
    'bd' => "Bangla\ Desh",
    'be' => 'Bèlgica',
    'bf' => "Burkina\ Faso",
    'bg' => 'Bulgària',
    'bh' => 'Bahrain',
    'bi' => 'Burundi',
    'bj' => 'Benín',
    'bl' => "Saint\ Barthélemy",
    'bm' => 'Bermudes',
    'bn' => 'Brunei',
    'bo' => 'Bolívia',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brasil',
    'bs' => 'Bahames',
    'bt' => 'Bhutan',
    'bv' => "Illa\ Bouvet",
    'bw' => 'Botswana',
    'by' => 'Bielorússia',
    'bz' => 'Belize',
    'ca' => 'Canadà',
    'cc' => "Illes\ Cocos",
    'cd' => "República\ Democràtica\ del\ Congo",
    'cf' => "República\ Centreafricana",
    'cg' => 'Congo',
    'ch' => 'Suïssa',
    'ci' => "Costa\ d’Ivori",
    'ck' => "Illes\ Cook",
    'cl' => 'Xile',
    'cm' => 'Camerun',
    'cn' => 'Xina',
    'co' => 'Colòmbia',
    'cr' => "Costa\ Rica",
    'cs' => "Sèrbia\ i\ Montenegro",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Cuba',
    'cv' => "Cap\ Verd",
    'cx' => "Illa\ Christmas",
    'cy' => 'Xipre',
    'cz' => "República\ Txeca",
    'dd' => "East\ Germany",
    'de' => 'Alemanya',
    'dj' => 'Djibouti',
    'dk' => 'Dinamarca',
    'dm' => 'Dominica',
    'do' => "República\ Dominicana",
    'dz' => 'Algèria',
    'ec' => 'Equador',
    'ee' => 'Estònia',
    'eg' => 'Egipte',
    'eh' => "Sàhara\ Occidental",
    'er' => 'Eritrea',
    'es' => 'Espanya',
    'et' => 'Etiòpia',
    'fi' => 'Finlàndia',
    'fj' => 'Fiji',
    'fk' => "Illes\ Malvines",
    'fm' => 'Micronèsia',
    'fo' => "Illes\ Fèroe",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'França',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabon',
    'gb' => "Regne\ Unit",
    'gd' => 'Grenada',
    'ge' => 'Geòrgia',
    'gf' => "Guaiana\ Francesa",
    'gg' => 'Guernsey',
    'gh' => 'Ghana',
    'gi' => 'Gibraltar',
    'gl' => 'Groenlàndia',
    'gm' => 'Gàmbia',
    'gn' => 'Guinea',
    'gp' => 'Guadeloupe',
    'gq' => "Guinea\ Equatorial",
    'gr' => 'Grècia',
    'gs' => "Illes\ Geòrgia\ del\ Sud\ i\ Sandwich\ del\ Sud",
    'gt' => 'Guatemala',
    'gu' => 'Guam',
    'gw' => "Guinea\ Bissau",
    'gy' => 'Guyana',
    'hk' => "Hong\ Kong",
    'hm' => "Illa\ Heard\ i\ Illes\ McDonald",
    'hn' => 'Hondures',
    'hr' => 'Croàcia',
    'ht' => 'Haití',
    'hu' => 'Hongria',
    'id' => 'Indonèsia',
    'ie' => 'Irlanda',
    'il' => 'Israel',
    'im' => "Illa\ de\ Man",
    'in' => 'Índia',
    'io' => "Territori\ Britànic\ de\ l\'Oceà\ Índic",
    'iq' => 'Iraq',
    'ir' => 'Iran',
    'is' => 'Islàndia',
    'it' => 'Itàlia',
    'je' => 'Jersey',
    'jm' => 'Jamaica',
    'jo' => 'Jordània',
    'jp' => 'Japó',
    'jt' => "Johnston\ Island",
    'ke' => 'Kenya',
    'kg' => 'Kirguizistan',
    'kh' => 'Cambodja',
    'ki' => 'Kiribati',
    'km' => 'Comores',
    'kn' => "Saint\ Christopher\ i\ Nevis",
    'kp' => "Corea\ del\ Nord",
    'kr' => "Corea\ del\ Sud",
    'kw' => 'Kuwait',
    'ky' => "Illes\ Caiman",
    'kz' => 'Kazakhstan',
    'la' => 'Laos',
    'lb' => 'Líban',
    'lc' => "Saint\ Lucia",
    'li' => 'Liechtenstein',
    'lk' => "Sri\ Lanka",
    'lr' => 'Libèria',
    'ls' => 'Lesotho',
    'lt' => 'Lituània',
    'lu' => 'Luxemburg',
    'lv' => 'Letònia',
    'ly' => 'Líbia',
    'ma' => 'Marroc',
    'mc' => 'Mònaco',
    'md' => 'Moldàvia',
    'me' => 'Montenegro',
    'mf' => "Saint\ Martin",
    'mg' => 'Madagascar',
    'mh' => "Illes\ Marshall",
    'mi' => "Midway\ Islands",
    'mk' => 'Macedònia',
    'ml' => 'Mali',
    'mm' => 'Myanmar',
    'mn' => 'Mongòlia',
    'mo' => 'Macau',
    'mp' => "Illes\ Mariannes\ del\ Nord",
    'mq' => 'Martinica',
    'mr' => 'Mauritània',
    'ms' => 'Montserrat',
    'mt' => 'Malta',
    'mu' => 'Maurici',
    'mv' => 'Maldives',
    'mw' => 'Malawi',
    'mx' => 'Mèxic',
    'my' => 'Malàisia',
    'mz' => 'Moçambic',
    'na' => 'Namíbia',
    'nc' => "Nova\ Caledònia",
    'ne' => 'Níger',
    'nf' => "Illa\ Norfolk",
    'ng' => 'Nigèria',
    'ni' => 'Nicaragua',
    'nl' => "Països\ Baixos",
    'no' => 'Noruega',
    'np' => 'Nepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "Nova\ Zelanda",
    'om' => 'Oman',
    'pa' => 'Panamà',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Perú',
    'pf' => "Polinèsia\ Francesa",
    'pg' => "Papua\ Nova\ Guinea",
    'ph' => 'Filipines',
    'pk' => 'Pakistan',
    'pl' => 'Polònia',
    'pm' => "Saint\ Pierre\ i\ Miquelon",
    'pn' => "Illes\ Pitcairn",
    'pr' => "Puerto\ Rico",
    'ps' => 'Palestina',
    'pt' => 'Portugal',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paraguai',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Qatar',
    'qo' => "Territoris\ allunyats\ d\'Oceania",
    'qu' => "Unió\ Europea",
    're' => "Illa\ de\ la\ Reunió",
    'ro' => 'Romania',
    'rs' => 'Sèrbia',
    'ru' => 'Rússia',
    'rw' => 'Rwanda',
    'sa' => "Aràbia\ Saudita",
    'sb' => "Illes\ Salomó",
    'sc' => 'Seychelles',
    'sd' => 'Sudan',
    'se' => 'Suècia',
    'sg' => 'Singapur',
    'sh' => "Saint\ Helena",
    'si' => 'Eslovènia',
    'sj' => "Svalbard\ i\ Jan\ Mayen",
    'sk' => 'Eslovàquia',
    'sl' => "Sierra\ Leone",
    'sm' => "San\ Marino",
    'sn' => 'Senegal',
    'so' => 'Somàlia',
    'sr' => 'Surinam',
    'st' => "São\ Tomé\ i\ Príncipe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salvador",
    'sy' => 'Síria',
    'sz' => 'Swazilàndia',
    'tc' => "Illes\ Turks\ i\ Caicos",
    'td' => 'Txad',
    'tf' => "Territoris\ Francesos\ del\ Sud",
    'tg' => 'Togo',
    'th' => 'Tailàndia',
    'tj' => 'Tadjikistan',
    'tk' => 'Tokelau',
    'tl' => "Timor\ Oriental",
    'tm' => 'Turkmenistan',
    'tn' => 'Tunísia',
    'to' => 'Tonga',
    'tr' => 'Turquia',
    'tt' => "Trinitat\ i\ Tobago",
    'tv' => 'Tuvalu',
    'tw' => 'Taiwan',
    'tz' => 'Tanzània',
    'ua' => 'Ucraïna',
    'ug' => 'Uganda',
    'um' => "Illes\ Perifèriques\ Menors\ dels\ EUA",
    'us' => "Estats\ Units",
    'uy' => 'Uruguai',
    'uz' => 'Uzbekistan',
    'va' => 'Vaticà',
    'vc' => "Saint\ Vincent\ i\ les\ Grenadines",
    'vd' => "North\ Vietnam",
    've' => 'Veneçuela',
    'vg' => "Illes\ Verges\ Britàniques",
    'vi' => "Illes\ Verges\ Nord\-americanes",
    'vn' => 'Vietnam',
    'vu' => 'Vanuatu',
    'wf' => "Wallis\ i\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Iemen',
    'yt' => 'Mayotte',
    'za' => "República\ de\ Sud\-àfrica",
    'zm' => 'Zàmbia',
    'zw' => 'Zimbabwe',
    'zz' => "Regió\ desconeguda\ o\ no\ vàlida",
);

%Locales::DB::Territory::ca::name_to_code = (
    'afganistan'                            => 'af',
    'albània'                              => 'al',
    'alemanya'                              => 'de',
    'algèria'                              => 'dz',
    'andorra'                               => 'ad',
    'angola'                                => 'ao',
    'anguilla'                              => 'ai',
    'antiguaibarbuda'                       => 'ag',
    'antillesneerlandeses'                  => 'an',
    'antàrtida'                            => 'aq',
    'argentina'                             => 'ar',
    'armènia'                              => 'am',
    'aruba'                                 => 'aw',
    'aràbiasaudita'                        => 'sa',
    'austràlia'                            => 'au',
    'azerbaidjan'                           => 'az',
    'bahames'                               => 'bs',
    'bahrain'                               => 'bh',
    'bangladesh'                            => 'bd',
    'barbados'                              => 'bb',
    'belize'                                => 'bz',
    'benín'                                => 'bj',
    'bermudes'                              => 'bm',
    'bhutan'                                => 'bt',
    'bielorússia'                          => 'by',
    'bolívia'                              => 'bo',
    'botswana'                              => 'bw',
    'brasil'                                => 'br',
    'britishantarcticterritory'             => 'bq',
    'brunei'                                => 'bn',
    'bulgària'                             => 'bg',
    'burkinafaso'                           => 'bf',
    'burundi'                               => 'bi',
    'bèlgica'                              => 'be',
    'bòsniaihercegovina'                   => 'ba',
    'cambodja'                              => 'kh',
    'camerun'                               => 'cm',
    'canadà'                               => 'ca',
    'cantonandenderburyislands'             => 'ct',
    'capverd'                               => 'cv',
    'colòmbia'                             => 'co',
    'comores'                               => 'km',
    'congo'                                 => 'cg',
    'coreadelnord'                          => 'kp',
    'coreadelsud'                           => 'kr',
    'costad’ivori'                        => 'ci',
    'costarica'                             => 'cr',
    'croàcia'                              => 'hr',
    'cuba'                                  => 'cu',
    'dinamarca'                             => 'dk',
    'djibouti'                              => 'dj',
    'dominica'                              => 'dm',
    'dronningmaudland'                      => 'nq',
    'eastgermany'                           => 'dd',
    'egipte'                                => 'eg',
    'elsalvador'                            => 'sv',
    'equador'                               => 'ec',
    'eritrea'                               => 'er',
    'eslovàquia'                           => 'sk',
    'eslovènia'                            => 'si',
    'espanya'                               => 'es',
    'estatsunits'                           => 'us',
    'estònia'                              => 'ee',
    'etiòpia'                              => 'et',
    'fiji'                                  => 'fj',
    'filipines'                             => 'ph',
    'finlàndia'                            => 'fi',
    'frança'                               => 'fr',
    'frenchsouthernandantarcticterritories' => 'fq',
    'gabon'                                 => 'ga',
    'geòrgia'                              => 'ge',
    'ghana'                                 => 'gh',
    'gibraltar'                             => 'gi',
    'grenada'                               => 'gd',
    'groenlàndia'                          => 'gl',
    'grècia'                               => 'gr',
    'guadeloupe'                            => 'gp',
    'guaianafrancesa'                       => 'gf',
    'guam'                                  => 'gu',
    'guatemala'                             => 'gt',
    'guernsey'                              => 'gg',
    'guinea'                                => 'gn',
    'guineabissau'                          => 'gw',
    'guineaequatorial'                      => 'gq',
    'guyana'                                => 'gy',
    'gàmbia'                               => 'gm',
    'haití'                                => 'ht',
    'hondures'                              => 'hn',
    'hongkong'                              => 'hk',
    'hongria'                               => 'hu',
    'iemen'                                 => 'ye',
    'illabouvet'                            => 'bv',
    'illachristmas'                         => 'cx',
    'illadelareunió'                       => 're',
    'illademan'                             => 'im',
    'illaheardiillesmcdonald'               => 'hm',
    'illanorfolk'                           => 'nf',
    'illesaland'                            => 'ax',
    'illescaiman'                           => 'ky',
    'illescocos'                            => 'cc',
    'illescook'                             => 'ck',
    'illesfèroe'                           => 'fo',
    'illesgeòrgiadelsudisandwichdelsud'    => 'gs',
    'illesmalvines'                         => 'fk',
    'illesmariannesdelnord'                 => 'mp',
    'illesmarshall'                         => 'mh',
    'illesperifèriquesmenorsdelseua'       => 'um',
    'illespitcairn'                         => 'pn',
    'illessalomó'                          => 'sb',
    'illesturksicaicos'                     => 'tc',
    'illesvergesbritàniques'               => 'vg',
    'illesvergesnordamericanes'             => 'vi',
    'indonèsia'                            => 'id',
    'iran'                                  => 'ir',
    'iraq'                                  => 'iq',
    'irlanda'                               => 'ie',
    'islàndia'                             => 'is',
    'israel'                                => 'il',
    'itàlia'                               => 'it',
    'jamaica'                               => 'jm',
    'japó'                                 => 'jp',
    'jersey'                                => 'je',
    'johnstonisland'                        => 'jt',
    'jordània'                             => 'jo',
    'kazakhstan'                            => 'kz',
    'kenya'                                 => 'ke',
    'kirguizistan'                          => 'kg',
    'kiribati'                              => 'ki',
    'kuwait'                                => 'kw',
    'laos'                                  => 'la',
    'lesotho'                               => 'ls',
    'letònia'                              => 'lv',
    'libèria'                              => 'lr',
    'liechtenstein'                         => 'li',
    'lituània'                             => 'lt',
    'luxemburg'                             => 'lu',
    'líban'                                => 'lb',
    'líbia'                                => 'ly',
    'macau'                                 => 'mo',
    'macedònia'                            => 'mk',
    'madagascar'                            => 'mg',
    'malawi'                                => 'mw',
    'maldives'                              => 'mv',
    'mali'                                  => 'ml',
    'malta'                                 => 'mt',
    'malàisia'                             => 'my',
    'marroc'                                => 'ma',
    'martinica'                             => 'mq',
    'maurici'                               => 'mu',
    'mauritània'                           => 'mr',
    'mayotte'                               => 'yt',
    'metropolitanfrance'                    => 'fx',
    'micronèsia'                           => 'fm',
    'midwayislands'                         => 'mi',
    'moldàvia'                             => 'md',
    'mongòlia'                             => 'mn',
    'montenegro'                            => 'me',
    'montserrat'                            => 'ms',
    'moçambic'                             => 'mz',
    'myanmar'                               => 'mm',
    'mèxic'                                => 'mx',
    'mònaco'                               => 'mc',
    'namíbia'                              => 'na',
    'nauru'                                 => 'nr',
    'nepal'                                 => 'np',
    'neutralzone'                           => 'nt',
    'nicaragua'                             => 'ni',
    'nigèria'                              => 'ng',
    'niue'                                  => 'nu',
    'northvietnam'                          => 'vd',
    'noruega'                               => 'no',
    'novacaledònia'                        => 'nc',
    'novazelanda'                           => 'nz',
    'níger'                                => 'ne',
    'oman'                                  => 'om',
    'pacificislandstrustterritory'          => 'pc',
    'pakistan'                              => 'pk',
    'palau'                                 => 'pw',
    'palestina'                             => 'ps',
    'panamacanalzone'                       => 'pz',
    'panamà'                               => 'pa',
    'papuanovaguinea'                       => 'pg',
    'paraguai'                              => 'py',
    'païsosbaixos'                         => 'nl',
    'peoplesdemocraticrepublicofyemen'      => 'yd',
    'perú'                                 => 'pe',
    'polinèsiafrancesa'                    => 'pf',
    'polònia'                              => 'pl',
    'portugal'                              => 'pt',
    'puertorico'                            => 'pr',
    'qatar'                                 => 'qa',
    'regiódesconegudaonovàlida'           => 'zz',
    'regneunit'                             => 'gb',
    'repúblicacentreafricana'              => 'cf',
    'repúblicademocràticadelcongo'        => 'cd',
    'repúblicadesudàfrica'                => 'za',
    'repúblicadominicana'                  => 'do',
    'repúblicatxeca'                       => 'cz',
    'romania'                               => 'ro',
    'rwanda'                                => 'rw',
    'rússia'                               => 'ru',
    'saintbarthélemy'                      => 'bl',
    'saintchristopherinevis'                => 'kn',
    'sainthelena'                           => 'sh',
    'saintlucia'                            => 'lc',
    'saintmartin'                           => 'mf',
    'saintpierreimiquelon'                  => 'pm',
    'saintvincentilesgrenadines'            => 'vc',
    'samoa'                                 => 'ws',
    'samoaamericana'                        => 'as',
    'sanmarino'                             => 'sm',
    'senegal'                               => 'sn',
    'seychelles'                            => 'sc',
    'sierraleone'                           => 'sl',
    'singapur'                              => 'sg',
    'somàlia'                              => 'so',
    'srilanka'                              => 'lk',
    'sudan'                                 => 'sd',
    'surinam'                               => 'sr',
    'suècia'                               => 'se',
    'suïssa'                               => 'ch',
    'svalbardijanmayen'                     => 'sj',
    'swazilàndia'                          => 'sz',
    'sàharaoccidental'                     => 'eh',
    'sãotoméipríncipe'                   => 'st',
    'sèrbia'                               => 'rs',
    'sèrbiaimontenegro'                    => 'cs',
    'síria'                                => 'sy',
    'tadjikistan'                           => 'tj',
    'tailàndia'                            => 'th',
    'taiwan'                                => 'tw',
    'tanzània'                             => 'tz',
    'territoribritànicdeloceàÍndic'      => 'io',
    'territorisallunyatsdoceania'           => 'qo',
    'territorisfrancesosdelsud'             => 'tf',
    'timororiental'                         => 'tl',
    'togo'                                  => 'tg',
    'tokelau'                               => 'tk',
    'tonga'                                 => 'to',
    'trinitatitobago'                       => 'tt',
    'tunísia'                              => 'tn',
    'turkmenistan'                          => 'tm',
    'turquia'                               => 'tr',
    'tuvalu'                                => 'tv',
    'txad'                                  => 'td',
    "u\.s\.miscellaneouspacificislands"     => 'pu',
    'ucraïna'                              => 'ua',
    'uganda'                                => 'ug',
    'unionofsovietsocialistrepublics'       => 'su',
    'uniódelsemiratsÀrabs'                => 'ae',
    'unióeuropea'                          => 'qu',
    'uruguai'                               => 'uy',
    'uzbekistan'                            => 'uz',
    'vanuatu'                               => 'vu',
    'vaticà'                               => 'va',
    'veneçuela'                            => 've',
    'vietnam'                               => 'vn',
    'wakeisland'                            => 'wk',
    'wallisifutuna'                         => 'wf',
    'xile'                                  => 'cl',
    'xina'                                  => 'cn',
    'xipre'                                 => 'cy',
    'zimbabwe'                              => 'zw',
    'zàmbia'                               => 'zm',
    'Àustria'                              => 'at',
    'Índia'                                => 'in',
);

1;

