package Locales::DB::Territory::uk;

# Auto generated from CLDR

$Locales::DB::Territory::uk::VERSION = '0.02';

$Locales::DB::Territory::uk::cldr_version = '1.7.1';

%Locales::DB::Territory::uk::code_to_name = (
    'ad' => 'Андорра',
    'ae' => "Обʼєднані\ Арабські\ Емірати",
    'af' => 'Афганістан',
    'ag' => "Антигуа\ і\ Барбуда",
    'ai' => 'Ангілья',
    'al' => 'Албанія',
    'am' => 'Вірменія',
    'an' => "Нідерландські\ Антильські\ Острови",
    'ao' => 'Ангола',
    'aq' => 'Антарктида',
    'ar' => 'Аргентина',
    'as' => "Американське\ Самоа",
    'at' => 'Австрія',
    'au' => 'Австралія',
    'aw' => 'Аруба',
    'ax' => "Аландські\ острови",
    'az' => 'Азербайджан',
    'ba' => "Боснія\ і\ Герцоговина",
    'bb' => 'Барбадос',
    'bd' => 'Бангладеш',
    'be' => 'Бельгія',
    'bf' => "Буркіна\-Фасо",
    'bg' => 'Болгарія',
    'bh' => 'Бахрейн',
    'bi' => 'Бурунді',
    'bj' => 'Бенін',
    'bl' => "Острів\ Святого\ Бартоломея",
    'bm' => 'Бермуди',
    'bn' => 'Бруней',
    'bo' => 'Болівія',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Бразилія',
    'bs' => 'Багами',
    'bt' => 'Бутан',
    'bv' => "Острів\ Буве",
    'bw' => 'Ботсвана',
    'by' => 'Білорусь',
    'bz' => 'Беліз',
    'ca' => 'Канада',
    'cc' => "Кокосові\ острови",
    'cd' => "Демократична\ Республіка\ Конґо",
    'cf' => "Центральноафриканська\ Республіка",
    'cg' => "Конґо\ \-\ Браззавіль",
    'ch' => 'Швейцарія',
    'ci' => "Кот\ д’Івуар",
    'ck' => "Острови\ Кука",
    'cl' => 'Чилі',
    'cm' => 'Камерун',
    'cn' => 'Китай',
    'co' => 'Колумбія',
    'cr' => "Коста\-Рика",
    'cs' => "Сербія\ та\ Чорногорія",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Куба',
    'cv' => "Кабо\-Верде",
    'cx' => "Острів\ Різдва",
    'cy' => 'Кіпр',
    'cz' => "Чеська\ республіка",
    'dd' => "East\ Germany",
    'de' => 'Німеччина',
    'dj' => 'Джібуті',
    'dk' => 'Данія',
    'dm' => 'Домінік',
    'do' => "Домініканська\ Республіка",
    'dz' => 'Алжир',
    'ec' => 'Еквадор',
    'ee' => 'Естонія',
    'eg' => 'Єгипет',
    'eh' => "Західна\ Сахара",
    'er' => 'Еритрея',
    'es' => 'Іспанія',
    'et' => 'Ефіопія',
    'fi' => 'Фінляндія',
    'fj' => 'Фіджі',
    'fk' => "Фолклендські\ острови",
    'fm' => "Мікронезія\ Федеративні\ Штати",
    'fo' => "Фарерські\ острови",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Франція',
    'fx' => "Metropolitan\ France",
    'ga' => 'Габон',
    'gb' => 'Великобританія',
    'gd' => 'Гренада',
    'ge' => 'Грузія',
    'gf' => "Французька\ Гвіана",
    'gg' => 'Гернсі',
    'gh' => 'Гана',
    'gi' => 'Гібралтар',
    'gl' => 'Гренландія',
    'gm' => 'Гамбія',
    'gn' => 'Гвінея',
    'gp' => 'Гваделупа',
    'gq' => "Екваторіальна\ Гвінея",
    'gr' => 'Греція',
    'gs' => "Південна\ Джорджія\ та\ Південні\ Сандвічеві\ Острови",
    'gt' => 'Гватемала',
    'gu' => 'Гуам',
    'gw' => "Гвінея\-Біссау",
    'gy' => 'Гайана',
    'hk' => 'Гонконґ',
    'hm' => "Острови\ Херд\ і\ Мак\-Дональд",
    'hn' => 'Гондурас',
    'hr' => 'Хорватія',
    'ht' => 'Гаїті',
    'hu' => 'Угорщина',
    'id' => 'Індонезія',
    'ie' => 'Ірландія',
    'il' => 'Ізраїль',
    'im' => "Острів\ Мен",
    'in' => 'Індія',
    'io' => "Британські\ території\ Індійського\ океану",
    'iq' => 'Ірак',
    'ir' => 'Іран',
    'is' => 'Ісландія',
    'it' => 'Італія',
    'je' => 'Джерсі',
    'jm' => 'Ямайка',
    'jo' => 'Йорданія',
    'jp' => 'Японія',
    'jt' => "Johnston\ Island",
    'ke' => 'Кенія',
    'kg' => 'Киргизстан',
    'kh' => 'Камбоджа',
    'ki' => 'Кірибаті',
    'km' => "Коморські\ Острови",
    'kn' => "Сент\-Кітс\ і\ Невіс",
    'kp' => "Північна\ Корея",
    'kr' => "Південна\ Корея",
    'kw' => 'Кувейт',
    'ky' => "Кайманові\ острови",
    'kz' => 'Казахстан',
    'la' => 'Лаос',
    'lb' => 'Ліван',
    'lc' => "Сент\-Люсія",
    'li' => 'Ліхтенштейн',
    'lk' => "Шрі\-Ланка",
    'lr' => 'Ліберія',
    'ls' => 'Лесото',
    'lt' => 'Литва',
    'lu' => 'Люксембург',
    'lv' => 'Латвія',
    'ly' => 'Лівія',
    'ma' => 'Марокко',
    'mc' => 'Монако',
    'md' => 'Молдова',
    'me' => 'Чорногорія',
    'mf' => "Острів\ Святого\ Мартіна",
    'mg' => 'Мадагаскар',
    'mh' => "Маршаллові\ Острови",
    'mi' => "Midway\ Islands",
    'mk' => 'Македонія',
    'ml' => 'Малі',
    'mm' => 'Мʼянма',
    'mn' => 'Монголія',
    'mo' => 'Макао',
    'mp' => "Північні\ Маріанські\ Острови",
    'mq' => 'Мартиніка',
    'mr' => 'Мавританія',
    'ms' => 'Монсеррат',
    'mt' => 'Мальта',
    'mu' => 'Маврикій',
    'mv' => 'Мальдіви',
    'mw' => 'Малаві',
    'mx' => 'Мексика',
    'my' => 'Малайзія',
    'mz' => 'Мозамбік',
    'na' => 'Намібія',
    'nc' => "Нова\ Каледонія",
    'ne' => 'Нігер',
    'nf' => "Острів\ Норфолк",
    'ng' => 'Нігерія',
    'ni' => 'Нікарагуа',
    'nl' => 'Нідерланди',
    'no' => 'Норвегія',
    'np' => 'Непал',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Науру',
    'nt' => "Neutral\ Zone",
    'nu' => 'Нія',
    'nz' => "Нова\ Зеландія",
    'om' => 'Оман',
    'pa' => 'Панама',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Перу',
    'pf' => "Французька\ Полінезія",
    'pg' => "Папуа\ Нова\ Гвінея",
    'ph' => 'Філіппіни',
    'pk' => 'Пакистан',
    'pl' => 'Польща',
    'pm' => "Сен\-Пʼєр\ і\ Мікелон",
    'pn' => 'Піткерн',
    'pr' => "Пуерто\-Ріко",
    'ps' => 'Палестина',
    'pt' => 'Португалія',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Палау',
    'py' => 'Парагвай',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Катар',
    'qo' => "Інша\ Океанія",
    'qu' => "Європейський\ Союз",
    're' => 'Реюньйон',
    'ro' => 'Румунія',
    'rs' => 'Сербія',
    'ru' => 'Росія',
    'rw' => 'Руанда',
    'sa' => "Саудівська\ Аравія",
    'sb' => "Соломонові\ Острови",
    'sc' => 'Сейшели',
    'sd' => 'Судан',
    'se' => 'Швеція',
    'sg' => 'Сінгапур',
    'sh' => "Острів\ Святої\ Єлени",
    'si' => 'Словенія',
    'sj' => "Острови\ Свальбард\ та\ Ян\-Маєн",
    'sk' => 'Словакія',
    'sl' => "Сьєрра\-Леоне",
    'sm' => "Сан\-Марино",
    'sn' => 'Сенегал',
    'so' => 'Сомалі',
    'sr' => 'Суринам',
    'st' => "Сан\-Томе\ і\ Прінсіпі",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => 'Сальвадор',
    'sy' => 'Сирія',
    'sz' => 'Свазіленд',
    'tc' => "Теркс\ і\ Кайкос",
    'td' => 'Чад',
    'tf' => "Французькі\ Південні\ Території",
    'tg' => 'Того',
    'th' => 'Таїланд',
    'tj' => 'Таджикистан',
    'tk' => 'Токелау',
    'tl' => "Східний\ Тимор",
    'tm' => 'Туркменистан',
    'tn' => 'Туніс',
    'to' => 'Тонга',
    'tr' => 'Туреччина',
    'tt' => "Тринідад\ і\ Тобаго",
    'tv' => 'Тувалу',
    'tw' => 'Тайвань',
    'tz' => 'Танзанія',
    'ua' => 'Україна',
    'ug' => 'Уганда',
    'um' => "Віддалені\ Острови\ США",
    'us' => 'США',
    'uy' => 'Уругвай',
    'uz' => 'Узбекистан',
    'va' => 'Ватикан',
    'vc' => "Сент\-Вінсент\ і\ Гренадини",
    'vd' => "North\ Vietnam",
    've' => 'Венесуела',
    'vg' => "Віргінські\ острови\ Британії",
    'vi' => "Віргінські\ острови\ США",
    'vn' => 'Вʼєтнам',
    'vu' => 'Вануату',
    'wf' => "Уолліс\ і\ Футуна",
    'wk' => "Wake\ Island",
    'ws' => 'Самоа',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Ємен',
    'yt' => 'Майот',
    'za' => 'ПАР',
    'zm' => 'Замбія',
    'zw' => 'Зімбабве',
    'zz' => "Невідомий\ або\ неправильний\ регіон",
);

%Locales::DB::Territory::uk::name_to_code = (
    'britishantarcticterritory'                                                              => 'bq',
    'cantonandenderburyislands'                                                              => 'ct',
    'dronningmaudland'                                                                       => 'nq',
    'eastgermany'                                                                            => 'dd',
    'frenchsouthernandantarcticterritories'                                                  => 'fq',
    'johnstonisland'                                                                         => 'jt',
    'metropolitanfrance'                                                                     => 'fx',
    'midwayislands'                                                                          => 'mi',
    'neutralzone'                                                                            => 'nt',
    'northvietnam'                                                                           => 'vd',
    'pacificislandstrustterritory'                                                           => 'pc',
    'panamacanalzone'                                                                        => 'pz',
    'peoplesdemocraticrepublicofyemen'                                                       => 'yd',
    "u\.s\.miscellaneouspacificislands"                                                      => 'pu',
    'unionofsovietsocialistrepublics'                                                        => 'su',
    'wakeisland'                                                                             => 'wk',
    'ЄвропейськийСоюз'                                                       => 'qu',
    'Єгипет'                                                                           => 'eg',
    'Ємен'                                                                               => 'ye',
    'Ізраїль'                                                                         => 'il',
    'Індонезія'                                                                     => 'id',
    'Індія'                                                                             => 'in',
    'ІншаОкеанія'                                                                 => 'qo',
    'Ірак'                                                                               => 'iq',
    'Іран'                                                                               => 'ir',
    'Ірландія'                                                                       => 'ie',
    'Ісландія'                                                                       => 'is',
    'Іспанія'                                                                         => 'es',
    'Італія'                                                                           => 'it',
    'Австралія'                                                                     => 'au',
    'Австрія'                                                                         => 'at',
    'Азербайджан'                                                                 => 'az',
    'Аландськіострови'                                                       => 'ax',
    'Албанія'                                                                         => 'al',
    'Алжир'                                                                             => 'dz',
    'АмериканськеСамоа'                                                     => 'as',
    'Ангола'                                                                           => 'ao',
    'Ангілья'                                                                         => 'ai',
    'Андорра'                                                                         => 'ad',
    'Антарктида'                                                                   => 'aq',
    'АнтигуаіБарбуда'                                                         => 'ag',
    'Аргентина'                                                                     => 'ar',
    'Аруба'                                                                             => 'aw',
    'Афганістан'                                                                   => 'af',
    'Багами'                                                                           => 'bs',
    'Бангладеш'                                                                     => 'bd',
    'Барбадос'                                                                       => 'bb',
    'Бахрейн'                                                                         => 'bh',
    'Бельгія'                                                                         => 'be',
    'Беліз'                                                                             => 'bz',
    'Бенін'                                                                             => 'bj',
    'Бермуди'                                                                         => 'bm',
    'Болгарія'                                                                       => 'bg',
    'Болівія'                                                                         => 'bo',
    'БосніяіГерцоговина'                                                   => 'ba',
    'Ботсвана'                                                                       => 'bw',
    'Бразилія'                                                                       => 'br',
    'БританськітериторіїІндійськогоокеану'               => 'io',
    'Бруней'                                                                           => 'bn',
    'БуркінаФасо'                                                                 => 'bf',
    'Бурунді'                                                                         => 'bi',
    'Бутан'                                                                             => 'bt',
    'Білорусь'                                                                       => 'by',
    'Вʼєтнам'                                                                         => 'vn',
    'Вануату'                                                                         => 'vu',
    'Ватикан'                                                                         => 'va',
    'Великобританія'                                                           => 'gb',
    'Венесуела'                                                                     => 've',
    'ВіддаленіОстровиСША'                                                 => 'um',
    'ВіргінськіостровиБританії'                                     => 'vg',
    'ВіргінськіостровиСША'                                               => 'vi',
    'Вірменія'                                                                       => 'am',
    'Габон'                                                                             => 'ga',
    'Гайана'                                                                           => 'gy',
    'Гамбія'                                                                           => 'gm',
    'Гана'                                                                               => 'gh',
    'Гаїті'                                                                             => 'ht',
    'Гваделупа'                                                                     => 'gp',
    'Гватемала'                                                                     => 'gt',
    'Гвінея'                                                                           => 'gn',
    'ГвінеяБіссау'                                                               => 'gw',
    'Гернсі'                                                                           => 'gg',
    'Гондурас'                                                                       => 'hn',
    'Гонконґ'                                                                         => 'hk',
    'Гренада'                                                                         => 'gd',
    'Гренландія'                                                                   => 'gl',
    'Греція'                                                                           => 'gr',
    'Грузія'                                                                           => 'ge',
    'Гуам'                                                                               => 'gu',
    'Гібралтар'                                                                     => 'gi',
    'Данія'                                                                             => 'dk',
    'ДемократичнаРеспублікаКонґо'                                 => 'cd',
    'Джерсі'                                                                           => 'je',
    'Джібуті'                                                                         => 'dj',
    'Домінік'                                                                         => 'dm',
    'ДомініканськаРеспубліка'                                         => 'do',
    'Еквадор'                                                                         => 'ec',
    'ЕкваторіальнаГвінея'                                                 => 'gq',
    'Еритрея'                                                                         => 'er',
    'Естонія'                                                                         => 'ee',
    'Ефіопія'                                                                         => 'et',
    'Замбія'                                                                           => 'zm',
    'ЗахіднаСахара'                                                             => 'eh',
    'Зімбабве'                                                                       => 'zw',
    'Йорданія'                                                                       => 'jo',
    'КабоВерде'                                                                     => 'cv',
    'Казахстан'                                                                     => 'kz',
    'Каймановіострови'                                                       => 'ky',
    'Камбоджа'                                                                       => 'kh',
    'Камерун'                                                                         => 'cm',
    'Канада'                                                                           => 'ca',
    'Катар'                                                                             => 'qa',
    'Кенія'                                                                             => 'ke',
    'Киргизстан'                                                                   => 'kg',
    'Китай'                                                                             => 'cn',
    'Кокосовіострови'                                                         => 'cc',
    'Колумбія'                                                                       => 'co',
    'КоморськіОстрови'                                                       => 'km',
    'КонґоБраззавіль'                                                         => 'cg',
    'КостаРика'                                                                     => 'cr',
    'Котд’Івуар'                                                                  => 'ci',
    'Куба'                                                                               => 'cu',
    'Кувейт'                                                                           => 'kw',
    'Кіпр'                                                                               => 'cy',
    'Кірибаті'                                                                       => 'ki',
    'Лаос'                                                                               => 'la',
    'Латвія'                                                                           => 'lv',
    'Лесото'                                                                           => 'ls',
    'Литва'                                                                             => 'lt',
    'Люксембург'                                                                   => 'lu',
    'Ліберія'                                                                         => 'lr',
    'Ліван'                                                                             => 'lb',
    'Лівія'                                                                             => 'ly',
    'Ліхтенштейн'                                                                 => 'li',
    'Мʼянма'                                                                           => 'mm',
    'Маврикій'                                                                       => 'mu',
    'Мавританія'                                                                   => 'mr',
    'Мадагаскар'                                                                   => 'mg',
    'Майот'                                                                             => 'yt',
    'Макао'                                                                             => 'mo',
    'Македонія'                                                                     => 'mk',
    'Малаві'                                                                           => 'mw',
    'Малайзія'                                                                       => 'my',
    'Мальдіви'                                                                       => 'mv',
    'Мальта'                                                                           => 'mt',
    'Малі'                                                                               => 'ml',
    'Марокко'                                                                         => 'ma',
    'Мартиніка'                                                                     => 'mq',
    'МаршалловіОстрови'                                                     => 'mh',
    'Мексика'                                                                         => 'mx',
    'Мозамбік'                                                                       => 'mz',
    'Молдова'                                                                         => 'md',
    'Монако'                                                                           => 'mc',
    'Монголія'                                                                       => 'mn',
    'Монсеррат'                                                                     => 'ms',
    'МікронезіяФедеративніШтати'                                   => 'fm',
    'Намібія'                                                                         => 'na',
    'Науру'                                                                             => 'nr',
    'Невідомийабонеправильнийрегіон'                           => 'zz',
    'Непал'                                                                             => 'np',
    'НоваЗеландія'                                                               => 'nz',
    'НоваКаледонія'                                                             => 'nc',
    'Норвегія'                                                                       => 'no',
    'Нігер'                                                                             => 'ne',
    'Нігерія'                                                                         => 'ng',
    'Нідерланди'                                                                   => 'nl',
    'НідерландськіАнтильськіОстрови'                           => 'an',
    'Нікарагуа'                                                                     => 'ni',
    'Німеччина'                                                                     => 'de',
    'Нія'                                                                                 => 'nu',
    'ОбʼєднаніАрабськіЕмірати'                                       => 'ae',
    'Оман'                                                                               => 'om',
    'ОстровиКука'                                                                 => 'ck',
    'ОстровиСвальбардтаЯнМаєн'                                       => 'sj',
    'ОстровиХердіМакДональд'                                           => 'hm',
    'ОстрівБуве'                                                                   => 'bv',
    'ОстрівМен'                                                                     => 'im',
    'ОстрівНорфолк'                                                             => 'nf',
    'ОстрівРіздва'                                                               => 'cx',
    'ОстрівСвятогоБартоломея'                                         => 'bl',
    'ОстрівСвятогоМартіна'                                               => 'mf',
    'ОстрівСвятоїЄлени'                                                     => 'sh',
    'ПАР'                                                                                 => 'za',
    'Пакистан'                                                                       => 'pk',
    'Палау'                                                                             => 'pw',
    'Палестина'                                                                     => 'ps',
    'Панама'                                                                           => 'pa',
    'ПапуаНоваГвінея'                                                         => 'pg',
    'Парагвай'                                                                       => 'py',
    'Перу'                                                                               => 'pe',
    'Польща'                                                                           => 'pl',
    'Португалія'                                                                   => 'pt',
    'ПуертоРіко'                                                                   => 'pr',
    'ПівденнаДжорджіятаПівденніСандвічевіОстрови' => 'gs',
    'ПівденнаКорея'                                                             => 'kr',
    'ПівнічнаКорея'                                                             => 'kp',
    'ПівнічніМаріанськіОстрови'                                     => 'mp',
    'Піткерн'                                                                         => 'pn',
    'Реюньйон'                                                                       => 're',
    'Росія'                                                                             => 'ru',
    'Руанда'                                                                           => 'rw',
    'Румунія'                                                                         => 'ro',
    'США'                                                                                 => 'us',
    'Сальвадор'                                                                     => 'sv',
    'Самоа'                                                                             => 'ws',
    'СанМарино'                                                                     => 'sm',
    'СанТомеіПрінсіпі'                                                       => 'st',
    'СаудівськаАравія'                                                       => 'sa',
    'Свазіленд'                                                                     => 'sz',
    'Сейшели'                                                                         => 'sc',
    'СенПʼєріМікелон'                                                         => 'pm',
    'Сенегал'                                                                         => 'sn',
    'СентВінсентіГренадини'                                             => 'vc',
    'СентКітсіНевіс'                                                           => 'kn',
    'СентЛюсія'                                                                     => 'lc',
    'Сербія'                                                                           => 'rs',
    'СербіятаЧорногорія'                                                   => 'cs',
    'Сирія'                                                                             => 'sy',
    'Словакія'                                                                       => 'sk',
    'Словенія'                                                                       => 'si',
    'СоломоновіОстрови'                                                     => 'sb',
    'Сомалі'                                                                           => 'so',
    'Судан'                                                                             => 'sd',
    'Суринам'                                                                         => 'sr',
    'СхіднийТимор'                                                               => 'tl',
    'СьєрраЛеоне'                                                                 => 'sl',
    'Сінгапур'                                                                       => 'sg',
    'Таджикистан'                                                                 => 'tj',
    'Тайвань'                                                                         => 'tw',
    'Танзанія'                                                                       => 'tz',
    'Таїланд'                                                                         => 'th',
    'ТерксіКайкос'                                                               => 'tc',
    'Того'                                                                               => 'tg',
    'Токелау'                                                                         => 'tk',
    'Тонга'                                                                             => 'to',
    'ТринідадіТобаго'                                                         => 'tt',
    'Тувалу'                                                                           => 'tv',
    'Туніс'                                                                             => 'tn',
    'Туреччина'                                                                     => 'tr',
    'Туркменистан'                                                               => 'tm',
    'Уганда'                                                                           => 'ug',
    'Угорщина'                                                                       => 'hu',
    'Узбекистан'                                                                   => 'uz',
    'Україна'                                                                         => 'ua',
    'УоллісіФутуна'                                                             => 'wf',
    'Уругвай'                                                                         => 'uy',
    'Фарерськіострови'                                                       => 'fo',
    'Фолклендськіострови'                                                 => 'fk',
    'ФранцузькаГвіана'                                                       => 'gf',
    'ФранцузькаПолінезія'                                                 => 'pf',
    'ФранцузькіПівденніТериторії'                                 => 'tf',
    'Франція'                                                                         => 'fr',
    'Фіджі'                                                                             => 'fj',
    'Філіппіни'                                                                     => 'ph',
    'Фінляндія'                                                                     => 'fi',
    'Хорватія'                                                                       => 'hr',
    'ЦентральноафриканськаРеспубліка'                         => 'cf',
    'Чад'                                                                                 => 'td',
    'Чеськареспубліка'                                                       => 'cz',
    'Чилі'                                                                               => 'cl',
    'Чорногорія'                                                                   => 'me',
    'Швейцарія'                                                                     => 'ch',
    'Швеція'                                                                           => 'se',
    'ШріЛанка'                                                                       => 'lk',
    'Ямайка'                                                                           => 'jm',
    'Японія'                                                                           => 'jp',
);

1;

