package Locales::DB::Territory::lv;

# Auto generated from CLDR

$Locales::DB::Territory::lv::VERSION = '0.02';

$Locales::DB::Territory::lv::cldr_version = '1.7.1';

%Locales::DB::Territory::lv::code_to_name = (
    'ad' => 'Andora',
    'ae' => "Apvienotie\ Arābu\ Emirāti",
    'af' => 'Afganistāna',
    'ag' => "Antigva\ un\ Barbuda",
    'ai' => 'Angilja',
    'al' => 'Albānija',
    'am' => 'Armēnija',
    'an' => "Nīderlandes\ Antiļas",
    'ao' => 'Angola',
    'aq' => 'Antarktika',
    'ar' => 'Argentīna',
    'as' => "Amerikāņu\ Samoa",
    'at' => 'Austrija',
    'au' => 'Austrālija',
    'aw' => 'Aruba',
    'ax' => 'Ālandi',
    'az' => 'Azerbaidžāna',
    'ba' => "Bosnija\ un\ Hercegovina",
    'bb' => 'Barbadosa',
    'bd' => 'Bangladeša',
    'be' => 'Beļģija',
    'bf' => 'Burkinafaso',
    'bg' => 'Bulgārija',
    'bh' => 'Bahreina',
    'bi' => 'Burundi',
    'bj' => 'Benina',
    'bl' => "Saint\ Barthélemy",
    'bm' => "Bermudu\ salas",
    'bn' => 'Bruneja',
    'bo' => 'Bolīvija',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brazīlija',
    'bs' => 'Bahamas',
    'bt' => 'Butāna',
    'bv' => "Buvē\ sala",
    'bw' => 'Botsvāna',
    'by' => 'Baltkrievija',
    'bz' => 'Beliza',
    'ca' => 'Kanāda',
    'cc' => "Kokosu\ jeb\ Kīlinga\ salas",
    'cd' => "Kongo\-Kinshasa",
    'cf' => "Centrālāfrikas\ Republika",
    'cg' => "Kongo\-Brazzaville",
    'ch' => 'Šveice',
    'ci' => 'Kotdivuāra',
    'ck' => "Kuka\ salas",
    'cl' => 'Čīle',
    'cm' => 'Kamerūna',
    'cn' => 'Ķīna',
    'co' => 'Kolumbija',
    'cr' => 'Kostarika',
    'cs' => "Serbija\ un\ Melnkalne",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Kuba',
    'cv' => 'Kaboverde',
    'cx' => "Ziemsvētku\ sala",
    'cy' => 'Kipra',
    'cz' => 'Čehija',
    'dd' => "East\ Germany",
    'de' => 'Vācija',
    'dj' => 'Džibutija',
    'dk' => 'Dānija',
    'dm' => 'Dominika',
    'do' => "Dominikānas\ Republika",
    'dz' => 'Alžīrija',
    'ec' => 'Ekvadora',
    'ee' => 'Igaunija',
    'eg' => 'Ēģipte',
    'eh' => 'Rietumsahāra',
    'er' => 'Eritreja',
    'es' => 'Spānija',
    'et' => 'Etiopija',
    'fi' => 'Somija',
    'fj' => 'Fidži',
    'fk' => "Folklenda\ salas",
    'fm' => "Mikronēzijas\ Federatīvās\ Valstis",
    'fo' => "Farēru\ salas",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Francija',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabona',
    'gb' => 'Lielbritānija',
    'gd' => 'Grenāda',
    'ge' => 'Gruzija',
    'gf' => "Franču\ Gviāna",
    'gg' => 'Gērnsija',
    'gh' => 'Gana',
    'gi' => 'Gibraltārs',
    'gl' => 'Grenlande',
    'gm' => 'Gambija',
    'gn' => 'Gvineja',
    'gp' => 'Gvadelupa',
    'gq' => "Ekvatoriālā\ Gvineja",
    'gr' => 'Grieķija',
    'gs' => "Dienviddžordžija\ un\ Dienvidsendviču\ salas",
    'gt' => 'Gvatemala',
    'gu' => 'Guama',
    'gw' => "Gvineja\-Bisava",
    'gy' => 'Gajāna',
    'hk' => 'Honkonga',
    'hm' => "Hērda\ un\ Makdonalda\ salas",
    'hn' => 'Hondurasa',
    'hr' => 'Horvātija',
    'ht' => 'Haiti',
    'hu' => 'Ungārija',
    'id' => 'Indonēzija',
    'ie' => 'Īrija',
    'il' => 'Izraēla',
    'im' => 'Mena',
    'in' => 'Indija',
    'io' => "Britu\ Indijas\ okeāna\ teritorija",
    'iq' => 'Irāka',
    'ir' => 'Irāna',
    'is' => 'Īslande',
    'it' => 'Itālija',
    'je' => 'Džērsija',
    'jm' => 'Jamaika',
    'jo' => 'Jordānija',
    'jp' => 'Japāna',
    'jt' => "Johnston\ Island",
    'ke' => 'Kenija',
    'kg' => 'Kirgīzija',
    'kh' => 'Kambodža',
    'ki' => 'Kiribati',
    'km' => "Komoru\ salas",
    'kn' => "Sentkitsa\ un\ Nevisa",
    'kp' => 'Ziemeļkoreja',
    'kr' => 'Dienvidkoreja',
    'kw' => 'Kuveita',
    'ky' => "Kaimanu\ salas",
    'kz' => 'Kazahstāna',
    'la' => 'Laosa',
    'lb' => 'Libāna',
    'lc' => 'Sentlūsija',
    'li' => 'Lihtenšteina',
    'lk' => 'Šrilanka',
    'lr' => 'Libērija',
    'ls' => 'Lesoto',
    'lt' => 'Lietuva',
    'lu' => 'Luksemburga',
    'lv' => 'Latvija',
    'ly' => 'Lībija',
    'ma' => 'Maroka',
    'mc' => 'Monako',
    'md' => 'Moldova',
    'me' => 'Melnkalne',
    'mf' => "Saint\ Martin",
    'mg' => 'Madagaskara',
    'mh' => "Māršala\ salas",
    'mi' => "Midway\ Islands",
    'mk' => 'Maķedonija',
    'ml' => 'Mali',
    'mm' => 'Mjanma',
    'mn' => 'Mongolija',
    'mo' => 'Makao',
    'mp' => "Ziemeļu\ Marianas\ salas",
    'mq' => 'Martinika',
    'mr' => 'Mauritānija',
    'ms' => 'Montserrata',
    'mt' => 'Malta',
    'mu' => 'Maurīcija',
    'mv' => 'Maldīvija',
    'mw' => 'Malāvija',
    'mx' => 'Meksika',
    'my' => 'Malaizija',
    'mz' => 'Mozambika',
    'na' => 'Namībija',
    'nc' => 'Jaunkaledonija',
    'ne' => 'Nigēra',
    'nf' => "Norfolkas\ sala",
    'ng' => 'Nigērija',
    'ni' => 'Nikaragva',
    'nl' => 'Nīderlande',
    'no' => 'Norvēģija',
    'np' => 'Nepāla',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => 'Jaunzēlande',
    'om' => 'Omāna',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Peru',
    'pf' => "Franču\ Polinēzija",
    'pg' => "Papua\-Jaungvineja",
    'ph' => 'Filipīnas',
    'pk' => 'Pakistāna',
    'pl' => 'Polija',
    'pm' => "Senpjēra\ un\ Mikelona",
    'pn' => 'Pitkērna',
    'pr' => 'Puertoriko',
    'ps' => "Palestīniešu\ pašpārvaldes\ teritorija",
    'pt' => 'Portugāle',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paragvaja',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Katara',
    'qo' => "ASV\ Mazās\ Aizjūras\ salas",
    'qu' => "Eiropas\ Savienība",
    're' => 'Reinjona',
    'ro' => 'Rumānija',
    'rs' => 'Serbija',
    'ru' => 'Krievija',
    'rw' => 'Ruanda',
    'sa' => "Saūda\ Arābija",
    'sb' => "Zālamana\ salas",
    'sc' => "Seišeļu\ salas",
    'sd' => 'Sudāna',
    'se' => 'Zviedrija',
    'sg' => 'Singapūra',
    'sh' => "Sv\.\ Helēnas\ sala",
    'si' => 'Slovēnija',
    'sj' => "Svalbāra\ un\ Jana\ Majena\ sala",
    'sk' => 'Slovākija',
    'sl' => 'Sjerraleone',
    'sm' => 'Sanmarīno',
    'sn' => 'Senegāla',
    'so' => 'Somālija',
    'sr' => 'Surinama',
    'st' => "Santome\ un\ Prinsipi",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => 'Salvadora',
    'sy' => 'Sīrija',
    'sz' => 'Svazilenda',
    'tc' => "Tērksas\ un\ Kaikosas\ salas",
    'td' => 'Čada',
    'tf' => "Franču\ dienvidu\ teritorijas",
    'tg' => 'Togo',
    'th' => 'Taizeme',
    'tj' => 'Tadžikistāna',
    'tk' => 'Tokelau',
    'tl' => 'Austrumtimora',
    'tm' => 'Turkmenistāna',
    'tn' => 'Tunisija',
    'to' => 'Tonga',
    'tr' => 'Turcija',
    'tt' => "Trinidāda\ un\ Tobāgo",
    'tv' => 'Tuvalu',
    'tw' => 'Taivāna',
    'tz' => 'Tanzānija',
    'ua' => 'Ukraina',
    'ug' => 'Uganda',
    'um' => "ASV\ mazās\ aizjūras\ teritorijas",
    'us' => "Amerikas\ Savienotās\ Valstis",
    'uy' => 'Urugvaja',
    'uz' => 'Uzbekistāna',
    'va' => 'Vatikāns',
    'vc' => "Sentvinsenta\ un\ Grenadīnas",
    'vd' => "North\ Vietnam",
    've' => 'Venecuēla',
    'vg' => "Britu\ Virdžīnu\ salas",
    'vi' => "Amerikāņu\ Virdžīnu\ salas",
    'vn' => 'Vjetnama',
    'vu' => 'Vanuatu',
    'wf' => "Volisa\ un\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Jemena',
    'yt' => 'Majota',
    'za' => 'Dienvidāfrika',
    'zm' => 'Zambija',
    'zw' => 'Zimbabve',
    'zz' => "\(nezināms\ reģion\)",
);

%Locales::DB::Territory::lv::name_to_code = (
    'afganistāna'                              => 'af',
    'albānija'                                 => 'al',
    'alžīrija'                                => 'dz',
    'amerikassavienotāsvalstis'                => 'us',
    'amerikāņusamoa'                          => 'as',
    'amerikāņuvirdžīnusalas'                => 'vi',
    'andora'                                    => 'ad',
    'angilja'                                   => 'ai',
    'angola'                                    => 'ao',
    'antarktika'                                => 'aq',
    'antigvaunbarbuda'                          => 'ag',
    'apvienotiearābuemirāti'                  => 'ae',
    'argentīna'                                => 'ar',
    'armēnija'                                 => 'am',
    'aruba'                                     => 'aw',
    'asvmazāsaizjūrassalas'                   => 'qo',
    'asvmazāsaizjūrasteritorijas'             => 'um',
    'austrija'                                  => 'at',
    'austrumtimora'                             => 'tl',
    'austrālija'                               => 'au',
    'azerbaidžāna'                            => 'az',
    'bahamas'                                   => 'bs',
    'bahreina'                                  => 'bh',
    'baltkrievija'                              => 'by',
    'bangladeša'                               => 'bd',
    'barbadosa'                                 => 'bb',
    'beliza'                                    => 'bz',
    'benina'                                    => 'bj',
    'bermudusalas'                              => 'bm',
    'beļģija'                                 => 'be',
    'bolīvija'                                 => 'bo',
    'bosnijaunhercegovina'                      => 'ba',
    'botsvāna'                                 => 'bw',
    'brazīlija'                                => 'br',
    'britishantarcticterritory'                 => 'bq',
    'brituindijasokeānateritorija'             => 'io',
    'brituvirdžīnusalas'                      => 'vg',
    'bruneja'                                   => 'bn',
    'bulgārija'                                => 'bg',
    'burkinafaso'                               => 'bf',
    'burundi'                                   => 'bi',
    'butāna'                                   => 'bt',
    'buvēsala'                                 => 'bv',
    'cantonandenderburyislands'                 => 'ct',
    'centrālāfrikasrepublika'                 => 'cf',
    'dienviddžordžijaundienvidsendvičusalas' => 'gs',
    'dienvidkoreja'                             => 'kr',
    'dienvidāfrika'                            => 'za',
    'dominika'                                  => 'dm',
    'dominikānasrepublika'                     => 'do',
    'dronningmaudland'                          => 'nq',
    'dānija'                                   => 'dk',
    'džibutija'                                => 'dj',
    'džērsija'                                => 'je',
    'eastgermany'                               => 'dd',
    'eiropassavienība'                         => 'qu',
    'ekvadora'                                  => 'ec',
    'ekvatoriālāgvineja'                      => 'gq',
    'eritreja'                                  => 'er',
    'etiopija'                                  => 'et',
    'farērusalas'                              => 'fo',
    'fidži'                                    => 'fj',
    'filipīnas'                                => 'ph',
    'folklendasalas'                            => 'fk',
    'francija'                                  => 'fr',
    'frančudienviduteritorijas'                => 'tf',
    'frančugviāna'                            => 'gf',
    'frančupolinēzija'                        => 'pf',
    'frenchsouthernandantarcticterritories'     => 'fq',
    'gabona'                                    => 'ga',
    'gajāna'                                   => 'gy',
    'gambija'                                   => 'gm',
    'gana'                                      => 'gh',
    'gibraltārs'                               => 'gi',
    'grenlande'                                 => 'gl',
    'grenāda'                                  => 'gd',
    'grieķija'                                 => 'gr',
    'gruzija'                                   => 'ge',
    'guama'                                     => 'gu',
    'gvadelupa'                                 => 'gp',
    'gvatemala'                                 => 'gt',
    'gvineja'                                   => 'gn',
    'gvinejabisava'                             => 'gw',
    'gērnsija'                                 => 'gg',
    'haiti'                                     => 'ht',
    'hondurasa'                                 => 'hn',
    'honkonga'                                  => 'hk',
    'horvātija'                                => 'hr',
    'hērdaunmakdonaldasalas'                   => 'hm',
    'igaunija'                                  => 'ee',
    'indija'                                    => 'in',
    'indonēzija'                               => 'id',
    'irāka'                                    => 'iq',
    'irāna'                                    => 'ir',
    'itālija'                                  => 'it',
    'izraēla'                                  => 'il',
    'jamaika'                                   => 'jm',
    'japāna'                                   => 'jp',
    'jaunkaledonija'                            => 'nc',
    'jaunzēlande'                              => 'nz',
    'jemena'                                    => 'ye',
    'johnstonisland'                            => 'jt',
    'jordānija'                                => 'jo',
    'kaboverde'                                 => 'cv',
    'kaimanusalas'                              => 'ky',
    'kambodža'                                 => 'kh',
    'kamerūna'                                 => 'cm',
    'kanāda'                                   => 'ca',
    'katara'                                    => 'qa',
    'kazahstāna'                               => 'kz',
    'kenija'                                    => 'ke',
    'kipra'                                     => 'cy',
    'kirgīzija'                                => 'kg',
    'kiribati'                                  => 'ki',
    'kokosujebkīlingasalas'                    => 'cc',
    'kolumbija'                                 => 'co',
    'komorusalas'                               => 'km',
    'kongobrazzaville'                          => 'cg',
    'kongokinshasa'                             => 'cd',
    'kostarika'                                 => 'cr',
    'kotdivuāra'                               => 'ci',
    'krievija'                                  => 'ru',
    'kuba'                                      => 'cu',
    'kukasalas'                                 => 'ck',
    'kuveita'                                   => 'kw',
    'laosa'                                     => 'la',
    'latvija'                                   => 'lv',
    'lesoto'                                    => 'ls',
    'libāna'                                   => 'lb',
    'libērija'                                 => 'lr',
    'lielbritānija'                            => 'gb',
    'lietuva'                                   => 'lt',
    'lihtenšteina'                             => 'li',
    'luksemburga'                               => 'lu',
    'lībija'                                   => 'ly',
    'madagaskara'                               => 'mg',
    'majota'                                    => 'yt',
    'makao'                                     => 'mo',
    'malaizija'                                 => 'my',
    'maldīvija'                                => 'mv',
    'mali'                                      => 'ml',
    'malta'                                     => 'mt',
    'malāvija'                                 => 'mw',
    'maroka'                                    => 'ma',
    'martinika'                                 => 'mq',
    'mauritānija'                              => 'mr',
    'maurīcija'                                => 'mu',
    'maķedonija'                               => 'mk',
    'meksika'                                   => 'mx',
    'melnkalne'                                 => 'me',
    'mena'                                      => 'im',
    'metropolitanfrance'                        => 'fx',
    'midwayislands'                             => 'mi',
    'mikronēzijasfederatīvāsvalstis'         => 'fm',
    'mjanma'                                    => 'mm',
    'moldova'                                   => 'md',
    'monako'                                    => 'mc',
    'mongolija'                                 => 'mn',
    'montserrata'                               => 'ms',
    'mozambika'                                 => 'mz',
    'māršalasalas'                            => 'mh',
    'namībija'                                 => 'na',
    'nauru'                                     => 'nr',
    'nepāla'                                   => 'np',
    'neutralzone'                               => 'nt',
    'nezināmsreģion'                          => 'zz',
    'nigēra'                                   => 'ne',
    'nigērija'                                 => 'ng',
    'nikaragva'                                 => 'ni',
    'niue'                                      => 'nu',
    'norfolkassala'                             => 'nf',
    'northvietnam'                              => 'vd',
    'norvēģija'                               => 'no',
    'nīderlande'                               => 'nl',
    'nīderlandesantiļas'                      => 'an',
    'omāna'                                    => 'om',
    'pacificislandstrustterritory'              => 'pc',
    'pakistāna'                                => 'pk',
    'palau'                                     => 'pw',
    'palestīniešupašpārvaldesteritorija'    => 'ps',
    'panama'                                    => 'pa',
    'panamacanalzone'                           => 'pz',
    'papuajaungvineja'                          => 'pg',
    'paragvaja'                                 => 'py',
    'peoplesdemocraticrepublicofyemen'          => 'yd',
    'peru'                                      => 'pe',
    'pitkērna'                                 => 'pn',
    'polija'                                    => 'pl',
    'portugāle'                                => 'pt',
    'puertoriko'                                => 'pr',
    'reinjona'                                  => 're',
    'rietumsahāra'                             => 'eh',
    'ruanda'                                    => 'rw',
    'rumānija'                                 => 'ro',
    'saintbarthélemy'                          => 'bl',
    'saintmartin'                               => 'mf',
    'salvadora'                                 => 'sv',
    'samoa'                                     => 'ws',
    'sanmarīno'                                => 'sm',
    'santomeunprinsipi'                         => 'st',
    'saūdaarābija'                            => 'sa',
    'seišeļusalas'                            => 'sc',
    'senegāla'                                 => 'sn',
    'senpjēraunmikelona'                       => 'pm',
    'sentkitsaunnevisa'                         => 'kn',
    'sentlūsija'                               => 'lc',
    'sentvinsentaungrenadīnas'                 => 'vc',
    'serbija'                                   => 'rs',
    'serbijaunmelnkalne'                        => 'cs',
    'singapūra'                                => 'sg',
    'sjerraleone'                               => 'sl',
    'slovākija'                                => 'sk',
    'slovēnija'                                => 'si',
    'somija'                                    => 'fi',
    'somālija'                                 => 'so',
    'spānija'                                  => 'es',
    'sudāna'                                   => 'sd',
    'surinama'                                  => 'sr',
    "sv\.helēnassala"                          => 'sh',
    'svalbāraunjanamajenasala'                 => 'sj',
    'svazilenda'                                => 'sz',
    'sīrija'                                   => 'sy',
    'tadžikistāna'                            => 'tj',
    'taivāna'                                  => 'tw',
    'taizeme'                                   => 'th',
    'tanzānija'                                => 'tz',
    'togo'                                      => 'tg',
    'tokelau'                                   => 'tk',
    'tonga'                                     => 'to',
    'trinidādauntobāgo'                       => 'tt',
    'tunisija'                                  => 'tn',
    'turcija'                                   => 'tr',
    'turkmenistāna'                            => 'tm',
    'tuvalu'                                    => 'tv',
    'tērksasunkaikosassalas'                   => 'tc',
    "u\.s\.miscellaneouspacificislands"         => 'pu',
    'uganda'                                    => 'ug',
    'ukraina'                                   => 'ua',
    'ungārija'                                 => 'hu',
    'unionofsovietsocialistrepublics'           => 'su',
    'urugvaja'                                  => 'uy',
    'uzbekistāna'                              => 'uz',
    'vanuatu'                                   => 'vu',
    'vatikāns'                                 => 'va',
    'venecuēla'                                => 've',
    'vjetnama'                                  => 'vn',
    'volisaunfutuna'                            => 'wf',
    'vācija'                                   => 'de',
    'wakeisland'                                => 'wk',
    'zambija'                                   => 'zm',
    'ziemeļkoreja'                             => 'kp',
    'ziemeļumarianassalas'                     => 'mp',
    'ziemsvētkusala'                           => 'cx',
    'zimbabve'                                  => 'zw',
    'zviedrija'                                 => 'se',
    'zālamanasalas'                            => 'sb',
    'Ālandi'                                   => 'ax',
    'Čada'                                     => 'td',
    'Čehija'                                   => 'cz',
    'Čīle'                                    => 'cl',
    'Ēģipte'                                  => 'eg',
    'Īrija'                                    => 'ie',
    'Īslande'                                  => 'is',
    'Ķīna'                                    => 'cn',
    'Šrilanka'                                 => 'lk',
    'Šveice'                                   => 'ch',
);

1;

