package Locales::DB::Territory::ru;

# Auto generated from CLDR

$Locales::DB::Territory::ru::VERSION = '0.02';

$Locales::DB::Territory::ru::cldr_version = '1.7.1';

%Locales::DB::Territory::ru::code_to_name = (
    'ad' => 'Андорра',
    'ae' => "Объединенные\ Арабские\ Эмираты",
    'af' => 'Афганистан',
    'ag' => "Антигуа\ и\ Барбуда",
    'ai' => 'Ангуилла',
    'al' => 'Албания',
    'am' => 'Армения',
    'an' => "Нидерландские\ Антильские\ острова",
    'ao' => 'Ангола',
    'aq' => 'Антарктика',
    'ar' => 'Аргентина',
    'as' => "Американское\ Самоа",
    'at' => 'Австрия',
    'au' => 'Австралия',
    'aw' => 'Аруба',
    'ax' => "Аландские\ острова",
    'az' => 'Азербайджан',
    'ba' => "Босния\ и\ Герцеговина",
    'bb' => 'Барбадос',
    'bd' => 'Бангладеш',
    'be' => 'Бельгия',
    'bf' => "Буркина\ Фасо",
    'bg' => 'Болгария',
    'bh' => 'Бахрейн',
    'bi' => 'Бурунди',
    'bj' => 'Бенин',
    'bl' => "Остров\ Святого\ Бартоломея",
    'bm' => "Бермудские\ Острова",
    'bn' => "Бруней\ Даруссалам",
    'bo' => 'Боливия',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Бразилия',
    'bs' => "Багамские\ острова",
    'bt' => 'Бутан',
    'bv' => "Остров\ Буве",
    'bw' => 'Ботсвана',
    'by' => 'Беларусь',
    'bz' => 'Белиз',
    'ca' => 'Канада',
    'cc' => "Кокосовые\ острова",
    'cd' => "Демократическая\ Республика\ Конго",
    'cf' => "Центрально\-Африканская\ Республика",
    'cg' => 'Конго',
    'ch' => 'Швейцария',
    'ci' => "Кот\ д’Ивуар",
    'ck' => "Острова\ Кука",
    'cl' => 'Чили',
    'cm' => 'Камерун',
    'cn' => 'Китай',
    'co' => 'Колумбия',
    'cr' => "Коста\-Рика",
    'cs' => "Сербия\ и\ Черногория",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Куба',
    'cv' => "Острова\ Зеленого\ Мыса",
    'cx' => "Остров\ Рождества",
    'cy' => 'Кипр',
    'cz' => "Чешская\ республика",
    'dd' => "East\ Germany",
    'de' => 'Германия',
    'dj' => 'Джибути',
    'dk' => 'Дания',
    'dm' => "Остров\ Доминика",
    'do' => "Доминиканская\ Республика",
    'dz' => 'Алжир',
    'ec' => 'Эквадор',
    'ee' => 'Эстония',
    'eg' => 'Египет',
    'eh' => "Западная\ Сахара",
    'er' => 'Эритрея',
    'es' => 'Испания',
    'et' => 'Эфиопия',
    'fi' => 'Финляндия',
    'fj' => 'Фиджи',
    'fk' => "Фолклендские\ острова",
    'fm' => "Федеративные\ Штаты\ Микронезии",
    'fo' => "Фарерские\ острова",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Франция',
    'fx' => "Metropolitan\ France",
    'ga' => 'Габон',
    'gb' => 'Великобритания',
    'gd' => 'Гренада',
    'ge' => 'Грузия',
    'gf' => "Французская\ Гвиана",
    'gg' => 'Гернси',
    'gh' => 'Гана',
    'gi' => 'Гибралтар',
    'gl' => 'Гренландия',
    'gm' => 'Гамбия',
    'gn' => 'Гвинея',
    'gp' => 'Гваделупа',
    'gq' => "Экваториальная\ Гвинея",
    'gr' => 'Греция',
    'gs' => "Южная\ Джорджия\ и\ Южные\ Сандвичевы\ Острова",
    'gt' => 'Гватемала',
    'gu' => 'Гуам',
    'gw' => "Гвинея\-Биссау",
    'gy' => 'Гайана',
    'hk' => 'Гонконг',
    'hm' => "Острова\ Херд\ и\ Макдональд",
    'hn' => 'Гондурас',
    'hr' => 'Хорватия',
    'ht' => 'Гаити',
    'hu' => 'Венгрия',
    'id' => 'Индонезия',
    'ie' => 'Ирландия',
    'il' => 'Израиль',
    'im' => "Остров\ Мэн",
    'in' => 'Индия',
    'io' => "Британская\ территория\ в\ Индийском\ океане",
    'iq' => 'Ирак',
    'ir' => 'Иран',
    'is' => 'Исландия',
    'it' => 'Италия',
    'je' => 'Джерси',
    'jm' => 'Ямайка',
    'jo' => 'Иордания',
    'jp' => 'Япония',
    'jt' => "Johnston\ Island",
    'ke' => 'Кения',
    'kg' => 'Кыргызстан',
    'kh' => 'Камбоджа',
    'ki' => 'Кирибати',
    'km' => "Коморские\ Острова",
    'kn' => "Сент\-Киттс\ и\ Невис",
    'kp' => "Корейская\ Народно\-Демократическая\ Республика",
    'kr' => "Республика\ Корея",
    'kw' => 'Кувейт',
    'ky' => "Каймановы\ острова",
    'kz' => 'Казахстан',
    'la' => 'Лаос',
    'lb' => 'Ливан',
    'lc' => "Сент\-Люсия",
    'li' => 'Лихтенштейн',
    'lk' => "Шри\-Ланка",
    'lr' => 'Либерия',
    'ls' => 'Лесото',
    'lt' => 'Литва',
    'lu' => 'Люксембург',
    'lv' => 'Латвия',
    'ly' => 'Ливия',
    'ma' => 'Марокко',
    'mc' => 'Монако',
    'md' => 'Молдова',
    'me' => 'Черногория',
    'mf' => "Остров\ Святого\ Мартина",
    'mg' => 'Мадагаскар',
    'mh' => "Маршалловы\ Острова",
    'mi' => "Midway\ Islands",
    'mk' => 'Македония',
    'ml' => 'Мали',
    'mm' => 'Мьянма',
    'mn' => 'Монголия',
    'mo' => 'Макао',
    'mp' => "Северные\ Марианские\ Острова",
    'mq' => 'Мартиник',
    'mr' => 'Мавритания',
    'ms' => 'Монсеррат',
    'mt' => 'Мальта',
    'mu' => 'Маврикий',
    'mv' => 'Мальдивы',
    'mw' => 'Малави',
    'mx' => 'Мексика',
    'my' => 'Малайзия',
    'mz' => 'Мозамбик',
    'na' => 'Намибия',
    'nc' => "Новая\ Каледония",
    'ne' => 'Нигер',
    'nf' => "Остров\ Норфолк",
    'ng' => 'Нигерия',
    'ni' => 'Никарагуа',
    'nl' => 'Нидерланды',
    'no' => 'Норвегия',
    'np' => 'Непал',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Науру',
    'nt' => "Neutral\ Zone",
    'nu' => 'Ниуе',
    'nz' => "Новая\ Зеландия",
    'om' => 'Оман',
    'pa' => 'Панама',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Перу',
    'pf' => "Французская\ Полинезия",
    'pg' => "Папуа\-Новая\ Гвинея",
    'ph' => 'Филиппины',
    'pk' => 'Пакистан',
    'pl' => 'Польша',
    'pm' => "Сен\-Пьер\ и\ Микелон",
    'pn' => 'Питкерн',
    'pr' => "Пуэрто\-Рико",
    'ps' => "Палестинская\ автономия",
    'pt' => 'Португалия',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Палау',
    'py' => 'Парагвай',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Катар',
    'qo' => "Внешняя\ Океания",
    'qu' => "Европейский\ союз",
    're' => 'Реюньон',
    'ro' => 'Румыния',
    'rs' => 'Сербия',
    'ru' => 'Россия',
    'rw' => 'Руанда',
    'sa' => "Саудовская\ Аравия",
    'sb' => "Соломоновы\ Острова",
    'sc' => "Сейшельские\ Острова",
    'sd' => 'Судан',
    'se' => 'Швеция',
    'sg' => 'Сингапур',
    'sh' => "Остров\ Святой\ Елены",
    'si' => 'Словения',
    'sj' => "Свальбард\ и\ Ян\-Майен",
    'sk' => 'Словакия',
    'sl' => "Сьерра\-Леоне",
    'sm' => "Сан\-Марино",
    'sn' => 'Сенегал',
    'so' => 'Сомали',
    'sr' => 'Суринам',
    'st' => "Сан\-Томе\ и\ Принсипи",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => 'Сальвадор',
    'sy' => "Сирийская\ Арабская\ Республика",
    'sz' => 'Свазиленд',
    'tc' => "Острова\ Тёркс\ и\ Кайкос",
    'td' => 'Чад',
    'tf' => "Французские\ Южные\ Территории",
    'tg' => 'Того',
    'th' => 'Таиланд',
    'tj' => 'Таджикистан',
    'tk' => 'Токелау',
    'tl' => "Восточный\ Тимор",
    'tm' => 'Туркменистан',
    'tn' => 'Тунис',
    'to' => 'Тонга',
    'tr' => 'Турция',
    'tt' => "Тринидад\ и\ Тобаго",
    'tv' => 'Тувалу',
    'tw' => 'Тайвань',
    'tz' => 'Танзания',
    'ua' => 'Украина',
    'ug' => 'Уганда',
    'um' => "Внешние\ малые\ острова\ \(США\)",
    'us' => 'США',
    'uy' => 'Уругвай',
    'uz' => 'Узбекистан',
    'va' => 'Ватикан',
    'vc' => "Сент\-Винсент\ и\ Гренадины",
    'vd' => "North\ Vietnam",
    've' => 'Венесуэла',
    'vg' => "Британские\ Виргинские\ Острова",
    'vi' => "Американские\ Виргинские\ острова",
    'vn' => 'Вьетнам',
    'vu' => 'Вануату',
    'wf' => "Уоллис\ и\ Футуна",
    'wk' => "Wake\ Island",
    'ws' => 'Самоа',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Йемен',
    'yt' => 'Майотта',
    'za' => "Южная\ Африка",
    'zm' => 'Замбия',
    'zw' => 'Зимбабве',
    'zz' => "Неизвестный\ или\ недействительный\ регион",
);

%Locales::DB::Territory::ru::name_to_code = (
    'britishantarcticterritory'                                                          => 'bq',
    'cantonandenderburyislands'                                                          => 'ct',
    'dronningmaudland'                                                                   => 'nq',
    'eastgermany'                                                                        => 'dd',
    'frenchsouthernandantarcticterritories'                                              => 'fq',
    'johnstonisland'                                                                     => 'jt',
    'metropolitanfrance'                                                                 => 'fx',
    'midwayislands'                                                                      => 'mi',
    'neutralzone'                                                                        => 'nt',
    'northvietnam'                                                                       => 'vd',
    'pacificislandstrustterritory'                                                       => 'pc',
    'panamacanalzone'                                                                    => 'pz',
    'peoplesdemocraticrepublicofyemen'                                                   => 'yd',
    "u\.s\.miscellaneouspacificislands"                                                  => 'pu',
    'unionofsovietsocialistrepublics'                                                    => 'su',
    'wakeisland'                                                                         => 'wk',
    'Австралия'                                                                 => 'au',
    'Австрия'                                                                     => 'at',
    'Азербайджан'                                                             => 'az',
    'Аландскиеострова'                                                   => 'ax',
    'Албания'                                                                     => 'al',
    'Алжир'                                                                         => 'dz',
    'АмериканскиеВиргинскиеострова'                         => 'vi',
    'АмериканскоеСамоа'                                                 => 'as',
    'Ангола'                                                                       => 'ao',
    'Ангуилла'                                                                   => 'ai',
    'Андорра'                                                                     => 'ad',
    'Антарктика'                                                               => 'aq',
    'АнтигуаиБарбуда'                                                     => 'ag',
    'Аргентина'                                                                 => 'ar',
    'Армения'                                                                     => 'am',
    'Аруба'                                                                         => 'aw',
    'Афганистан'                                                               => 'af',
    'Багамскиеострова'                                                   => 'bs',
    'Бангладеш'                                                                 => 'bd',
    'Барбадос'                                                                   => 'bb',
    'Бахрейн'                                                                     => 'bh',
    'Беларусь'                                                                   => 'by',
    'Белиз'                                                                         => 'bz',
    'Бельгия'                                                                     => 'be',
    'Бенин'                                                                         => 'bj',
    'БермудскиеОстрова'                                                 => 'bm',
    'Болгария'                                                                   => 'bg',
    'Боливия'                                                                     => 'bo',
    'БоснияиГерцеговина'                                               => 'ba',
    'Ботсвана'                                                                   => 'bw',
    'Бразилия'                                                                   => 'br',
    'БританскаятерриториявИндийскомокеане'           => 'io',
    'БританскиеВиргинскиеОстрова'                             => 'vg',
    'БрунейДаруссалам'                                                   => 'bn',
    'БуркинаФасо'                                                             => 'bf',
    'Бурунди'                                                                     => 'bi',
    'Бутан'                                                                         => 'bt',
    'Вануату'                                                                     => 'vu',
    'Ватикан'                                                                     => 'va',
    'Великобритания'                                                       => 'gb',
    'Венгрия'                                                                     => 'hu',
    'Венесуэла'                                                                 => 've',
    'ВнешниемалыеостроваСША'                                       => 'um',
    'ВнешняяОкеания'                                                       => 'qo',
    'ВосточныйТимор'                                                       => 'tl',
    'Вьетнам'                                                                     => 'vn',
    'Габон'                                                                         => 'ga',
    'Гаити'                                                                         => 'ht',
    'Гайана'                                                                       => 'gy',
    'Гамбия'                                                                       => 'gm',
    'Гана'                                                                           => 'gh',
    'Гваделупа'                                                                 => 'gp',
    'Гватемала'                                                                 => 'gt',
    'Гвинея'                                                                       => 'gn',
    'ГвинеяБиссау'                                                           => 'gw',
    'Германия'                                                                   => 'de',
    'Гернси'                                                                       => 'gg',
    'Гибралтар'                                                                 => 'gi',
    'Гондурас'                                                                   => 'hn',
    'Гонконг'                                                                     => 'hk',
    'Гренада'                                                                     => 'gd',
    'Гренландия'                                                               => 'gl',
    'Греция'                                                                       => 'gr',
    'Грузия'                                                                       => 'ge',
    'Гуам'                                                                           => 'gu',
    'Дания'                                                                         => 'dk',
    'ДемократическаяРеспубликаКонго'                       => 'cd',
    'Джерси'                                                                       => 'je',
    'Джибути'                                                                     => 'dj',
    'ДоминиканскаяРеспублика'                                     => 'do',
    'Европейскийсоюз'                                                     => 'qu',
    'Египет'                                                                       => 'eg',
    'Замбия'                                                                       => 'zm',
    'ЗападнаяСахара'                                                       => 'eh',
    'Зимбабве'                                                                   => 'zw',
    'Израиль'                                                                     => 'il',
    'Индия'                                                                         => 'in',
    'Индонезия'                                                                 => 'id',
    'Иордания'                                                                   => 'jo',
    'Ирак'                                                                           => 'iq',
    'Иран'                                                                           => 'ir',
    'Ирландия'                                                                   => 'ie',
    'Исландия'                                                                   => 'is',
    'Испания'                                                                     => 'es',
    'Италия'                                                                       => 'it',
    'Йемен'                                                                         => 'ye',
    'Казахстан'                                                                 => 'kz',
    'Каймановыострова'                                                   => 'ky',
    'Камбоджа'                                                                   => 'kh',
    'Камерун'                                                                     => 'cm',
    'Канада'                                                                       => 'ca',
    'Катар'                                                                         => 'qa',
    'Кения'                                                                         => 'ke',
    'Кипр'                                                                           => 'cy',
    'Кирибати'                                                                   => 'ki',
    'Китай'                                                                         => 'cn',
    'Кокосовыеострова'                                                   => 'cc',
    'Колумбия'                                                                   => 'co',
    'КоморскиеОстрова'                                                   => 'km',
    'Конго'                                                                         => 'cg',
    'КорейскаяНародноДемократическаяРеспублика' => 'kp',
    'КостаРика'                                                                 => 'cr',
    'Котд’Ивуар'                                                              => 'ci',
    'Куба'                                                                           => 'cu',
    'Кувейт'                                                                       => 'kw',
    'Кыргызстан'                                                               => 'kg',
    'Лаос'                                                                           => 'la',
    'Латвия'                                                                       => 'lv',
    'Лесото'                                                                       => 'ls',
    'Либерия'                                                                     => 'lr',
    'Ливан'                                                                         => 'lb',
    'Ливия'                                                                         => 'ly',
    'Литва'                                                                         => 'lt',
    'Лихтенштейн'                                                             => 'li',
    'Люксембург'                                                               => 'lu',
    'Маврикий'                                                                   => 'mu',
    'Мавритания'                                                               => 'mr',
    'Мадагаскар'                                                               => 'mg',
    'Майотта'                                                                     => 'yt',
    'Макао'                                                                         => 'mo',
    'Македония'                                                                 => 'mk',
    'Малави'                                                                       => 'mw',
    'Малайзия'                                                                   => 'my',
    'Мали'                                                                           => 'ml',
    'Мальдивы'                                                                   => 'mv',
    'Мальта'                                                                       => 'mt',
    'Марокко'                                                                     => 'ma',
    'Мартиник'                                                                   => 'mq',
    'МаршалловыОстрова'                                                 => 'mh',
    'Мексика'                                                                     => 'mx',
    'Мозамбик'                                                                   => 'mz',
    'Молдова'                                                                     => 'md',
    'Монако'                                                                       => 'mc',
    'Монголия'                                                                   => 'mn',
    'Монсеррат'                                                                 => 'ms',
    'Мьянма'                                                                       => 'mm',
    'Намибия'                                                                     => 'na',
    'Науру'                                                                         => 'nr',
    'Неизвестныйилинедействительныйрегион'           => 'zz',
    'Непал'                                                                         => 'np',
    'Нигер'                                                                         => 'ne',
    'Нигерия'                                                                     => 'ng',
    'НидерландскиеАнтильскиеострова'                       => 'an',
    'Нидерланды'                                                               => 'nl',
    'Никарагуа'                                                                 => 'ni',
    'Ниуе'                                                                           => 'nu',
    'НоваяЗеландия'                                                         => 'nz',
    'НоваяКаледония'                                                       => 'nc',
    'Норвегия'                                                                   => 'no',
    'ОбъединенныеАрабскиеЭмираты'                             => 'ae',
    'Оман'                                                                           => 'om',
    'ОстровБуве'                                                               => 'bv',
    'ОстровДоминика'                                                       => 'dm',
    'ОстровМэн'                                                                 => 'im',
    'ОстровНорфолк'                                                         => 'nf',
    'ОстровРождества'                                                     => 'cx',
    'ОстровСвятогоБартоломея'                                     => 'bl',
    'ОстровСвятогоМартина'                                           => 'mf',
    'ОстровСвятойЕлены'                                                 => 'sh',
    'ОстроваЗеленогоМыса'                                             => 'cv',
    'ОстроваКука'                                                             => 'ck',
    'ОстроваТёрксиКайкос'                                             => 'tc',
    'ОстроваХердиМакдональд'                                       => 'hm',
    'Пакистан'                                                                   => 'pk',
    'Палау'                                                                         => 'pw',
    'Палестинскаяавтономия'                                         => 'ps',
    'Панама'                                                                       => 'pa',
    'ПапуаНоваяГвинея'                                                   => 'pg',
    'Парагвай'                                                                   => 'py',
    'Перу'                                                                           => 'pe',
    'Питкерн'                                                                     => 'pn',
    'Польша'                                                                       => 'pl',
    'Португалия'                                                               => 'pt',
    'ПуэртоРико'                                                               => 'pr',
    'РеспубликаКорея'                                                     => 'kr',
    'Реюньон'                                                                     => 're',
    'Россия'                                                                       => 'ru',
    'Руанда'                                                                       => 'rw',
    'Румыния'                                                                     => 'ro',
    'США'                                                                             => 'us',
    'Сальвадор'                                                                 => 'sv',
    'Самоа'                                                                         => 'ws',
    'СанМарино'                                                                 => 'sm',
    'СанТомеиПринсипи'                                                   => 'st',
    'СаудовскаяАравия'                                                   => 'sa',
    'Свазиленд'                                                                 => 'sz',
    'СвальбардиЯнМайен'                                                 => 'sj',
    'СеверныеМарианскиеОстрова'                                 => 'mp',
    'СейшельскиеОстрова'                                               => 'sc',
    'СенПьериМикелон'                                                     => 'pm',
    'Сенегал'                                                                     => 'sn',
    'СентВинсентиГренадины'                                         => 'vc',
    'СентКиттсиНевис'                                                     => 'kn',
    'СентЛюсия'                                                                 => 'lc',
    'Сербия'                                                                       => 'rs',
    'СербияиЧерногория'                                                 => 'cs',
    'Сингапур'                                                                   => 'sg',
    'СирийскаяАрабскаяРеспублика'                             => 'sy',
    'Словакия'                                                                   => 'sk',
    'Словения'                                                                   => 'si',
    'СоломоновыОстрова'                                                 => 'sb',
    'Сомали'                                                                       => 'so',
    'Судан'                                                                         => 'sd',
    'Суринам'                                                                     => 'sr',
    'СьерраЛеоне'                                                             => 'sl',
    'Таджикистан'                                                             => 'tj',
    'Таиланд'                                                                     => 'th',
    'Тайвань'                                                                     => 'tw',
    'Танзания'                                                                   => 'tz',
    'Того'                                                                           => 'tg',
    'Токелау'                                                                     => 'tk',
    'Тонга'                                                                         => 'to',
    'ТринидадиТобаго'                                                     => 'tt',
    'Тувалу'                                                                       => 'tv',
    'Тунис'                                                                         => 'tn',
    'Туркменистан'                                                           => 'tm',
    'Турция'                                                                       => 'tr',
    'Уганда'                                                                       => 'ug',
    'Узбекистан'                                                               => 'uz',
    'Украина'                                                                     => 'ua',
    'УоллисиФутуна'                                                         => 'wf',
    'Уругвай'                                                                     => 'uy',
    'Фарерскиеострова'                                                   => 'fo',
    'ФедеративныеШтатыМикронезии'                             => 'fm',
    'Фиджи'                                                                         => 'fj',
    'Филиппины'                                                                 => 'ph',
    'Финляндия'                                                                 => 'fi',
    'Фолклендскиеострова'                                             => 'fk',
    'Франция'                                                                     => 'fr',
    'ФранцузскаяГвиана'                                                 => 'gf',
    'ФранцузскаяПолинезия'                                           => 'pf',
    'ФранцузскиеЮжныеТерритории'                               => 'tf',
    'Хорватия'                                                                   => 'hr',
    'ЦентральноАфриканскаяРеспублика'                     => 'cf',
    'Чад'                                                                             => 'td',
    'Черногория'                                                               => 'me',
    'Чешскаяреспублика'                                                 => 'cz',
    'Чили'                                                                           => 'cl',
    'Швейцария'                                                                 => 'ch',
    'Швеция'                                                                       => 'se',
    'ШриЛанка'                                                                   => 'lk',
    'Эквадор'                                                                     => 'ec',
    'ЭкваториальнаяГвинея'                                           => 'gq',
    'Эритрея'                                                                     => 'er',
    'Эстония'                                                                     => 'ee',
    'Эфиопия'                                                                     => 'et',
    'ЮжнаяАфрика'                                                             => 'za',
    'ЮжнаяДжорджияиЮжныеСандвичевыОстрова'           => 'gs',
    'Ямайка'                                                                       => 'jm',
    'Япония'                                                                       => 'jp',
);

1;

