package Locales::DB::Territory::gl;

# Auto generated from CLDR

$Locales::DB::Territory::gl::VERSION = '0.02';

$Locales::DB::Territory::gl::cldr_version = '1.7.1';

%Locales::DB::Territory::gl::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "Emiratos\ Árabes\ Unidos",
    'af' => 'Afganistán',
    'ag' => "Antiga\ e\ Barbuda",
    'ai' => 'Anguila',
    'al' => 'Albania',
    'am' => 'Armenia',
    'an' => "Antillas\ Holandesas",
    'ao' => 'Angola',
    'aq' => 'Antártida',
    'ar' => 'Arxentina',
    'as' => "Samoa\ Americana",
    'at' => 'Austria',
    'au' => 'Australia',
    'aw' => 'Aruba',
    'ax' => "Illas\ Aland",
    'az' => 'Acerbaixán',
    'ba' => "Bosnia\ e\ Hercegovina",
    'bb' => 'Barbados',
    'bd' => 'Bangladesh',
    'be' => 'Bélxica',
    'bf' => "Burkina\ Faso",
    'bg' => 'Bulgaria',
    'bh' => 'Bahrein',
    'bi' => 'Burundi',
    'bj' => 'Benin',
    'bl' => "San\ Bartolomé",
    'bm' => 'Bermudas',
    'bn' => 'Brunei',
    'bo' => 'Bolivia',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brasil',
    'bs' => 'Bahamas',
    'bt' => 'Bután',
    'bv' => "Illa\ Bouvet",
    'bw' => 'Botsuana',
    'by' => 'Bielorrusia',
    'bz' => 'Belice',
    'ca' => 'Canadá',
    'cc' => "Illas\ Cocos",
    'cd' => "República\ Democrática\ do\ Congo",
    'cf' => "República\ Africana\ Central",
    'cg' => 'Congo',
    'ch' => 'Suíza',
    'ci' => "Costa\ de\ Marfil",
    'ck' => "Illas\ Cook",
    'cl' => 'Chile',
    'cm' => 'Camerún',
    'cn' => 'China',
    'co' => 'Colombia',
    'cr' => "Costa\ Rica",
    'cs' => "Serbia\ e\ Montenegro",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Cuba',
    'cv' => "Cabo\ Verde",
    'cx' => "Illa\ Christmas",
    'cy' => 'Chipre',
    'cz' => "República\ Checa",
    'dd' => "East\ Germany",
    'de' => 'Alemaña',
    'dj' => 'Xibuti',
    'dk' => 'Dinamarca',
    'dm' => 'Dominica',
    'do' => "República\ Dominicana",
    'dz' => 'Arxelia',
    'ec' => 'Ecuador',
    'ee' => 'Estonia',
    'eg' => 'Exipto',
    'eh' => "Sahara\ Occidental",
    'er' => 'Eritrea',
    'es' => 'España',
    'et' => 'Etiopía',
    'fi' => 'Finlandia',
    'fj' => 'Fixi',
    'fk' => "Illas\ Malvinas",
    'fm' => 'Micronesia',
    'fo' => "Illas\ Feroe",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Francia',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabón',
    'gb' => "Reino\ Unido",
    'gd' => 'Granada',
    'ge' => 'Xeorxia',
    'gf' => "Güiana\ Francesa",
    'gg' => 'Guernsey',
    'gh' => 'Gana',
    'gi' => 'Xibraltar',
    'gl' => 'Grenlandia',
    'gm' => 'Gambia',
    'gn' => 'Guinea',
    'gp' => 'Guadalupe',
    'gq' => "Guinea\ Ecuatorial",
    'gr' => 'Grecia',
    'gs' => "Xeorxia\ do\ Sur\ e\ Illas\ Sandwich",
    'gt' => 'Guatemala',
    'gu' => 'Guam',
    'gw' => "Guinea\-Bissau",
    'gy' => 'Güiana',
    'hk' => "Hong\ Kong",
    'hm' => "Illa\ Heard\ e\ Illas\ McDonald",
    'hn' => 'Honduras',
    'hr' => 'Croacia',
    'ht' => 'Haití',
    'hu' => 'Hungría',
    'id' => 'Indonesia',
    'ie' => 'Irlanda',
    'il' => 'Israel',
    'im' => "Illa\ de\ Man",
    'in' => 'India',
    'io' => "Territorio\ Británico\ do\ Océano\ Índico",
    'iq' => 'Iraq',
    'ir' => 'Irán',
    'is' => 'Islandia',
    'it' => 'Italia',
    'je' => 'Jersey',
    'jm' => 'Xamaica',
    'jo' => 'Xordania',
    'jp' => 'Xapón',
    'jt' => "Johnston\ Island",
    'ke' => 'Quenia',
    'kg' => 'Quirguicistán',
    'kh' => 'Cambodia',
    'ki' => 'Kiribati',
    'km' => 'Comores',
    'kn' => "San\ Cristovo\ e\ Nevis",
    'kp' => "Corea\ do\ Norte",
    'kr' => "Corea\ do\ Sur",
    'kw' => 'Kuwait',
    'ky' => "Illas\ Caimán",
    'kz' => 'Kazakhstan',
    'la' => 'Laos',
    'lb' => 'Líbano',
    'lc' => "Santa\ Lucía",
    'li' => 'Liechtenstein',
    'lk' => "Sri\ Lanka",
    'lr' => 'Liberia',
    'ls' => 'Lesotho',
    'lt' => 'Lituania',
    'lu' => 'Luxemburgo',
    'lv' => 'Letonia',
    'ly' => 'Libia',
    'ma' => 'Marrocos',
    'mc' => 'Mónaco',
    'md' => 'Moldova',
    'me' => 'Montenegro',
    'mf' => "San\ Martiño",
    'mg' => 'Madagascar',
    'mh' => "Illas\ Marshall",
    'mi' => "Midway\ Islands",
    'mk' => 'Macedonia',
    'ml' => 'Mali',
    'mm' => 'Myanmar',
    'mn' => 'Mongolia',
    'mo' => 'Macau',
    'mp' => "Illas\ Marianas\ do\ norte",
    'mq' => 'Martinica',
    'mr' => 'Mauritania',
    'ms' => 'Montserrat',
    'mt' => 'Malta',
    'mu' => 'Mauricio',
    'mv' => 'Maldivas',
    'mw' => 'Malaui',
    'mx' => 'México',
    'my' => 'Malaisia',
    'mz' => 'Mozambique',
    'na' => 'Namibia',
    'nc' => "Nova\ Caledonia",
    'ne' => 'Níxer',
    'nf' => "Illa\ Norfolk",
    'ng' => 'Nixeria',
    'ni' => 'Nicaragua',
    'nl' => "Países\ Baixos",
    'no' => 'Noruega',
    'np' => 'Nepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "Nova\ Celandia",
    'om' => 'Omán',
    'pa' => 'Panamá',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Perú',
    'pf' => "Polinesia\ Francesa",
    'pg' => "Papúa\ Nova\ Guinea",
    'ph' => 'Filipinas',
    'pk' => 'Paquistán',
    'pl' => 'Polonia',
    'pm' => "San\ Pedro\ e\ Miguelón",
    'pn' => 'Pitcairn',
    'pr' => "Porto\ Rico",
    'ps' => 'Palestina',
    'pt' => 'Portugal',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paraguai',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Qatar',
    'qo' => "Oceanía\ Distante",
    'qu' => "Unión\ Europea",
    're' => 'Reunión',
    'ro' => 'Romanía',
    'rs' => 'Serbia',
    'ru' => 'Rusia',
    'rw' => 'Ruanda',
    'sa' => "Arabia\ Saudita",
    'sb' => "Illas\ Salomón",
    'sc' => 'Seixeles',
    'sd' => 'Sudán',
    'se' => 'Suecia',
    'sg' => 'Singapur',
    'sh' => "Santa\ Helena",
    'si' => 'Eslovenia',
    'sj' => "Svalbard\ e\ Jan\ Mayen",
    'sk' => 'Eslovaquia',
    'sl' => "Serra\ Leoa",
    'sm' => "San\ Marino",
    'sn' => 'Senegal',
    'so' => 'Somalia',
    'sr' => 'Surinam',
    'st' => "Santo\ Tomé\ e\ Príncipe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salvador",
    'sy' => 'Siria',
    'sz' => 'Suacilandia',
    'tc' => "Illas\ Turks\ e\ Caicos",
    'td' => 'Xad',
    'tf' => "Territorios\ Franceses\ do\ Sul",
    'tg' => 'Togo',
    'th' => 'Tailandia',
    'tj' => 'Taxiquistán',
    'tk' => 'Tokelau',
    'tl' => "Timor\ Leste",
    'tm' => 'Turkmenistán',
    'tn' => 'Tunisia',
    'to' => 'Tonga',
    'tr' => 'Turquía',
    'tt' => "Trindade\ e\ Tobago",
    'tv' => 'Tuvalu',
    'tw' => 'Taiwán',
    'tz' => 'Tanzania',
    'ua' => 'Ucraína',
    'ug' => 'Uganda',
    'um' => "Illas\ Menores\ Distantes\ dos\ EUA\.",
    'us' => "Estados\ Unidos\ de\ América",
    'uy' => 'Uruguai',
    'uz' => 'Uzbekistán',
    'va' => "Cidade\ do\ Vaticano",
    'vc' => "San\ Vicente\ e\ Granadinas",
    'vd' => "North\ Vietnam",
    've' => 'Venezuela',
    'vg' => "Illas\ Virxes\ Británicas",
    'vi' => "Illas\ Virxes\ Estadounidenses",
    'vn' => 'Vietnam',
    'vu' => 'Vanuatu',
    'wf' => "Wallis\ e\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Iemen',
    'yt' => 'Mayotte',
    'za' => 'Sudáfrica',
    'zm' => 'Zambia',
    'zw' => 'Cimbabue',
    'zz' => "rexión\ descoñecida\ ou\ non\ válida",
);

%Locales::DB::Territory::gl::name_to_code = (
    'acerbaixán'                           => 'az',
    'afganistán'                           => 'af',
    'albania'                               => 'al',
    'alemaña'                              => 'de',
    'andorra'                               => 'ad',
    'angola'                                => 'ao',
    'anguila'                               => 'ai',
    'antigaebarbuda'                        => 'ag',
    'antillasholandesas'                    => 'an',
    'antártida'                            => 'aq',
    'arabiasaudita'                         => 'sa',
    'armenia'                               => 'am',
    'aruba'                                 => 'aw',
    'arxelia'                               => 'dz',
    'arxentina'                             => 'ar',
    'australia'                             => 'au',
    'austria'                               => 'at',
    'bahamas'                               => 'bs',
    'bahrein'                               => 'bh',
    'bangladesh'                            => 'bd',
    'barbados'                              => 'bb',
    'belice'                                => 'bz',
    'benin'                                 => 'bj',
    'bermudas'                              => 'bm',
    'bielorrusia'                           => 'by',
    'bolivia'                               => 'bo',
    'bosniaehercegovina'                    => 'ba',
    'botsuana'                              => 'bw',
    'brasil'                                => 'br',
    'britishantarcticterritory'             => 'bq',
    'brunei'                                => 'bn',
    'bulgaria'                              => 'bg',
    'burkinafaso'                           => 'bf',
    'burundi'                               => 'bi',
    'bután'                                => 'bt',
    'bélxica'                              => 'be',
    'caboverde'                             => 'cv',
    'cambodia'                              => 'kh',
    'camerún'                              => 'cm',
    'canadá'                               => 'ca',
    'cantonandenderburyislands'             => 'ct',
    'chile'                                 => 'cl',
    'china'                                 => 'cn',
    'chipre'                                => 'cy',
    'cidadedovaticano'                      => 'va',
    'cimbabue'                              => 'zw',
    'colombia'                              => 'co',
    'comores'                               => 'km',
    'congo'                                 => 'cg',
    'coreadonorte'                          => 'kp',
    'coreadosur'                            => 'kr',
    'costademarfil'                         => 'ci',
    'costarica'                             => 'cr',
    'croacia'                               => 'hr',
    'cuba'                                  => 'cu',
    'dinamarca'                             => 'dk',
    'dominica'                              => 'dm',
    'dronningmaudland'                      => 'nq',
    'eastgermany'                           => 'dd',
    'ecuador'                               => 'ec',
    'elsalvador'                            => 'sv',
    'emiratosÁrabesunidos'                 => 'ae',
    'eritrea'                               => 'er',
    'eslovaquia'                            => 'sk',
    'eslovenia'                             => 'si',
    'españa'                               => 'es',
    'estadosunidosdeamérica'               => 'us',
    'estonia'                               => 'ee',
    'etiopía'                              => 'et',
    'exipto'                                => 'eg',
    'filipinas'                             => 'ph',
    'finlandia'                             => 'fi',
    'fixi'                                  => 'fj',
    'francia'                               => 'fr',
    'frenchsouthernandantarcticterritories' => 'fq',
    'gabón'                                => 'ga',
    'gambia'                                => 'gm',
    'gana'                                  => 'gh',
    'granada'                               => 'gd',
    'grecia'                                => 'gr',
    'grenlandia'                            => 'gl',
    'guadalupe'                             => 'gp',
    'guam'                                  => 'gu',
    'guatemala'                             => 'gt',
    'guernsey'                              => 'gg',
    'guinea'                                => 'gn',
    'guineabissau'                          => 'gw',
    'guineaecuatorial'                      => 'gq',
    'güiana'                               => 'gy',
    'güianafrancesa'                       => 'gf',
    'haití'                                => 'ht',
    'honduras'                              => 'hn',
    'hongkong'                              => 'hk',
    'hungría'                              => 'hu',
    'iemen'                                 => 'ye',
    'illabouvet'                            => 'bv',
    'illachristmas'                         => 'cx',
    'illademan'                             => 'im',
    'illaheardeillasmcdonald'               => 'hm',
    'illanorfolk'                           => 'nf',
    'illasaland'                            => 'ax',
    'illascaimán'                          => 'ky',
    'illascocos'                            => 'cc',
    'illascook'                             => 'ck',
    'illasferoe'                            => 'fo',
    'illasmalvinas'                         => 'fk',
    'illasmarianasdonorte'                  => 'mp',
    'illasmarshall'                         => 'mh',
    "illasmenoresdistantesdoseua\."         => 'um',
    'illassalomón'                         => 'sb',
    'illasturksecaicos'                     => 'tc',
    'illasvirxesbritánicas'                => 'vg',
    'illasvirxesestadounidenses'            => 'vi',
    'india'                                 => 'in',
    'indonesia'                             => 'id',
    'iraq'                                  => 'iq',
    'irlanda'                               => 'ie',
    'irán'                                 => 'ir',
    'islandia'                              => 'is',
    'israel'                                => 'il',
    'italia'                                => 'it',
    'jersey'                                => 'je',
    'johnstonisland'                        => 'jt',
    'kazakhstan'                            => 'kz',
    'kiribati'                              => 'ki',
    'kuwait'                                => 'kw',
    'laos'                                  => 'la',
    'lesotho'                               => 'ls',
    'letonia'                               => 'lv',
    'liberia'                               => 'lr',
    'libia'                                 => 'ly',
    'liechtenstein'                         => 'li',
    'lituania'                              => 'lt',
    'luxemburgo'                            => 'lu',
    'líbano'                               => 'lb',
    'macau'                                 => 'mo',
    'macedonia'                             => 'mk',
    'madagascar'                            => 'mg',
    'malaisia'                              => 'my',
    'malaui'                                => 'mw',
    'maldivas'                              => 'mv',
    'mali'                                  => 'ml',
    'malta'                                 => 'mt',
    'marrocos'                              => 'ma',
    'martinica'                             => 'mq',
    'mauricio'                              => 'mu',
    'mauritania'                            => 'mr',
    'mayotte'                               => 'yt',
    'metropolitanfrance'                    => 'fx',
    'micronesia'                            => 'fm',
    'midwayislands'                         => 'mi',
    'moldova'                               => 'md',
    'mongolia'                              => 'mn',
    'montenegro'                            => 'me',
    'montserrat'                            => 'ms',
    'mozambique'                            => 'mz',
    'myanmar'                               => 'mm',
    'méxico'                               => 'mx',
    'mónaco'                               => 'mc',
    'namibia'                               => 'na',
    'nauru'                                 => 'nr',
    'nepal'                                 => 'np',
    'neutralzone'                           => 'nt',
    'nicaragua'                             => 'ni',
    'niue'                                  => 'nu',
    'nixeria'                               => 'ng',
    'northvietnam'                          => 'vd',
    'noruega'                               => 'no',
    'novacaledonia'                         => 'nc',
    'novacelandia'                          => 'nz',
    'níxer'                                => 'ne',
    'oceaníadistante'                      => 'qo',
    'omán'                                 => 'om',
    'pacificislandstrustterritory'          => 'pc',
    'palau'                                 => 'pw',
    'palestina'                             => 'ps',
    'panamacanalzone'                       => 'pz',
    'panamá'                               => 'pa',
    'papúanovaguinea'                      => 'pg',
    'paquistán'                            => 'pk',
    'paraguai'                              => 'py',
    'paísesbaixos'                         => 'nl',
    'peoplesdemocraticrepublicofyemen'      => 'yd',
    'perú'                                 => 'pe',
    'pitcairn'                              => 'pn',
    'polinesiafrancesa'                     => 'pf',
    'polonia'                               => 'pl',
    'portorico'                             => 'pr',
    'portugal'                              => 'pt',
    'qatar'                                 => 'qa',
    'quenia'                                => 'ke',
    'quirguicistán'                        => 'kg',
    'reinounido'                            => 'gb',
    'repúblicaafricanacentral'             => 'cf',
    'repúblicacheca'                       => 'cz',
    'repúblicademocráticadocongo'         => 'cd',
    'repúblicadominicana'                  => 'do',
    'reunión'                              => 're',
    'rexióndescoñecidaounonválida'       => 'zz',
    'romanía'                              => 'ro',
    'ruanda'                                => 'rw',
    'rusia'                                 => 'ru',
    'saharaoccidental'                      => 'eh',
    'samoa'                                 => 'ws',
    'samoaamericana'                        => 'as',
    'sanbartolomé'                         => 'bl',
    'sancristovoenevis'                     => 'kn',
    'sanmarino'                             => 'sm',
    'sanmartiño'                           => 'mf',
    'sanpedroemiguelón'                    => 'pm',
    'santahelena'                           => 'sh',
    'santalucía'                           => 'lc',
    'santotoméepríncipe'                  => 'st',
    'sanvicenteegranadinas'                 => 'vc',
    'seixeles'                              => 'sc',
    'senegal'                               => 'sn',
    'serbia'                                => 'rs',
    'serbiaemontenegro'                     => 'cs',
    'serraleoa'                             => 'sl',
    'singapur'                              => 'sg',
    'siria'                                 => 'sy',
    'somalia'                               => 'so',
    'srilanka'                              => 'lk',
    'suacilandia'                           => 'sz',
    'sudáfrica'                            => 'za',
    'sudán'                                => 'sd',
    'suecia'                                => 'se',
    'surinam'                               => 'sr',
    'suíza'                                => 'ch',
    'svalbardejanmayen'                     => 'sj',
    'tailandia'                             => 'th',
    'taiwán'                               => 'tw',
    'tanzania'                              => 'tz',
    'taxiquistán'                          => 'tj',
    'territoriobritánicodoocéanoÍndico'  => 'io',
    'territoriosfrancesesdosul'             => 'tf',
    'timorleste'                            => 'tl',
    'togo'                                  => 'tg',
    'tokelau'                               => 'tk',
    'tonga'                                 => 'to',
    'trindadeetobago'                       => 'tt',
    'tunisia'                               => 'tn',
    'turkmenistán'                         => 'tm',
    'turquía'                              => 'tr',
    'tuvalu'                                => 'tv',
    "u\.s\.miscellaneouspacificislands"     => 'pu',
    'ucraína'                              => 'ua',
    'uganda'                                => 'ug',
    'unionofsovietsocialistrepublics'       => 'su',
    'unióneuropea'                         => 'qu',
    'uruguai'                               => 'uy',
    'uzbekistán'                           => 'uz',
    'vanuatu'                               => 'vu',
    'venezuela'                             => 've',
    'vietnam'                               => 'vn',
    'wakeisland'                            => 'wk',
    'wallisefutuna'                         => 'wf',
    'xad'                                   => 'td',
    'xamaica'                               => 'jm',
    'xapón'                                => 'jp',
    'xeorxia'                               => 'ge',
    'xeorxiadosureillassandwich'            => 'gs',
    'xibraltar'                             => 'gi',
    'xibuti'                                => 'dj',
    'xordania'                              => 'jo',
    'zambia'                                => 'zm',
);

1;

