package Locales::DB::Territory::so;

# Auto generated from CLDR

$Locales::DB::Territory::so::VERSION = '0.02';

$Locales::DB::Territory::so::cldr_version = '1.7.1';

%Locales::DB::Territory::so::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "Imaaraadka\ Carabta\ ee\ Midoobay",
    'af' => 'Afgaanistaan',
    'ag' => "Antigua\ and\ Barbuda",
    'ai' => 'Anguilla',
    'al' => 'Albania',
    'am' => 'Armeeniya',
    'an' => "Netherlands\ Antilles",
    'ao' => 'Angoola',
    'aq' => 'Antarctica',
    'ar' => 'Argentina',
    'as' => "American\ Samoa",
    'at' => 'Osteeriya',
    'au' => 'Awstraaliya',
    'aw' => 'Aruba',
    'ax' => "\Ã\land\ Islands",
    'az' => 'Azerbaijan',
    'ba' => "Boosniya\ Heersigoviina",
    'bb' => 'Baarbadoos',
    'bd' => "Bangaala\-Deesh",
    'be' => 'Beljiyam',
    'bf' => "Burkina\ Faso",
    'bg' => 'Bulgaria',
    'bh' => 'Baxrayn',
    'bi' => 'Burundi',
    'bj' => 'Beniin',
    'bl' => "Saint\ Barth\Ã\©lemy",
    'bm' => 'Bermuda',
    'bn' => 'Brunei',
    'bo' => 'Bolivia',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Braasiil',
    'bs' => 'Bahamas',
    'bt' => 'Bhutan',
    'bv' => "Bouvet\ Island",
    'bw' => 'Botswana',
    'by' => 'Belarus',
    'bz' => 'Belize',
    'ca' => 'Kanada',
    'cc' => "Cocos\ \[Keeling\]\ Islands",
    'cd' => "Congo\ \[DRC\]",
    'cf' => "Central\ African\ Republic",
    'cg' => "Congo\ \[Republic\]",
    'ch' => 'Swiiserlaand',
    'ci' => "Ivory\ Coast",
    'ck' => "Cook\ Islands",
    'cl' => 'Jili',
    'cm' => 'Kameruun',
    'cn' => 'Shiinaha',
    'co' => 'Colombia',
    'cr' => "Costa\ Rica",
    'cs' => "Serbia\ and\ Montenegro",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Kuuba',
    'cv' => "Cape\ Verde",
    'cx' => "Christmas\ Island",
    'cy' => 'Cyprus',
    'cz' => 'Jekoslafaakiya',
    'dd' => "East\ Germany",
    'de' => 'Jarmal',
    'dj' => 'Jabuuti',
    'dk' => 'Danmaark',
    'dm' => 'Dominica',
    'do' => "Dominican\ Republic",
    'dz' => 'Algeria',
    'ec' => 'Ikwadoor',
    'ee' => 'Estonia',
    'eg' => 'Masar',
    'eh' => "Western\ Sahara",
    'er' => 'Eritrea',
    'es' => 'Isbeyn',
    'et' => 'Itoobiya',
    'fi' => 'Fiinlaand',
    'fj' => 'Fiji',
    'fk' => "Falkland\ Islands\ \[Islas\ Malvinas\]",
    'fm' => 'Micronesia',
    'fo' => "Faroe\ Islands",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Faransiis',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabon',
    'gb' => "United\ Kingdom",
    'gd' => 'Giriinaada',
    'ge' => 'Georgia',
    'gf' => "French\ Guiana",
    'gg' => 'Guernsey',
    'gh' => 'Ghana',
    'gi' => 'Gibraltar',
    'gl' => 'Greenland',
    'gm' => 'Gambia',
    'gn' => 'Gini',
    'gp' => 'Guadeloupe',
    'gq' => "Equatorial\ Guinea",
    'gr' => 'Giriigga',
    'gs' => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt' => 'Guatemala',
    'gu' => 'Guam',
    'gw' => "Guinea\-Bissau",
    'gy' => 'Guyana',
    'hk' => "Hong\ Kong",
    'hm' => "Heard\ Island\ and\ McDonald\ Islands",
    'hn' => 'Honduras',
    'hr' => 'Korweeshiya',
    'ht' => 'Haiti',
    'hu' => 'Hangeri',
    'id' => 'Indoneesiya',
    'ie' => 'Ayrlaanda',
    'il' => 'Israaʼiil',
    'im' => "Isle\ of\ Man",
    'in' => 'Hindiya',
    'io' => "British\ Indian\ Ocean\ Territory",
    'iq' => 'Ciraaq',
    'ir' => 'Iiraan',
    'is' => 'Iislaand',
    'it' => 'Talyaani',
    'je' => 'Jersey',
    'jm' => 'Jameyka',
    'jo' => 'Urdun',
    'jp' => 'Jabbaan',
    'jt' => "Johnston\ Island",
    'ke' => 'Kiiniya',
    'kg' => 'Kyrgyzstan',
    'kh' => 'Kamboodiya',
    'ki' => 'Kiribati',
    'km' => 'Comoros',
    'kn' => "Saint\ Kitts\ and\ Nevis",
    'kp' => "Kuuriyada\ Waqooyi",
    'kr' => "Kuuriyada\ Koonfureed",
    'kw' => 'Kuwayt',
    'ky' => "Cayman\ Islands",
    'kz' => 'Kasaakhistaan',
    'la' => 'Laos',
    'lb' => 'Lubnaan',
    'lc' => "Saint\ Lucia",
    'li' => 'Liechtenstein',
    'lk' => 'Siirilaanka',
    'lr' => 'Laybeeriya',
    'ls' => 'Losooto',
    'lt' => 'Lithuania',
    'lu' => 'Luksemboorg',
    'lv' => 'Laatfiya',
    'ly' => 'Liibiya',
    'ma' => 'Marooko',
    'mc' => 'Moonako',
    'md' => 'Moldova',
    'me' => 'Montenegro',
    'mf' => "Saint\ Martin",
    'mg' => 'Madagascar',
    'mh' => "Marshall\ Islands",
    'mi' => "Midway\ Islands",
    'mk' => 'Makadooniya',
    'ml' => 'Maali',
    'mm' => "Myanmar\ \[Burma\]",
    'mn' => 'Mongolia',
    'mo' => 'Macau',
    'mp' => "Northern\ Mariana\ Islands",
    'mq' => 'Martinique',
    'mr' => 'Muritaaniya',
    'ms' => 'Montserrat',
    'mt' => 'Maalda',
    'mu' => 'Mauritius',
    'mv' => 'Maaldiqeen',
    'mw' => 'Malaawi',
    'mx' => 'Meksiko',
    'my' => 'Malaysia',
    'mz' => 'Musambiig',
    'na' => 'Namiibiya',
    'nc' => "New\ Caledonia",
    'ne' => 'Niger',
    'nf' => "Norfolk\ Island",
    'ng' => 'Nayjeeriya',
    'ni' => 'Nikaraaguwa',
    'nl' => 'Netherlands',
    'no' => 'Noorweey',
    'np' => 'Nepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => 'Neyuusilaand',
    'om' => 'Cumaan',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Peru',
    'pf' => "French\ Polynesia",
    'pg' => "Papua\ New\ Guinea",
    'ph' => 'Filibiin',
    'pk' => 'Bakistaan',
    'pl' => 'Booland',
    'pm' => "Saint\ Pierre\ and\ Miquelon",
    'pn' => "Pitcairn\ Islands",
    'pr' => "Puerto\ Rico",
    'ps' => "Palestinian\ Territories",
    'pt' => 'Bortuqaal',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paraguay',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Qadar',
    'qo' => "Outlying\ Oceania",
    'qu' => "European\ Union",
    're' => "R\Ã\©union",
    'ro' => 'Rumaaniya',
    'rs' => 'Serbia',
    'ru' => 'Ruush',
    'rw' => 'Rwanda',
    'sa' => "Sacuudi\ Carabiya",
    'sb' => "Solomon\ Islands",
    'sc' => 'Seychelles',
    'sd' => 'Sudaan',
    'se' => 'Iswidhan',
    'sg' => 'Singapore',
    'sh' => "Saint\ Helena",
    'si' => 'Slovenia',
    'sj' => "Svalbard\ and\ Jan\ Mayen",
    'sk' => 'Slovakia',
    'sl' => 'Siraaliyoon',
    'sm' => "San\ Marino",
    'sn' => 'Senegal',
    'so' => 'Soomaaliya',
    'sr' => 'Suriname',
    'st' => "S\Ã\£o\ Tom\Ã\©\ and\ Pr\Ã\­ncipe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salvador",
    'sy' => 'Suuriya',
    'sz' => 'Swaziland',
    'tc' => "Turks\ and\ Caicos\ Islands",
    'td' => 'Jaad',
    'tf' => "French\ Southern\ Territories",
    'tg' => 'Toogo',
    'th' => 'Taylaand',
    'tj' => 'Tajikistan',
    'tk' => 'Tokelau',
    'tl' => "East\ Timor",
    'tm' => 'Turkmenistan',
    'tn' => 'Tuniisiya',
    'to' => 'Tonga',
    'tr' => 'Turki',
    'tt' => "Trinidad\ and\ Tobago",
    'tv' => 'Tuvalu',
    'tw' => 'Taiwan',
    'tz' => 'Tansaaniya',
    'ua' => 'Ukraine',
    'ug' => 'Ugaanda',
    'um' => "U\.S\.\ Minor\ Outlying\ Islands",
    'us' => "Qaramada\ Midoobey\ ee\ Maraykanka",
    'uy' => 'Uruguay',
    'uz' => 'Uzbekistan',
    'va' => 'Faatikaan',
    'vc' => "Saint\ Vincent\ and\ the\ Grenadines",
    'vd' => "North\ Vietnam",
    've' => 'Fenisuweela',
    'vg' => "British\ Virgin\ Islands",
    'vi' => "U\.S\.\ Virgin\ Islands",
    'vn' => 'Fiyetnaam',
    'vu' => 'Vanuatu',
    'wf' => "Wallis\ and\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Yaman',
    'yt' => 'Mayotte',
    'za' => "Koonfur\ Afrika",
    'zm' => 'Saambiya',
    'zw' => 'Simbaabwe',
    'zz' => "Far\ aan\ la\ aqoon\ amase\ aan\ saxnayn",
);

%Locales::DB::Territory::so::name_to_code = (
    'afgaanistaan'                           => 'af',
    'albania'                                => 'al',
    'algeria'                                => 'dz',
    'americansamoa'                          => 'as',
    'andorra'                                => 'ad',
    'angoola'                                => 'ao',
    'anguilla'                               => 'ai',
    'antarctica'                             => 'aq',
    'antiguaandbarbuda'                      => 'ag',
    'argentina'                              => 'ar',
    'armeeniya'                              => 'am',
    'aruba'                                  => 'aw',
    'awstraaliya'                            => 'au',
    'ayrlaanda'                              => 'ie',
    'azerbaijan'                             => 'az',
    'baarbadoos'                             => 'bb',
    'bahamas'                                => 'bs',
    'bakistaan'                              => 'pk',
    'bangaaladeesh'                          => 'bd',
    'baxrayn'                                => 'bh',
    'belarus'                                => 'by',
    'belize'                                 => 'bz',
    'beljiyam'                               => 'be',
    'beniin'                                 => 'bj',
    'bermuda'                                => 'bm',
    'bhutan'                                 => 'bt',
    'bolivia'                                => 'bo',
    'booland'                                => 'pl',
    'boosniyaheersigoviina'                  => 'ba',
    'bortuqaal'                              => 'pt',
    'botswana'                               => 'bw',
    'bouvetisland'                           => 'bv',
    'braasiil'                               => 'br',
    'britishantarcticterritory'              => 'bq',
    'britishindianoceanterritory'            => 'io',
    'britishvirginislands'                   => 'vg',
    'brunei'                                 => 'bn',
    'bulgaria'                               => 'bg',
    'burkinafaso'                            => 'bf',
    'burundi'                                => 'bi',
    'cantonandenderburyislands'              => 'ct',
    'capeverde'                              => 'cv',
    'caymanislands'                          => 'ky',
    'centralafricanrepublic'                 => 'cf',
    'christmasisland'                        => 'cx',
    'ciraaq'                                 => 'iq',
    'cocoskeelingislands'                    => 'cc',
    'colombia'                               => 'co',
    'comoros'                                => 'km',
    'congodrc'                               => 'cd',
    'congorepublic'                          => 'cg',
    'cookislands'                            => 'ck',
    'costarica'                              => 'cr',
    'cumaan'                                 => 'om',
    'cyprus'                                 => 'cy',
    'danmaark'                               => 'dk',
    'dominica'                               => 'dm',
    'dominicanrepublic'                      => 'do',
    'dronningmaudland'                       => 'nq',
    'eastgermany'                            => 'dd',
    'easttimor'                              => 'tl',
    'elsalvador'                             => 'sv',
    'equatorialguinea'                       => 'gq',
    'eritrea'                                => 'er',
    'estonia'                                => 'ee',
    'europeanunion'                          => 'qu',
    'faatikaan'                              => 'va',
    'falklandislandsislasmalvinas'           => 'fk',
    'faraanlaaqoonamaseaansaxnayn'           => 'zz',
    'faransiis'                              => 'fr',
    'faroeislands'                           => 'fo',
    'fenisuweela'                            => 've',
    'fiinlaand'                              => 'fi',
    'fiji'                                   => 'fj',
    'filibiin'                               => 'ph',
    'fiyetnaam'                              => 'vn',
    'frenchguiana'                           => 'gf',
    'frenchpolynesia'                        => 'pf',
    'frenchsouthernandantarcticterritories'  => 'fq',
    'frenchsouthernterritories'              => 'tf',
    'gabon'                                  => 'ga',
    'gambia'                                 => 'gm',
    'georgia'                                => 'ge',
    'ghana'                                  => 'gh',
    'gibraltar'                              => 'gi',
    'gini'                                   => 'gn',
    'giriigga'                               => 'gr',
    'giriinaada'                             => 'gd',
    'greenland'                              => 'gl',
    'guadeloupe'                             => 'gp',
    'guam'                                   => 'gu',
    'guatemala'                              => 'gt',
    'guernsey'                               => 'gg',
    'guineabissau'                           => 'gw',
    'guyana'                                 => 'gy',
    'haiti'                                  => 'ht',
    'hangeri'                                => 'hu',
    'heardislandandmcdonaldislands'          => 'hm',
    'hindiya'                                => 'in',
    'honduras'                               => 'hn',
    'hongkong'                               => 'hk',
    'iiraan'                                 => 'ir',
    'iislaand'                               => 'is',
    'ikwadoor'                               => 'ec',
    'imaaraadkacarabtaeemidoobay'            => 'ae',
    'indoneesiya'                            => 'id',
    'isbeyn'                                 => 'es',
    'isleofman'                              => 'im',
    'israaʼiil'                             => 'il',
    'iswidhan'                               => 'se',
    'itoobiya'                               => 'et',
    'ivorycoast'                             => 'ci',
    'jaad'                                   => 'td',
    'jabbaan'                                => 'jp',
    'jabuuti'                                => 'dj',
    'jameyka'                                => 'jm',
    'jarmal'                                 => 'de',
    'jekoslafaakiya'                         => 'cz',
    'jersey'                                 => 'je',
    'jili'                                   => 'cl',
    'johnstonisland'                         => 'jt',
    'kamboodiya'                             => 'kh',
    'kameruun'                               => 'cm',
    'kanada'                                 => 'ca',
    'kasaakhistaan'                          => 'kz',
    'kiiniya'                                => 'ke',
    'kiribati'                               => 'ki',
    'koonfurafrika'                          => 'za',
    'korweeshiya'                            => 'hr',
    'kuuba'                                  => 'cu',
    'kuuriyadakoonfureed'                    => 'kr',
    'kuuriyadawaqooyi'                       => 'kp',
    'kuwayt'                                 => 'kw',
    'kyrgyzstan'                             => 'kg',
    'laatfiya'                               => 'lv',
    'laos'                                   => 'la',
    'laybeeriya'                             => 'lr',
    'liechtenstein'                          => 'li',
    'liibiya'                                => 'ly',
    'lithuania'                              => 'lt',
    'losooto'                                => 'ls',
    'lubnaan'                                => 'lb',
    'luksemboorg'                            => 'lu',
    'maalda'                                 => 'mt',
    'maaldiqeen'                             => 'mv',
    'maali'                                  => 'ml',
    'macau'                                  => 'mo',
    'madagascar'                             => 'mg',
    'makadooniya'                            => 'mk',
    'malaawi'                                => 'mw',
    'malaysia'                               => 'my',
    'marooko'                                => 'ma',
    'marshallislands'                        => 'mh',
    'martinique'                             => 'mq',
    'masar'                                  => 'eg',
    'mauritius'                              => 'mu',
    'mayotte'                                => 'yt',
    'meksiko'                                => 'mx',
    'metropolitanfrance'                     => 'fx',
    'micronesia'                             => 'fm',
    'midwayislands'                          => 'mi',
    'moldova'                                => 'md',
    'mongolia'                               => 'mn',
    'montenegro'                             => 'me',
    'montserrat'                             => 'ms',
    'moonako'                                => 'mc',
    'muritaaniya'                            => 'mr',
    'musambiig'                              => 'mz',
    'myanmarburma'                           => 'mm',
    'namiibiya'                              => 'na',
    'nauru'                                  => 'nr',
    'nayjeeriya'                             => 'ng',
    'nepal'                                  => 'np',
    'netherlands'                            => 'nl',
    'netherlandsantilles'                    => 'an',
    'neutralzone'                            => 'nt',
    'newcaledonia'                           => 'nc',
    'neyuusilaand'                           => 'nz',
    'niger'                                  => 'ne',
    'nikaraaguwa'                            => 'ni',
    'niue'                                   => 'nu',
    'noorweey'                               => 'no',
    'norfolkisland'                          => 'nf',
    'northernmarianaislands'                 => 'mp',
    'northvietnam'                           => 'vd',
    'osteeriya'                              => 'at',
    'outlyingoceania'                        => 'qo',
    'pacificislandstrustterritory'           => 'pc',
    'palau'                                  => 'pw',
    'palestinianterritories'                 => 'ps',
    'panama'                                 => 'pa',
    'panamacanalzone'                        => 'pz',
    'papuanewguinea'                         => 'pg',
    'paraguay'                               => 'py',
    'peoplesdemocraticrepublicofyemen'       => 'yd',
    'peru'                                   => 'pe',
    'pitcairnislands'                        => 'pn',
    'puertorico'                             => 'pr',
    'qadar'                                  => 'qa',
    'qaramadamidoobeyeemaraykanka'           => 'us',
    'rumaaniya'                              => 'ro',
    'ruush'                                  => 'ru',
    'rwanda'                                 => 'rw',
    "r\Ã\©union"                           => 're',
    'saambiya'                               => 'zm',
    'sacuudicarabiya'                        => 'sa',
    "saintbarth\Ã\©lemy"                   => 'bl',
    'sainthelena'                            => 'sh',
    'saintkittsandnevis'                     => 'kn',
    'saintlucia'                             => 'lc',
    'saintmartin'                            => 'mf',
    'saintpierreandmiquelon'                 => 'pm',
    'saintvincentandthegrenadines'           => 'vc',
    'samoa'                                  => 'ws',
    'sanmarino'                              => 'sm',
    'senegal'                                => 'sn',
    'serbia'                                 => 'rs',
    'serbiaandmontenegro'                    => 'cs',
    'seychelles'                             => 'sc',
    'shiinaha'                               => 'cn',
    'siirilaanka'                            => 'lk',
    'simbaabwe'                              => 'zw',
    'singapore'                              => 'sg',
    'siraaliyoon'                            => 'sl',
    'slovakia'                               => 'sk',
    'slovenia'                               => 'si',
    'solomonislands'                         => 'sb',
    'soomaaliya'                             => 'so',
    'southgeorgiaandthesouthsandwichislands' => 'gs',
    'sudaan'                                 => 'sd',
    'suriname'                               => 'sr',
    'suuriya'                                => 'sy',
    'svalbardandjanmayen'                    => 'sj',
    'swaziland'                              => 'sz',
    'swiiserlaand'                           => 'ch',
    "s\Ã\£otom\Ã\©andpr\Ã\­ncipe"      => 'st',
    'taiwan'                                 => 'tw',
    'tajikistan'                             => 'tj',
    'talyaani'                               => 'it',
    'tansaaniya'                             => 'tz',
    'taylaand'                               => 'th',
    'tokelau'                                => 'tk',
    'tonga'                                  => 'to',
    'toogo'                                  => 'tg',
    'trinidadandtobago'                      => 'tt',
    'tuniisiya'                              => 'tn',
    'turki'                                  => 'tr',
    'turkmenistan'                           => 'tm',
    'turksandcaicosislands'                  => 'tc',
    'tuvalu'                                 => 'tv',
    "u\.s\.minoroutlyingislands"             => 'um',
    "u\.s\.miscellaneouspacificislands"      => 'pu',
    "u\.s\.virginislands"                    => 'vi',
    'ugaanda'                                => 'ug',
    'ukraine'                                => 'ua',
    'unionofsovietsocialistrepublics'        => 'su',
    'unitedkingdom'                          => 'gb',
    'urdun'                                  => 'jo',
    'uruguay'                                => 'uy',
    'uzbekistan'                             => 'uz',
    'vanuatu'                                => 'vu',
    'wakeisland'                             => 'wk',
    'wallisandfutuna'                        => 'wf',
    'westernsahara'                          => 'eh',
    'yaman'                                  => 'ye',
    "\Ã\landislands"                      => 'ax',
);

1;

