package Locales::DB::Territory::sr;

# Auto generated from CLDR

$Locales::DB::Territory::sr::VERSION = '0.02';

$Locales::DB::Territory::sr::cldr_version = '1.7.1';

%Locales::DB::Territory::sr::code_to_name = (
    'ad' => 'Андора',
    'ae' => "Уједињени\ Арапски\ Емирати",
    'af' => 'Авганистан',
    'ag' => "Антигве\ и\ Барбуда",
    'ai' => 'Ангвила',
    'al' => 'Албанија',
    'am' => 'Арменија',
    'an' => "Холандски\ Антили",
    'ao' => 'Ангола',
    'aq' => 'Антарктик',
    'ar' => 'Аргентина',
    'as' => "Америчка\ Самоа",
    'at' => 'Аустрија',
    'au' => 'Аустралија',
    'aw' => 'Аруба',
    'ax' => "Аландска\ острва",
    'az' => 'Азербејџан',
    'ba' => "Босна\ и\ Херцеговина",
    'bb' => 'Барбадос',
    'bd' => 'Бангладеш',
    'be' => 'Белгија',
    'bf' => "Буркина\ Фасо",
    'bg' => 'Бугарска',
    'bh' => 'Бахреин',
    'bi' => 'Бурунди',
    'bj' => 'Бенин',
    'bl' => "Свети\ Бартоломеј",
    'bm' => 'Бермуда',
    'bn' => 'Брунеј',
    'bo' => 'Боливија',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Бразил',
    'bs' => 'Бахами',
    'bt' => 'Бутан',
    'bv' => "Буве\ Острва",
    'bw' => 'Боцвана',
    'by' => 'Белорусија',
    'bz' => 'Белизе',
    'ca' => 'Канада',
    'cc' => "Кокос\ \(Келинг\)\ Острва",
    'cd' => "Демократска\ република\ Конго",
    'cf' => "Централно\ Афричка\ Република",
    'cg' => 'Конго',
    'ch' => 'Швајцарска',
    'ci' => "Обала\ Слоноваче",
    'ck' => "Кукова\ Острва",
    'cl' => 'Чиле',
    'cm' => 'Камерун',
    'cn' => 'Кина',
    'co' => 'Колумбија',
    'cr' => 'Костарика',
    'cs' => "Србија\ и\ Црна\ Гора",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Куба',
    'cv' => "Капе\ Верде",
    'cx' => "Божићна\ острва",
    'cy' => 'Кипар',
    'cz' => 'Чешка',
    'dd' => "East\ Germany",
    'de' => 'Немачка',
    'dj' => 'Џибути',
    'dk' => 'Данска',
    'dm' => 'Доминика',
    'do' => "Доминиканска\ Република",
    'dz' => 'Алжир',
    'ec' => 'Еквадор',
    'ee' => 'Естонија',
    'eg' => 'Египат',
    'eh' => "Западна\ Сахара",
    'er' => 'Еритреја',
    'es' => 'Шпанија',
    'et' => 'Етиопија',
    'fi' => 'Финска',
    'fj' => 'Фиџи',
    'fk' => "Фолкландска\ Острва",
    'fm' => 'Микронезија',
    'fo' => "Фарска\ Острва",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Француска',
    'fx' => "Metropolitan\ France",
    'ga' => 'Габон',
    'gb' => "Велика\ Британија",
    'gd' => 'Гренада',
    'ge' => 'Грузија',
    'gf' => "Француска\ Гвајана",
    'gg' => 'Гурнси',
    'gh' => 'Гана',
    'gi' => 'Гибралтар',
    'gl' => 'Гренланд',
    'gm' => 'Гамбија',
    'gn' => 'Гвинеја',
    'gp' => 'Гваделупе',
    'gq' => "Екваторијална\ Гвинеја",
    'gr' => 'Грчка',
    'gs' => "Јужна\ Џорџија\ и\ Јужна\ Сендвич\ Острва",
    'gt' => 'Гватемала',
    'gu' => 'Гуам',
    'gw' => "Гвинеја\-Бисао",
    'gy' => 'Гвајана',
    'hk' => "Хонг\ Конг",
    'hm' => "Херд\ и\ Мекдоналд\ Острва",
    'hn' => 'Хондурас',
    'hr' => 'Хрватска',
    'ht' => 'Хаити',
    'hu' => 'Мађарска',
    'id' => 'Индонезија',
    'ie' => 'Ирска',
    'il' => 'Израел',
    'im' => "Острво\ Ман",
    'in' => 'Индија',
    'io' => "Британска\ територија\ у\ Индијском\ океану",
    'iq' => 'Ирак',
    'ir' => 'Иран',
    'is' => 'Исланд',
    'it' => 'Италија',
    'je' => 'Џерси',
    'jm' => 'Јамајка',
    'jo' => 'Јордан',
    'jp' => 'Јапан',
    'jt' => "Johnston\ Island",
    'ke' => 'Кенија',
    'kg' => 'Киргизстан',
    'kh' => 'Камбоџа',
    'ki' => 'Кирибати',
    'km' => "Коморска\ Острва",
    'kn' => "Сент\ Китс\ и\ Невис",
    'kp' => "Северна\ Кореја",
    'kr' => "Јужна\ Кореја",
    'kw' => 'Кувајт',
    'ky' => "Кајманска\ Острва",
    'kz' => 'Казахстан',
    'la' => 'Лаос',
    'lb' => 'Либан',
    'lc' => "Сент\ Луција",
    'li' => 'Лихтенштајн',
    'lk' => "Шри\ Ланка",
    'lr' => 'Либерија',
    'ls' => 'Лесото',
    'lt' => 'Литванија',
    'lu' => 'Луксембург',
    'lv' => 'Летонија',
    'ly' => 'Либија',
    'ma' => 'Мароко',
    'mc' => 'Монако',
    'md' => 'Молдавија',
    'me' => "Црна\ Гора",
    'mf' => "Сент\ Мартин",
    'mg' => 'Мадагаскар',
    'mh' => "Маршалска\ Острва",
    'mi' => "Midway\ Islands",
    'mk' => 'Македонија',
    'ml' => 'Мали',
    'mm' => 'Мијанмар',
    'mn' => 'Монголија',
    'mo' => 'Макао',
    'mp' => "Северна\ Маријанска\ Острва",
    'mq' => 'Мартиник',
    'mr' => 'Мауританија',
    'ms' => 'Монсерат',
    'mt' => 'Малта',
    'mu' => 'Маурицијус',
    'mv' => 'Малдиви',
    'mw' => 'Малави',
    'mx' => 'Мексико',
    'my' => 'Малезија',
    'mz' => 'Мозамбик',
    'na' => 'Намибија',
    'nc' => "Нова\ Каледонија",
    'ne' => 'Нигер',
    'nf' => "Норфолк\ Острво",
    'ng' => 'Нигерија',
    'ni' => 'Никарагва',
    'nl' => 'Холандија',
    'no' => 'Норвешка',
    'np' => 'Непал',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Науру',
    'nt' => "Neutral\ Zone",
    'nu' => 'Ниуе',
    'nz' => "Нови\ Зеланд",
    'om' => 'Оман',
    'pa' => 'Панама',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Перу',
    'pf' => "Француска\ Полинезија",
    'pg' => "Папуа\ Нова\ Гвинеја",
    'ph' => 'Филипини',
    'pk' => 'Пакистан',
    'pl' => 'Пољска',
    'pm' => "Сен\ Пјер\ и\ Микелон",
    'pn' => 'Питкерн',
    'pr' => "Порто\ Рико",
    'ps' => "Палестинска\ територија",
    'pt' => 'Португал',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Палау',
    'py' => 'Парагвај',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Катар',
    'qo' => "Остала\ океанија",
    'qu' => "Европска\ Унија",
    're' => 'Реинион',
    'ro' => 'Румунија',
    'rs' => 'Србија',
    'ru' => 'Русија',
    'rw' => 'Руанда',
    'sa' => "Саудијска\ Арабија",
    'sb' => "Соломонска\ Острва",
    'sc' => 'Сејшели',
    'sd' => 'Судан',
    'se' => 'Шведска',
    'sg' => 'Сингапур',
    'sh' => "Света\ Јелена",
    'si' => 'Словенија',
    'sj' => "Свалбард\ и\ Јанмајен\ Острва",
    'sk' => 'Словачка',
    'sl' => "Сијера\ Леоне",
    'sm' => "Сан\ Марино",
    'sn' => 'Сенегал',
    'so' => 'Сомалија',
    'sr' => 'Суринам',
    'st' => "Сао\ Томе\ и\ Принципе",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => 'Салвадор',
    'sy' => 'Сирија',
    'sz' => 'Свазиленд',
    'tc' => "Туркс\ и\ Кајкос\ Острва",
    'td' => 'Чад',
    'tf' => "Француске\ Јужне\ Територије",
    'tg' => 'Того',
    'th' => 'Тајланд',
    'tj' => 'Таџикистан',
    'tk' => 'Токелау',
    'tl' => "Источни\ Тимор",
    'tm' => 'Туркменистан',
    'tn' => 'Тунис',
    'to' => 'Тонга',
    'tr' => 'Турска',
    'tt' => "Тринидад\ и\ Тобаго",
    'tv' => 'Тувалу',
    'tw' => 'Тајван',
    'tz' => 'Танзанија',
    'ua' => 'Украјина',
    'ug' => 'Уганда',
    'um' => "Мања\ удаљена\ острва\ САД",
    'us' => "Сједињене\ Америчке\ Државе",
    'uy' => 'Уругвај',
    'uz' => 'Узбекистан',
    'va' => 'Ватикан',
    'vc' => "Сент\ Винсент\ и\ Гренадини",
    'vd' => "North\ Vietnam",
    've' => 'Венецуела',
    'vg' => "Британска\ Девичанска\ Острва",
    'vi' => "С\.А\.Д\.\ Девичанска\ Острва",
    'vn' => 'Вијетнам',
    'vu' => 'Вануату',
    'wf' => "Валис\ и\ Футуна\ Острва",
    'wk' => "Wake\ Island",
    'ws' => 'Самоа',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Јемен',
    'yt' => 'Мајоте',
    'za' => "Јужноафричка\ Република",
    'zm' => 'Замбија',
    'zw' => 'Зимбабве',
    'zz' => "Непозната\ или\ неважећа\ област",
);

%Locales::DB::Territory::sr::name_to_code = (
    'britishantarcticterritory'                                              => 'bq',
    'cantonandenderburyislands'                                              => 'ct',
    'dronningmaudland'                                                       => 'nq',
    'eastgermany'                                                            => 'dd',
    'frenchsouthernandantarcticterritories'                                  => 'fq',
    'johnstonisland'                                                         => 'jt',
    'metropolitanfrance'                                                     => 'fx',
    'midwayislands'                                                          => 'mi',
    'neutralzone'                                                            => 'nt',
    'northvietnam'                                                           => 'vd',
    'pacificislandstrustterritory'                                           => 'pc',
    'panamacanalzone'                                                        => 'pz',
    'peoplesdemocraticrepublicofyemen'                                       => 'yd',
    "u\.s\.miscellaneouspacificislands"                                      => 'pu',
    'unionofsovietsocialistrepublics'                                        => 'su',
    'wakeisland'                                                             => 'wk',
    'Јамајка'                                                         => 'jm',
    'Јапан'                                                             => 'jp',
    'Јемен'                                                             => 'ye',
    'Јордан'                                                           => 'jo',
    'ЈужнаЏорџијаиЈужнаСендвичОстрва'         => 'gs',
    'ЈужнаКореја'                                                 => 'kr',
    'ЈужноафричкаРепублика'                             => 'za',
    'Џерси'                                                             => 'je',
    'Џибути'                                                           => 'dj',
    'Авганистан'                                                   => 'af',
    'Азербејџан'                                                   => 'az',
    'Аландскаострва'                                           => 'ax',
    'Албанија'                                                       => 'al',
    'Алжир'                                                             => 'dz',
    'АмеричкаСамоа'                                             => 'as',
    'Ангвила'                                                         => 'ai',
    'Ангола'                                                           => 'ao',
    'Андора'                                                           => 'ad',
    'Антарктик'                                                     => 'aq',
    'АнтигвеиБарбуда'                                         => 'ag',
    'Аргентина'                                                     => 'ar',
    'Арменија'                                                       => 'am',
    'Аруба'                                                             => 'aw',
    'Аустралија'                                                   => 'au',
    'Аустрија'                                                       => 'at',
    'Бангладеш'                                                     => 'bd',
    'Барбадос'                                                       => 'bb',
    'Бахами'                                                           => 'bs',
    'Бахреин'                                                         => 'bh',
    'Белгија'                                                         => 'be',
    'Белизе'                                                           => 'bz',
    'Белорусија'                                                   => 'by',
    'Бенин'                                                             => 'bj',
    'Бермуда'                                                         => 'bm',
    'Божићнаострва'                                             => 'cx',
    'Боливија'                                                       => 'bo',
    'БоснаиХерцеговина'                                     => 'ba',
    'Боцвана'                                                         => 'bw',
    'Бразил'                                                           => 'br',
    'БританскаДевичанскаОстрва'                     => 'vg',
    'БританскатериторијауИндијскомокеану' => 'io',
    'Брунеј'                                                           => 'bn',
    'БувеОстрва'                                                   => 'bv',
    'Бугарска'                                                       => 'bg',
    'БуркинаФасо'                                                 => 'bf',
    'Бурунди'                                                         => 'bi',
    'Бутан'                                                             => 'bt',
    'ВалисиФутунаОстрва'                                   => 'wf',
    'Вануату'                                                         => 'vu',
    'Ватикан'                                                         => 'va',
    'ВеликаБританија'                                         => 'gb',
    'Венецуела'                                                     => 've',
    'Вијетнам'                                                       => 'vn',
    'Габон'                                                             => 'ga',
    'Гамбија'                                                         => 'gm',
    'Гана'                                                               => 'gh',
    'Гваделупе'                                                     => 'gp',
    'Гватемала'                                                     => 'gt',
    'Гвајана'                                                         => 'gy',
    'Гвинеја'                                                         => 'gn',
    'ГвинејаБисао'                                               => 'gw',
    'Гибралтар'                                                     => 'gi',
    'Гренада'                                                         => 'gd',
    'Гренланд'                                                       => 'gl',
    'Грузија'                                                         => 'ge',
    'Грчка'                                                             => 'gr',
    'Гуам'                                                               => 'gu',
    'Гурнси'                                                           => 'gg',
    'Данска'                                                           => 'dk',
    'ДемократскарепубликаКонго'                     => 'cd',
    'Доминика'                                                       => 'dm',
    'ДоминиканскаРепублика'                             => 'do',
    'ЕвропскаУнија'                                             => 'qu',
    'Египат'                                                           => 'eg',
    'Еквадор'                                                         => 'ec',
    'ЕкваторијалнаГвинеја'                               => 'gq',
    'Еритреја'                                                       => 'er',
    'Естонија'                                                       => 'ee',
    'Етиопија'                                                       => 'et',
    'Замбија'                                                         => 'zm',
    'ЗападнаСахара'                                             => 'eh',
    'Зимбабве'                                                       => 'zw',
    'Израел'                                                           => 'il',
    'Индија'                                                           => 'in',
    'Индонезија'                                                   => 'id',
    'Ирак'                                                               => 'iq',
    'Иран'                                                               => 'ir',
    'Ирска'                                                             => 'ie',
    'Исланд'                                                           => 'is',
    'ИсточниТимор'                                               => 'tl',
    'Италија'                                                         => 'it',
    'Казахстан'                                                     => 'kz',
    'Камбоџа'                                                         => 'kh',
    'Камерун'                                                         => 'cm',
    'Канада'                                                           => 'ca',
    'КапеВерде'                                                     => 'cv',
    'Катар'                                                             => 'qa',
    'КајманскаОстрва'                                         => 'ky',
    'Кенија'                                                           => 'ke',
    'Кина'                                                               => 'cn',
    'Кипар'                                                             => 'cy',
    'Киргизстан'                                                   => 'kg',
    'Кирибати'                                                       => 'ki',
    'КокосКелингОстрва'                                     => 'cc',
    'Колумбија'                                                     => 'co',
    'КоморскаОстрва'                                           => 'km',
    'Конго'                                                             => 'cg',
    'Костарика'                                                     => 'cr',
    'Куба'                                                               => 'cu',
    'Кувајт'                                                           => 'kw',
    'КуковаОстрва'                                               => 'ck',
    'Лаос'                                                               => 'la',
    'Лесото'                                                           => 'ls',
    'Летонија'                                                       => 'lv',
    'Либан'                                                             => 'lb',
    'Либерија'                                                       => 'lr',
    'Либија'                                                           => 'ly',
    'Литванија'                                                     => 'lt',
    'Лихтенштајн'                                                 => 'li',
    'Луксембург'                                                   => 'lu',
    'Мадагаскар'                                                   => 'mg',
    'Макао'                                                             => 'mo',
    'Македонија'                                                   => 'mk',
    'Малави'                                                           => 'mw',
    'Малдиви'                                                         => 'mv',
    'Малезија'                                                       => 'my',
    'Мали'                                                               => 'ml',
    'Малта'                                                             => 'mt',
    'Мароко'                                                           => 'ma',
    'Мартиник'                                                       => 'mq',
    'МаршалскаОстрва'                                         => 'mh',
    'Мауританија'                                                 => 'mr',
    'Маурицијус'                                                   => 'mu',
    'Мађарска'                                                       => 'hu',
    'Мајоте'                                                           => 'yt',
    'МањаудаљенаострваСАД'                               => 'um',
    'Мексико'                                                         => 'mx',
    'Микронезија'                                                 => 'fm',
    'Мијанмар'                                                       => 'mm',
    'Мозамбик'                                                       => 'mz',
    'Молдавија'                                                     => 'md',
    'Монако'                                                           => 'mc',
    'Монголија'                                                     => 'mn',
    'Монсерат'                                                       => 'ms',
    'Намибија'                                                       => 'na',
    'Науру'                                                             => 'nr',
    'Немачка'                                                         => 'de',
    'Непал'                                                             => 'np',
    'Непознатаилиневажећаобласт'                   => 'zz',
    'Нигер'                                                             => 'ne',
    'Нигерија'                                                       => 'ng',
    'Никарагва'                                                     => 'ni',
    'Ниуе'                                                               => 'nu',
    'НоваКаледонија'                                           => 'nc',
    'НовиЗеланд'                                                   => 'nz',
    'Норвешка'                                                       => 'no',
    'НорфолкОстрво'                                             => 'nf',
    'ОбалаСлоноваче'                                           => 'ci',
    'Оман'                                                               => 'om',
    'Осталаокеанија'                                           => 'qo',
    'ОстрвоМан'                                                     => 'im',
    'Пакистан'                                                       => 'pk',
    'Палау'                                                             => 'pw',
    'Палестинскатериторија'                             => 'ps',
    'Панама'                                                           => 'pa',
    'ПапуаНоваГвинеја'                                       => 'pg',
    'Парагвај'                                                       => 'py',
    'Перу'                                                               => 'pe',
    'Питкерн'                                                         => 'pn',
    'ПортоРико'                                                     => 'pr',
    'Португал'                                                       => 'pt',
    'Пољска'                                                           => 'pl',
    'Реинион'                                                         => 're',
    'Руанда'                                                           => 'rw',
    'Румунија'                                                       => 'ro',
    'Русија'                                                           => 'ru',
    "С\.А\.Д\.ДевичанскаОстрва"                           => 'vi',
    'Салвадор'                                                       => 'sv',
    'Самоа'                                                             => 'ws',
    'СанМарино'                                                     => 'sm',
    'СаоТомеиПринципе'                                       => 'st',
    'СаудијскаАрабија'                                       => 'sa',
    'Свазиленд'                                                     => 'sz',
    'СвалбардиЈанмајенОстрва'                         => 'sj',
    'СветаЈелена'                                                 => 'sh',
    'СветиБартоломеј'                                         => 'bl',
    'СевернаКореја'                                             => 'kp',
    'СевернаМаријанскаОстрва'                         => 'mp',
    'СенПјериМикелон'                                         => 'pm',
    'Сенегал'                                                         => 'sn',
    'СентВинсентиГренадини'                             => 'vc',
    'СентКитсиНевис'                                           => 'kn',
    'СентЛуција'                                                   => 'lc',
    'СентМартин'                                                   => 'mf',
    'Сејшели'                                                         => 'sc',
    'Сингапур'                                                       => 'sg',
    'Сирија'                                                           => 'sy',
    'СијераЛеоне'                                                 => 'sl',
    'Словачка'                                                       => 'sk',
    'Словенија'                                                     => 'si',
    'СоломонскаОстрва'                                       => 'sb',
    'Сомалија'                                                       => 'so',
    'Србија'                                                           => 'rs',
    'СрбијаиЦрнаГора'                                         => 'cs',
    'Судан'                                                             => 'sd',
    'Суринам'                                                         => 'sr',
    'СједињенеАмеричкеДржаве'                         => 'us',
    'Танзанија'                                                     => 'tz',
    'Тајван'                                                           => 'tw',
    'Тајланд'                                                         => 'th',
    'Таџикистан'                                                   => 'tj',
    'Того'                                                               => 'tg',
    'Токелау'                                                         => 'tk',
    'Тонга'                                                             => 'to',
    'ТринидадиТобаго'                                         => 'tt',
    'Тувалу'                                                           => 'tv',
    'Тунис'                                                             => 'tn',
    'Туркменистан'                                               => 'tm',
    'ТурксиКајкосОстрва'                                   => 'tc',
    'Турска'                                                           => 'tr',
    'Уганда'                                                           => 'ug',
    'Узбекистан'                                                   => 'uz',
    'Украјина'                                                       => 'ua',
    'Уругвај'                                                         => 'uy',
    'УједињениАрапскиЕмирати'                         => 'ae',
    'ФарскаОстрва'                                               => 'fo',
    'Филипини'                                                       => 'ph',
    'Финска'                                                           => 'fi',
    'Фиџи'                                                               => 'fj',
    'ФолкландскаОстрва'                                     => 'fk',
    'Француска'                                                     => 'fr',
    'ФранцускаГвајана'                                       => 'gf',
    'ФранцускаПолинезија'                                 => 'pf',
    'ФранцускеЈужнеТериторије'                       => 'tf',
    'Хаити'                                                             => 'ht',
    'ХердиМекдоналдОстрва'                               => 'hm',
    'Холандија'                                                     => 'nl',
    'ХоландскиАнтили'                                         => 'an',
    'ХонгКонг'                                                       => 'hk',
    'Хондурас'                                                       => 'hn',
    'Хрватска'                                                       => 'hr',
    'ЦентралноАфричкаРепублика'                     => 'cf',
    'ЦрнаГора'                                                       => 'me',
    'Чад'                                                                 => 'td',
    'Чешка'                                                             => 'cz',
    'Чиле'                                                               => 'cl',
    'Швајцарска'                                                   => 'ch',
    'Шведска'                                                         => 'se',
    'Шпанија'                                                         => 'es',
    'ШриЛанка'                                                       => 'lk',
);

1;

