package Locales::DB::Territory::ja;

# Auto generated from CLDR

$Locales::DB::Territory::ja::VERSION = '0.02';

$Locales::DB::Territory::ja::cldr_version = '1.7.1';

%Locales::DB::Territory::ja::code_to_name = (
    'ad' => 'アンドラ',
    'ae' => 'アラブ首長国連邦',
    'af' => 'アフガニスタン',
    'ag' => 'アンティグア・バーブーダ',
    'ai' => 'アンギラ',
    'al' => 'アルバニア',
    'am' => 'アルメニア',
    'an' => 'オランダ領アンティル諸島',
    'ao' => 'アンゴラ',
    'aq' => '南極大陸',
    'ar' => 'アルゼンチン',
    'as' => '米領サモア',
    'at' => 'オーストリア',
    'au' => 'オーストラリア',
    'aw' => 'アルバ島',
    'ax' => 'オーランド諸島',
    'az' => 'アゼルバイジャン',
    'ba' => 'ボスニア・ヘルツェゴビナ',
    'bb' => 'バルバドス',
    'bd' => 'バングラデシュ',
    'be' => 'ベルギー',
    'bf' => 'ブルキナファソ',
    'bg' => 'ブルガリア',
    'bh' => 'バーレーン',
    'bi' => 'ブルンジ',
    'bj' => 'ベニン',
    'bl' => 'サン・バルテルミー',
    'bm' => 'バミューダ',
    'bn' => 'ブルネイ',
    'bo' => 'ボリビア',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'ブラジル',
    'bs' => 'バハマ',
    'bt' => 'ブータン',
    'bv' => 'ブーベ島',
    'bw' => 'ボツワナ',
    'by' => 'ベラルーシ',
    'bz' => 'ベリーズ',
    'ca' => 'カナダ',
    'cc' => "ココス\ \(キーリング\)\ 諸島",
    'cd' => "コンゴ民主共和国\ \(キンシャサ\)",
    'cf' => '中央アフリカ共和国',
    'cg' => "コンゴ共和国\ \(ブラザビル\)",
    'ch' => 'スイス',
    'ci' => 'コートジボワール',
    'ck' => 'クック諸島',
    'cl' => 'チリ',
    'cm' => 'カメルーン',
    'cn' => '中国',
    'co' => 'コロンビア',
    'cr' => 'コスタリカ',
    'cs' => 'セルビア・モンテネグロ',
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'キューバ',
    'cv' => 'カーボベルデ',
    'cx' => 'クリスマス島',
    'cy' => 'キプロス',
    'cz' => 'チェコ共和国',
    'dd' => "East\ Germany",
    'de' => 'ドイツ',
    'dj' => 'ジブチ',
    'dk' => 'デンマーク',
    'dm' => 'ドミニカ国',
    'do' => 'ドミニカ共和国',
    'dz' => 'アルジェリア',
    'ec' => 'エクアドル',
    'ee' => 'エストニア',
    'eg' => 'エジプト',
    'eh' => '西サハラ',
    'er' => 'エリトリア',
    'es' => 'スペイン',
    'et' => 'エチオピア',
    'fi' => 'フィンランド',
    'fj' => 'フィジー',
    'fk' => 'フォークランド諸島',
    'fm' => 'ミクロネシア',
    'fo' => 'フェロー諸島',
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'フランス',
    'fx' => "Metropolitan\ France",
    'ga' => 'ガボン',
    'gb' => 'イギリス',
    'gd' => 'グレナダ',
    'ge' => 'グルジア',
    'gf' => '仏領ギアナ',
    'gg' => 'ガーンジー',
    'gh' => 'ガーナ',
    'gi' => 'ジブラルタル',
    'gl' => 'グリーンランド',
    'gm' => 'ガンビア',
    'gn' => 'ギニア',
    'gp' => 'グアドループ',
    'gq' => '赤道ギニア',
    'gr' => 'ギリシャ',
    'gs' => '南ジョージア島・南サンドイッチ諸島',
    'gt' => 'グアテマラ',
    'gu' => 'グアム',
    'gw' => 'ギニアビサウ',
    'gy' => 'ガイアナ',
    'hk' => '香港',
    'hm' => 'ハード島・マクドナルド諸島',
    'hn' => 'ホンジュラス',
    'hr' => 'クロアチア',
    'ht' => 'ハイチ',
    'hu' => 'ハンガリー',
    'id' => 'インドネシア',
    'ie' => 'アイルランド',
    'il' => 'イスラエル',
    'im' => 'マン島',
    'in' => 'インド',
    'io' => '英領インド洋植民地',
    'iq' => 'イラク',
    'ir' => 'イラン',
    'is' => 'アイスランド',
    'it' => 'イタリア',
    'je' => 'ジャージー',
    'jm' => 'ジャマイカ',
    'jo' => 'ヨルダン',
    'jp' => '日本',
    'jt' => "Johnston\ Island",
    'ke' => 'ケニア',
    'kg' => 'キルギスタン',
    'kh' => 'カンボジア',
    'ki' => 'キリバス',
    'km' => 'コモロ',
    'kn' => 'セントクリストファー・ネイビス',
    'kp' => '朝鮮民主主義人民共和国',
    'kr' => '大韓民国',
    'kw' => 'クウェート',
    'ky' => 'ケイマン諸島',
    'kz' => 'カザフスタン',
    'la' => 'ラオス',
    'lb' => 'レバノン',
    'lc' => 'セントルシア',
    'li' => 'リヒテンシュタイン',
    'lk' => 'スリランカ',
    'lr' => 'リベリア',
    'ls' => 'レソト',
    'lt' => 'リトアニア',
    'lu' => 'ルクセンブルグ',
    'lv' => 'ラトビア',
    'ly' => 'リビア',
    'ma' => 'モロッコ',
    'mc' => 'モナコ',
    'md' => 'モルドバ',
    'me' => 'モンテネグロ',
    'mf' => 'セント・マーチン',
    'mg' => 'マダガスカル',
    'mh' => 'マーシャル諸島共和国',
    'mi' => "Midway\ Islands",
    'mk' => 'マケドニア',
    'ml' => 'マリ',
    'mm' => 'ミャンマー',
    'mn' => 'モンゴル',
    'mo' => 'マカオ',
    'mp' => '北マリアナ諸島',
    'mq' => 'マルティニーク島',
    'mr' => 'モーリタニア',
    'ms' => 'モントセラト島',
    'mt' => 'マルタ',
    'mu' => 'モーリシャス',
    'mv' => 'モルジブ',
    'mw' => 'マラウィ',
    'mx' => 'メキシコ',
    'my' => 'マレーシア',
    'mz' => 'モザンビーク',
    'na' => 'ナミビア',
    'nc' => 'ニューカレドニア',
    'ne' => 'ニジェール',
    'nf' => 'ノーフォーク島',
    'ng' => 'ナイジェリア',
    'ni' => 'ニカラグア',
    'nl' => 'オランダ',
    'no' => 'ノルウェー',
    'np' => 'ネパール',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'ナウル',
    'nt' => "Neutral\ Zone",
    'nu' => 'ニウエ島',
    'nz' => 'ニュージーランド',
    'om' => 'オマーン',
    'pa' => 'パナマ',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'ペルー',
    'pf' => '仏領ポリネシア',
    'pg' => 'パプアニューギニア',
    'ph' => 'フィリピン',
    'pk' => 'パキスタン',
    'pl' => 'ポーランド',
    'pm' => 'サンピエール島・ミクロン島',
    'pn' => 'ピトケアン島',
    'pr' => 'プエルトリコ',
    'ps' => 'パレスチナ領土',
    'pt' => 'ポルトガル',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'パラオ',
    'py' => 'パラグアイ',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'カタール',
    'qo' => 'その他のオセアニア',
    'qu' => '欧州連合',
    're' => 'レユニオン島',
    'ro' => 'ルーマニア',
    'rs' => 'セルビア',
    'ru' => 'ロシア',
    'rw' => 'ルワンダ',
    'sa' => 'サウジアラビア',
    'sb' => 'ソロモン諸島',
    'sc' => 'セーシェル',
    'sd' => 'スーダン',
    'se' => 'スウェーデン',
    'sg' => 'シンガポール',
    'sh' => 'セントヘレナ',
    'si' => 'スロベニア',
    'sj' => 'スバールバル諸島・ヤンマイエン島',
    'sk' => 'スロバキア',
    'sl' => 'シエラレオネ',
    'sm' => 'サンマリノ',
    'sn' => 'セネガル',
    'so' => 'ソマリア',
    'sr' => 'スリナム',
    'st' => 'サントメ・プリンシペ',
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => 'エルサルバドル',
    'sy' => 'シリア',
    'sz' => 'スワジランド',
    'tc' => 'タークス諸島・カイコス諸島',
    'td' => 'チャド',
    'tf' => 'フランス領極南諸島',
    'tg' => 'トーゴ',
    'th' => 'タイ',
    'tj' => 'タジキスタン',
    'tk' => 'トケラウ諸島',
    'tl' => '東ティモール',
    'tm' => 'トルクメニスタン',
    'tn' => 'チュニジア',
    'to' => 'トンガ',
    'tr' => 'トルコ',
    'tt' => 'トリニダード・トバゴ',
    'tv' => 'ツバル',
    'tw' => '台湾',
    'tz' => 'タンザニア',
    'ua' => 'ウクライナ',
    'ug' => 'ウガンダ',
    'um' => '米領太平洋諸島',
    'us' => 'アメリカ合衆国',
    'uy' => 'ウルグアイ',
    'uz' => 'ウズベキスタン',
    'va' => 'バチカン市国',
    'vc' => 'セントビンセント・グレナディーン諸島',
    'vd' => "North\ Vietnam",
    've' => 'ベネズエラ',
    'vg' => 'イギリス領ヴァージン諸島',
    'vi' => 'アメリカ領ヴァージン諸島',
    'vn' => 'ベトナム',
    'vu' => 'バヌアツ',
    'wf' => 'ウォリス・フツナ',
    'wk' => "Wake\ Island",
    'ws' => 'サモア',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'イエメン',
    'yt' => 'マヨット島',
    'za' => '南アフリカ',
    'zm' => 'ザンビア',
    'zw' => 'ジンバブエ',
    'zz' => '不明な地域',
);

%Locales::DB::Territory::ja::name_to_code = (
    'britishantarcticterritory'                              => 'bq',
    'cantonandenderburyislands'                              => 'ct',
    'dronningmaudland'                                       => 'nq',
    'eastgermany'                                            => 'dd',
    'frenchsouthernandantarcticterritories'                  => 'fq',
    'johnstonisland'                                         => 'jt',
    'metropolitanfrance'                                     => 'fx',
    'midwayislands'                                          => 'mi',
    'neutralzone'                                            => 'nt',
    'northvietnam'                                           => 'vd',
    'pacificislandstrustterritory'                           => 'pc',
    'panamacanalzone'                                        => 'pz',
    'peoplesdemocraticrepublicofyemen'                       => 'yd',
    "u\.s\.miscellaneouspacificislands"                      => 'pu',
    'unionofsovietsocialistrepublics'                        => 'su',
    'wakeisland'                                             => 'wk',
    'その他のオセアニア'                            => 'qo',
    'アイスランド'                                     => 'is',
    'アイルランド'                                     => 'ie',
    'アゼルバイジャン'                               => 'az',
    'アフガニスタン'                                  => 'af',
    'アメリカ合衆国'                                  => 'us',
    'アメリカ領ヴァージン諸島'                   => 'vi',
    'アラブ首長国連邦'                               => 'ae',
    'アルジェリア'                                     => 'dz',
    'アルゼンチン'                                     => 'ar',
    'アルバニア'                                        => 'al',
    'アルバ島'                                           => 'aw',
    'アルメニア'                                        => 'am',
    'アンギラ'                                           => 'ai',
    'アンゴラ'                                           => 'ao',
    'アンティグア・バーブーダ'                   => 'ag',
    'アンドラ'                                           => 'ad',
    'イエメン'                                           => 'ye',
    'イギリス'                                           => 'gb',
    'イギリス領ヴァージン諸島'                   => 'vg',
    'イスラエル'                                        => 'il',
    'イタリア'                                           => 'it',
    'イラク'                                              => 'iq',
    'イラン'                                              => 'ir',
    'インド'                                              => 'in',
    'インドネシア'                                     => 'id',
    'ウォリス・フツナ'                               => 'wf',
    'ウガンダ'                                           => 'ug',
    'ウクライナ'                                        => 'ua',
    'ウズベキスタン'                                  => 'uz',
    'ウルグアイ'                                        => 'uy',
    'エクアドル'                                        => 'ec',
    'エジプト'                                           => 'eg',
    'エストニア'                                        => 'ee',
    'エチオピア'                                        => 'et',
    'エリトリア'                                        => 'er',
    'エルサルバドル'                                  => 'sv',
    'オマーン'                                           => 'om',
    'オランダ'                                           => 'nl',
    'オランダ領アンティル諸島'                   => 'an',
    'オーストラリア'                                  => 'au',
    'オーストリア'                                     => 'at',
    'オーランド諸島'                                  => 'ax',
    'カザフスタン'                                     => 'kz',
    'カタール'                                           => 'qa',
    'カナダ'                                              => 'ca',
    'カメルーン'                                        => 'cm',
    'カンボジア'                                        => 'kh',
    'カーボベルデ'                                     => 'cv',
    'ガイアナ'                                           => 'gy',
    'ガボン'                                              => 'ga',
    'ガンビア'                                           => 'gm',
    'ガーナ'                                              => 'gh',
    'ガーンジー'                                        => 'gg',
    'キプロス'                                           => 'cy',
    'キューバ'                                           => 'cu',
    'キリバス'                                           => 'ki',
    'キルギスタン'                                     => 'kg',
    'ギニア'                                              => 'gn',
    'ギニアビサウ'                                     => 'gw',
    'ギリシャ'                                           => 'gr',
    'クウェート'                                        => 'kw',
    'クック諸島'                                        => 'ck',
    'クリスマス島'                                     => 'cx',
    'クロアチア'                                        => 'hr',
    'グアテマラ'                                        => 'gt',
    'グアドループ'                                     => 'gp',
    'グアム'                                              => 'gu',
    'グリーンランド'                                  => 'gl',
    'グルジア'                                           => 'ge',
    'グレナダ'                                           => 'gd',
    'ケイマン諸島'                                     => 'ky',
    'ケニア'                                              => 'ke',
    'ココスキーリング諸島'                         => 'cc',
    'コスタリカ'                                        => 'cr',
    'コモロ'                                              => 'km',
    'コロンビア'                                        => 'co',
    'コンゴ共和国ブラザビル'                      => 'cg',
    'コンゴ民主共和国キンシャサ'                => 'cd',
    'コートジボワール'                               => 'ci',
    'サウジアラビア'                                  => 'sa',
    'サモア'                                              => 'ws',
    'サントメ・プリンシペ'                         => 'st',
    'サンピエール島・ミクロン島'                => 'pm',
    'サンマリノ'                                        => 'sm',
    'サン・バルテルミー'                            => 'bl',
    'ザンビア'                                           => 'zm',
    'シエラレオネ'                                     => 'sl',
    'シリア'                                              => 'sy',
    'シンガポール'                                     => 'sg',
    'ジブチ'                                              => 'dj',
    'ジブラルタル'                                     => 'gi',
    'ジャマイカ'                                        => 'jm',
    'ジャージー'                                        => 'je',
    'ジンバブエ'                                        => 'zw',
    'スイス'                                              => 'ch',
    'スウェーデン'                                     => 'se',
    'スバールバル諸島・ヤンマイエン島'       => 'sj',
    'スペイン'                                           => 'es',
    'スリナム'                                           => 'sr',
    'スリランカ'                                        => 'lk',
    'スロバキア'                                        => 'sk',
    'スロベニア'                                        => 'si',
    'スワジランド'                                     => 'sz',
    'スーダン'                                           => 'sd',
    'セネガル'                                           => 'sn',
    'セルビア'                                           => 'rs',
    'セルビア・モンテネグロ'                      => 'cs',
    'セントクリストファー・ネイビス'          => 'kn',
    'セントビンセント・グレナディーン諸島' => 'vc',
    'セントヘレナ'                                     => 'sh',
    'セントルシア'                                     => 'lc',
    'セント・マーチン'                               => 'mf',
    'セーシェル'                                        => 'sc',
    'ソマリア'                                           => 'so',
    'ソロモン諸島'                                     => 'sb',
    'タイ'                                                 => 'th',
    'タジキスタン'                                     => 'tj',
    'タンザニア'                                        => 'tz',
    'タークス諸島・カイコス諸島'                => 'tc',
    'チェコ共和国'                                     => 'cz',
    'チャド'                                              => 'td',
    'チュニジア'                                        => 'tn',
    'チリ'                                                 => 'cl',
    'ツバル'                                              => 'tv',
    'デンマーク'                                        => 'dk',
    'トケラウ諸島'                                     => 'tk',
    'トリニダード・トバゴ'                         => 'tt',
    'トルクメニスタン'                               => 'tm',
    'トルコ'                                              => 'tr',
    'トンガ'                                              => 'to',
    'トーゴ'                                              => 'tg',
    'ドイツ'                                              => 'de',
    'ドミニカ共和国'                                  => 'do',
    'ドミニカ国'                                        => 'dm',
    'ナイジェリア'                                     => 'ng',
    'ナウル'                                              => 'nr',
    'ナミビア'                                           => 'na',
    'ニウエ島'                                           => 'nu',
    'ニカラグア'                                        => 'ni',
    'ニジェール'                                        => 'ne',
    'ニューカレドニア'                               => 'nc',
    'ニュージーランド'                               => 'nz',
    'ネパール'                                           => 'np',
    'ノルウェー'                                        => 'no',
    'ノーフォーク島'                                  => 'nf',
    'ハイチ'                                              => 'ht',
    'ハンガリー'                                        => 'hu',
    'ハード島・マクドナルド諸島'                => 'hm',
    'バチカン市国'                                     => 'va',
    'バヌアツ'                                           => 'vu',
    'バハマ'                                              => 'bs',
    'バミューダ'                                        => 'bm',
    'バルバドス'                                        => 'bb',
    'バングラデシュ'                                  => 'bd',
    'バーレーン'                                        => 'bh',
    'パキスタン'                                        => 'pk',
    'パナマ'                                              => 'pa',
    'パプアニューギニア'                            => 'pg',
    'パラオ'                                              => 'pw',
    'パラグアイ'                                        => 'py',
    'パレスチナ領土'                                  => 'ps',
    'ピトケアン島'                                     => 'pn',
    'フィジー'                                           => 'fj',
    'フィリピン'                                        => 'ph',
    'フィンランド'                                     => 'fi',
    'フェロー諸島'                                     => 'fo',
    'フォークランド諸島'                            => 'fk',
    'フランス'                                           => 'fr',
    'フランス領極南諸島'                            => 'tf',
    'ブラジル'                                           => 'br',
    'ブルガリア'                                        => 'bg',
    'ブルキナファソ'                                  => 'bf',
    'ブルネイ'                                           => 'bn',
    'ブルンジ'                                           => 'bi',
    'ブータン'                                           => 'bt',
    'ブーベ島'                                           => 'bv',
    'プエルトリコ'                                     => 'pr',
    'ベトナム'                                           => 'vn',
    'ベニン'                                              => 'bj',
    'ベネズエラ'                                        => 've',
    'ベラルーシ'                                        => 'by',
    'ベリーズ'                                           => 'bz',
    'ベルギー'                                           => 'be',
    'ペルー'                                              => 'pe',
    'ホンジュラス'                                     => 'hn',
    'ボスニア・ヘルツェゴビナ'                   => 'ba',
    'ボツワナ'                                           => 'bw',
    'ボリビア'                                           => 'bo',
    'ポルトガル'                                        => 'pt',
    'ポーランド'                                        => 'pl',
    'マカオ'                                              => 'mo',
    'マケドニア'                                        => 'mk',
    'マダガスカル'                                     => 'mg',
    'マヨット島'                                        => 'yt',
    'マラウィ'                                           => 'mw',
    'マリ'                                                 => 'ml',
    'マルタ'                                              => 'mt',
    'マルティニーク島'                               => 'mq',
    'マレーシア'                                        => 'my',
    'マン島'                                              => 'im',
    'マーシャル諸島共和国'                         => 'mh',
    'ミクロネシア'                                     => 'fm',
    'ミャンマー'                                        => 'mm',
    'メキシコ'                                           => 'mx',
    'モザンビーク'                                     => 'mz',
    'モナコ'                                              => 'mc',
    'モルジブ'                                           => 'mv',
    'モルドバ'                                           => 'md',
    'モロッコ'                                           => 'ma',
    'モンゴル'                                           => 'mn',
    'モンテネグロ'                                     => 'me',
    'モントセラト島'                                  => 'ms',
    'モーリシャス'                                     => 'mu',
    'モーリタニア'                                     => 'mr',
    'ヨルダン'                                           => 'jo',
    'ラオス'                                              => 'la',
    'ラトビア'                                           => 'lv',
    'リトアニア'                                        => 'lt',
    'リヒテンシュタイン'                            => 'li',
    'リビア'                                              => 'ly',
    'リベリア'                                           => 'lr',
    'ルクセンブルグ'                                  => 'lu',
    'ルワンダ'                                           => 'rw',
    'ルーマニア'                                        => 'ro',
    'レソト'                                              => 'ls',
    'レバノン'                                           => 'lb',
    'レユニオン島'                                     => 're',
    'ロシア'                                              => 'ru',
    '不明な地域'                                        => 'zz',
    '中国'                                                 => 'cn',
    '中央アフリカ共和国'                            => 'cf',
    '仏領ギアナ'                                        => 'gf',
    '仏領ポリネシア'                                  => 'pf',
    '北マリアナ諸島'                                  => 'mp',
    '南アフリカ'                                        => 'za',
    '南ジョージア島・南サンドイッチ諸島'    => 'gs',
    '南極大陸'                                           => 'aq',
    '台湾'                                                 => 'tw',
    '大韓民国'                                           => 'kr',
    '日本'                                                 => 'jp',
    '朝鮮民主主義人民共和国'                      => 'kp',
    '東ティモール'                                     => 'tl',
    '欧州連合'                                           => 'qu',
    '米領サモア'                                        => 'as',
    '米領太平洋諸島'                                  => 'um',
    '英領インド洋植民地'                            => 'io',
    '西サハラ'                                           => 'eh',
    '赤道ギニア'                                        => 'gq',
    '香港'                                                 => 'hk',
);

1;

