package Locales::DB::Territory::de;

# Auto generated from CLDR

$Locales::DB::Territory::de::VERSION = '0.02';

$Locales::DB::Territory::de::cldr_version = '1.7.1';

%Locales::DB::Territory::de::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "Vereinigte\ Arabische\ Emirate",
    'af' => 'Afghanistan',
    'ag' => "Antigua\ und\ Barbuda",
    'ai' => 'Anguilla',
    'al' => 'Albanien',
    'am' => 'Armenien',
    'an' => "Niederländische\ Antillen",
    'ao' => 'Angola',
    'aq' => 'Antarktis',
    'ar' => 'Argentinien',
    'as' => "Amerikanisch\-Samoa",
    'at' => 'Österreich',
    'au' => 'Australien',
    'aw' => 'Aruba',
    'ax' => 'Alandinseln',
    'az' => 'Aserbaidschan',
    'ba' => "Bosnien\ und\ Herzegowina",
    'bb' => 'Barbados',
    'bd' => 'Bangladesch',
    'be' => 'Belgien',
    'bf' => "Burkina\ Faso",
    'bg' => 'Bulgarien',
    'bh' => 'Bahrain',
    'bi' => 'Burundi',
    'bj' => 'Benin',
    'bl' => "St\.\ Barthélemy",
    'bm' => 'Bermuda',
    'bn' => "Brunei\ Darussalam",
    'bo' => 'Bolivien',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brasilien',
    'bs' => 'Bahamas',
    'bt' => 'Bhutan',
    'bv' => 'Bouvetinsel',
    'bw' => 'Botsuana',
    'by' => 'Belarus',
    'bz' => 'Belize',
    'ca' => 'Kanada',
    'cc' => 'Kokosinseln',
    'cd' => "Demokratische\ Republik\ Kongo",
    'cf' => "Zentralafrikanische\ Republik",
    'cg' => 'Kongo',
    'ch' => 'Schweiz',
    'ci' => 'Elfenbeinküste',
    'ck' => 'Cookinseln',
    'cl' => 'Chile',
    'cm' => 'Kamerun',
    'cn' => 'China',
    'co' => 'Kolumbien',
    'cr' => "Costa\ Rica",
    'cs' => "Serbien\ und\ Montenegro",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Kuba',
    'cv' => "Kap\ Verde",
    'cx' => 'Weihnachtsinsel',
    'cy' => 'Zypern',
    'cz' => "Tschechische\ Republik",
    'dd' => "East\ Germany",
    'de' => 'Deutschland',
    'dj' => 'Dschibuti',
    'dk' => 'Dänemark',
    'dm' => 'Dominica',
    'do' => "Dominikanische\ Republik",
    'dz' => 'Algerien',
    'ec' => 'Ecuador',
    'ee' => 'Estland',
    'eg' => 'Ägypten',
    'eh' => 'Westsahara',
    'er' => 'Eritrea',
    'es' => 'Spanien',
    'et' => 'Äthiopien',
    'fi' => 'Finnland',
    'fj' => 'Fidschi',
    'fk' => 'Falklandinseln',
    'fm' => 'Mikronesien',
    'fo' => 'Färöer',
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Frankreich',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabun',
    'gb' => "Vereinigtes\ Königreich",
    'gd' => 'Grenada',
    'ge' => 'Georgien',
    'gf' => "Französisch\-Guayana",
    'gg' => 'Guernsey',
    'gh' => 'Ghana',
    'gi' => 'Gibraltar',
    'gl' => 'Grönland',
    'gm' => 'Gambia',
    'gn' => 'Guinea',
    'gp' => 'Guadeloupe',
    'gq' => 'Äquatorialguinea',
    'gr' => 'Griechenland',
    'gs' => "Südgeorgien\ und\ die\ Südlichen\ Sandwichinseln",
    'gt' => 'Guatemala',
    'gu' => 'Guam',
    'gw' => "Guinea\-Bissau",
    'gy' => 'Guyana',
    'hk' => 'Hongkong',
    'hm' => "Heard\-\ und\ McDonald\-Inseln",
    'hn' => 'Honduras',
    'hr' => 'Kroatien',
    'ht' => 'Haiti',
    'hu' => 'Ungarn',
    'id' => 'Indonesien',
    'ie' => 'Irland',
    'il' => 'Israel',
    'im' => "Isle\ of\ Man",
    'in' => 'Indien',
    'io' => "Britisches\ Territorium\ im\ Indischen\ Ozean",
    'iq' => 'Irak',
    'ir' => 'Iran',
    'is' => 'Island',
    'it' => 'Italien',
    'je' => 'Jersey',
    'jm' => 'Jamaika',
    'jo' => 'Jordanien',
    'jp' => 'Japan',
    'jt' => "Johnston\ Island",
    'ke' => 'Kenia',
    'kg' => 'Kirgisistan',
    'kh' => 'Kambodscha',
    'ki' => 'Kiribati',
    'km' => 'Komoren',
    'kn' => "St\.\ Kitts\ und\ Nevis",
    'kp' => "Demokratische\ Volksrepublik\ Korea",
    'kr' => "Republik\ Korea",
    'kw' => 'Kuwait',
    'ky' => 'Kaimaninseln',
    'kz' => 'Kasachstan',
    'la' => 'Laos',
    'lb' => 'Libanon',
    'lc' => "St\.\ Lucia",
    'li' => 'Liechtenstein',
    'lk' => "Sri\ Lanka",
    'lr' => 'Liberia',
    'ls' => 'Lesotho',
    'lt' => 'Litauen',
    'lu' => 'Luxemburg',
    'lv' => 'Lettland',
    'ly' => 'Libyen',
    'ma' => 'Marokko',
    'mc' => 'Monaco',
    'md' => "Republik\ Moldau",
    'me' => 'Montenegro',
    'mf' => "St\.\ Martin",
    'mg' => 'Madagaskar',
    'mh' => 'Marshallinseln',
    'mi' => "Midway\ Islands",
    'mk' => 'Mazedonien',
    'ml' => 'Mali',
    'mm' => 'Myanmar',
    'mn' => 'Mongolei',
    'mo' => 'Macau',
    'mp' => "Nördliche\ Marianen",
    'mq' => 'Martinique',
    'mr' => 'Mauretanien',
    'ms' => 'Montserrat',
    'mt' => 'Malta',
    'mu' => 'Mauritius',
    'mv' => 'Malediven',
    'mw' => 'Malawi',
    'mx' => 'Mexiko',
    'my' => 'Malaysia',
    'mz' => 'Mosambik',
    'na' => 'Namibia',
    'nc' => 'Neukaledonien',
    'ne' => 'Niger',
    'nf' => 'Norfolkinsel',
    'ng' => 'Nigeria',
    'ni' => 'Nicaragua',
    'nl' => 'Niederlande',
    'no' => 'Norwegen',
    'np' => 'Nepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => 'Neuseeland',
    'om' => 'Oman',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Peru',
    'pf' => "Französisch\-Polynesien",
    'pg' => "Papua\-Neuguinea",
    'ph' => 'Philippinen',
    'pk' => 'Pakistan',
    'pl' => 'Polen',
    'pm' => "St\.\ Pierre\ und\ Miquelon",
    'pn' => 'Pitcairn',
    'pr' => "Puerto\ Rico",
    'ps' => "Palästinensische\ Gebiete",
    'pt' => 'Portugal',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paraguay',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Katar',
    'qo' => "Äußeres\ Ozeanien",
    'qu' => "Europäische\ Union",
    're' => 'Réunion',
    'ro' => 'Rumänien',
    'rs' => 'Serbien',
    'ru' => "Russische\ Föderation",
    'rw' => 'Ruanda',
    'sa' => "Saudi\-Arabien",
    'sb' => 'Salomonen',
    'sc' => 'Seychellen',
    'sd' => 'Sudan',
    'se' => 'Schweden',
    'sg' => 'Singapur',
    'sh' => "St\.\ Helena",
    'si' => 'Slowenien',
    'sj' => "Svalbard\ und\ Jan\ Mayen",
    'sk' => 'Slowakei',
    'sl' => "Sierra\ Leone",
    'sm' => "San\ Marino",
    'sn' => 'Senegal',
    'so' => 'Somalia',
    'sr' => 'Suriname',
    'st' => "São\ Tomé\ und\ Príncipe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salvador",
    'sy' => 'Syrien',
    'sz' => 'Swasiland',
    'tc' => "Turks\-\ und\ Caicosinseln",
    'td' => 'Tschad',
    'tf' => "Französische\ Süd\-\ und\ Antarktisgebiete",
    'tg' => 'Togo',
    'th' => 'Thailand',
    'tj' => 'Tadschikistan',
    'tk' => 'Tokelau',
    'tl' => 'Osttimor',
    'tm' => 'Turkmenistan',
    'tn' => 'Tunesien',
    'to' => 'Tonga',
    'tr' => 'Türkei',
    'tt' => "Trinidad\ und\ Tobago",
    'tv' => 'Tuvalu',
    'tw' => 'Taiwan',
    'tz' => 'Tansania',
    'ua' => 'Ukraine',
    'ug' => 'Uganda',
    'um' => "Amerikanisch\-Ozeanien",
    'us' => "Vereinigte\ Staaten",
    'uy' => 'Uruguay',
    'uz' => 'Usbekistan',
    'va' => 'Vatikanstadt',
    'vc' => "St\.\ Vincent\ und\ die\ Grenadinen",
    'vd' => "North\ Vietnam",
    've' => 'Venezuela',
    'vg' => "Britische\ Jungferninseln",
    'vi' => "Amerikanische\ Jungferninseln",
    'vn' => 'Vietnam',
    'vu' => 'Vanuatu',
    'wf' => "Wallis\ und\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Jemen',
    'yt' => 'Mayotte',
    'za' => 'Südafrika',
    'zm' => 'Sambia',
    'zw' => 'Simbabwe',
    'zz' => "Unbekannte\ oder\ ungültige\ Region",
);

%Locales::DB::Territory::de::name_to_code = (
    'afghanistan'                                => 'af',
    'alandinseln'                                => 'ax',
    'albanien'                                   => 'al',
    'algerien'                                   => 'dz',
    'amerikanischejungferninseln'                => 'vi',
    'amerikanischozeanien'                       => 'um',
    'amerikanischsamoa'                          => 'as',
    'andorra'                                    => 'ad',
    'angola'                                     => 'ao',
    'anguilla'                                   => 'ai',
    'antarktis'                                  => 'aq',
    'antiguaundbarbuda'                          => 'ag',
    'argentinien'                                => 'ar',
    'armenien'                                   => 'am',
    'aruba'                                      => 'aw',
    'aserbaidschan'                              => 'az',
    'australien'                                 => 'au',
    'bahamas'                                    => 'bs',
    'bahrain'                                    => 'bh',
    'bangladesch'                                => 'bd',
    'barbados'                                   => 'bb',
    'belarus'                                    => 'by',
    'belgien'                                    => 'be',
    'belize'                                     => 'bz',
    'benin'                                      => 'bj',
    'bermuda'                                    => 'bm',
    'bhutan'                                     => 'bt',
    'bolivien'                                   => 'bo',
    'bosnienundherzegowina'                      => 'ba',
    'botsuana'                                   => 'bw',
    'bouvetinsel'                                => 'bv',
    'brasilien'                                  => 'br',
    'britischejungferninseln'                    => 'vg',
    'britischesterritoriumimindischenozean'      => 'io',
    'britishantarcticterritory'                  => 'bq',
    'bruneidarussalam'                           => 'bn',
    'bulgarien'                                  => 'bg',
    'burkinafaso'                                => 'bf',
    'burundi'                                    => 'bi',
    'cantonandenderburyislands'                  => 'ct',
    'chile'                                      => 'cl',
    'china'                                      => 'cn',
    'cookinseln'                                 => 'ck',
    'costarica'                                  => 'cr',
    'demokratischerepublikkongo'                 => 'cd',
    'demokratischevolksrepublikkorea'            => 'kp',
    'deutschland'                                => 'de',
    'dominica'                                   => 'dm',
    'dominikanischerepublik'                     => 'do',
    'dronningmaudland'                           => 'nq',
    'dschibuti'                                  => 'dj',
    'dänemark'                                  => 'dk',
    'eastgermany'                                => 'dd',
    'ecuador'                                    => 'ec',
    'elfenbeinküste'                            => 'ci',
    'elsalvador'                                 => 'sv',
    'eritrea'                                    => 'er',
    'estland'                                    => 'ee',
    'europäischeunion'                          => 'qu',
    'falklandinseln'                             => 'fk',
    'fidschi'                                    => 'fj',
    'finnland'                                   => 'fi',
    'frankreich'                                 => 'fr',
    'französischesüdundantarktisgebiete'       => 'tf',
    'französischguayana'                        => 'gf',
    'französischpolynesien'                     => 'pf',
    'frenchsouthernandantarcticterritories'      => 'fq',
    'färöer'                                   => 'fo',
    'gabun'                                      => 'ga',
    'gambia'                                     => 'gm',
    'georgien'                                   => 'ge',
    'ghana'                                      => 'gh',
    'gibraltar'                                  => 'gi',
    'grenada'                                    => 'gd',
    'griechenland'                               => 'gr',
    'grönland'                                  => 'gl',
    'guadeloupe'                                 => 'gp',
    'guam'                                       => 'gu',
    'guatemala'                                  => 'gt',
    'guernsey'                                   => 'gg',
    'guinea'                                     => 'gn',
    'guineabissau'                               => 'gw',
    'guyana'                                     => 'gy',
    'haiti'                                      => 'ht',
    'heardundmcdonaldinseln'                     => 'hm',
    'honduras'                                   => 'hn',
    'hongkong'                                   => 'hk',
    'indien'                                     => 'in',
    'indonesien'                                 => 'id',
    'irak'                                       => 'iq',
    'iran'                                       => 'ir',
    'irland'                                     => 'ie',
    'island'                                     => 'is',
    'isleofman'                                  => 'im',
    'israel'                                     => 'il',
    'italien'                                    => 'it',
    'jamaika'                                    => 'jm',
    'japan'                                      => 'jp',
    'jemen'                                      => 'ye',
    'jersey'                                     => 'je',
    'johnstonisland'                             => 'jt',
    'jordanien'                                  => 'jo',
    'kaimaninseln'                               => 'ky',
    'kambodscha'                                 => 'kh',
    'kamerun'                                    => 'cm',
    'kanada'                                     => 'ca',
    'kapverde'                                   => 'cv',
    'kasachstan'                                 => 'kz',
    'katar'                                      => 'qa',
    'kenia'                                      => 'ke',
    'kirgisistan'                                => 'kg',
    'kiribati'                                   => 'ki',
    'kokosinseln'                                => 'cc',
    'kolumbien'                                  => 'co',
    'komoren'                                    => 'km',
    'kongo'                                      => 'cg',
    'kroatien'                                   => 'hr',
    'kuba'                                       => 'cu',
    'kuwait'                                     => 'kw',
    'laos'                                       => 'la',
    'lesotho'                                    => 'ls',
    'lettland'                                   => 'lv',
    'libanon'                                    => 'lb',
    'liberia'                                    => 'lr',
    'libyen'                                     => 'ly',
    'liechtenstein'                              => 'li',
    'litauen'                                    => 'lt',
    'luxemburg'                                  => 'lu',
    'macau'                                      => 'mo',
    'madagaskar'                                 => 'mg',
    'malawi'                                     => 'mw',
    'malaysia'                                   => 'my',
    'malediven'                                  => 'mv',
    'mali'                                       => 'ml',
    'malta'                                      => 'mt',
    'marokko'                                    => 'ma',
    'marshallinseln'                             => 'mh',
    'martinique'                                 => 'mq',
    'mauretanien'                                => 'mr',
    'mauritius'                                  => 'mu',
    'mayotte'                                    => 'yt',
    'mazedonien'                                 => 'mk',
    'metropolitanfrance'                         => 'fx',
    'mexiko'                                     => 'mx',
    'midwayislands'                              => 'mi',
    'mikronesien'                                => 'fm',
    'monaco'                                     => 'mc',
    'mongolei'                                   => 'mn',
    'montenegro'                                 => 'me',
    'montserrat'                                 => 'ms',
    'mosambik'                                   => 'mz',
    'myanmar'                                    => 'mm',
    'namibia'                                    => 'na',
    'nauru'                                      => 'nr',
    'nepal'                                      => 'np',
    'neukaledonien'                              => 'nc',
    'neuseeland'                                 => 'nz',
    'neutralzone'                                => 'nt',
    'nicaragua'                                  => 'ni',
    'niederlande'                                => 'nl',
    'niederländischeantillen'                   => 'an',
    'niger'                                      => 'ne',
    'nigeria'                                    => 'ng',
    'niue'                                       => 'nu',
    'norfolkinsel'                               => 'nf',
    'northvietnam'                               => 'vd',
    'norwegen'                                   => 'no',
    'nördlichemarianen'                         => 'mp',
    'oman'                                       => 'om',
    'osttimor'                                   => 'tl',
    'pacificislandstrustterritory'               => 'pc',
    'pakistan'                                   => 'pk',
    'palau'                                      => 'pw',
    'palästinensischegebiete'                   => 'ps',
    'panama'                                     => 'pa',
    'panamacanalzone'                            => 'pz',
    'papuaneuguinea'                             => 'pg',
    'paraguay'                                   => 'py',
    'peoplesdemocraticrepublicofyemen'           => 'yd',
    'peru'                                       => 'pe',
    'philippinen'                                => 'ph',
    'pitcairn'                                   => 'pn',
    'polen'                                      => 'pl',
    'portugal'                                   => 'pt',
    'puertorico'                                 => 'pr',
    'republikkorea'                              => 'kr',
    'republikmoldau'                             => 'md',
    'ruanda'                                     => 'rw',
    'rumänien'                                  => 'ro',
    'russischeföderation'                       => 'ru',
    'réunion'                                   => 're',
    'salomonen'                                  => 'sb',
    'sambia'                                     => 'zm',
    'samoa'                                      => 'ws',
    'sanmarino'                                  => 'sm',
    'saudiarabien'                               => 'sa',
    'schweden'                                   => 'se',
    'schweiz'                                    => 'ch',
    'senegal'                                    => 'sn',
    'serbien'                                    => 'rs',
    'serbienundmontenegro'                       => 'cs',
    'seychellen'                                 => 'sc',
    'sierraleone'                                => 'sl',
    'simbabwe'                                   => 'zw',
    'singapur'                                   => 'sg',
    'slowakei'                                   => 'sk',
    'slowenien'                                  => 'si',
    'somalia'                                    => 'so',
    'spanien'                                    => 'es',
    'srilanka'                                   => 'lk',
    "st\.barthélemy"                            => 'bl',
    "st\.helena"                                 => 'sh',
    "st\.kittsundnevis"                          => 'kn',
    "st\.lucia"                                  => 'lc',
    "st\.martin"                                 => 'mf',
    "st\.pierreundmiquelon"                      => 'pm',
    "st\.vincentunddiegrenadinen"                => 'vc',
    'sudan'                                      => 'sd',
    'suriname'                                   => 'sr',
    'svalbardundjanmayen'                        => 'sj',
    'swasiland'                                  => 'sz',
    'syrien'                                     => 'sy',
    'sãotoméundpríncipe'                      => 'st',
    'südafrika'                                 => 'za',
    'südgeorgienunddiesüdlichensandwichinseln' => 'gs',
    'tadschikistan'                              => 'tj',
    'taiwan'                                     => 'tw',
    'tansania'                                   => 'tz',
    'thailand'                                   => 'th',
    'togo'                                       => 'tg',
    'tokelau'                                    => 'tk',
    'tonga'                                      => 'to',
    'trinidadundtobago'                          => 'tt',
    'tschad'                                     => 'td',
    'tschechischerepublik'                       => 'cz',
    'tunesien'                                   => 'tn',
    'turkmenistan'                               => 'tm',
    'turksundcaicosinseln'                       => 'tc',
    'tuvalu'                                     => 'tv',
    'türkei'                                    => 'tr',
    "u\.s\.miscellaneouspacificislands"          => 'pu',
    'uganda'                                     => 'ug',
    'ukraine'                                    => 'ua',
    'unbekannteoderungültigeregion'             => 'zz',
    'ungarn'                                     => 'hu',
    'unionofsovietsocialistrepublics'            => 'su',
    'uruguay'                                    => 'uy',
    'usbekistan'                                 => 'uz',
    'vanuatu'                                    => 'vu',
    'vatikanstadt'                               => 'va',
    'venezuela'                                  => 've',
    'vereinigtearabischeemirate'                 => 'ae',
    'vereinigteskönigreich'                     => 'gb',
    'vereinigtestaaten'                          => 'us',
    'vietnam'                                    => 'vn',
    'wakeisland'                                 => 'wk',
    'wallisundfutuna'                            => 'wf',
    'weihnachtsinsel'                            => 'cx',
    'westsahara'                                 => 'eh',
    'zentralafrikanischerepublik'                => 'cf',
    'zypern'                                     => 'cy',
    'Ägypten'                                   => 'eg',
    'Äquatorialguinea'                          => 'gq',
    'Äthiopien'                                 => 'et',
    'Äußeresozeanien'                          => 'qo',
    'Österreich'                                => 'at',
);

1;

