package Locales::DB::Territory::lo;

# Auto generated from CLDR

$Locales::DB::Territory::lo::VERSION = '0.02';

$Locales::DB::Territory::lo::cldr_version = '1.7.1';

%Locales::DB::Territory::lo::code_to_name = (
    'ad' => 'ອັນດໍລາ',
    'ae' => 'ສະຫະລັດອາຫລັບເອມິເລດ',
    'af' => 'ອັຟການິດສະຖານ',
    'ag' => "Antigua\ and\ Barbuda",
    'ai' => 'ອັນກິລາ',
    'al' => 'ແອລເບເນຍ',
    'am' => 'ອາມິເນຍ',
    'an' => 'ເນເທີແລນແອນເທິນ',
    'ao' => 'ອັນໂກລາ',
    'aq' => 'Antarctica',
    'ar' => 'ອາເຈນຕິນາ່',
    'as' => "American\ Samoa",
    'at' => 'ອົອດສະເຕຼຍ',
    'au' => 'ອົອດສະຕາລີ',
    'aw' => 'ອາລູບາ',
    'ax' => "\Ã\land\ Islands",
    'az' => 'ອາເຊີໄບຈັນ',
    'ba' => "ບັອດສເນຍ\ ແລະ\ ເຮີດໂກວິເນຍ",
    'bb' => 'ບາບາຄັອດ',
    'bd' => 'ບັງກະລາເທດ',
    'be' => 'ເບວຢຽມ',
    'bf' => 'ເບີກິນາຟາໂຊ',
    'bg' => 'ບັງກາເລຍ',
    'bh' => 'ບາເລນ',
    'bi' => 'ບູລັນຕິ',
    'bj' => 'ເບນິນ',
    'bl' => "Saint\ Barth\Ã\©lemy",
    'bm' => 'ເບີມິວດາ',
    'bn' => 'ບູຮໄນ',
    'bo' => 'ໂບລິເວຍ',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'ບຼາຊິວ',
    'bs' => 'ບາຮາມາສ',
    'bt' => 'ພູຖານ',
    'bv' => "Bouvet\ Island",
    'bw' => 'ບອັດສະວານາ',
    'by' => 'ເບນລາຮັສ',
    'bz' => 'ເບລິຊ',
    'ca' => 'ການາດາ',
    'cc' => "Cocos\ \[Keeling\]\ Islands",
    'cd' => "Congo\ \[DRC\]",
    'cf' => 'ສາທາລະນະລັດອັບຟຼິກກາກາງ',
    'cg' => 'ຄອງໂກ',
    'ch' => 'ສະວິດເຊີແລນ',
    'ci' => 'ຝັ່ງທະເລໄອວໍລິ',
    'ck' => "Cook\ Islands",
    'cl' => 'ຊິສິ',
    'cm' => 'ຄາເມລູນ',
    'cn' => 'ຈີນ',
    'co' => 'ໂຄລຳເບຍ',
    'cr' => 'ຄອສຕາລິກາ',
    'cs' => 'ເຊີເບຍ',
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'ຄິວບາ',
    'cv' => 'ເຄບວອດ',
    'cx' => "Christmas\ Island",
    'cy' => 'ໄຊປັຼດ',
    'cz' => 'ສາທາລະນະລັດເຊັກ',
    'dd' => "East\ Germany",
    'de' => 'ເຢຍລະມັນ',
    'dj' => 'ຄິໂບຕິ',
    'dk' => 'ເດນມາກ',
    'dm' => 'ໂດເມນິກາ',
    'do' => 'ສາທາລະນະລັດໂດມິນິກັນ',
    'dz' => 'ແອລຈິເລຍ',
    'ec' => 'ເອກວາດໍ',
    'ee' => 'ເອສໂຕເນຍ',
    'eg' => 'ອີຢິບ',
    'eh' => 'ຊາຮາລາຕະເວັນຕົກ',
    'er' => 'ອິນຊີ',
    'es' => 'ສະເປນ',
    'et' => 'ເອທິໂອເປຍ',
    'fi' => 'ຟິນແລນ',
    'fj' => 'ຟິຈິ',
    'fk' => "Falkland\ Islands\ \[Islas\ Malvinas\]",
    'fm' => 'ໄມໂຄນິເຊຍ',
    'fo' => "Faroe\ Islands",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'ຝລັ່ງ',
    'fx' => "Metropolitan\ France",
    'ga' => 'ກາບອນ',
    'gb' => 'ສະຫະລາດຊະອານາຈັກ',
    'gd' => 'Grenada',
    'ge' => 'ຈໍເຈຍ',
    'gf' => 'ເຟັນສກິວນາ',
    'gg' => 'Guernsey',
    'gh' => 'ການ່າ',
    'gi' => 'Gibraltar',
    'gl' => 'Greenland',
    'gm' => 'ແກມເບຍ',
    'gn' => 'ກິວນີ',
    'gp' => 'ກົວເດີລູບ',
    'gq' => 'ເອຄົວໂທເລຍລະກິນີ',
    'gr' => 'ກິຼກ',
    'gs' => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt' => 'ກົວເຕມາລາ',
    'gu' => 'Guam',
    'gw' => "ກິວນີ\-ບິສໂຊ",
    'gy' => 'ກູຢານາ',
    'hk' => 'ຮ່ອງກົງ',
    'hm' => "Heard\ Island\ and\ McDonald\ Islands",
    'hn' => 'ອວນຄູຣັສ',
    'hr' => 'ໂຄເອເຊຍ',
    'ht' => 'ໄອທີ',
    'hu' => 'ຮົງກາຣີ',
    'id' => 'ອິນໂດເນເຊຍ',
    'ie' => 'ໄອແລນ',
    'il' => 'ອິສລະເອວ',
    'im' => "Isle\ of\ Man",
    'in' => 'ອິນເດຍ',
    'io' => "British\ Indian\ Ocean\ Territory",
    'iq' => 'ອີລັກ',
    'ir' => 'ອີລ່ານ',
    'is' => 'ໄອສແລນ',
    'it' => 'ອິຕາລີ',
    'je' => 'Jersey',
    'jm' => 'ຈາໄມກາ',
    'jo' => 'ຈໍແດນ',
    'jp' => 'ຍີ່ປຸ່ນ',
    'jt' => "Johnston\ Island",
    'ke' => 'ເຄນຢ່າ',
    'kg' => 'ເດີກິດສະຖານ',
    'kh' => 'ກຳປູເຈຍ',
    'ki' => 'ຄີລິບາດ',
    'km' => 'ໂຄໂມຣອດ',
    'kn' => "Saint\ Kitts\ and\ Nevis",
    'kp' => 'ເກົາຫລີເໜືອ',
    'kr' => 'ເກົາຫລີໃຕ້',
    'kw' => 'ຄູເວດ',
    'ky' => "Cayman\ Islands",
    'kz' => 'ຄາຊັດສະຖານ',
    'la' => 'ລາວ',
    'lb' => 'ເລບານອນ',
    'lc' => "Saint\ Lucia",
    'li' => 'ໄລເທນສະໄຕ',
    'lk' => 'ສີລັງກາ',
    'lr' => 'ລິເບີເລຍ',
    'ls' => 'ເລໂຊໂທ',
    'lt' => 'ລິເທີເນຍ',
    'lu' => 'ລຸກແຊມເບີກ',
    'lv' => 'ລຼາດເວຍ',
    'ly' => 'ລິເບຍ',
    'ma' => 'ໂມລັອກໂຄ',
    'mc' => 'ໂມນາໂກ',
    'md' => 'ໂມນໂຄວາ',
    'me' => 'Montenegro',
    'mf' => "Saint\ Martin",
    'mg' => 'ມາຄາກັສກາ',
    'mh' => "Marshall\ Islands",
    'mi' => "Midway\ Islands",
    'mk' => 'ແມຊິໂຄເນຍ',
    'ml' => 'ມາລິ',
    'mm' => 'ສະຫະພາບພະມ້າ',
    'mn' => 'ມົງໂກລີ',
    'mo' => 'ມາເກົ້າ',
    'mp' => "Northern\ Mariana\ Islands",
    'mq' => 'ມາຕິນິກ',
    'mr' => 'ມໍລິກທາເນຍ',
    'ms' => 'ມອນເຊີລາດ',
    'mt' => 'ມັນຕາ',
    'mu' => 'ມໍຣິຕຽດ',
    'mv' => 'Maldives',
    'mw' => 'Malawi',
    'mx' => 'ແມັກຊິໂກ',
    'my' => 'ມາເລເຊຍ',
    'mz' => 'ໂມແຊມບິກ',
    'na' => 'ນາມິເບຍ',
    'nc' => 'ນິວຄາລິໂຄເນຍ',
    'ne' => 'ໄນເຈີ',
    'nf' => "Norfolk\ Island",
    'ng' => 'ໄນຈີເລຍ',
    'ni' => 'ນິຄາລາກົວ',
    'nl' => 'ເນເທີແລນ',
    'no' => 'ນໍເວ',
    'np' => 'ເນປານ',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'ນີຢູ',
    'nz' => 'ນິວຊີແລນ',
    'om' => 'ໂອມານ',
    'pa' => 'ປານາມາ',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'ເປລູ',
    'pf' => 'ເຟັນຣໂພລິນີເຊຍ',
    'pg' => 'ປາປົວນິວກີນີ',
    'ph' => 'ຟິລິປິນ',
    'pk' => 'ປາກິສຖານ',
    'pl' => 'ໂປແລນ',
    'pm' => "Saint\ Pierre\ and\ Miquelon",
    'pn' => "Pitcairn\ Islands",
    'pr' => 'ເປີໂຕລິໂກ',
    'ps' => "Palestinian\ Territories",
    'pt' => 'ໂປຕຸກກັນ',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'ປາລາກວຍ',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'ກາຕາ',
    'qo' => "Outlying\ Oceania",
    'qu' => "European\ Union",
    're' => "R\Ã\©union",
    'ro' => 'ລູເມເນຍ',
    'rs' => 'Serbia',
    'ru' => 'ລັດເຊຍ',
    'rw' => 'ລາວັນດາ',
    'sa' => 'ຊາອຸດິອາລະເບຍ',
    'sb' => "Solomon\ Islands",
    'sc' => 'ເຊແຊວ',
    'sd' => 'ຊູດານ',
    'se' => 'ສະວິເດັນ',
    'sg' => 'ສິງກະໂປ',
    'sh' => "Saint\ Helena",
    'si' => 'ສະໂລເວເນຍ',
    'sj' => "Svalbard\ and\ Jan\ Mayen",
    'sk' => 'ສະໂລວາເກຍ',
    'sl' => 'ເຊຍລາສິອອນ',
    'sm' => "San\ Marino",
    'sn' => 'ຊິນີກັນ',
    'so' => 'ໂຊມາເລຍ',
    'sr' => 'ຊູລິນາມິ',
    'st' => "S\Ã\£o\ Tom\Ã\©\ and\ Pr\Ã\­ncipe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => 'ເອຊາວາດໍ',
    'sy' => 'ຊິເລຍ',
    'sz' => 'ສະວາຊິແລນ',
    'tc' => "Turks\ and\ Caicos\ Islands",
    'td' => 'ຊາດ',
    'tf' => 'ອານາເຂດທາງໃຕ້ຂອງຝລັ່ງເສດ',
    'tg' => 'ໂຕໂກ',
    'th' => 'ປະເທດໄທ',
    'tj' => 'ທາຈິກິສະຖານ',
    'tk' => 'ໂທກິໂລ',
    'tl' => 'ຕິມໍຕາເວັນອອກ',
    'tm' => 'ເຕຣີກເມນິສະຖານ',
    'tn' => 'ຕູນິເຊຍ',
    'to' => 'ຕອງກາ',
    'tr' => 'ຕຸນກີ',
    'tt' => 'ທິນິແດດ',
    'tv' => 'Tuvalu',
    'tw' => 'ໄຕ້ຫວັນ',
    'tz' => 'ທານຊາເນຍ',
    'ua' => 'ຢູເຄຼນ',
    'ug' => 'ອູການດາ',
    'um' => "U\.S\.\ Minor\ Outlying\ Islands",
    'us' => 'ສະຫະລັດອາເມລິກາ',
    'uy' => 'ລູກວຍອຸຣ',
    'uz' => 'ອຸດເບກິສະຖານ',
    'va' => 'ວາຕິກັນ',
    'vc' => "Saint\ Vincent\ and\ the\ Grenadines",
    'vd' => "North\ Vietnam",
    've' => 'ເວເນຊູເອລາ',
    'vg' => 'ບຣິທິດເວີຈິນໄອແລນ',
    'vi' => 'ຢູເອສເວີຈິນໄອແລນ',
    'vn' => 'ຫວຽດນາມ',
    'vu' => 'ວານົວຕູ',
    'wf' => "Wallis\ and\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'ເຢເມນ',
    'yt' => 'ມາຢອດ',
    'za' => 'ອາຟະລິກາໃຕ້',
    'zm' => 'ແຊມເບຍ',
    'zw' => 'ຊິມບັບເວ',
    'zz' => "Unknown\ or\ Invalid\ Region",
);

%Locales::DB::Territory::lo::name_to_code = (
    'americansamoa'                                                            => 'as',
    'antarctica'                                                               => 'aq',
    'antiguaandbarbuda'                                                        => 'ag',
    'bouvetisland'                                                             => 'bv',
    'britishantarcticterritory'                                                => 'bq',
    'britishindianoceanterritory'                                              => 'io',
    'cantonandenderburyislands'                                                => 'ct',
    'caymanislands'                                                            => 'ky',
    'christmasisland'                                                          => 'cx',
    'cocoskeelingislands'                                                      => 'cc',
    'congodrc'                                                                 => 'cd',
    'cookislands'                                                              => 'ck',
    'dronningmaudland'                                                         => 'nq',
    'eastgermany'                                                              => 'dd',
    'europeanunion'                                                            => 'qu',
    'falklandislandsislasmalvinas'                                             => 'fk',
    'faroeislands'                                                             => 'fo',
    'frenchsouthernandantarcticterritories'                                    => 'fq',
    'gibraltar'                                                                => 'gi',
    'greenland'                                                                => 'gl',
    'grenada'                                                                  => 'gd',
    'guam'                                                                     => 'gu',
    'guernsey'                                                                 => 'gg',
    'heardislandandmcdonaldislands'                                            => 'hm',
    'isleofman'                                                                => 'im',
    'jersey'                                                                   => 'je',
    'johnstonisland'                                                           => 'jt',
    'malawi'                                                                   => 'mw',
    'maldives'                                                                 => 'mv',
    'marshallislands'                                                          => 'mh',
    'metropolitanfrance'                                                       => 'fx',
    'midwayislands'                                                            => 'mi',
    'montenegro'                                                               => 'me',
    'nauru'                                                                    => 'nr',
    'neutralzone'                                                              => 'nt',
    'norfolkisland'                                                            => 'nf',
    'northernmarianaislands'                                                   => 'mp',
    'northvietnam'                                                             => 'vd',
    'outlyingoceania'                                                          => 'qo',
    'pacificislandstrustterritory'                                             => 'pc',
    'palau'                                                                    => 'pw',
    'palestinianterritories'                                                   => 'ps',
    'panamacanalzone'                                                          => 'pz',
    'peoplesdemocraticrepublicofyemen'                                         => 'yd',
    'pitcairnislands'                                                          => 'pn',
    "r\Ã\©union"                                                             => 're',
    "saintbarth\Ã\©lemy"                                                     => 'bl',
    'sainthelena'                                                              => 'sh',
    'saintkittsandnevis'                                                       => 'kn',
    'saintlucia'                                                               => 'lc',
    'saintmartin'                                                              => 'mf',
    'saintpierreandmiquelon'                                                   => 'pm',
    'saintvincentandthegrenadines'                                             => 'vc',
    'samoa'                                                                    => 'ws',
    'sanmarino'                                                                => 'sm',
    'serbia'                                                                   => 'rs',
    'solomonislands'                                                           => 'sb',
    'southgeorgiaandthesouthsandwichislands'                                   => 'gs',
    'svalbardandjanmayen'                                                      => 'sj',
    "s\Ã\£otom\Ã\©andpr\Ã\­ncipe"                                        => 'st',
    'turksandcaicosislands'                                                    => 'tc',
    'tuvalu'                                                                   => 'tv',
    "u\.s\.minoroutlyingislands"                                               => 'um',
    "u\.s\.miscellaneouspacificislands"                                        => 'pu',
    'unionofsovietsocialistrepublics'                                          => 'su',
    'unknownorinvalidregion'                                                   => 'zz',
    'wakeisland'                                                               => 'wk',
    'wallisandfutuna'                                                          => 'wf',
    "\Ã\landislands"                                                        => 'ax',
    'ກາຕາ'                                                             => 'qa',
    'ການາດາ'                                                       => 'ca',
    'ການ່າ'                                                          => 'gh',
    'ກາບອນ'                                                          => 'ga',
    'ກຳປູເຈຍ'                                                    => 'kh',
    'ກິວນີ'                                                          => 'gn',
    'ກິວນີບິສໂຊ'                                           => 'gw',
    'ກິຼກ'                                                             => 'gr',
    'ກູຢານາ'                                                       => 'gy',
    'ກົວເດີລູບ'                                              => 'gp',
    'ກົວເຕມາລາ'                                              => 'gt',
    'ຄອງໂກ'                                                          => 'cg',
    'ຄອສຕາລິກາ'                                              => 'cr',
    'ຄາຊັດສະຖານ'                                           => 'kz',
    'ຄາເມລູນ'                                                    => 'cm',
    'ຄິວບາ'                                                          => 'cu',
    'ຄິໂບຕິ'                                                       => 'dj',
    'ຄີລິບາດ'                                                    => 'ki',
    'ຄູເວດ'                                                          => 'kw',
    'ຈາໄມກາ'                                                       => 'jm',
    'ຈີນ'                                                                => 'cn',
    'ຈໍເຈຍ'                                                          => 'ge',
    'ຈໍແດນ'                                                          => 'jo',
    'ຊາດ'                                                                => 'td',
    'ຊາອຸດິອາລະເບຍ'                                  => 'sa',
    'ຊາຮາລາຕະເວັນຕົກ'                            => 'eh',
    'ຊິນີກັນ'                                                    => 'sn',
    'ຊິມບັບເວ'                                                 => 'zw',
    'ຊິສິ'                                                             => 'cl',
    'ຊິເລຍ'                                                          => 'sy',
    'ຊູດານ'                                                          => 'sd',
    'ຊູລິນາມິ'                                                 => 'sr',
    'ຍີ່ປຸ່ນ'                                                    => 'jp',
    'ຕອງກາ'                                                          => 'to',
    'ຕິມໍຕາເວັນອອກ'                                  => 'tl',
    'ຕຸນກີ'                                                          => 'tr',
    'ຕູນິເຊຍ'                                                    => 'tn',
    'ທາຈິກິສະຖານ'                                        => 'tj',
    'ທານຊາເນຍ'                                                 => 'tz',
    'ທິນິແດດ'                                                    => 'tt',
    'ນາມິເບຍ'                                                    => 'na',
    'ນິຄາລາກົວ'                                              => 'ni',
    'ນິວຄາລິໂຄເນຍ'                                     => 'nc',
    'ນິວຊີແລນ'                                                 => 'nz',
    'ນີຢູ'                                                             => 'nu',
    'ນໍເວ'                                                             => 'no',
    'ບຣິທິດເວີຈິນໄອແລນ'                      => 'vg',
    'ບອັດສະວານາ'                                           => 'bw',
    'ບັງກະລາເທດ'                                           => 'bd',
    'ບັງກາເລຍ'                                                 => 'bg',
    'ບັອດສເນຍແລະເຮີດໂກວິເນຍ'       => 'ba',
    'ບາບາຄັອດ'                                                 => 'bb',
    'ບາຮາມາສ'                                                    => 'bs',
    'ບາເລນ'                                                          => 'bh',
    'ບູລັນຕິ'                                                    => 'bi',
    'ບູຮໄນ'                                                          => 'bn',
    'ບຼາຊິວ'                                                       => 'br',
    'ປະເທດໄທ'                                                    => 'th',
    'ປາກິສຖານ'                                                 => 'pk',
    'ປານາມາ'                                                       => 'pa',
    'ປາປົວນິວກີນີ'                                     => 'pg',
    'ປາລາກວຍ'                                                    => 'py',
    'ຝລັ່ງ'                                                          => 'fr',
    'ຝັ່ງທະເລໄອວໍລິ'                               => 'ci',
    'ພູຖານ'                                                          => 'bt',
    'ຟິຈິ'                                                             => 'fj',
    'ຟິນແລນ'                                                       => 'fi',
    'ຟິລິປິນ'                                                    => 'ph',
    'ມອນເຊີລາດ'                                              => 'ms',
    'ມັນຕາ'                                                          => 'mt',
    'ມາຄາກັສກາ'                                              => 'mg',
    'ມາຕິນິກ'                                                    => 'mq',
    'ມາຢອດ'                                                          => 'yt',
    'ມາລິ'                                                             => 'ml',
    'ມາເກົ້າ'                                                    => 'mo',
    'ມາເລເຊຍ'                                                    => 'my',
    'ມົງໂກລີ'                                                    => 'mn',
    'ມໍຣິຕຽດ'                                                    => 'mu',
    'ມໍລິກທາເນຍ'                                           => 'mr',
    'ຢູເຄຼນ'                                                       => 'ua',
    'ຢູເອສເວີຈິນໄອແລນ'                         => 'vi',
    'ລັດເຊຍ'                                                       => 'ru',
    'ລາວ'                                                                => 'la',
    'ລາວັນດາ'                                                    => 'rw',
    'ລິເທີເນຍ'                                                 => 'lt',
    'ລິເບຍ'                                                          => 'ly',
    'ລິເບີເລຍ'                                                 => 'lr',
    'ລຸກແຊມເບີກ'                                           => 'lu',
    'ລູກວຍອຸຣ'                                                 => 'uy',
    'ລູເມເນຍ'                                                    => 'ro',
    'ລຼາດເວຍ'                                                    => 'lv',
    'ວາຕິກັນ'                                                    => 'va',
    'ວານົວຕູ'                                                    => 'vu',
    'ສະວາຊິແລນ'                                              => 'sz',
    'ສະວິດເຊີແລນ'                                        => 'ch',
    'ສະວິເດັນ'                                                 => 'se',
    'ສະຫະພາບພະມ້າ'                                     => 'mm',
    'ສະຫະລັດອາຫລັບເອມິເລດ'             => 'ae',
    'ສະຫະລັດອາເມລິກາ'                            => 'us',
    'ສະຫະລາດຊະອານາຈັກ'                         => 'gb',
    'ສະເປນ'                                                          => 'es',
    'ສະໂລວາເກຍ'                                              => 'sk',
    'ສະໂລເວເນຍ'                                              => 'si',
    'ສາທາລະນະລັດອັບຟຼິກກາກາງ'    => 'cf',
    'ສາທາລະນະລັດເຊັກ'                            => 'cz',
    'ສາທາລະນະລັດໂດມິນິກັນ'             => 'do',
    'ສິງກະໂປ'                                                    => 'sg',
    'ສີລັງກາ'                                                    => 'lk',
    'ຫວຽດນາມ'                                                    => 'vn',
    'ອວນຄູຣັສ'                                                 => 'hn',
    'ອັນກິລາ'                                                    => 'ai',
    'ອັນດໍລາ'                                                    => 'ad',
    'ອັນໂກລາ'                                                    => 'ao',
    'ອັຟການິດສະຖານ'                                  => 'af',
    'ອານາເຂດທາງໃຕ້ຂອງຝລັ່ງເສດ' => 'tf',
    'ອາຟະລິກາໃຕ້'                                        => 'za',
    'ອາມິເນຍ'                                                    => 'am',
    'ອາລູບາ'                                                       => 'aw',
    'ອາເຈນຕິນາ່'                                           => 'ar',
    'ອາເຊີໄບຈັນ'                                           => 'az',
    'ອິຕາລີ'                                                       => 'it',
    'ອິນຊີ'                                                          => 'er',
    'ອິນເດຍ'                                                       => 'in',
    'ອິນໂດເນເຊຍ'                                           => 'id',
    'ອິສລະເອວ'                                                 => 'il',
    'ອີຢິບ'                                                          => 'eg',
    'ອີລັກ'                                                          => 'iq',
    'ອີລ່ານ'                                                       => 'ir',
    'ອຸດເບກິສະຖານ'                                     => 'uz',
    'ອູການດາ'                                                    => 'ug',
    'ອົອດສະຕາລີ'                                           => 'au',
    'ອົອດສະເຕຼຍ'                                           => 'at',
    'ຮົງກາຣີ'                                                    => 'hu',
    'ຮ່ອງກົງ'                                                    => 'hk',
    'ເກົາຫລີເໜືອ'                                        => 'kp',
    'ເກົາຫລີໃຕ້'                                           => 'kr',
    'ເຄນຢ່າ'                                                       => 'ke',
    'ເຄບວອດ'                                                       => 'cv',
    'ເຊຍລາສິອອນ'                                           => 'sl',
    'ເຊີເບຍ'                                                       => 'cs',
    'ເຊແຊວ'                                                          => 'sc',
    'ເດນມາກ'                                                       => 'dk',
    'ເດີກິດສະຖານ'                                        => 'kg',
    'ເຕຣີກເມນິສະຖານ'                               => 'tm',
    'ເນປານ'                                                          => 'np',
    'ເນເທີແລນ'                                                 => 'nl',
    'ເນເທີແລນແອນເທິນ'                            => 'an',
    'ເບນລາຮັສ'                                                 => 'by',
    'ເບນິນ'                                                          => 'bj',
    'ເບລິຊ'                                                          => 'bz',
    'ເບວຢຽມ'                                                       => 'be',
    'ເບີກິນາຟາໂຊ'                                        => 'bf',
    'ເບີມິວດາ'                                                 => 'bm',
    'ເປລູ'                                                             => 'pe',
    'ເປີໂຕລິໂກ'                                              => 'pr',
    'ເຟັນຣໂພລິນີເຊຍ'                               => 'pf',
    'ເຟັນສກິວນາ'                                           => 'gf',
    'ເຢຍລະມັນ'                                                 => 'de',
    'ເຢເມນ'                                                          => 'ye',
    'ເລບານອນ'                                                    => 'lb',
    'ເລໂຊໂທ'                                                       => 'ls',
    'ເວເນຊູເອລາ'                                           => 've',
    'ເອກວາດໍ'                                                    => 'ec',
    'ເອຄົວໂທເລຍລະກິນີ'                         => 'gq',
    'ເອຊາວາດໍ'                                                 => 'sv',
    'ເອທິໂອເປຍ'                                              => 'et',
    'ເອສໂຕເນຍ'                                                 => 'ee',
    'ແກມເບຍ'                                                       => 'gm',
    'ແຊມເບຍ'                                                       => 'zm',
    'ແມຊິໂຄເນຍ'                                              => 'mk',
    'ແມັກຊິໂກ'                                                 => 'mx',
    'ແອລຈິເລຍ'                                                 => 'dz',
    'ແອລເບເນຍ'                                                 => 'al',
    'ໂຄລຳເບຍ'                                                    => 'co',
    'ໂຄເອເຊຍ'                                                    => 'hr',
    'ໂຄໂມຣອດ'                                                    => 'km',
    'ໂຊມາເລຍ'                                                    => 'so',
    'ໂດເມນິກາ'                                                 => 'dm',
    'ໂຕໂກ'                                                             => 'tg',
    'ໂທກິໂລ'                                                       => 'tk',
    'ໂບລິເວຍ'                                                    => 'bo',
    'ໂປຕຸກກັນ'                                                 => 'pt',
    'ໂປແລນ'                                                          => 'pl',
    'ໂມນາໂກ'                                                       => 'mc',
    'ໂມນໂຄວາ'                                                    => 'md',
    'ໂມລັອກໂຄ'                                                 => 'ma',
    'ໂມແຊມບິກ'                                                 => 'mz',
    'ໂອມານ'                                                          => 'om',
    'ໄຊປັຼດ'                                                       => 'cy',
    'ໄຕ້ຫວັນ'                                                    => 'tw',
    'ໄນຈີເລຍ'                                                    => 'ng',
    'ໄນເຈີ'                                                          => 'ne',
    'ໄມໂຄນິເຊຍ'                                              => 'fm',
    'ໄລເທນສະໄຕ'                                              => 'li',
    'ໄອທີ'                                                             => 'ht',
    'ໄອສແລນ'                                                       => 'is',
    'ໄອແລນ'                                                          => 'ie',
);

1;

