package Locales::DB::Territory::et;

# Auto generated from CLDR

$Locales::DB::Territory::et::VERSION = '0.02';

$Locales::DB::Territory::et::cldr_version = '1.7.1';

%Locales::DB::Territory::et::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "Araabia\ Ühendemiraadid",
    'af' => 'Afganistan',
    'ag' => "Antigua\ ja\ Barbuda",
    'ai' => 'Anguilla',
    'al' => 'Albaania',
    'am' => 'Armeenia',
    'an' => "Hollandi\ Antillid",
    'ao' => 'Angola',
    'aq' => 'Antarktis',
    'ar' => 'Argentina',
    'as' => "Ameerika\ Samoa",
    'at' => 'Austria',
    'au' => 'Austraalia',
    'aw' => 'Aruba',
    'ax' => 'Ahvenamaa',
    'az' => 'Aserbaidžaan',
    'ba' => "Bosnia\ ja\ Hertsegoviina",
    'bb' => 'Barbados',
    'bd' => 'Bangladesh',
    'be' => 'Belgia',
    'bf' => "Burkina\ Faso",
    'bg' => 'Bulgaaria',
    'bh' => 'Bahrein',
    'bi' => 'Burundi',
    'bj' => 'Benin',
    'bl' => "Saint\ Barth\Ã\©lemy",
    'bm' => 'Bermuda',
    'bn' => 'Brunei',
    'bo' => 'Boliivia',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brasiilia',
    'bs' => 'Bahama',
    'bt' => 'Bhutan',
    'bv' => "Bouvet’\ saar",
    'bw' => 'Botswana',
    'by' => 'Valgevene',
    'bz' => 'Belize',
    'ca' => 'Kanada',
    'cc' => 'Kookossaared',
    'cd' => "Kongo\ DV",
    'cf' => "Kesk\-Aafrika\ Vabariik",
    'cg' => "Kongo\ Vabariik",
    'ch' => 'Šveits',
    'ci' => "Côte\ d\'Ivoire",
    'ck' => "Cooki\ saared",
    'cl' => 'Tšiili',
    'cm' => 'Kamerun',
    'cn' => 'Hiina',
    'co' => 'Colombia',
    'cr' => "Costa\ Rica",
    'cs' => "Serbia\ ja\ Montenegro",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Kuuba',
    'cv' => 'Roheneemesaared',
    'cx' => 'Jõulusaar',
    'cy' => 'Küpros',
    'cz' => 'Tšehhi',
    'dd' => "East\ Germany",
    'de' => 'Saksamaa',
    'dj' => 'Djibouti',
    'dk' => 'Taani',
    'dm' => 'Dominica',
    'do' => "Dominikaani\ Vabariik",
    'dz' => 'Alžeeria',
    'ec' => 'Ecuador',
    'ee' => 'Eesti',
    'eg' => 'Egiptus',
    'eh' => "Lääne\-Sahara",
    'er' => 'Eritrea',
    'es' => 'Hispaania',
    'et' => 'Etioopia',
    'fi' => 'Soome',
    'fj' => 'Fidži',
    'fk' => "Falklandi\ saared",
    'fm' => "Mikroneesia\ Liiduriigid",
    'fo' => "Fääri\ saared",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Prantsusmaa',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabon',
    'gb' => 'Suurbritannia',
    'gd' => 'Grenada',
    'ge' => 'Gruusia',
    'gf' => "Prantsuse\ Guajaana",
    'gg' => 'Guernsey',
    'gh' => 'Ghana',
    'gi' => 'Gibraltar',
    'gl' => 'Gröönimaa',
    'gm' => 'Gambia',
    'gn' => 'Guinea',
    'gp' => 'Guadeloupe',
    'gq' => "Ekvatoriaal\-Guinea",
    'gr' => 'Kreeka',
    'gs' => "Lõuna\-Georgia\ ja\ Lõuna\-Sandwichi\ saared",
    'gt' => 'Guatemala',
    'gu' => 'Guam',
    'gw' => "Guinea\-Bissau",
    'gy' => 'Guyana',
    'hk' => 'Hongkong',
    'hm' => "Heard\ ja\ McDonald",
    'hn' => 'Honduras',
    'hr' => 'Horvaatia',
    'ht' => 'Haiti',
    'hu' => 'Ungari',
    'id' => 'Indoneesia',
    'ie' => 'Iirimaa',
    'il' => 'Iisrael',
    'im' => "Mani\ saar",
    'in' => 'India',
    'io' => "Briti\ India\ ookeani\ ala",
    'iq' => 'Iraak',
    'ir' => 'Iraan',
    'is' => 'Island',
    'it' => 'Itaalia',
    'je' => 'Jersey',
    'jm' => 'Jamaica',
    'jo' => 'Jordaania',
    'jp' => 'Jaapan',
    'jt' => "Johnston\ Island",
    'ke' => 'Kenya',
    'kg' => 'Kõrgõzstan',
    'kh' => 'Kambodža',
    'ki' => 'Kiribati',
    'km' => 'Komoorid',
    'kn' => "Saint\ Kitts\ ja\ Nevis",
    'kp' => "Põhja\-Korea",
    'kr' => "Lõuna\-Korea",
    'kw' => 'Kuveit',
    'ky' => 'Kaimanisaared',
    'kz' => 'Kasahstan',
    'la' => 'Laos',
    'lb' => 'Liibanon',
    'lc' => "Saint\ Lucia",
    'li' => 'Liechtenstein',
    'lk' => "Sri\ Lanka",
    'lr' => 'Libeeria',
    'ls' => 'Lesotho',
    'lt' => 'Leedu',
    'lu' => 'Luksemburg',
    'lv' => 'Läti',
    'ly' => 'Liibüa',
    'ma' => 'Maroko',
    'mc' => 'Monaco',
    'md' => 'Moldova',
    'me' => 'Montenegro',
    'mf' => "Saint\ Martin",
    'mg' => 'Madagaskar',
    'mh' => "Marshalli\ Saared",
    'mi' => "Midway\ Islands",
    'mk' => 'Makedoonia',
    'ml' => 'Mali',
    'mm' => 'Myanmar',
    'mn' => 'Mongoolia',
    'mo' => 'Aomen',
    'mp' => "Põhja\-Mariaanid",
    'mq' => 'Martinique',
    'mr' => 'Mauritaania',
    'ms' => 'Montserrat',
    'mt' => 'Malta',
    'mu' => 'Mauritius',
    'mv' => 'Maldiivid',
    'mw' => 'Malawi',
    'mx' => 'Mehhiko',
    'my' => 'Malaisia',
    'mz' => 'Mosambiik',
    'na' => 'Namiibia',
    'nc' => "Uus\-Kaledoonia",
    'ne' => 'Niger',
    'nf' => 'Norfolk',
    'ng' => 'Nigeeria',
    'ni' => 'Nicaragua',
    'nl' => 'Holland',
    'no' => 'Norra',
    'np' => 'Nepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "Uus\-Meremaa",
    'om' => 'Omaan',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Peruu',
    'pf' => "Prantsuse\ Polüneesia",
    'pg' => "Paapua\ Uus\-Guinea",
    'ph' => 'Filipiinid',
    'pk' => 'Pakistan',
    'pl' => 'Poola',
    'pm' => "Saint\-Pierre\ ja\ Miquelon",
    'pn' => 'Pitcairn',
    'pr' => "Puerto\ Rico",
    'ps' => "Palestiina\ ala",
    'pt' => 'Portugal',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Belau',
    'py' => 'Paraguay',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Katar',
    'qo' => "Okeaania\ hajasaared",
    'qu' => "Euroopa\ Liit",
    're' => 'Réunion',
    'ro' => 'Rumeenia',
    'rs' => 'Serbia',
    'ru' => 'Venemaa',
    'rw' => 'Rwanda',
    'sa' => "Saudi\ Araabia",
    'sb' => "Saalomoni\ Saared",
    'sc' => 'Seišellid',
    'sd' => 'Sudaan',
    'se' => 'Rootsi',
    'sg' => 'Singapur',
    'sh' => "Saint\ Helena",
    'si' => 'Sloveenia',
    'sj' => "Svalbard\ ja\ Jan\ Mayen",
    'sk' => 'Slovakkia',
    'sl' => "Sierra\ Leone",
    'sm' => "San\ Marino",
    'sn' => 'Senegal',
    'so' => 'Somaalia',
    'sr' => 'Suriname',
    'st' => "São\ Tomé\ ja\ Príncipe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salvador",
    'sy' => 'Süüria',
    'sz' => 'Svaasimaa',
    'tc' => "Turks\ ja\ Caicos",
    'td' => 'Tšaad',
    'tf' => "Prantsuse\ Lõunaalad",
    'tg' => 'Togo',
    'th' => 'Tai',
    'tj' => 'Tadžikistan',
    'tk' => 'Tokelau',
    'tl' => "Ida\-Timor",
    'tm' => 'Türkmenistan',
    'tn' => 'Tuneesia',
    'to' => 'Tonga',
    'tr' => 'Türgi',
    'tt' => "Trinidad\ ja\ Tobago",
    'tv' => 'Tuvalu',
    'tw' => 'Taiwan',
    'tz' => 'Tansaania',
    'ua' => 'Ukraina',
    'ug' => 'Uganda',
    'um' => "Ühendriikide\ hajasaared",
    'us' => "Ameerika\ Ühendriigid",
    'uy' => 'Uruguay',
    'uz' => 'Usbekistan',
    'va' => 'Vatikan',
    'vc' => "Saint\ Vincent\ ja\ Grenadiinid",
    'vd' => "North\ Vietnam",
    've' => 'Venezuela',
    'vg' => "Briti\ Neitsisaared",
    'vi' => "USA\ Neitsisaared",
    'vn' => 'Vietnam',
    'vu' => 'Vanuatu',
    'wf' => "Wallis\ ja\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Jeemen',
    'yt' => 'Mayotte',
    'za' => "Lõuna\-Aafrika\ Vabariik",
    'zm' => 'Sambia',
    'zw' => 'Zimbabwe',
    'zz' => 'määramata',
);

%Locales::DB::Territory::et::name_to_code = (
    'afganistan'                            => 'af',
    'ahvenamaa'                             => 'ax',
    'albaania'                              => 'al',
    'alžeeria'                             => 'dz',
    'ameerikasamoa'                         => 'as',
    'ameerikaÜhendriigid'                  => 'us',
    'andorra'                               => 'ad',
    'angola'                                => 'ao',
    'anguilla'                              => 'ai',
    'antarktis'                             => 'aq',
    'antiguajabarbuda'                      => 'ag',
    'aomen'                                 => 'mo',
    'araabiaÜhendemiraadid'                => 'ae',
    'argentina'                             => 'ar',
    'armeenia'                              => 'am',
    'aruba'                                 => 'aw',
    'aserbaidžaan'                         => 'az',
    'austraalia'                            => 'au',
    'austria'                               => 'at',
    'bahama'                                => 'bs',
    'bahrein'                               => 'bh',
    'bangladesh'                            => 'bd',
    'barbados'                              => 'bb',
    'belau'                                 => 'pw',
    'belgia'                                => 'be',
    'belize'                                => 'bz',
    'benin'                                 => 'bj',
    'bermuda'                               => 'bm',
    'bhutan'                                => 'bt',
    'boliivia'                              => 'bo',
    'bosniajahertsegoviina'                 => 'ba',
    'botswana'                              => 'bw',
    'bouvet’saar'                         => 'bv',
    'brasiilia'                             => 'br',
    'britiindiaookeaniala'                  => 'io',
    'britineitsisaared'                     => 'vg',
    'britishantarcticterritory'             => 'bq',
    'brunei'                                => 'bn',
    'bulgaaria'                             => 'bg',
    'burkinafaso'                           => 'bf',
    'burundi'                               => 'bi',
    'cantonandenderburyislands'             => 'ct',
    'colombia'                              => 'co',
    'cookisaared'                           => 'ck',
    'costarica'                             => 'cr',
    'côtedivoire'                          => 'ci',
    'djibouti'                              => 'dj',
    'dominica'                              => 'dm',
    'dominikaanivabariik'                   => 'do',
    'dronningmaudland'                      => 'nq',
    'eastgermany'                           => 'dd',
    'ecuador'                               => 'ec',
    'eesti'                                 => 'ee',
    'egiptus'                               => 'eg',
    'ekvatoriaalguinea'                     => 'gq',
    'elsalvador'                            => 'sv',
    'eritrea'                               => 'er',
    'etioopia'                              => 'et',
    'euroopaliit'                           => 'qu',
    'falklandisaared'                       => 'fk',
    'fidži'                                => 'fj',
    'filipiinid'                            => 'ph',
    'frenchsouthernandantarcticterritories' => 'fq',
    'fäärisaared'                         => 'fo',
    'gabon'                                 => 'ga',
    'gambia'                                => 'gm',
    'ghana'                                 => 'gh',
    'gibraltar'                             => 'gi',
    'grenada'                               => 'gd',
    'gruusia'                               => 'ge',
    'gröönimaa'                           => 'gl',
    'guadeloupe'                            => 'gp',
    'guam'                                  => 'gu',
    'guatemala'                             => 'gt',
    'guernsey'                              => 'gg',
    'guinea'                                => 'gn',
    'guineabissau'                          => 'gw',
    'guyana'                                => 'gy',
    'haiti'                                 => 'ht',
    'heardjamcdonald'                       => 'hm',
    'hiina'                                 => 'cn',
    'hispaania'                             => 'es',
    'holland'                               => 'nl',
    'hollandiantillid'                      => 'an',
    'honduras'                              => 'hn',
    'hongkong'                              => 'hk',
    'horvaatia'                             => 'hr',
    'idatimor'                              => 'tl',
    'iirimaa'                               => 'ie',
    'iisrael'                               => 'il',
    'india'                                 => 'in',
    'indoneesia'                            => 'id',
    'iraak'                                 => 'iq',
    'iraan'                                 => 'ir',
    'island'                                => 'is',
    'itaalia'                               => 'it',
    'jaapan'                                => 'jp',
    'jamaica'                               => 'jm',
    'jeemen'                                => 'ye',
    'jersey'                                => 'je',
    'johnstonisland'                        => 'jt',
    'jordaania'                             => 'jo',
    'jõulusaar'                            => 'cx',
    'kaimanisaared'                         => 'ky',
    'kambodža'                             => 'kh',
    'kamerun'                               => 'cm',
    'kanada'                                => 'ca',
    'kasahstan'                             => 'kz',
    'katar'                                 => 'qa',
    'kenya'                                 => 'ke',
    'keskaafrikavabariik'                   => 'cf',
    'kiribati'                              => 'ki',
    'komoorid'                              => 'km',
    'kongodv'                               => 'cd',
    'kongovabariik'                         => 'cg',
    'kookossaared'                          => 'cc',
    'kreeka'                                => 'gr',
    'kuuba'                                 => 'cu',
    'kuveit'                                => 'kw',
    'kõrgõzstan'                          => 'kg',
    'küpros'                               => 'cy',
    'laos'                                  => 'la',
    'leedu'                                 => 'lt',
    'lesotho'                               => 'ls',
    'libeeria'                              => 'lr',
    'liechtenstein'                         => 'li',
    'liibanon'                              => 'lb',
    'liibüa'                               => 'ly',
    'luksemburg'                            => 'lu',
    'läti'                                 => 'lv',
    'läänesahara'                         => 'eh',
    'lõunaaafrikavabariik'                 => 'za',
    'lõunageorgiajalõunasandwichisaared'  => 'gs',
    'lõunakorea'                           => 'kr',
    'madagaskar'                            => 'mg',
    'makedoonia'                            => 'mk',
    'malaisia'                              => 'my',
    'malawi'                                => 'mw',
    'maldiivid'                             => 'mv',
    'mali'                                  => 'ml',
    'malta'                                 => 'mt',
    'manisaar'                              => 'im',
    'maroko'                                => 'ma',
    'marshallisaared'                       => 'mh',
    'martinique'                            => 'mq',
    'mauritaania'                           => 'mr',
    'mauritius'                             => 'mu',
    'mayotte'                               => 'yt',
    'mehhiko'                               => 'mx',
    'metropolitanfrance'                    => 'fx',
    'midwayislands'                         => 'mi',
    'mikroneesialiiduriigid'                => 'fm',
    'moldova'                               => 'md',
    'monaco'                                => 'mc',
    'mongoolia'                             => 'mn',
    'montenegro'                            => 'me',
    'montserrat'                            => 'ms',
    'mosambiik'                             => 'mz',
    'myanmar'                               => 'mm',
    'määramata'                           => 'zz',
    'namiibia'                              => 'na',
    'nauru'                                 => 'nr',
    'nepal'                                 => 'np',
    'neutralzone'                           => 'nt',
    'nicaragua'                             => 'ni',
    'nigeeria'                              => 'ng',
    'niger'                                 => 'ne',
    'niue'                                  => 'nu',
    'norfolk'                               => 'nf',
    'norra'                                 => 'no',
    'northvietnam'                          => 'vd',
    'okeaaniahajasaared'                    => 'qo',
    'omaan'                                 => 'om',
    'paapuauusguinea'                       => 'pg',
    'pacificislandstrustterritory'          => 'pc',
    'pakistan'                              => 'pk',
    'palestiinaala'                         => 'ps',
    'panama'                                => 'pa',
    'panamacanalzone'                       => 'pz',
    'paraguay'                              => 'py',
    'peoplesdemocraticrepublicofyemen'      => 'yd',
    'peruu'                                 => 'pe',
    'pitcairn'                              => 'pn',
    'poola'                                 => 'pl',
    'portugal'                              => 'pt',
    'prantsuseguajaana'                     => 'gf',
    'prantsuselõunaalad'                   => 'tf',
    'prantsusepolüneesia'                  => 'pf',
    'prantsusmaa'                           => 'fr',
    'puertorico'                            => 'pr',
    'põhjakorea'                           => 'kp',
    'põhjamariaanid'                       => 'mp',
    'roheneemesaared'                       => 'cv',
    'rootsi'                                => 'se',
    'rumeenia'                              => 'ro',
    'rwanda'                                => 'rw',
    'réunion'                              => 're',
    'saalomonisaared'                       => 'sb',
    "saintbarth\Ã\©lemy"                  => 'bl',
    'sainthelena'                           => 'sh',
    'saintkittsjanevis'                     => 'kn',
    'saintlucia'                            => 'lc',
    'saintmartin'                           => 'mf',
    'saintpierrejamiquelon'                 => 'pm',
    'saintvincentjagrenadiinid'             => 'vc',
    'saksamaa'                              => 'de',
    'sambia'                                => 'zm',
    'samoa'                                 => 'ws',
    'sanmarino'                             => 'sm',
    'saudiaraabia'                          => 'sa',
    'seišellid'                            => 'sc',
    'senegal'                               => 'sn',
    'serbia'                                => 'rs',
    'serbiajamontenegro'                    => 'cs',
    'sierraleone'                           => 'sl',
    'singapur'                              => 'sg',
    'slovakkia'                             => 'sk',
    'sloveenia'                             => 'si',
    'somaalia'                              => 'so',
    'soome'                                 => 'fi',
    'srilanka'                              => 'lk',
    'sudaan'                                => 'sd',
    'suriname'                              => 'sr',
    'suurbritannia'                         => 'gb',
    'svaasimaa'                             => 'sz',
    'svalbardjajanmayen'                    => 'sj',
    'sãotoméjapríncipe'                  => 'st',
    'süüria'                              => 'sy',
    'taani'                                 => 'dk',
    'tadžikistan'                          => 'tj',
    'tai'                                   => 'th',
    'taiwan'                                => 'tw',
    'tansaania'                             => 'tz',
    'togo'                                  => 'tg',
    'tokelau'                               => 'tk',
    'tonga'                                 => 'to',
    'trinidadjatobago'                      => 'tt',
    'tuneesia'                              => 'tn',
    'turksjacaicos'                         => 'tc',
    'tuvalu'                                => 'tv',
    'türgi'                                => 'tr',
    'türkmenistan'                         => 'tm',
    'tšaad'                                => 'td',
    'tšehhi'                               => 'cz',
    'tšiili'                               => 'cl',
    "u\.s\.miscellaneouspacificislands"     => 'pu',
    'uganda'                                => 'ug',
    'ukraina'                               => 'ua',
    'ungari'                                => 'hu',
    'unionofsovietsocialistrepublics'       => 'su',
    'uruguay'                               => 'uy',
    'usaneitsisaared'                       => 'vi',
    'usbekistan'                            => 'uz',
    'uuskaledoonia'                         => 'nc',
    'uusmeremaa'                            => 'nz',
    'valgevene'                             => 'by',
    'vanuatu'                               => 'vu',
    'vatikan'                               => 'va',
    'venemaa'                               => 'ru',
    'venezuela'                             => 've',
    'vietnam'                               => 'vn',
    'wakeisland'                            => 'wk',
    'wallisjafutuna'                        => 'wf',
    'zimbabwe'                              => 'zw',
    'Ühendriikidehajasaared'               => 'um',
    'Šveits'                               => 'ch',
);

1;

