package Locales::DB::Territory::fa;

# Auto generated from CLDR

$Locales::DB::Territory::fa::VERSION = '0.02';

$Locales::DB::Territory::fa::cldr_version = '1.7.1';

%Locales::DB::Territory::fa::code_to_name = (
    'ad' => 'آندورا',
    'ae' => "امارات\ متحدهٔ\ عربی",
    'af' => 'افغانستان',
    'ag' => "آنتیگوا\ و\ باربودا",
    'ai' => 'آنگیل',
    'al' => 'آلبانی',
    'am' => 'ارمنستان',
    'an' => "آنتیل\ هلند",
    'ao' => 'آنگولا',
    'aq' => 'جنوبگان',
    'ar' => 'آرژانتین',
    'as' => "ساموای\ امریکا",
    'at' => 'اتریش',
    'au' => 'استرالیا',
    'aw' => 'آروبا',
    'ax' => "جزایر\ آلاند",
    'az' => "جمهوری\ آذربایجان",
    'ba' => "بوسنی\ و\ هرزگوین",
    'bb' => 'باربادوس',
    'bd' => 'بنگلادش',
    'be' => 'بلژیک',
    'bf' => 'بورکینافاسو',
    'bg' => 'بلغارستان',
    'bh' => 'بحرین',
    'bi' => 'بوروندی',
    'bj' => 'بنین',
    'bl' => "سنت\ بارتلیمی",
    'bm' => 'برمودا',
    'bn' => 'برونئی',
    'bo' => 'بولیوی',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'برزیل',
    'bs' => 'باهاما',
    'bt' => 'بوتان',
    'bv' => "جزیرهٔ\ بووت",
    'bw' => 'بوتسوانا',
    'by' => 'بیلوروسی',
    'bz' => 'بلیز',
    'ca' => 'کانادا',
    'cc' => "جزایر\ کوکوس",
    'cd' => "کنگو\ کینشاسا",
    'cf' => "جمهوری\ افریقای\ مرکزی",
    'cg' => "کنگو\ برازویل",
    'ch' => 'سوئیس',
    'ci' => "ساحل\ عاج",
    'ck' => "جزایر\ کوک",
    'cl' => 'شیلی',
    'cm' => 'کامرون',
    'cn' => 'چین',
    'co' => 'کلمبیا',
    'cr' => 'کاستاریکا',
    'cs' => "صربستان\ و\ مونته‌نگرو",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'کوبا',
    'cv' => "کیپ\ ورد",
    'cx' => "جزیرهٔ\ کریسمس",
    'cy' => 'قبرس',
    'cz' => "جمهوری\ چک",
    'dd' => "East\ Germany",
    'de' => 'آلمان',
    'dj' => 'جیبوتی',
    'dk' => 'دانمارک',
    'dm' => 'دومینیک',
    'do' => "جمهوری\ دومینیکن",
    'dz' => 'الجزایر',
    'ec' => 'اکوادر',
    'ee' => 'استونی',
    'eg' => 'مصر',
    'eh' => "صحرای\ غربی",
    'er' => 'اریتره',
    'es' => 'اسپانیا',
    'et' => 'اتیوپی',
    'fi' => 'فنلاند',
    'fj' => 'فیجی',
    'fk' => "جزایر\ فالکلند",
    'fm' => 'میکرونزی',
    'fo' => "جزایر\ فارو",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'فرانسه',
    'fx' => "Metropolitan\ France",
    'ga' => 'گابون',
    'gb' => 'بریتانیا',
    'gd' => 'گرانادا',
    'ge' => 'گرجستان',
    'gf' => "گویان\ فرانسه",
    'gg' => 'گرنزی',
    'gh' => 'غنا',
    'gi' => 'جبل‌الطارق',
    'gl' => 'گروئنلند',
    'gm' => 'گامبیا',
    'gn' => 'گینه',
    'gp' => 'گوادلوپ',
    'gq' => "گینهٔ\ استوایی",
    'gr' => 'یونان',
    'gs' => "جورجیای\ جنوبی\ و\ جزایر\ ساندویچ\ جنوبی",
    'gt' => 'گواتمالا',
    'gu' => 'گوام',
    'gw' => "گینهٔ\ بیسائو",
    'gy' => 'گویان',
    'hk' => 'هنگ‌کنگ',
    'hm' => "جزیرهٔ\ هرد\ و\ جزایر\ مک‌دونالد",
    'hn' => 'هندوراس',
    'hr' => 'کرواسی',
    'ht' => 'هاییتی',
    'hu' => 'مجارستان',
    'id' => 'اندونزی',
    'ie' => 'ایرلند',
    'il' => 'اسرائیل',
    'im' => "جزیرهٔ\ مان",
    'in' => 'هند',
    'io' => "مستعمره‌های\ بریتانیا\ در\ اقیانوس\ هند",
    'iq' => 'عراق',
    'ir' => 'ایران',
    'is' => 'ایسلند',
    'it' => 'ایتالیا',
    'je' => 'جرسی',
    'jm' => 'جامائیکا',
    'jo' => 'اردن',
    'jp' => 'ژاپن',
    'jt' => "Johnston\ Island",
    'ke' => 'کنیا',
    'kg' => 'قرقیزستان',
    'kh' => 'کامبوج',
    'ki' => 'کیریباتی',
    'km' => 'کومورو',
    'kn' => "سنت\ کیتس\ و\ نویس",
    'kp' => "کرهٔ\ شمالی",
    'kr' => "کرهٔ\ جنوبی",
    'kw' => 'کویت',
    'ky' => "جزایر\ کِیمن",
    'kz' => 'قزاقستان',
    'la' => 'لائوس',
    'lb' => 'لبنان',
    'lc' => "سنت\ لوسیا",
    'li' => 'لیختن‌اشتاین',
    'lk' => 'سری‌لانکا',
    'lr' => 'لیبریا',
    'ls' => 'لسوتو',
    'lt' => 'لیتوانی',
    'lu' => 'لوکزامبورگ',
    'lv' => 'لتونی',
    'ly' => 'لیبی',
    'ma' => 'مراکش',
    'mc' => 'موناکو',
    'md' => 'مولداوی',
    'me' => 'مونته‌نگرو',
    'mf' => "سنت\ مارتین",
    'mg' => 'ماداگاسکار',
    'mh' => "جزایر\ مارشال",
    'mi' => "Midway\ Islands",
    'mk' => 'مقدونیه',
    'ml' => 'مالی',
    'mm' => 'میانمار',
    'mn' => 'مغولستان',
    'mo' => 'ماکائو',
    'mp' => "جزایر\ ماریانای\ شمالی",
    'mq' => 'مارتینیک',
    'mr' => 'موریتانی',
    'ms' => 'مونت‌سرات',
    'mt' => 'مالت',
    'mu' => 'موریس',
    'mv' => 'مالدیو',
    'mw' => 'مالاوی',
    'mx' => 'مکزیک',
    'my' => 'مالزی',
    'mz' => 'موزامبیک',
    'na' => 'نامیبیا',
    'nc' => "کالدونیای\ جدید",
    'ne' => 'نیجر',
    'nf' => "جزیرهٔ\ نورفولک",
    'ng' => 'نیجریه',
    'ni' => 'نیکاراگوئه',
    'nl' => 'هلند',
    'no' => 'نروژ',
    'np' => 'نپال',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'نائورو',
    'nt' => "Neutral\ Zone",
    'nu' => 'نیوئه',
    'nz' => "زلاند\ نو",
    'om' => 'عمان',
    'pa' => 'پاناما',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'پرو',
    'pf' => "پلی‌نزی\ فرانسه",
    'pg' => "پاپوا\ گینهٔ\ نو",
    'ph' => 'فیلیپین',
    'pk' => 'پاکستان',
    'pl' => 'لهستان',
    'pm' => "سنت\ پیر\ و\ میکلون",
    'pn' => 'پیتکایرن',
    'pr' => "پورتو\ ریکو",
    'ps' => 'فلسطین',
    'pt' => 'پرتغال',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'پالائو',
    'py' => 'پاراگوئه',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'قطر',
    'qo' => "بخش‌های\ دورافتادهٔ\ اقیانوسیه",
    'qu' => "اتحادیهٔ\ اروپا",
    're' => 'ریونیون',
    'ro' => 'رومانی',
    'rs' => 'صربستان',
    'ru' => 'روسیه',
    'rw' => 'رواندا',
    'sa' => 'عربستان',
    'sb' => "جزایر\ سلیمان",
    'sc' => 'سیشل',
    'sd' => 'سودان',
    'se' => 'سوئد',
    'sg' => 'سنگاپور',
    'sh' => "سنت\ هلن",
    'si' => 'اسلوونی',
    'sj' => "اسوالبارد\ و\ جان\ ماین",
    'sk' => 'اسلواکی',
    'sl' => 'سیرالئون',
    'sm' => "سان\ مارینو",
    'sn' => 'سنگال',
    'so' => 'سومالی',
    'sr' => 'سورینام',
    'st' => "سائو\ تومه\ و\ پرینسیپه",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => 'السالوادور',
    'sy' => 'سوریه',
    'sz' => 'سوازیلند',
    'tc' => "جزایر\ ترک\ و\ کایکوس",
    'td' => 'چاد',
    'tf' => "مستعمره‌های\ جنوبی\ فرانسه",
    'tg' => 'توگو',
    'th' => 'تایلند',
    'tj' => 'تاجیکستان',
    'tk' => 'توکلائو',
    'tl' => "تیمور\ شرقی",
    'tm' => 'ترکمنستان',
    'tn' => 'تونس',
    'to' => 'تونگا',
    'tr' => 'ترکیه',
    'tt' => "ترینیداد\ و\ توباگو",
    'tv' => 'تووالو',
    'tw' => 'تایوان',
    'tz' => 'تانزانیا',
    'ua' => 'اوکراین',
    'ug' => 'اوگاندا',
    'um' => "جزایر\ کوچک\ دورافتادهٔ\ ایالات\ متحده",
    'us' => "ایالات\ متحدهٔ\ امریکا",
    'uy' => 'اوروگوئه',
    'uz' => 'ازبکستان',
    'va' => 'واتیکان',
    'vc' => "سنت\ وینسنت\ و\ گرنادین",
    'vd' => "North\ Vietnam",
    've' => 'ونزوئلا',
    'vg' => "جزایر\ ویرجین\ بریتانیا",
    'vi' => "جزایر\ ویرجین\ ایالات\ متحده",
    'vn' => 'ویتنام',
    'vu' => 'وانواتو',
    'wf' => "والیس\ و\ فیوتونا",
    'wk' => "Wake\ Island",
    'ws' => 'ساموا',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'یمن',
    'yt' => 'مایوت',
    'za' => "افریقای\ جنوبی",
    'zm' => 'زامبیا',
    'zw' => 'زیمبابوه',
    'zz' => "ناحیهٔ\ نامشخص\ یا\ نامعتبر",
);

%Locales::DB::Territory::fa::name_to_code = (
    'britishantarcticterritory'                                       => 'bq',
    'cantonandenderburyislands'                                       => 'ct',
    'dronningmaudland'                                                => 'nq',
    'eastgermany'                                                     => 'dd',
    'frenchsouthernandantarcticterritories'                           => 'fq',
    'johnstonisland'                                                  => 'jt',
    'metropolitanfrance'                                              => 'fx',
    'midwayislands'                                                   => 'mi',
    'neutralzone'                                                     => 'nt',
    'northvietnam'                                                    => 'vd',
    'pacificislandstrustterritory'                                    => 'pc',
    'panamacanalzone'                                                 => 'pz',
    'peoplesdemocraticrepublicofyemen'                                => 'yd',
    "u\.s\.miscellaneouspacificislands"                               => 'pu',
    'unionofsovietsocialistrepublics'                                 => 'su',
    'wakeisland'                                                      => 'wk',
    'آروبا'                                                      => 'aw',
    'آرژانتین'                                                => 'ar',
    'آلبانی'                                                    => 'al',
    'آلمان'                                                      => 'de',
    'آنتیلهلند'                                              => 'an',
    'آنتیگواوباربودا'                                  => 'ag',
    'آندورا'                                                    => 'ad',
    'آنگولا'                                                    => 'ao',
    'آنگیل'                                                      => 'ai',
    'اتحادیهٔاروپا'                                      => 'qu',
    'اتریش'                                                      => 'at',
    'اتیوپی'                                                    => 'et',
    'اردن'                                                        => 'jo',
    'ارمنستان'                                                => 'am',
    'اریتره'                                                    => 'er',
    'ازبکستان'                                                => 'uz',
    'استرالیا'                                                => 'au',
    'استونی'                                                    => 'ee',
    'اسرائیل'                                                  => 'il',
    'اسلواکی'                                                  => 'sk',
    'اسلوونی'                                                  => 'si',
    'اسوالباردوجانماین'                              => 'sj',
    'اسپانیا'                                                  => 'es',
    'افریقایجنوبی'                                        => 'za',
    'افغانستان'                                              => 'af',
    'الجزایر'                                                  => 'dz',
    'السالوادور'                                            => 'sv',
    'اماراتمتحدهٔعربی'                                => 'ae',
    'اندونزی'                                                  => 'id',
    'اوروگوئه'                                                => 'uy',
    'اوکراین'                                                  => 'ua',
    'اوگاندا'                                                  => 'ug',
    'اکوادر'                                                    => 'ec',
    'ایالاتمتحدهٔامریکا'                            => 'us',
    'ایتالیا'                                                  => 'it',
    'ایران'                                                      => 'ir',
    'ایرلند'                                                    => 'ie',
    'ایسلند'                                                    => 'is',
    'باربادوس'                                                => 'bb',
    'باهاما'                                                    => 'bs',
    'بحرین'                                                      => 'bh',
    'بخش‌هایدورافتادهٔاقیانوسیه'           => 'qo',
    'برزیل'                                                      => 'br',
    'برمودا'                                                    => 'bm',
    'برونئی'                                                    => 'bn',
    'بریتانیا'                                                => 'gb',
    'بلغارستان'                                              => 'bg',
    'بلژیک'                                                      => 'be',
    'بلیز'                                                        => 'bz',
    'بنگلادش'                                                  => 'bd',
    'بنین'                                                        => 'bj',
    'بوتان'                                                      => 'bt',
    'بوتسوانا'                                                => 'bw',
    'بوروندی'                                                  => 'bi',
    'بورکینافاسو'                                          => 'bf',
    'بوسنیوهرزگوین'                                      => 'ba',
    'بولیوی'                                                    => 'bo',
    'بیلوروسی'                                                => 'by',
    'تاجیکستان'                                              => 'tj',
    'تانزانیا'                                                => 'tz',
    'تایلند'                                                    => 'th',
    'تایوان'                                                    => 'tw',
    'ترکمنستان'                                              => 'tm',
    'ترکیه'                                                      => 'tr',
    'ترینیدادوتوباگو'                                  => 'tt',
    'تونس'                                                        => 'tn',
    'تونگا'                                                      => 'to',
    'تووالو'                                                    => 'tv',
    'توکلائو'                                                  => 'tk',
    'توگو'                                                        => 'tg',
    'تیمورشرقی'                                              => 'tl',
    'جامائیکا'                                                => 'jm',
    'جبل‌الطارق'                                           => 'gi',
    'جرسی'                                                        => 'je',
    'جزایرآلاند'                                            => 'ax',
    'جزایرترکوکایکوس'                                  => 'tc',
    'جزایرسلیمان'                                          => 'sb',
    'جزایرفارو'                                              => 'fo',
    'جزایرفالکلند'                                        => 'fk',
    'جزایرمارشال'                                          => 'mh',
    'جزایرماریانایشمالی'                            => 'mp',
    'جزایرویرجینایالاتمتحده'                    => 'vi',
    'جزایرویرجینبریتانیا'                          => 'vg',
    'جزایرکوچکدورافتادهٔایالاتمتحده'    => 'um',
    'جزایرکوک'                                                => 'ck',
    'جزایرکوکوس'                                            => 'cc',
    'جزایرکِیمن'                                            => 'ky',
    'جزیرهٔبووت'                                            => 'bv',
    'جزیرهٔمان'                                              => 'im',
    'جزیرهٔنورفولک'                                      => 'nf',
    'جزیرهٔهردوجزایرمک‌دونالد'               => 'hm',
    'جزیرهٔکریسمس'                                        => 'cx',
    'جمهوریآذربایجان'                                  => 'az',
    'جمهوریافریقایمرکزی'                            => 'cf',
    'جمهوریدومینیکن'                                    => 'do',
    'جمهوریچک'                                                => 'cz',
    'جنوبگان'                                                  => 'aq',
    'جورجیایجنوبیوجزایرساندویچجنوبی'    => 'gs',
    'جیبوتی'                                                    => 'dj',
    'دانمارک'                                                  => 'dk',
    'دومینیک'                                                  => 'dm',
    'رواندا'                                                    => 'rw',
    'روسیه'                                                      => 'ru',
    'رومانی'                                                    => 'ro',
    'ریونیون'                                                  => 're',
    'زامبیا'                                                    => 'zm',
    'زلاندنو'                                                  => 'nz',
    'زیمبابوه'                                                => 'zw',
    'سائوتومهوپرینسیپه'                              => 'st',
    'ساحلعاج'                                                  => 'ci',
    'ساموا'                                                      => 'ws',
    'ساموایامریکا'                                        => 'as',
    'سانمارینو'                                              => 'sm',
    'سری‌لانکا'                                             => 'lk',
    'سنتبارتلیمی'                                          => 'bl',
    'سنتلوسیا'                                                => 'lc',
    'سنتمارتین'                                              => 'mf',
    'سنتهلن'                                                    => 'sh',
    'سنتوینسنتوگرنادین'                              => 'vc',
    'سنتپیرومیکلون'                                      => 'pm',
    'سنتکیتسونویس'                                        => 'kn',
    'سنگال'                                                      => 'sn',
    'سنگاپور'                                                  => 'sg',
    'سوئد'                                                        => 'se',
    'سوئیس'                                                      => 'ch',
    'سوازیلند'                                                => 'sz',
    'سودان'                                                      => 'sd',
    'سورینام'                                                  => 'sr',
    'سوریه'                                                      => 'sy',
    'سومالی'                                                    => 'so',
    'سیرالئون'                                                => 'sl',
    'سیشل'                                                        => 'sc',
    'شیلی'                                                        => 'cl',
    'صحرایغربی'                                              => 'eh',
    'صربستان'                                                  => 'rs',
    'صربستانومونته‌نگرو'                           => 'cs',
    'عراق'                                                        => 'iq',
    'عربستان'                                                  => 'sa',
    'عمان'                                                        => 'om',
    'غنا'                                                          => 'gh',
    'فرانسه'                                                    => 'fr',
    'فلسطین'                                                    => 'ps',
    'فنلاند'                                                    => 'fi',
    'فیجی'                                                        => 'fj',
    'فیلیپین'                                                  => 'ph',
    'قبرس'                                                        => 'cy',
    'قرقیزستان'                                              => 'kg',
    'قزاقستان'                                                => 'kz',
    'قطر'                                                          => 'qa',
    'لائوس'                                                      => 'la',
    'لبنان'                                                      => 'lb',
    'لتونی'                                                      => 'lv',
    'لسوتو'                                                      => 'ls',
    'لهستان'                                                    => 'pl',
    'لوکزامبورگ'                                            => 'lu',
    'لیبریا'                                                    => 'lr',
    'لیبی'                                                        => 'ly',
    'لیتوانی'                                                  => 'lt',
    'لیختن‌اشتاین'                                       => 'li',
    'ماداگاسکار'                                            => 'mg',
    'مارتینیک'                                                => 'mq',
    'مالاوی'                                                    => 'mw',
    'مالت'                                                        => 'mt',
    'مالدیو'                                                    => 'mv',
    'مالزی'                                                      => 'my',
    'مالی'                                                        => 'ml',
    'ماکائو'                                                    => 'mo',
    'مایوت'                                                      => 'yt',
    'مجارستان'                                                => 'hu',
    'مراکش'                                                      => 'ma',
    'مستعمره‌هایبریتانیادراقیانوسهند' => 'io',
    'مستعمره‌هایجنوبیفرانسه'                   => 'tf',
    'مصر'                                                          => 'eg',
    'مغولستان'                                                => 'mn',
    'مقدونیه'                                                  => 'mk',
    'موریتانی'                                                => 'mr',
    'موریس'                                                      => 'mu',
    'موزامبیک'                                                => 'mz',
    'مولداوی'                                                  => 'md',
    'موناکو'                                                    => 'mc',
    'مونته‌نگرو'                                           => 'me',
    'مونت‌سرات'                                             => 'ms',
    'مکزیک'                                                      => 'mx',
    'میانمار'                                                  => 'mm',
    'میکرونزی'                                                => 'fm',
    'نائورو'                                                    => 'nr',
    'ناحیهٔنامشخصیانامعتبر'                      => 'zz',
    'نامیبیا'                                                  => 'na',
    'نروژ'                                                        => 'no',
    'نپال'                                                        => 'np',
    'نیجر'                                                        => 'ne',
    'نیجریه'                                                    => 'ng',
    'نیوئه'                                                      => 'nu',
    'نیکاراگوئه'                                            => 'ni',
    'هاییتی'                                                    => 'ht',
    'هلند'                                                        => 'nl',
    'هند'                                                          => 'in',
    'هندوراس'                                                  => 'hn',
    'هنگ‌کنگ'                                                 => 'hk',
    'واتیکان'                                                  => 'va',
    'والیسوفیوتونا'                                      => 'wf',
    'وانواتو'                                                  => 'vu',
    'ونزوئلا'                                                  => 've',
    'ویتنام'                                                    => 'vn',
    'پاراگوئه'                                                => 'py',
    'پالائو'                                                    => 'pw',
    'پاناما'                                                    => 'pa',
    'پاپواگینهٔنو'                                        => 'pg',
    'پاکستان'                                                  => 'pk',
    'پرتغال'                                                    => 'pt',
    'پرو'                                                          => 'pe',
    'پلی‌نزیفرانسه'                                     => 'pf',
    'پورتوریکو'                                              => 'pr',
    'پیتکایرن'                                                => 'pn',
    'چاد'                                                          => 'td',
    'چین'                                                          => 'cn',
    'ژاپن'                                                        => 'jp',
    'کاستاریکا'                                              => 'cr',
    'کالدونیایجدید'                                      => 'nc',
    'کامبوج'                                                    => 'kh',
    'کامرون'                                                    => 'cm',
    'کانادا'                                                    => 'ca',
    'کرهٔجنوبی'                                              => 'kr',
    'کرهٔشمالی'                                              => 'kp',
    'کرواسی'                                                    => 'hr',
    'کلمبیا'                                                    => 'co',
    'کنگوبرازویل'                                          => 'cg',
    'کنگوکینشاسا'                                          => 'cd',
    'کنیا'                                                        => 'ke',
    'کوبا'                                                        => 'cu',
    'کومورو'                                                    => 'km',
    'کویت'                                                        => 'kw',
    'کیریباتی'                                                => 'ki',
    'کیپورد'                                                    => 'cv',
    'گابون'                                                      => 'ga',
    'گامبیا'                                                    => 'gm',
    'گرانادا'                                                  => 'gd',
    'گرجستان'                                                  => 'ge',
    'گرنزی'                                                      => 'gg',
    'گروئنلند'                                                => 'gl',
    'گواتمالا'                                                => 'gt',
    'گوادلوپ'                                                  => 'gp',
    'گوام'                                                        => 'gu',
    'گویان'                                                      => 'gy',
    'گویانفرانسه'                                          => 'gf',
    'گینه'                                                        => 'gn',
    'گینهٔاستوایی'                                        => 'gq',
    'گینهٔبیسائو'                                          => 'gw',
    'یمن'                                                          => 'ye',
    'یونان'                                                      => 'gr',
);

1;

