package Locales::DB::Territory::is;

# Auto generated from CLDR

$Locales::DB::Territory::is::VERSION = '0.02';

$Locales::DB::Territory::is::cldr_version = '1.7.1';

%Locales::DB::Territory::is::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "Sameinuðu\ arabísku\ furstadæmin",
    'af' => 'Afganistan',
    'ag' => "Antígva\ og\ Barbúda",
    'ai' => 'Angvilla',
    'al' => 'Albanía',
    'am' => 'Armenía',
    'an' => "Hollensku\ Antillur",
    'ao' => 'Angóla',
    'aq' => 'Suðurskautslandið',
    'ar' => 'Argentína',
    'as' => "Bandaríska\ Samóa",
    'at' => 'Austurríki',
    'au' => 'Ástralía',
    'aw' => 'Arúba',
    'ax' => 'Áland',
    'az' => 'Aserbaídsjan',
    'ba' => "Bosnía\ og\ Hersegóvína",
    'bb' => 'Barbados',
    'bd' => 'Bangladess',
    'be' => 'Belgía',
    'bf' => "Búrkína\ Fasó",
    'bg' => 'Búlgaría',
    'bh' => 'Barein',
    'bi' => 'Búrúndí',
    'bj' => 'Benín',
    'bl' => "Saint\ Barthélemy",
    'bm' => 'Bermúdaeyjar',
    'bn' => 'Brúnei',
    'bo' => 'Bólivía',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brasilía',
    'bs' => 'Bahamaeyjar',
    'bt' => 'Bútan',
    'bv' => 'Bouveteyja',
    'bw' => 'Botsvana',
    'by' => "Hvíta\-Rússland",
    'bz' => 'Belís',
    'ca' => 'Kanada',
    'cc' => 'Kókoseyjar',
    'cd' => "Kongó\-Kinshasa",
    'cf' => "Mið\-Afríkulýðveldið",
    'cg' => "Kongó\-Brazzaville",
    'ch' => 'Sviss',
    'ci' => 'Fílabeinsströndin',
    'ck' => 'Cookseyjar',
    'cl' => 'Chíle',
    'cm' => 'Kamerún',
    'cn' => 'Kína',
    'co' => 'Kólumbía',
    'cr' => 'Kostaríka',
    'cs' => "Serbía\ og\ Svartfjallaland",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Kúba',
    'cv' => 'Grænhöfðaeyjar',
    'cx' => 'Jólaey',
    'cy' => 'Kýpur',
    'cz' => 'Tékkland',
    'dd' => "East\ Germany",
    'de' => 'Þýskaland',
    'dj' => 'Djíbútí',
    'dk' => 'Danmörk',
    'dm' => 'Dóminíka',
    'do' => "Dóminíska\ lýðveldið",
    'dz' => 'Alsír',
    'ec' => 'Ekvador',
    'ee' => 'Eistland',
    'eg' => 'Egyptaland',
    'eh' => "Vestur\-Sahara",
    'er' => 'Erítrea',
    'es' => 'Spánn',
    'et' => 'Eþíópía',
    'fi' => 'Finnland',
    'fj' => 'Fídjieyjar',
    'fk' => 'Falklandseyjar',
    'fm' => 'Mikrónesía',
    'fo' => 'Færeyjar',
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Frakkland',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabon',
    'gb' => 'Bretland',
    'gd' => 'Grenada',
    'ge' => 'Georgía',
    'gf' => "Franska\ Gvæjana",
    'gg' => 'Guernsey',
    'gh' => 'Gana',
    'gi' => 'Gíbraltar',
    'gl' => 'Grænland',
    'gm' => 'Gambía',
    'gn' => 'Gínea',
    'gp' => 'Gvadelúpeyjar',
    'gq' => "Miðbaugs\-Gínea",
    'gr' => 'Grikkland',
    'gs' => "Suður\-Georgía\ og\ Suður\-Sandvíkureyjar",
    'gt' => 'Gvatemala',
    'gu' => 'Gvam',
    'gw' => "Gínea\-Bissá",
    'gy' => 'Gvæjana',
    'hk' => "Hong\ Kong",
    'hm' => "Heard\ og\ McDonaldseyjar",
    'hn' => 'Hondúras',
    'hr' => 'Króatía',
    'ht' => 'Haítí',
    'hu' => 'Ungverjaland',
    'id' => 'Indónesía',
    'ie' => 'Írland',
    'il' => 'Ísrael',
    'im' => 'Mön',
    'in' => 'Indland',
    'io' => "Bresku\ Indlandshafseyjar",
    'iq' => 'Írak',
    'ir' => 'Íran',
    'is' => 'Ísland',
    'it' => 'Ítalía',
    'je' => 'Jersey',
    'jm' => 'Jamaíka',
    'jo' => 'Jórdanía',
    'jp' => 'Japan',
    'jt' => "Johnston\ Island",
    'ke' => 'Kenía',
    'kg' => 'Kirgisistan',
    'kh' => 'Kambódía',
    'ki' => 'Kíribatí',
    'km' => 'Kómoreyjar',
    'kn' => "Sankti\ Kristófer\ og\ Nevis",
    'kp' => "Norður\-Kórea",
    'kr' => "Suður\-Kórea",
    'kw' => 'Kúveit',
    'ky' => 'Caymaneyjar',
    'kz' => 'Kasakstan',
    'la' => 'Laos',
    'lb' => 'Líbanon',
    'lc' => "Sankti\ Lúsía",
    'li' => 'Liechtenstein',
    'lk' => "Srí\ Lanka",
    'lr' => 'Líbería',
    'ls' => 'Lesótó',
    'lt' => 'Litháen',
    'lu' => 'Lúxemborg',
    'lv' => 'Lettland',
    'ly' => 'Líbía',
    'ma' => 'Marokkó',
    'mc' => 'Mónakó',
    'md' => 'Moldóva',
    'me' => 'Svartfjallaland',
    'mf' => "Saint\ Martin",
    'mg' => 'Madagaskar',
    'mh' => 'Marshalleyjar',
    'mi' => "Midway\ Islands",
    'mk' => 'Makedónía',
    'ml' => 'Malí',
    'mm' => 'Mjanmar',
    'mn' => 'Mongólía',
    'mo' => 'Makáo',
    'mp' => "Norður\-Maríanaeyjar",
    'mq' => 'Martiník',
    'mr' => 'Máritanía',
    'ms' => 'Montserrat',
    'mt' => 'Malta',
    'mu' => 'Máritíus',
    'mv' => 'Maldíveyjar',
    'mw' => 'Malaví',
    'mx' => 'Mexíkó',
    'my' => 'Malasía',
    'mz' => 'Mósambík',
    'na' => 'Namibía',
    'nc' => "Nýja\-Kaledónía",
    'ne' => 'Níger',
    'nf' => 'Norfolkeyja',
    'ng' => 'Nígería',
    'ni' => 'Níkaragva',
    'nl' => 'Niðurlönd',
    'no' => 'Noregur',
    'np' => 'Nepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nárú',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "Nýja\-Sjáland",
    'om' => 'Óman',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Perú',
    'pf' => "Franska\ Pólýnesía",
    'pg' => "Papúa\ Nýja\-Gínea",
    'ph' => 'Filippseyjar',
    'pk' => 'Pakistan',
    'pl' => 'Pólland',
    'pm' => "Sankti\ Pierre\ og\ Miquelon",
    'pn' => 'Pitcairn',
    'pr' => "Púertó\ Ríkó",
    'ps' => 'Palestína',
    'pt' => 'Portúgal',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palá',
    'py' => 'Paragvæ',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Katar',
    'qo' => "Ytri\ Eyjaálfa",
    'qu' => 'Evrópusambandið',
    're' => 'Réunion',
    'ro' => 'Rúmenía',
    'rs' => 'Serbía',
    'ru' => 'Rússland',
    'rw' => 'Rúanda',
    'sa' => "Sádi\-Arabía",
    'sb' => 'Salómonseyjar',
    'sc' => 'Seychelleseyjar',
    'sd' => 'Súdan',
    'se' => 'Svíþjóð',
    'sg' => 'Singapúr',
    'sh' => "Sankti\ Helena",
    'si' => 'Slóvenía',
    'sj' => "Svalbarði\ og\ Jan\ Mayen",
    'sk' => 'Slóvakía',
    'sl' => "Síerra\ Leóne",
    'sm' => "San\ Marínó",
    'sn' => 'Senegal',
    'so' => 'Sómalía',
    'sr' => 'Súrínam',
    'st' => "Saó\ Tóme\ og\ Prinsípe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salvador",
    'sy' => 'Sýrland',
    'sz' => 'Svasíland',
    'tc' => "Turks\-\ og\ Caicoseyjar",
    'td' => 'Tsjad',
    'tf' => "Frönsku\ suðlægu\ landsvæðin",
    'tg' => 'Tógó',
    'th' => 'Taíland',
    'tj' => 'Tadsjikistan',
    'tk' => 'Tókelá',
    'tl' => "Austur\-Tímor",
    'tm' => 'Túrkmenistan',
    'tn' => 'Túnis',
    'to' => 'Tonga',
    'tr' => 'Tyrkland',
    'tt' => "Trínidad\ og\ Tóbagó",
    'tv' => 'Túvalú',
    'tw' => 'Taívan',
    'tz' => 'Tansanía',
    'ua' => 'Úkraína',
    'ug' => 'Úganda',
    'um' => "Smáeyjar\ Bandaríkjanna",
    'us' => 'Bandaríkin',
    'uy' => 'Úrúgvæ',
    'uz' => 'Úsbekistan',
    'va' => 'Páfagarður',
    'vc' => "Sankti\ Vinsent\ og\ Grenadíneyjar",
    'vd' => "North\ Vietnam",
    've' => 'Venesúela',
    'vg' => "Bresku\ Jómfrúareyjar",
    'vi' => "Bandarísku\ Jómfrúareyjar",
    'vn' => 'Víetnam',
    'vu' => 'Vanúatú',
    'wf' => "Wallis\-\ og\ Fútúnaeyjar",
    'wk' => "Wake\ Island",
    'ws' => 'Samóa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Jemen',
    'yt' => 'Mayotte',
    'za' => "Suður\-Afríka",
    'zm' => 'Sambía',
    'zw' => 'Simbabve',
    'zz' => "\(óþekkt\)",
);

%Locales::DB::Territory::is::name_to_code = (
    'afganistan'                            => 'af',
    'albanía'                              => 'al',
    'alsír'                                => 'dz',
    'andorra'                               => 'ad',
    'angvilla'                              => 'ai',
    'angóla'                               => 'ao',
    'antígvaogbarbúda'                    => 'ag',
    'argentína'                            => 'ar',
    'armenía'                              => 'am',
    'arúba'                                => 'aw',
    'aserbaídsjan'                         => 'az',
    'austurríki'                           => 'at',
    'austurtímor'                          => 'tl',
    'bahamaeyjar'                           => 'bs',
    'bandaríkin'                           => 'us',
    'bandarískasamóa'                     => 'as',
    'bandarískujómfrúareyjar'            => 'vi',
    'bangladess'                            => 'bd',
    'barbados'                              => 'bb',
    'barein'                                => 'bh',
    'belgía'                               => 'be',
    'belís'                                => 'bz',
    'benín'                                => 'bj',
    'bermúdaeyjar'                         => 'bm',
    'bosníaoghersegóvína'                => 'ba',
    'botsvana'                              => 'bw',
    'bouveteyja'                            => 'bv',
    'brasilía'                             => 'br',
    'breskuindlandshafseyjar'               => 'io',
    'breskujómfrúareyjar'                 => 'vg',
    'bretland'                              => 'gb',
    'britishantarcticterritory'             => 'bq',
    'brúnei'                               => 'bn',
    'bólivía'                             => 'bo',
    'búlgaría'                            => 'bg',
    'búrkínafasó'                        => 'bf',
    'búrúndí'                            => 'bi',
    'bútan'                                => 'bt',
    'cantonandenderburyislands'             => 'ct',
    'caymaneyjar'                           => 'ky',
    'chíle'                                => 'cl',
    'cookseyjar'                            => 'ck',
    'danmörk'                              => 'dk',
    'djíbútí'                            => 'dj',
    'dronningmaudland'                      => 'nq',
    'dóminíka'                            => 'dm',
    'dóminískalýðveldið'               => 'do',
    'eastgermany'                           => 'dd',
    'egyptaland'                            => 'eg',
    'eistland'                              => 'ee',
    'ekvador'                               => 'ec',
    'elsalvador'                            => 'sv',
    'erítrea'                              => 'er',
    'evrópusambandið'                     => 'qu',
    'eþíópía'                           => 'et',
    'falklandseyjar'                        => 'fk',
    'filippseyjar'                          => 'ph',
    'finnland'                              => 'fi',
    'frakkland'                             => 'fr',
    'franskagvæjana'                       => 'gf',
    'franskapólýnesía'                   => 'pf',
    'frenchsouthernandantarcticterritories' => 'fq',
    'frönskusuðlægulandsvæðin'         => 'tf',
    'færeyjar'                             => 'fo',
    'fídjieyjar'                           => 'fj',
    'fílabeinsströndin'                   => 'ci',
    'gabon'                                 => 'ga',
    'gambía'                               => 'gm',
    'gana'                                  => 'gh',
    'georgía'                              => 'ge',
    'grenada'                               => 'gd',
    'grikkland'                             => 'gr',
    'grænhöfðaeyjar'                     => 'cv',
    'grænland'                             => 'gl',
    'guernsey'                              => 'gg',
    'gvadelúpeyjar'                        => 'gp',
    'gvam'                                  => 'gu',
    'gvatemala'                             => 'gt',
    'gvæjana'                              => 'gy',
    'gíbraltar'                            => 'gi',
    'gínea'                                => 'gn',
    'gíneabissá'                          => 'gw',
    'haítí'                               => 'ht',
    'heardogmcdonaldseyjar'                 => 'hm',
    'hollenskuantillur'                     => 'an',
    'hondúras'                             => 'hn',
    'hongkong'                              => 'hk',
    'hvítarússland'                       => 'by',
    'indland'                               => 'in',
    'indónesía'                           => 'id',
    'jamaíka'                              => 'jm',
    'japan'                                 => 'jp',
    'jemen'                                 => 'ye',
    'jersey'                                => 'je',
    'johnstonisland'                        => 'jt',
    'jólaey'                               => 'cx',
    'jórdanía'                            => 'jo',
    'kambódía'                            => 'kh',
    'kamerún'                              => 'cm',
    'kanada'                                => 'ca',
    'kasakstan'                             => 'kz',
    'katar'                                 => 'qa',
    'kenía'                                => 'ke',
    'kirgisistan'                           => 'kg',
    'kongóbrazzaville'                     => 'cg',
    'kongókinshasa'                        => 'cd',
    'kostaríka'                            => 'cr',
    'króatía'                             => 'hr',
    'kína'                                 => 'cn',
    'kíribatí'                            => 'ki',
    'kókoseyjar'                           => 'cc',
    'kólumbía'                            => 'co',
    'kómoreyjar'                           => 'km',
    'kúba'                                 => 'cu',
    'kúveit'                               => 'kw',
    'kýpur'                                => 'cy',
    'laos'                                  => 'la',
    'lesótó'                              => 'ls',
    'lettland'                              => 'lv',
    'liechtenstein'                         => 'li',
    'litháen'                              => 'lt',
    'líbanon'                              => 'lb',
    'líbería'                             => 'lr',
    'líbía'                               => 'ly',
    'lúxemborg'                            => 'lu',
    'madagaskar'                            => 'mg',
    'makedónía'                           => 'mk',
    'makáo'                                => 'mo',
    'malasía'                              => 'my',
    'malaví'                               => 'mw',
    'maldíveyjar'                          => 'mv',
    'malta'                                 => 'mt',
    'malí'                                 => 'ml',
    'marokkó'                              => 'ma',
    'marshalleyjar'                         => 'mh',
    'martiník'                             => 'mq',
    'mayotte'                               => 'yt',
    'metropolitanfrance'                    => 'fx',
    'mexíkó'                              => 'mx',
    'midwayislands'                         => 'mi',
    'mikrónesía'                          => 'fm',
    'miðafríkulýðveldið'               => 'cf',
    'miðbaugsgínea'                       => 'gq',
    'mjanmar'                               => 'mm',
    'moldóva'                              => 'md',
    'mongólía'                            => 'mn',
    'montserrat'                            => 'ms',
    'máritanía'                           => 'mr',
    'máritíus'                            => 'mu',
    'mónakó'                              => 'mc',
    'mósambík'                            => 'mz',
    'mön'                                  => 'im',
    'namibía'                              => 'na',
    'nepal'                                 => 'np',
    'neutralzone'                           => 'nt',
    'niue'                                  => 'nu',
    'niðurlönd'                           => 'nl',
    'noregur'                               => 'no',
    'norfolkeyja'                           => 'nf',
    'northvietnam'                          => 'vd',
    'norðurkórea'                         => 'kp',
    'norðurmaríanaeyjar'                  => 'mp',
    'nárú'                                => 'nr',
    'níger'                                => 'ne',
    'nígería'                             => 'ng',
    'níkaragva'                            => 'ni',
    'nýjakaledónía'                      => 'nc',
    'nýjasjáland'                         => 'nz',
    'pacificislandstrustterritory'          => 'pc',
    'pakistan'                              => 'pk',
    'palestína'                            => 'ps',
    'palá'                                 => 'pw',
    'panama'                                => 'pa',
    'panamacanalzone'                       => 'pz',
    'papúanýjagínea'                     => 'pg',
    'paragvæ'                              => 'py',
    'peoplesdemocraticrepublicofyemen'      => 'yd',
    'perú'                                 => 'pe',
    'pitcairn'                              => 'pn',
    'portúgal'                             => 'pt',
    'páfagarður'                          => 'va',
    'pólland'                              => 'pl',
    'púertóríkó'                        => 'pr',
    'réunion'                              => 're',
    'rúanda'                               => 'rw',
    'rúmenía'                             => 'ro',
    'rússland'                             => 'ru',
    'saintbarthélemy'                      => 'bl',
    'saintmartin'                           => 'mf',
    'salómonseyjar'                        => 'sb',
    'sambía'                               => 'zm',
    'sameinuðuarabískufurstadæmin'       => 'ae',
    'samóa'                                => 'ws',
    'sanktihelena'                          => 'sh',
    'sanktikristóferognevis'               => 'kn',
    'sanktilúsía'                         => 'lc',
    'sanktipierreogmiquelon'                => 'pm',
    'sanktivinsentoggrenadíneyjar'         => 'vc',
    'sanmarínó'                           => 'sm',
    'saótómeogprinsípe'                  => 'st',
    'senegal'                               => 'sn',
    'serbía'                               => 'rs',
    'serbíaogsvartfjallaland'              => 'cs',
    'seychelleseyjar'                       => 'sc',
    'simbabve'                              => 'zw',
    'singapúr'                             => 'sg',
    'slóvakía'                            => 'sk',
    'slóvenía'                            => 'si',
    'smáeyjarbandaríkjanna'               => 'um',
    'spánn'                                => 'es',
    'srílanka'                             => 'lk',
    'suðurafríka'                         => 'za',
    'suðurgeorgíaogsuðursandvíkureyjar' => 'gs',
    'suðurkórea'                          => 'kr',
    'suðurskautslandið'                   => 'aq',
    'svalbarðiogjanmayen'                  => 'sj',
    'svartfjallaland'                       => 'me',
    'svasíland'                            => 'sz',
    'sviss'                                 => 'ch',
    'svíþjóð'                           => 'se',
    'sádiarabía'                          => 'sa',
    'síerraleóne'                         => 'sl',
    'sómalía'                             => 'so',
    'súdan'                                => 'sd',
    'súrínam'                             => 'sr',
    'sýrland'                              => 'sy',
    'tadsjikistan'                          => 'tj',
    'tansanía'                             => 'tz',
    'taíland'                              => 'th',
    'taívan'                               => 'tw',
    'tonga'                                 => 'to',
    'trínidadogtóbagó'                   => 'tt',
    'tsjad'                                 => 'td',
    'turksogcaicoseyjar'                    => 'tc',
    'tyrkland'                              => 'tr',
    'tékkland'                             => 'cz',
    'tógó'                                => 'tg',
    'tókelá'                              => 'tk',
    'túnis'                                => 'tn',
    'túrkmenistan'                         => 'tm',
    'túvalú'                              => 'tv',
    "u\.s\.miscellaneouspacificislands"     => 'pu',
    'ungverjaland'                          => 'hu',
    'unionofsovietsocialistrepublics'       => 'su',
    'vanúatú'                             => 'vu',
    'venesúela'                            => 've',
    'vestursahara'                          => 'eh',
    'víetnam'                              => 'vn',
    'wakeisland'                            => 'wk',
    'wallisogfútúnaeyjar'                 => 'wf',
    'ytrieyjaálfa'                         => 'qo',
    'Áland'                                => 'ax',
    'Ástralía'                            => 'au',
    'Írak'                                 => 'iq',
    'Íran'                                 => 'ir',
    'Írland'                               => 'ie',
    'Ísland'                               => 'is',
    'Ísrael'                               => 'il',
    'Ítalía'                              => 'it',
    'Óman'                                 => 'om',
    'Úganda'                               => 'ug',
    'Úkraína'                             => 'ua',
    'Úrúgvæ'                             => 'uy',
    'Úsbekistan'                           => 'uz',
    'Þýskaland'                           => 'de',
    'óþekkt'                              => 'zz',
);

1;

