package Locales::DB::Native;

# Auto generated from CLDR

$Locales::DB::Native::VERSION = '0.02';

$Locales::DB::Native::cldr_version = '1.7.1';

%Locales::DB::Native::code_to_name = (
    'sid'   => 'Sidaamu Afo',
    'ne'    => 'नेपाली',
    'tr'    => 'Türkçe',
    'ki'    => 'Kikuyu',
    'gor'   => 'Gorontalo',
    'elx'   => 'Elamite',
    'tlh'   => 'Klingon',
    'sog'   => 'Sogdien',
    'my'    => 'ဗမာ',
    'gl'    => 'galego',
    'lun'   => 'Lunda',
    'kum'   => 'Kumyk',
    'krc'   => 'Karachay-Balkar',
    'fat'   => 'Fanti',
    'ro'    => 'română',
    'mno'   => 'Manobo Language',
    'tn'    => 'Setswana',
    'co'    => 'Corsican',
    'bnt'   => 'Bantu',
    'bas'   => 'Basa',
    'br'    => 'Breton',
    'lam'   => 'Lamba',
    'mwl'   => 'Mirandese',
    'cy'    => 'Cymraeg',
    'bo'    => 'པོད་སྐད་',
    'syc'   => 'Classical Syriac',
    'gil'   => 'Gilbertese',
    'cs'    => 'čeština',
    'frm'   => 'Middle French',
    'sux'   => 'Sumerian',
    'kut'   => 'Kutenai',
    'km'    => 'ភាសាខ្មែរ',
    'af'    => 'Afrikaans',
    'ti'    => 'ትግርኛ',
    'tai'   => 'Tai Language',
    'ky'    => 'Кыргыз',
    'mun'   => 'Munda Language',
    'ga'    => 'Gaeilge',
    'rar'   => 'Rarotongan',
    'hsb'   => 'Upper Sorbian',
    'ada'   => 'Adangme',
    'ka'    => 'ქართული',
    'iro'   => 'Iroquoian Language',
    'dak'   => 'Dakota',
    'arn'   => 'Araucanian',
    'mi'    => 'Maori',
    'sv'    => 'svenska',
    'sal'   => 'Salishan Language',
    'und'   => 'Unknown or Invalid Language',
    'de_at' => 'Österreichisches Deutsch',
    'hu'    => 'magyar',
    'za'    => 'Zhuang',
    'mkh'   => 'Mon-Khmer Language',
    'fa'    => 'فارسی',
    'pau'   => 'Palauan',
    'byn'   => 'ብሊን',
    'wal'   => 'ወላይታቱ',
    'afh'   => 'Afrihili',
    'ssa'   => 'Nilo-Saharan Language',
    'man'   => 'Mandingo',
    'se'    => 'davvisámegiella',
    'pt_br' => 'português do Brasil',
    'dyu'   => 'Dyula',
    'mic'   => 'Micmac',
    'kv'    => 'Komi',
    'cmc'   => 'Chamic Language',
    've'    => 'Venda',
    'na'    => 'Nauru',
    'son'   => 'Songhai',
    'kcg'   => 'Tyap',
    'ba'    => 'Bashkir',
    'bin'   => 'Bini',
    'sco'   => 'Scots',
    'fr_ca' => 'français canadien',
    'no'    => 'Norwegian',
    'pra'   => 'Prakrit Language',
    'lv'    => 'latviešu',
    'ln'    => 'lingála',
    'rom'   => 'Romany',
    'id'    => 'Bahasa Indonesia',
    'arc'   => 'Aramaic',
    'trv'   => 'Taroko',
    'si'    => 'Sinhala',
    'mas'   => 'Masai',
    'kac'   => 'Kachin',
    'om'    => 'Oromoo',
    'roa'   => 'Romance Language',
    'fi'    => 'suomi',
    'ab'    => 'Abkhazian',
    'chm'   => 'Mari',
    'mai'   => 'Maithili',
    'wo'    => 'Wolof',
    'li'    => 'Limburgish',
    'kpe'   => 'Kpelle',
    'pt_pt' => 'português europeu',
    'jpr'   => 'Judeo-Persian',
    'fan'   => 'Fang',
    'zen'   => 'Zenaga',
    'ii'    => 'ꆈꌠꉙ',
    'gmh'   => 'Middle High German',
    'gv'    => 'Manx',
    'nia'   => 'Nias',
    'bra'   => 'Braj',
    'fil'   => 'Filipino',
    'pa'    => 'ਪੰਜਾਬੀ',
    'gem'   => 'Germanic Language',
    'gay'   => 'Gayo',
    'am'    => 'አማርኛ',
    'bi'    => 'Bislama',
    'ee'    => 'Ewe',
    'ace'   => 'Achinese',
    'kj'    => 'Kuanyama',
    'bat'   => 'Baltic Language',
    'umb'   => 'Umbundu',
    'ota'   => 'Ottoman Turkish',
    'alt'   => 'Southern Altai',
    'bem'   => 'Bemba',
    'xal'   => 'Kalmyk',
    'en_ca' => 'Canadian English',
    'car'   => 'Carib',
    'fy'    => 'Western Frisian',
    'eo'    => 'esperanto',
    'mn'    => 'монгол',
    'nv'    => 'Navajo',
    'gd'    => 'Scottish Gaelic',
    'as'    => 'অসমীয়া',
    'ae'    => 'Avestan',
    'nqo'   => 'N’Ko',
    'ia'    => 'interlingua',
    'bua'   => 'Buriat',
    'map'   => 'Austronesian Language',
    'bai'   => 'Bamileke Language',
    'ber'   => 'Berber',
    'cr'    => 'Cree',
    'vi'    => 'Tiếng Việt',
    'sg'    => 'Sango',
    'day'   => 'Dayak',
    'mdf'   => 'Moksha',
    'bm'    => 'Bambara',
    'nr'    => 'South Ndebele',
    'kam'   => 'Kamba',
    'yao'   => 'Yao',
    'kw'    => 'Cornish',
    'ira'   => 'Iranian Language',
    'pon'   => 'Pohnpeian',
    'tum'   => 'Tumbuka',
    'pag'   => 'Pangasinan',
    'nym'   => 'Nyamwezi',
    'ang'   => 'Old English',
    'uz'    => 'Ўзбек',
    'fiu'   => 'Finno-Ugrian Language',
    'ht'    => 'Haitian',
    'suk'   => 'Sukuma',
    'enm'   => 'Middle English',
    'bej'   => 'Beja',
    'yo'    => 'Yorùbá',
    'bad'   => 'Banda',
    'nub'   => 'Nubian Language',
    'dgr'   => 'Dogrib',
    'ter'   => 'Tereno',
    'mni'   => 'Manipuri',
    'gu'    => 'ગુજરાતી',
    'bg'    => 'български',
    'raj'   => 'Rajasthani',
    'kos'   => 'Kosraean',
    'del'   => 'Delaware',
    'chr'   => 'Cherokee',
    'sq'    => 'shqipe',
    'ca'    => 'català',
    'paa'   => 'Papuan Language',
    'srn'   => 'Sranan Tongo',
    'sk'    => 'slovenčina',
    'oj'    => 'Ojibwa',
    'nds'   => 'Plattdüütsch',
    'luo'   => 'Luo',
    'cai'   => 'Central American Indian Language',
    'eka'   => 'Ekajuk',
    'ty'    => 'Tahitian',
    'en_gb' => 'British English',
    'gaa'   => 'Ga',
    'jrb'   => 'Judeo-Arabic',
    'es'    => 'español',
    'sw'    => 'Kiswahili',
    'yap'   => 'Yapese',
    'sla'   => 'Slavic Language',
    'hup'   => 'Hupa',
    'phi'   => 'Philippine Language',
    'sa'    => 'संस्कृत भाषा',
    'new'   => 'Newari',
    'anp'   => 'Angika',
    'akk'   => 'Akkadian',
    'osa'   => 'Osage',
    'krl'   => 'Karelian',
    'loz'   => 'Lozi',
    'ie'    => 'Interlingue',
    'et'    => 'eesti',
    'tl'    => 'Tagalog',
    'nd'    => 'North Ndebele',
    'sad'   => 'Sandawe',
    'mk'    => 'македонски',
    'hil'   => 'Hiligaynon',
    'en'    => 'English',
    'cpf'   => 'French-based Creole or Pidgin',
    'udm'   => 'Udmurt',
    'aus'   => 'Australian Language',
    'zza'   => 'Zaza',
    'chb'   => 'Chibcha',
    'de'    => 'Deutsch',
    'zu'    => 'isiZulu',
    'alg'   => 'Algonquian Language',
    'snk'   => 'Soninke',
    'kbd'   => 'Kabardian',
    'pro'   => 'Old Provençal',
    'mga'   => 'Middle Irish',
    'mag'   => 'Magahi',
    'wak'   => 'Wakashan Language',
    'hz'    => 'Herero',
    'nn'    => 'nynorsk',
    'nai'   => 'North American Indian Language',
    'haw'   => 'Hawaiian',
    'bn'    => 'বাংলা',
    'sel'   => 'Selkup',
    'pal'   => 'Pahlavi',
    'frr'   => 'Northern Frisian',
    'min'   => 'Minangkabau',
    'he'    => 'עברית',
    'ban'   => 'Balinese',
    'zh'    => '中文',
    'lol'   => 'Mongo',
    'dum'   => 'Middle Dutch',
    'fr_ch' => 'français suisse',
    'sm'    => 'Samoan',
    'ar'    => 'العربية',
    'ny'    => 'Nyanja',
    'grb'   => 'Grebo',
    'was'   => 'Washo',
    'sat'   => 'Santali',
    'tyv'   => 'Tuvinian',
    'mwr'   => 'Marwari',
    'egy'   => 'Ancient Egyptian',
    'sus'   => 'Susu',
    'da'    => 'dansk',
    'ug'    => 'Uyghur',
    'cel'   => 'Celtic Language',
    'moh'   => 'Mohawk',
    'gsw'   => 'Schwiizertüütsch',
    'him'   => 'Himachali',
    'tpi'   => 'Tok Pisin',
    'ta'    => 'தமிழ்',
    'ady'   => 'Adyghe',
    'efi'   => 'Efik',
    'rw'    => 'Kinyarwanda',
    'mos'   => 'Mossi',
    'doi'   => 'Dogri',
    'en_au' => 'Australian English',
    'nzi'   => 'Nzima',
    'st'    => 'Sesotho',
    'ain'   => 'Ainu',
    'ko'    => '한국어',
    'sit'   => 'Sino-Tibetan Language',
    'ak'    => 'Akan',
    'sem'   => 'Semitic Language',
    'chp'   => 'Chipewyan',
    'zun'   => 'Zuni',
    'mfe'   => 'Morisyen',
    'cus'   => 'Cushitic Language',
    'mo'    => 'Moldavian',
    'cop'   => 'Coptic',
    'mis'   => 'Miscellaneous Language',
    'ps'    => 'پښتو',
    'wen'   => 'Sorbian Language',
    'nwc'   => 'Classical Newari',
    'av'    => 'Avaric',
    'sms'   => 'Skolt Sami',
    'fon'   => 'Fon',
    'kab'   => 'Kabyle',
    'nic'   => 'Niger-Kordofanian Language',
    'rap'   => 'Rapanui',
    'is'    => 'íslenska',
    'qu'    => 'Quechua',
    'oto'   => 'Otomian Language',
    'shn'   => 'Shan',
    'mt'    => 'Malti',
    'men'   => 'Mende',
    'hy'    => 'Հայերէն',
    'la'    => 'Latin',
    'ms'    => 'Bahasa Melayu',
    'bh'    => 'Bihari',
    'myv'   => 'Erzya',
    'fro'   => 'Old French',
    'tsi'   => 'Tsimshian',
    'oc'    => 'occitan',
    'pap'   => 'Papiamento',
    'zxx'   => 'No linguistic content',
    'art'   => 'Artificial Language',
    'it'    => 'italiano',
    'tiv'   => 'Tiv',
    'scn'   => 'Sicilian',
    'nyo'   => 'Nyoro',
    'kha'   => 'Khasi',
    'sma'   => 'Southern Sami',
    'mdr'   => 'Mandar',
    'hai'   => 'Haida',
    'vot'   => 'Votic',
    'ach'   => 'Acoli',
    'ale'   => 'Aleut',
    'vai'   => 'Vai',
    'ng'    => 'Ndonga',
    'dv'    => 'Divehi',
    'kru'   => 'Kurukh',
    'sai'   => 'South American Indian Language',
    'lu'    => 'Luba-Katanga',
    'jv'    => 'Javanese',
    'smj'   => 'Lule Sami',
    'tli'   => 'Tlingit',
    'pt'    => 'português',
    'hi'    => 'हिन्दी',
    'ks'    => 'Kashmiri',
    'mh'    => 'Marshallese',
    'gwi'   => 'Gwichʼin',
    'smn'   => 'Inari Sami',
    'kg'    => 'Kongo',
    'lad'   => 'Ladino',
    'csb'   => 'Kashubian',
    'os'    => 'Ossetic',
    'ho'    => 'Hiri Motu',
    'fr'    => 'français',
    'got'   => 'Gothic',
    'kaa'   => 'Kara-Kalpak',
    'ewo'   => 'Ewondo',
    'afa'   => 'Afro-Asiatic Language',
    'sr'    => 'Српски',
    'kok'   => 'कोंकणी',
    'vo'    => 'Volapük',
    'ff'    => 'Fulah',
    'tet'   => 'Tetum',
    'tem'   => 'Timne',
    'lus'   => 'Lushai',
    'fj'    => 'Fijian',
    'srr'   => 'Serer',
    'pam'   => 'Pampanga',
    'tkl'   => 'Tokelau',
    'sn'    => 'Shona',
    'inh'   => 'Ingush',
    'cpe'   => 'English-based Creole or Pidgin',
    'kaw'   => 'Kawi',
    'sd'    => 'Sindhi',
    'ath'   => 'Athapascan Language',
    'yi'    => 'Yiddish',
    'bho'   => 'Bhojpuri',
    'cch'   => 'Atsam',
    'arp'   => 'Arapaho',
    'frs'   => 'Eastern Frisian',
    'gon'   => 'Gondi',
    'ha'    => 'Haoussa',
    'gba'   => 'Gbaya',
    'hit'   => 'Hittite',
    'lg'    => 'Ganda',
    'war'   => 'Waray',
    'mad'   => 'Madurese',
    'bug'   => 'Buginese',
    'sl'    => 'slovenščina',
    'rup'   => 'Aromanian',
    'mul'   => 'Multiple Languages',
    'dua'   => 'Duala',
    'tig'   => 'ትግረ',
    'mr'    => 'मराठी',
    'cad'   => 'Caddo',
    'rm'    => 'Rhaeto-Romance',
    'kaj'   => 'Jju',
    'dz'    => 'རྫོང་ཁ',
    'ilo'   => 'Iloko',
    'kn'    => 'ಕನ್ನಡ',
    'rn'    => 'Rundi',
    'uga'   => 'Ugaritic',
    'nog'   => 'Nogai',
    'cho'   => 'Choctaw',
    'jbo'   => 'Lojban',
    'crh'   => 'Crimean Turkish',
    'de_ch' => 'Schweizer Hochdeutsch',
    'ik'    => 'Inupiaq',
    'hmn'   => 'Hmong',
    'cpp'   => 'Portuguese-based Creole or Pidgin',
    'tup'   => 'Tupi Language',
    'tk'    => 'Turkmen',
    'sga'   => 'Old Irish',
    'mg'    => 'Malagasy',
    'su'    => 'Sundanese',
    'sc'    => 'Sardinian',
    'sio'   => 'Siouan Language',
    'sgn'   => 'Sign Language',
    'chy'   => 'Cheyenne',
    'ru'    => 'русский',
    'goh'   => 'Old High German',
    'zap'   => 'Zapotec',
    'nb'    => 'norsk bokmål',
    'kar'   => 'Karen',
    'nso'   => 'Northern Sotho',
    'ku'    => 'كوردی',
    'znd'   => 'Zande',
    'lo'    => 'ລາວ',
    'az'    => 'azərbaycanca',
    'sah'   => 'Yakut',
    'lb'    => 'Luxembourgish',
    'aa'    => 'Qafar',
    'fur'   => 'furlan',
    'mus'   => 'Creek',
    'ts'    => 'Xitsonga',
    'ml'    => 'മലയാളം',
    'grc'   => 'Ancient Greek',
    'sas'   => 'Sasak',
    'nah'   => 'Nahuatl',
    'btk'   => 'Batak',
    'peo'   => 'Old Persian',
    'bal'   => 'Baluchi',
    'nyn'   => 'Nyankole',
    'kho'   => 'Khotanese',
    'zbl'   => 'Blissymbols',
    'crp'   => 'Creole or Pidgin',
    'es_es' => 'español de España',
    'inc'   => 'Indic Language',
    'kl'    => 'Kalaallisut',
    'bs'    => 'bosanski',
    'iu'    => 'Inuktitut',
    'to'    => 'lea fakatonga',
    'cu'    => 'Church Slavic',
    'en_us' => 'U.S. English',
    'ch'    => 'Chamorro',
    'eu'    => 'euskara',
    'lah'   => 'Lahnda',
    'wa'    => 'Walloon',
    'nl_be' => 'Vlaams',
    'ine'   => 'Indo-European Language',
    'pl'    => 'polski',
    'cau'   => 'Caucasian Language',
    'ay'    => 'Aymara',
    'lez'   => 'Lezghian',
    'den'   => 'Slave',
    'mak'   => 'Makasar',
    'lui'   => 'Luiseno',
    'non'   => 'Old Norse',
    'apa'   => 'Apache Language',
    'lua'   => 'Luba-Lulua',
    'an'    => 'Aragonese',
    'gez'   => 'ግዕዝኛ',
    'kfo'   => 'Koro',
    'uk'    => 'українська',
    'khi'   => 'Khoisan Language',
    'ceb'   => 'Cebuano',
    'kr'    => 'Kanuri',
    'tt'    => 'Tatar',
    'smi'   => 'Sami Language',
    'ast'   => 'Asturian',
    'fo'    => 'føroyskt',
    'syr'   => 'Syriac',
    'ss'    => 'Swati',
    'or'    => 'ଓଡ଼ିଆ',
    'dra'   => 'Dravidian Language',
    'sh'    => 'Serbo-Croatian',
    'xh'    => 'isiXhosa',
    'io'    => 'Ido',
    'th'    => 'ไทย',
    'so'    => 'Soomaali',
    'tut'   => 'Altaic Language',
    'iba'   => 'Iban',
    'kmb'   => 'Kimbundu',
    'sam'   => 'Samaritan Aramaic',
    'dar'   => 'Dargwa',
    'phn'   => 'Phoenician',
    'lt'    => 'lietuvių',
    'chg'   => 'Chagatai',
    'bik'   => 'Bikol',
    'gn'    => 'Guarani',
    'hr'    => 'hrvatski',
    'ypk'   => 'Yupik Language',
    'be'    => 'беларуская',
    'niu'   => 'Niuean',
    'din'   => 'Dinka',
    'ur'    => 'اردو',
    'cv'    => 'Chuvash',
    'chk'   => 'Chuukese',
    'arw'   => 'Arawak',
    'tw'    => 'Twi',
    'tmh'   => 'Tamashek',
    'ce'    => 'Chechen',
    'chn'   => 'Chinook Jargon',
    'awa'   => 'Awadhi',
    'ja'    => '日本語',
    'kro'   => 'Kru',
    'tvl'   => 'Tuvalu',
    'dsb'   => 'Lower Sorbian',
    'tg'    => 'Tajik',
    'pi'    => 'Pali',
    'tog'   => 'Nyasa Tonga',
    'ijo'   => 'Ijo',
    'te'    => 'తెలుగు',
    'bla'   => 'Siksika',
    'ig'    => 'Igbo',
    'myn'   => 'Mayan Language',
    'nl'    => 'Nederlands',
    'mnc'   => 'Manchu',
    'nap'   => 'Neapolitan',
    'el'    => 'Ελληνικά',
    'kk'    => 'Қазақ',
);

%Locales::DB::Native::value_is_fallback = (
    'ki'  => '1',
    'gor' => '1',
    'elx' => '1',
    'tlh' => '1',
    'sog' => '1',
    'lun' => '1',
    'kum' => '1',
    'krc' => '1',
    'fat' => '1',
    'mno' => '1',
    'co'  => '1',
    'bnt' => '1',
    'bas' => '1',
    'br'  => '1',
    'lam' => '1',
    'mwl' => '1',
    'syc' => '1',
    'gil' => '1',
    'frm' => '1',
    'sux' => '1',
    'kut' => '1',
    'tai' => '1',
    'mun' => '1',
    'rar' => '1',
    'hsb' => '1',
    'ada' => '1',
    'iro' => '1',
    'dak' => '1',
    'arn' => '1',
    'mi'  => '1',
    'sal' => '1',
    'und' => '1',
    'za'  => '1',
    'mkh' => '1',
    'pau' => '1',
    'afh' => '1',
    'ssa' => '1',
    'man' => '1',
    'dyu' => '1',
    'mic' => '1',
    'kv'  => '1',
    'cmc' => '1',
    'na'  => '1',
    'son' => '1',
    'ba'  => '1',
    'bin' => '1',
    'sco' => '1',
    'pra' => '1',
    'rom' => '1',
    'arc' => '1',
    'mas' => '1',
    'kac' => '1',
    'roa' => '1',
    'ab'  => '1',
    'chm' => '1',
    'mai' => '1',
    'li'  => '1',
    'jpr' => '1',
    'fan' => '1',
    'zen' => '1',
    'gmh' => '1',
    'nia' => '1',
    'bra' => '1',
    'gem' => '1',
    'gay' => '1',
    'bi'  => '1',
    'ace' => '1',
    'kj'  => '1',
    'bat' => '1',
    'umb' => '1',
    'ota' => '1',
    'alt' => '1',
    'bem' => '1',
    'xal' => '1',
    'car' => '1',
    'fy'  => '1',
    'nv'  => '1',
    'gd'  => '1',
    'ae'  => '1',
    'nqo' => '1',
    'bua' => '1',
    'map' => '1',
    'bai' => '1',
    'ber' => '1',
    'cr'  => '1',
    'sg'  => '1',
    'day' => '1',
    'mdf' => '1',
    'bm'  => '1',
    'yao' => '1',
    'ira' => '1',
    'pon' => '1',
    'tum' => '1',
    'pag' => '1',
    'nym' => '1',
    'ang' => '1',
    'fiu' => '1',
    'ht'  => '1',
    'suk' => '1',
    'bej' => '1',
    'enm' => '1',
    'bad' => '1',
    'nub' => '1',
    'dgr' => '1',
    'ter' => '1',
    'mni' => '1',
    'raj' => '1',
    'kos' => '1',
    'del' => '1',
    'chr' => '1',
    'paa' => '1',
    'srn' => '1',
    'oj'  => '1',
    'luo' => '1',
    'cai' => '1',
    'eka' => '1',
    'ty'  => '1',
    'jrb' => '1',
    'yap' => '1',
    'sla' => '1',
    'hup' => '1',
    'phi' => '1',
    'new' => '1',
    'anp' => '1',
    'akk' => '1',
    'osa' => '1',
    'krl' => '1',
    'loz' => '1',
    'ie'  => '1',
    'nd'  => '1',
    'sad' => '1',
    'cpf' => '1',
    'hil' => '1',
    'udm' => '1',
    'aus' => '1',
    'zza' => '1',
    'chb' => '1',
    'alg' => '1',
    'snk' => '1',
    'kbd' => '1',
    'pro' => '1',
    'mga' => '1',
    'mag' => '1',
    'wak' => '1',
    'hz'  => '1',
    'nai' => '1',
    'sel' => '1',
    'pal' => '1',
    'frr' => '1',
    'min' => '1',
    'ban' => '1',
    'lol' => '1',
    'dum' => '1',
    'sm'  => '1',
    'grb' => '1',
    'was' => '1',
    'sat' => '1',
    'tyv' => '1',
    'mwr' => '1',
    'egy' => '1',
    'sus' => '1',
    'cel' => '1',
    'moh' => '1',
    'him' => '1',
    'tpi' => '1',
    'ady' => '1',
    'efi' => '1',
    'doi' => '1',
    'mos' => '1',
    'nzi' => '1',
    'ain' => '1',
    'sit' => '1',
    'sem' => '1',
    'chp' => '1',
    'zun' => '1',
    'cus' => '1',
    'mfe' => '1',
    'mis' => '1',
    'wen' => '1',
    'nwc' => '1',
    'av'  => '1',
    'sms' => '1',
    'fon' => '1',
    'kab' => '1',
    'nic' => '1',
    'rap' => '1',
    'qu'  => '1',
    'oto' => '1',
    'shn' => '1',
    'la'  => '1',
    'men' => '1',
    'bh'  => '1',
    'fro' => '1',
    'myv' => '1',
    'tsi' => '1',
    'pap' => '1',
    'zxx' => '1',
    'art' => '1',
    'tiv' => '1',
    'scn' => '1',
    'kha' => '1',
    'nyo' => '1',
    'sma' => '1',
    'hai' => '1',
    'mdr' => '1',
    'vot' => '1',
    'ach' => '1',
    'ale' => '1',
    'vai' => '1',
    'ng'  => '1',
    'kru' => '1',
    'sai' => '1',
    'jv'  => '1',
    'lu'  => '1',
    'smj' => '1',
    'tli' => '1',
    'ks'  => '1',
    'mh'  => '1',
    'gwi' => '1',
    'smn' => '1',
    'kg'  => '1',
    'lad' => '1',
    'csb' => '1',
    'ho'  => '1',
    'os'  => '1',
    'got' => '1',
    'kaa' => '1',
    'ewo' => '1',
    'afa' => '1',
    'vo'  => '1',
    'ff'  => '1',
    'tet' => '1',
    'tem' => '1',
    'fj'  => '1',
    'lus' => '1',
    'srr' => '1',
    'pam' => '1',
    'tkl' => '1',
    'sn'  => '1',
    'inh' => '1',
    'cpe' => '1',
    'kaw' => '1',
    'sd'  => '1',
    'ath' => '1',
    'yi'  => '1',
    'bho' => '1',
    'arp' => '1',
    'frs' => '1',
    'gon' => '1',
    'gba' => '1',
    'hit' => '1',
    'lg'  => '1',
    'war' => '1',
    'bug' => '1',
    'mad' => '1',
    'rup' => '1',
    'dua' => '1',
    'mul' => '1',
    'cad' => '1',
    'rm'  => '1',
    'ilo' => '1',
    'rn'  => '1',
    'uga' => '1',
    'cho' => '1',
    'nog' => '1',
    'jbo' => '1',
    'crh' => '1',
    'ik'  => '1',
    'hmn' => '1',
    'cpp' => '1',
    'tup' => '1',
    'tk'  => '1',
    'sga' => '1',
    'mg'  => '1',
    'su'  => '1',
    'sc'  => '1',
    'sio' => '1',
    'sgn' => '1',
    'chy' => '1',
    'goh' => '1',
    'zap' => '1',
    'kar' => '1',
    'znd' => '1',
    'sah' => '1',
    'lb'  => '1',
    'mus' => '1',
    'grc' => '1',
    'sas' => '1',
    'nah' => '1',
    'btk' => '1',
    'bal' => '1',
    'peo' => '1',
    'kho' => '1',
    'nyn' => '1',
    'zbl' => '1',
    'crp' => '1',
    'inc' => '1',
    'cu'  => '1',
    'ch'  => '1',
    'lah' => '1',
    'wa'  => '1',
    'ine' => '1',
    'cau' => '1',
    'ay'  => '1',
    'lez' => '1',
    'den' => '1',
    'lui' => '1',
    'mak' => '1',
    'apa' => '1',
    'non' => '1',
    'an'  => '1',
    'lua' => '1',
    'khi' => '1',
    'ceb' => '1',
    'kr'  => '1',
    'smi' => '1',
    'ast' => '1',
    'dra' => '1',
    'io'  => '1',
    'tut' => '1',
    'iba' => '1',
    'kmb' => '1',
    'sam' => '1',
    'dar' => '1',
    'phn' => '1',
    'bik' => '1',
    'chg' => '1',
    'gn'  => '1',
    'ypk' => '1',
    'din' => '1',
    'niu' => '1',
    'cv'  => '1',
    'arw' => '1',
    'chk' => '1',
    'tw'  => '1',
    'tmh' => '1',
    'ce'  => '1',
    'chn' => '1',
    'awa' => '1',
    'kro' => '1',
    'tvl' => '1',
    'dsb' => '1',
    'pi'  => '1',
    'tog' => '1',
    'ijo' => '1',
    'bla' => '1',
    'myn' => '1',
    'mnc' => '1',
    'nap' => '1',
);

1;
