package Locales::DB::Territory::cy;

# Auto generated from CLDR

$Locales::DB::Territory::cy::VERSION = '0.02';

$Locales::DB::Territory::cy::cldr_version = '1.7.1';

%Locales::DB::Territory::cy::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "Emiraethau\ Arabaidd\ Unedig",
    'af' => 'Affganistan',
    'ag' => "Antigwa\ a\ Barbuda",
    'ai' => 'Anguilla',
    'al' => 'Albania',
    'am' => 'Armenia',
    'an' => "Ynysoedd\ Caribî\ yr\ Iseldiroedd",
    'ao' => 'Angola',
    'aq' => 'Antarctica',
    'ar' => "Yr\ Ariannin",
    'as' => "Samoa\ Americanaidd",
    'at' => 'Awstria',
    'au' => 'Awstralia',
    'aw' => 'Aruba',
    'ax' => "Ynysoedd\ Aland",
    'az' => 'Azerbaijan',
    'ba' => "Bosnia\ a\ Herzegovina",
    'bb' => 'Barbados',
    'bd' => 'Bangladesh',
    'be' => "Gwlad\ Belg",
    'bf' => "Burkina\ Faso",
    'bg' => 'Bwlgaria',
    'bh' => 'Bahrain',
    'bi' => 'Burundi',
    'bj' => 'Benin',
    'bl' => "Saint\ Barth\Ã\©lemy",
    'bm' => 'Bermwda',
    'bn' => 'Brunei',
    'bo' => 'Bolifia',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brasil',
    'bs' => "Y\ Bahamas",
    'bt' => 'Bhwtan',
    'bv' => "Ynys\ Bouvet",
    'bw' => 'Botswana',
    'by' => 'Belarws',
    'bz' => 'Belize',
    'ca' => 'Canada',
    'cc' => "Ynysoedd\ Cocos\ \(Keeling\)",
    'cd' => "Gweriniaeth\ Ddemocrataidd\ y\ Congo",
    'cf' => "Gweriniaeth\ Canol\ Affrica",
    'cg' => 'Congo',
    'ch' => "Y\ Swistir",
    'ci' => "Côte\ d’Ivoire",
    'ck' => "Ynysoedd\ Cook",
    'cl' => 'Chile',
    'cm' => "Y\ Camerŵn",
    'cn' => 'Tseina',
    'co' => 'Colombia',
    'cr' => "Costa\ Rica",
    'cs' => "Serbia\ and\ Montenegro",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Ciwba',
    'cv' => "Cape\ Verde",
    'cx' => "Ynys\ y\ Nadolig",
    'cy' => 'Cyprus',
    'cz' => "Gweriniaeth\ Tsiec",
    'dd' => "East\ Germany",
    'de' => "Yr\ Almaen",
    'dj' => 'Djibouti',
    'dk' => 'Denmarc',
    'dm' => 'Dominica',
    'do' => "Y\ Weriniaeth\ Ddominicaidd",
    'dz' => 'Algeria',
    'ec' => 'Ecwador',
    'ee' => 'Estonia',
    'eg' => "Yr\ Aifft",
    'eh' => "Gorllewin\ Sahara",
    'er' => 'Eritrea',
    'es' => 'Sbaen',
    'et' => 'Ethiopia',
    'fi' => "Y\ Ffindir",
    'fj' => 'Fiji',
    'fk' => "Ynysoedd\ y\ Falkland",
    'fm' => 'Micronesia',
    'fo' => "Ynysoedd\ Ffaröe",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Ffrainc',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabon',
    'gb' => "Prydain\ Fawr",
    'gd' => 'Grenada',
    'ge' => 'Georgia',
    'gf' => "Giana\ Ffrengig",
    'gg' => 'Guernsey',
    'gh' => 'Ghana',
    'gi' => 'Gibraltar',
    'gl' => "Yr\ Ynys\ Las",
    'gm' => 'Gambia',
    'gn' => 'Gini',
    'gp' => 'Guadeloupe',
    'gq' => "Gini\ Gyhydeddol",
    'gr' => "Gwlad\ Groeg",
    'gs' => "Ynysoedd\ De\ Georgia\ a\ De\ Sandwich",
    'gt' => 'Guatemala',
    'gu' => 'Guam',
    'gw' => "Guinea\-Bissau",
    'gy' => 'Guyana',
    'hk' => "Hong\ Kong\ S\.A\.R\.\,\ Tseina",
    'hm' => "Ynys\ Heard\ ac\ Ynysoedd\ McDonald",
    'hn' => 'Hondwras',
    'hr' => 'Croatia',
    'ht' => 'Haiti',
    'hu' => 'Hwngari',
    'id' => 'Indonesia',
    'ie' => 'Iwerddon',
    'il' => 'Israel',
    'im' => "Ynys\ Manaw",
    'in' => 'India',
    'io' => "Tiriogaeth\ Cefnfor\ India\ Prydain",
    'iq' => 'Irac',
    'ir' => 'Iran',
    'is' => "Gwlad\ yr\ Iâ",
    'it' => "Yr\ Eidal",
    'je' => 'Jersey',
    'jm' => 'Jamaica',
    'jo' => "Yr\ Iorddonen",
    'jp' => 'Siapan',
    'jt' => "Johnston\ Island",
    'ke' => 'Cenia',
    'kg' => 'Cirgistan',
    'kh' => 'Cambodia',
    'ki' => 'Kiribati',
    'km' => 'Comoros',
    'kn' => "Saint\ Kitts\ a\ Nevis",
    'kp' => "Gogledd\ Corea",
    'kr' => "De\ Corea",
    'kw' => 'Coweit',
    'ky' => "Ynysoedd\ Cayman",
    'kz' => 'Kazakhstan',
    'la' => 'Laos',
    'lb' => 'Libanus',
    'lc' => "Saint\ Lucia",
    'li' => 'Liechtenstein',
    'lk' => "Sri\ Lanka",
    'lr' => 'Liberia',
    'ls' => 'Lesotho',
    'lt' => 'Lithwania',
    'lu' => 'Lwcsembwrg',
    'lv' => 'Latfia',
    'ly' => 'Libia',
    'ma' => 'Moroco',
    'mc' => 'Monaco',
    'md' => 'Moldofa',
    'me' => 'Montenegro',
    'mf' => "Saint\ Martin",
    'mg' => 'Madagascar',
    'mh' => "Ynysoedd\ Marshall",
    'mi' => "Midway\ Islands",
    'mk' => 'Macedonia',
    'ml' => 'Mali',
    'mm' => 'Myanmar',
    'mn' => 'Mongolia',
    'mo' => "Macao\ S\.A\.R\.\,\ Tseina",
    'mp' => "Ynysoedd\ Gogledd\ Mariana",
    'mq' => 'Martinique',
    'mr' => 'Mawritania',
    'ms' => 'Montserrat',
    'mt' => 'Malta',
    'mu' => 'Mawrisiws',
    'mv' => 'Maldives',
    'mw' => 'Malawi',
    'mx' => 'Mecsico',
    'my' => 'Malaysia',
    'mz' => 'Mozambique',
    'na' => 'Namibia',
    'nc' => "Caledonia\ Newydd",
    'ne' => 'Niger',
    'nf' => "Ynys\ Norfolk",
    'ng' => 'Nigeria',
    'ni' => 'Nicaragwa',
    'nl' => "Yr\ Iseldiroedd",
    'no' => 'Norwy',
    'np' => 'Nepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nawrw',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "Seland\ Newydd",
    'om' => 'Oman',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Perw',
    'pf' => "Polynesia\ Ffrainc",
    'pg' => "Papua\ Gini\ Newydd",
    'ph' => 'Philipinau',
    'pk' => 'Pacistan',
    'pl' => "Gwlad\ Pwyl",
    'pm' => "Saint\ Pierre\ a\ Miquelon",
    'pn' => 'Pitcairn',
    'pr' => "Puerto\ Rico",
    'ps' => "Tiriogaeth\ Palesteina",
    'pt' => 'Portiwgal',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paraguay',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Qatar',
    'qo' => "Ynysoedd\ Pellenig\ y\ De",
    'qu' => "European\ Union",
    're' => 'Réunion',
    'ro' => 'Rwmania',
    'rs' => 'Serbia',
    'ru' => 'Rwsia',
    'rw' => 'Rwanda',
    'sa' => "Sawdi\-Arabia",
    'sb' => "Ynysoedd\ Solomon",
    'sc' => 'Seychelles',
    'sd' => "Y\ Swdan",
    'se' => 'Sweden',
    'sg' => 'Singapore',
    'sh' => "Saint\ Helena",
    'si' => 'Slofenia',
    'sj' => "Svalbard\ a\ Jan\ Mayen",
    'sk' => 'Slofacia',
    'sl' => "Sierra\ Leone",
    'sm' => "San\ Marino",
    'sn' => 'Senegal',
    'so' => 'Somalia',
    'sr' => 'Swrinam',
    'st' => "Sao\ Tome\ a\ Principe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salfador",
    'sy' => 'Syria',
    'sz' => 'Swaziland',
    'tc' => "Ynysoedd\ Turks\ a\ Caicos",
    'td' => 'Chad',
    'tf' => "Tiriogaethau\ Ffrengig\ y\ De",
    'tg' => 'Togo',
    'th' => "Gwlad\ Thai",
    'tj' => 'Tajicistan',
    'tk' => 'Tokelau',
    'tl' => "Timor\-Leste",
    'tm' => 'Tyrcmenistan',
    'tn' => 'Tiwnisia',
    'to' => 'Tonga',
    'tr' => 'Twrci',
    'tt' => "Trinidad\ a\ Thobago",
    'tv' => 'Twfalw',
    'tw' => 'Taiwan',
    'tz' => 'Tansanïa',
    'ua' => 'Wcráin',
    'ug' => 'Uganda',
    'um' => "Mân\ Ynysoedd\ Pellenig\ yr\ Unol\ Daleithiau",
    'us' => "Yr\ Unol\ Daleithiau",
    'uy' => 'Uruguay',
    'uz' => 'Wsbecistan',
    'va' => "Y\ Fatican",
    'vc' => "Saint\ Vincent\ a’r\ Grenadines",
    'vd' => "North\ Vietnam",
    've' => 'Venezuela',
    'vg' => "Ynysoedd\ Prydeinig\ y\ Wyryf",
    'vi' => "Ynysoedd\ Americanaidd\ y\ Wyryf",
    'vn' => 'Fietnam',
    'vu' => 'Vanuatu',
    'wf' => "Wallis\ a\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Yemen',
    'yt' => 'Mayotte',
    'za' => "De\ Affrica",
    'zm' => 'Sambia',
    'zw' => 'Simbabwe',
    'zz' => "Unknown\ or\ Invalid\ Region",
);

%Locales::DB::Territory::cy::name_to_code = (
    'affganistan'                           => 'af',
    'albania'                               => 'al',
    'algeria'                               => 'dz',
    'andorra'                               => 'ad',
    'angola'                                => 'ao',
    'anguilla'                              => 'ai',
    'antarctica'                            => 'aq',
    'antigwaabarbuda'                       => 'ag',
    'armenia'                               => 'am',
    'aruba'                                 => 'aw',
    'awstralia'                             => 'au',
    'awstria'                               => 'at',
    'azerbaijan'                            => 'az',
    'bahrain'                               => 'bh',
    'bangladesh'                            => 'bd',
    'barbados'                              => 'bb',
    'belarws'                               => 'by',
    'belize'                                => 'bz',
    'benin'                                 => 'bj',
    'bermwda'                               => 'bm',
    'bhwtan'                                => 'bt',
    'bolifia'                               => 'bo',
    'bosniaaherzegovina'                    => 'ba',
    'botswana'                              => 'bw',
    'brasil'                                => 'br',
    'britishantarcticterritory'             => 'bq',
    'brunei'                                => 'bn',
    'burkinafaso'                           => 'bf',
    'burundi'                               => 'bi',
    'bwlgaria'                              => 'bg',
    'caledonianewydd'                       => 'nc',
    'cambodia'                              => 'kh',
    'canada'                                => 'ca',
    'cantonandenderburyislands'             => 'ct',
    'capeverde'                             => 'cv',
    'cenia'                                 => 'ke',
    'chad'                                  => 'td',
    'chile'                                 => 'cl',
    'cirgistan'                             => 'kg',
    'ciwba'                                 => 'cu',
    'colombia'                              => 'co',
    'comoros'                               => 'km',
    'congo'                                 => 'cg',
    'costarica'                             => 'cr',
    'coweit'                                => 'kw',
    'croatia'                               => 'hr',
    'cyprus'                                => 'cy',
    'côted’ivoire'                       => 'ci',
    'deaffrica'                             => 'za',
    'decorea'                               => 'kr',
    'denmarc'                               => 'dk',
    'djibouti'                              => 'dj',
    'dominica'                              => 'dm',
    'dronningmaudland'                      => 'nq',
    'eastgermany'                           => 'dd',
    'ecwador'                               => 'ec',
    'elsalfador'                            => 'sv',
    'emiraethauarabaiddunedig'              => 'ae',
    'eritrea'                               => 'er',
    'estonia'                               => 'ee',
    'ethiopia'                              => 'et',
    'europeanunion'                         => 'qu',
    'ffrainc'                               => 'fr',
    'fietnam'                               => 'vn',
    'fiji'                                  => 'fj',
    'frenchsouthernandantarcticterritories' => 'fq',
    'gabon'                                 => 'ga',
    'gambia'                                => 'gm',
    'georgia'                               => 'ge',
    'ghana'                                 => 'gh',
    'gianaffrengig'                         => 'gf',
    'gibraltar'                             => 'gi',
    'gini'                                  => 'gn',
    'ginigyhydeddol'                        => 'gq',
    'gogleddcorea'                          => 'kp',
    'gorllewinsahara'                       => 'eh',
    'grenada'                               => 'gd',
    'guadeloupe'                            => 'gp',
    'guam'                                  => 'gu',
    'guatemala'                             => 'gt',
    'guernsey'                              => 'gg',
    'guineabissau'                          => 'gw',
    'guyana'                                => 'gy',
    'gweriniaethcanolaffrica'               => 'cf',
    'gweriniaethddemocrataiddycongo'        => 'cd',
    'gweriniaethtsiec'                      => 'cz',
    'gwladbelg'                             => 'be',
    'gwladgroeg'                            => 'gr',
    'gwladpwyl'                             => 'pl',
    'gwladthai'                             => 'th',
    'gwladyriâ'                            => 'is',
    'haiti'                                 => 'ht',
    'hondwras'                              => 'hn',
    "hongkongs\.a\.r\.\,tseina"             => 'hk',
    'hwngari'                               => 'hu',
    'india'                                 => 'in',
    'indonesia'                             => 'id',
    'irac'                                  => 'iq',
    'iran'                                  => 'ir',
    'israel'                                => 'il',
    'iwerddon'                              => 'ie',
    'jamaica'                               => 'jm',
    'jersey'                                => 'je',
    'johnstonisland'                        => 'jt',
    'kazakhstan'                            => 'kz',
    'kiribati'                              => 'ki',
    'laos'                                  => 'la',
    'latfia'                                => 'lv',
    'lesotho'                               => 'ls',
    'libanus'                               => 'lb',
    'liberia'                               => 'lr',
    'libia'                                 => 'ly',
    'liechtenstein'                         => 'li',
    'lithwania'                             => 'lt',
    'lwcsembwrg'                            => 'lu',
    "macaos\.a\.r\.\,tseina"                => 'mo',
    'macedonia'                             => 'mk',
    'madagascar'                            => 'mg',
    'malawi'                                => 'mw',
    'malaysia'                              => 'my',
    'maldives'                              => 'mv',
    'mali'                                  => 'ml',
    'malta'                                 => 'mt',
    'martinique'                            => 'mq',
    'mawrisiws'                             => 'mu',
    'mawritania'                            => 'mr',
    'mayotte'                               => 'yt',
    'mecsico'                               => 'mx',
    'metropolitanfrance'                    => 'fx',
    'micronesia'                            => 'fm',
    'midwayislands'                         => 'mi',
    'moldofa'                               => 'md',
    'monaco'                                => 'mc',
    'mongolia'                              => 'mn',
    'montenegro'                            => 'me',
    'montserrat'                            => 'ms',
    'moroco'                                => 'ma',
    'mozambique'                            => 'mz',
    'myanmar'                               => 'mm',
    'mânynysoeddpellenigyrunoldaleithiau'  => 'um',
    'namibia'                               => 'na',
    'nawrw'                                 => 'nr',
    'nepal'                                 => 'np',
    'neutralzone'                           => 'nt',
    'nicaragwa'                             => 'ni',
    'niger'                                 => 'ne',
    'nigeria'                               => 'ng',
    'niue'                                  => 'nu',
    'northvietnam'                          => 'vd',
    'norwy'                                 => 'no',
    'oman'                                  => 'om',
    'pacificislandstrustterritory'          => 'pc',
    'pacistan'                              => 'pk',
    'palau'                                 => 'pw',
    'panama'                                => 'pa',
    'panamacanalzone'                       => 'pz',
    'papuagininewydd'                       => 'pg',
    'paraguay'                              => 'py',
    'peoplesdemocraticrepublicofyemen'      => 'yd',
    'perw'                                  => 'pe',
    'philipinau'                            => 'ph',
    'pitcairn'                              => 'pn',
    'polynesiaffrainc'                      => 'pf',
    'portiwgal'                             => 'pt',
    'prydainfawr'                           => 'gb',
    'puertorico'                            => 'pr',
    'qatar'                                 => 'qa',
    'rwanda'                                => 'rw',
    'rwmania'                               => 'ro',
    'rwsia'                                 => 'ru',
    'réunion'                              => 're',
    "saintbarth\Ã\©lemy"                  => 'bl',
    'sainthelena'                           => 'sh',
    'saintkittsanevis'                      => 'kn',
    'saintlucia'                            => 'lc',
    'saintmartin'                           => 'mf',
    'saintpierreamiquelon'                  => 'pm',
    'saintvincenta’rgrenadines'           => 'vc',
    'sambia'                                => 'zm',
    'samoa'                                 => 'ws',
    'samoaamericanaidd'                     => 'as',
    'sanmarino'                             => 'sm',
    'saotomeaprincipe'                      => 'st',
    'sawdiarabia'                           => 'sa',
    'sbaen'                                 => 'es',
    'selandnewydd'                          => 'nz',
    'senegal'                               => 'sn',
    'serbia'                                => 'rs',
    'serbiaandmontenegro'                   => 'cs',
    'seychelles'                            => 'sc',
    'siapan'                                => 'jp',
    'sierraleone'                           => 'sl',
    'simbabwe'                              => 'zw',
    'singapore'                             => 'sg',
    'slofacia'                              => 'sk',
    'slofenia'                              => 'si',
    'somalia'                               => 'so',
    'srilanka'                              => 'lk',
    'svalbardajanmayen'                     => 'sj',
    'swaziland'                             => 'sz',
    'sweden'                                => 'se',
    'swrinam'                               => 'sr',
    'syria'                                 => 'sy',
    'taiwan'                                => 'tw',
    'tajicistan'                            => 'tj',
    'tansanïa'                             => 'tz',
    'timorleste'                            => 'tl',
    'tiriogaethauffrengigyde'               => 'tf',
    'tiriogaethcefnforindiaprydain'         => 'io',
    'tiriogaethpalesteina'                  => 'ps',
    'tiwnisia'                              => 'tn',
    'togo'                                  => 'tg',
    'tokelau'                               => 'tk',
    'tonga'                                 => 'to',
    'trinidadathobago'                      => 'tt',
    'tseina'                                => 'cn',
    'twfalw'                                => 'tv',
    'twrci'                                 => 'tr',
    'tyrcmenistan'                          => 'tm',
    "u\.s\.miscellaneouspacificislands"     => 'pu',
    'uganda'                                => 'ug',
    'unionofsovietsocialistrepublics'       => 'su',
    'unknownorinvalidregion'                => 'zz',
    'uruguay'                               => 'uy',
    'vanuatu'                               => 'vu',
    'venezuela'                             => 've',
    'wakeisland'                            => 'wk',
    'wallisafutuna'                         => 'wf',
    'wcráin'                               => 'ua',
    'wsbecistan'                            => 'uz',
    'ybahamas'                              => 'bs',
    'ycamerŵn'                             => 'cm',
    'yemen'                                 => 'ye',
    'yfatican'                              => 'va',
    'yffindir'                              => 'fi',
    'ynysbouvet'                            => 'bv',
    'ynysheardacynysoeddmcdonald'           => 'hm',
    'ynysmanaw'                             => 'im',
    'ynysnorfolk'                           => 'nf',
    'ynysoeddaland'                         => 'ax',
    'ynysoeddamericanaiddywyryf'            => 'vi',
    'ynysoeddcaribîyriseldiroedd'          => 'an',
    'ynysoeddcayman'                        => 'ky',
    'ynysoeddcocoskeeling'                  => 'cc',
    'ynysoeddcook'                          => 'ck',
    'ynysoedddegeorgiaadesandwich'          => 'gs',
    'ynysoeddffaröe'                       => 'fo',
    'ynysoeddgogleddmariana'                => 'mp',
    'ynysoeddmarshall'                      => 'mh',
    'ynysoeddpellenigyde'                   => 'qo',
    'ynysoeddprydeinigywyryf'               => 'vg',
    'ynysoeddsolomon'                       => 'sb',
    'ynysoeddturksacaicos'                  => 'tc',
    'ynysoeddyfalkland'                     => 'fk',
    'ynysynadolig'                          => 'cx',
    'yraifft'                               => 'eg',
    'yralmaen'                              => 'de',
    'yrariannin'                            => 'ar',
    'yreidal'                               => 'it',
    'yriorddonen'                           => 'jo',
    'yriseldiroedd'                         => 'nl',
    'yrunoldaleithiau'                      => 'us',
    'yrynyslas'                             => 'gl',
    'yswdan'                                => 'sd',
    'yswistir'                              => 'ch',
    'yweriniaethddominicaidd'               => 'do',
);

1;

