package Locales::DB::Territory::el;

# Auto generated from CLDR

$Locales::DB::Territory::el::VERSION = '0.02';

$Locales::DB::Territory::el::cldr_version = '1.7.1';

%Locales::DB::Territory::el::code_to_name = (
    'ad' => 'Ανδόρα',
    'ae' => "Ηνωμένα\ Αραβικά\ Εμιράτα",
    'af' => 'Αφγανιστάν',
    'ag' => "Αντίγκουα\ και\ Μπαρμπούντα",
    'ai' => 'Ανγκουίλα',
    'al' => 'Αλβανία',
    'am' => 'Αρμενία',
    'an' => "Ολλανδικές\ Αντίλλες",
    'ao' => 'Ανγκόλα',
    'aq' => 'Ανταρκτική',
    'ar' => 'Αργεντινή',
    'as' => "Αμερικανική\ Σαμόα",
    'at' => 'Αυστρία',
    'au' => 'Αυστραλία',
    'aw' => 'Αρούμπα',
    'ax' => "Νήσοι\ Άλαντ",
    'az' => 'Αζερμπαϊτζάν',
    'ba' => "Βοσνία\ \-\ Ερζεγοβίνη",
    'bb' => 'Μπαρμπάντος',
    'bd' => 'Μπανγκλαντές',
    'be' => 'Βέλγιο',
    'bf' => "Μπουρκίνα\ Φάσο",
    'bg' => 'Βουλγαρία',
    'bh' => 'Μπαχρέιν',
    'bi' => 'Μπουρούντι',
    'bj' => 'Μπενίν',
    'bl' => "Άγιος\ Βαρθολομαίος",
    'bm' => 'Βερμούδες',
    'bn' => 'Μπρουνέι',
    'bo' => 'Βολιβία',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Βραζιλία',
    'bs' => 'Μπαχάμες',
    'bt' => 'Μπουτάν',
    'bv' => "Νήσος\ Μπουβέ",
    'bw' => 'Μποτσουάνα',
    'by' => 'Λευκορωσία',
    'bz' => 'Μπελίσε',
    'ca' => 'Καναδάς',
    'cc' => "Νήσοι\ Κόκος",
    'cd' => "Κονγκό\ \-\ Κινσάσα",
    'cf' => "Κεντροαφρικανική\ Δημοκρατία",
    'cg' => "Κονγκό\ \-\ Μπραζαβίλ",
    'ch' => 'Ελβετία',
    'ci' => "Ακτή\ Ελεφαντοστού",
    'ck' => "Νήσοι\ Κουκ",
    'cl' => 'Χιλή',
    'cm' => 'Καμερούν',
    'cn' => 'Κίνα',
    'co' => 'Κολομβία',
    'cr' => "Κόστα\ Ρίκα",
    'cs' => "Σερβία\ και\ Μαυροβούνιο",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Κούβα',
    'cv' => "Πράσινο\ Ακρωτήριο",
    'cx' => "Νήσος\ Χριστουγέννων",
    'cy' => 'Κύπρος',
    'cz' => 'Τσεχία',
    'dd' => "East\ Germany",
    'de' => 'Γερμανία',
    'dj' => 'Τζιμπουτί',
    'dk' => 'Δανία',
    'dm' => 'Ντομίνικα',
    'do' => "Δομινικανή\ Δημοκρατία",
    'dz' => 'Αλγερία',
    'ec' => 'Ισημερινός',
    'ee' => 'Εσθονία',
    'eg' => 'Αίγυπτος',
    'eh' => "Δυτική\ Σαχάρα",
    'er' => 'Ερυθραία',
    'es' => 'Ισπανία',
    'et' => 'Αιθιοπία',
    'fi' => 'Φινλανδία',
    'fj' => 'Φίτζι',
    'fk' => "Νήσοι\ Φώκλαντ",
    'fm' => 'Μικρονησία',
    'fo' => "Νήσοι\ Φερόε",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Γαλλία',
    'fx' => "Metropolitan\ France",
    'ga' => 'Γκαμπόν',
    'gb' => "Ηνωμένο\ Βασίλειο",
    'gd' => 'Γρενάδα',
    'ge' => 'Γεωργία',
    'gf' => "Γαλλική\ Γουιάνα",
    'gg' => 'Γκερνσέι',
    'gh' => 'Γκάνα',
    'gi' => 'Γιβραλτάρ',
    'gl' => 'Γροιλανδία',
    'gm' => 'Γκάμπια',
    'gn' => 'Γουινέα',
    'gp' => 'Γουαδελούπη',
    'gq' => "Ισημερινή\ Γουινέα",
    'gr' => 'Ελλάδα',
    'gs' => "Νότια\ Γεωργία\ και\ Νότιες\ Νήσοι\ Σάντουιτς",
    'gt' => 'Γουατεμάλα',
    'gu' => 'Γκουάμ',
    'gw' => "Γουινέα\-Μπισάου",
    'gy' => 'Γουιάνα',
    'hk' => "Χονγκ\ Κονγκ",
    'hm' => "Νήσοι\ Χερντ\ και\ Μακντόναλντ",
    'hn' => 'Ονδούρα',
    'hr' => 'Κροατία',
    'ht' => 'Αϊτή',
    'hu' => 'Ουγγαρία',
    'id' => 'Ινδονησία',
    'ie' => 'Ιρλανδία',
    'il' => 'Ισραήλ',
    'im' => "Νήσος\ Μαν",
    'in' => 'Ινδία',
    'io' => "Βρετανικά\ Εδάφη\ Ινδικού\ Ωκεανού",
    'iq' => 'Ιράκ',
    'ir' => 'Ιράν',
    'is' => 'Ισλανδία',
    'it' => 'Ιταλία',
    'je' => 'Υερσέη',
    'jm' => 'Τζαμάικα',
    'jo' => 'Ιορδανία',
    'jp' => 'Ιαπωνία',
    'jt' => "Johnston\ Island",
    'ke' => 'Κένυα',
    'kg' => 'Κιργιζία',
    'kh' => 'Καμπότζη',
    'ki' => 'Κιριμπάτι',
    'km' => 'Κομόρος',
    'kn' => "Σαιντ\ Κιτς\ και\ Νέβις",
    'kp' => "Βόρεια\ Κορέα",
    'kr' => "Νότια\ Κορέα",
    'kw' => 'Κουβέιτ',
    'ky' => "Νήσοι\ Κέιμαν",
    'kz' => 'Καζακστάν',
    'la' => 'Λάος',
    'lb' => 'Λίβανος',
    'lc' => "Αγία\ Λουκία",
    'li' => 'Λιχτενστάιν',
    'lk' => "Σρι\ Λάνκα",
    'lr' => 'Λιβερία',
    'ls' => 'Λεσότο',
    'lt' => 'Λιθουανία',
    'lu' => 'Λουξεμβούργο',
    'lv' => 'Λετονία',
    'ly' => 'Λιβύη',
    'ma' => 'Μαρόκο',
    'mc' => 'Μονακό',
    'md' => 'Μολδαβία',
    'me' => 'Μαυροβούνιο',
    'mf' => "Άγιος\ Μαρτίνος",
    'mg' => 'Μαδαγασκάρη',
    'mh' => "Νήσοι\ Μάρσαλ",
    'mi' => "Midway\ Islands",
    'mk' => "ΠΓΔ\ Μακεδονίας",
    'ml' => 'Μάλι',
    'mm' => 'Μιανμάρ',
    'mn' => 'Μογγολία',
    'mo' => 'Μακάο',
    'mp' => "Βόρειες\ Μαριάνες\ Νήσοι",
    'mq' => 'Μαρτινίκα',
    'mr' => 'Μαυριτανία',
    'ms' => 'Μονσεράτ',
    'mt' => 'Μάλτα',
    'mu' => 'Μαυρίκιος',
    'mv' => 'Μαλδίβες',
    'mw' => 'Μαλάουι',
    'mx' => 'Μεξικό',
    'my' => 'Μαλαισία',
    'mz' => 'Μοζαμβίκη',
    'na' => 'Ναμίμπια',
    'nc' => "Νέα\ Καληδονία",
    'ne' => 'Νίγηρας',
    'nf' => "Νήσος\ Νόρφολκ",
    'ng' => 'Νιγηρία',
    'ni' => 'Νικαράγουα',
    'nl' => 'Ολλανδία',
    'no' => 'Νορβηγία',
    'np' => 'Νεπάλ',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Ναούρου',
    'nt' => "Neutral\ Zone",
    'nu' => 'Νιούε',
    'nz' => "Νέα\ Ζηλανδία",
    'om' => 'Ομάν',
    'pa' => 'Παναμάς',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Περού',
    'pf' => "Γαλλική\ Πολυνησία",
    'pg' => "Παπούα\ Νέα\ Γουινέα",
    'ph' => 'Φιλιππίνες',
    'pk' => 'Πακιστάν',
    'pl' => 'Πολωνία',
    'pm' => "Σαιντ\ Πιέρ\ και\ Μικελόν",
    'pn' => 'Πίτκερν',
    'pr' => "Πουέρτο\ Ρίκο",
    'ps' => "Παλαιστινιακά\ Εδάφη",
    'pt' => 'Πορτογαλία',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Παλάου',
    'py' => 'Παραγουάη',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Κατάρ',
    'qo' => "Περιφερειακή\ Ωκεανία",
    'qu' => "Ευρωπαϊκή\ Ένωση",
    're' => 'Ρεϋνιόν',
    'ro' => 'Ρουμανία',
    'rs' => 'Σερβία',
    'ru' => 'Ρωσία',
    'rw' => 'Ρουάντα',
    'sa' => "Σαουδική\ Αραβία",
    'sb' => "Νήσοι\ Σολομώντος",
    'sc' => 'Σεϋχέλλες',
    'sd' => 'Σουδάν',
    'se' => 'Σουηδία',
    'sg' => 'Σιγκαπούρη',
    'sh' => "Αγία\ Ελένη",
    'si' => 'Σλοβενία',
    'sj' => "Σβαλμπάρντ\ και\ Γιαν\ Μαγιέν",
    'sk' => 'Σλοβακία',
    'sl' => "Σιέρα\ Λεόνε",
    'sm' => "Άγιος\ Μαρίνος",
    'sn' => 'Σενεγάλη',
    'so' => 'Σομαλία',
    'sr' => 'Σουρινάμ',
    'st' => "Σάο\ Τομέ\ και\ Πρίνσιπε",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "Ελ\ Σαλβαδόρ",
    'sy' => 'Συρία',
    'sz' => 'Σουαζιλάνδη',
    'tc' => "Νήσοι\ Τερκς\ και\ Κάικος",
    'td' => 'Τσαντ',
    'tf' => "Γαλλικά\ Νότια\ Εδάφη",
    'tg' => 'Τόγκο',
    'th' => 'Ταϊλάνδη',
    'tj' => 'Τατζικιστάν',
    'tk' => 'Τοκελάου',
    'tl' => "Ανατολικό\ Τιμόρ",
    'tm' => 'Τουρκμενιστάν',
    'tn' => 'Τυνησία',
    'to' => 'Τόνγκα',
    'tr' => 'Τουρκία',
    'tt' => "Τρινιντάντ\ και\ Τομπάγκο",
    'tv' => 'Τουβαλού',
    'tw' => 'Ταϊβάν',
    'tz' => 'Τανζανία',
    'ua' => 'Ουκρανία',
    'ug' => 'Ουγκάντα',
    'um' => "Απομακρυσμένες\ Νησίδες\ Η\.Π\.Α\.",
    'us' => "Ηνωμένες\ Πολιτείες\ της\ Αμερικής",
    'uy' => 'Ουρουγουάη',
    'uz' => 'Ουζμπεκιστάν',
    'va' => 'Βατικανό',
    'vc' => "Άγιος\ Βικέντιος\ και\ Γρεναδίνες",
    'vd' => "North\ Vietnam",
    've' => 'Βενεζουέλα',
    'vg' => "Βρετανικές\ Παρθένοι\ Νήσοι",
    'vi' => "Αμερικανικές\ Παρθένοι\ Νήσοι",
    'vn' => 'Βιετνάμ',
    'vu' => 'Βανουάτου',
    'wf' => "Νήσοι\ Ουαλλίς\ και\ Φουτουνά",
    'wk' => "Wake\ Island",
    'ws' => 'Σαμόα',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Υεμένη',
    'yt' => 'Μαγιότ',
    'za' => "Νότια\ Αφρική",
    'zm' => 'Ζάμπια',
    'zw' => 'Ζιμπάμπουε',
    'zz' => "Άγνωστη\ ή\ μη\ έγκυρη\ περιοχή",
);

%Locales::DB::Territory::el::name_to_code = (
    'britishantarcticterritory'                                              => 'bq',
    'cantonandenderburyislands'                                              => 'ct',
    'dronningmaudland'                                                       => 'nq',
    'eastgermany'                                                            => 'dd',
    'frenchsouthernandantarcticterritories'                                  => 'fq',
    'johnstonisland'                                                         => 'jt',
    'metropolitanfrance'                                                     => 'fx',
    'midwayislands'                                                          => 'mi',
    'neutralzone'                                                            => 'nt',
    'northvietnam'                                                           => 'vd',
    'pacificislandstrustterritory'                                           => 'pc',
    'panamacanalzone'                                                        => 'pz',
    'peoplesdemocraticrepublicofyemen'                                       => 'yd',
    "u\.s\.miscellaneouspacificislands"                                      => 'pu',
    'unionofsovietsocialistrepublics'                                        => 'su',
    'wakeisland'                                                             => 'wk',
    'ΆγιοςΒαρθολομαίος'                                     => 'bl',
    'ΆγιοςΒικέντιοςκαιΓρεναδίνες'                 => 'vc',
    'ΆγιοςΜαρίνος'                                               => 'sm',
    'ΆγιοςΜαρτίνος'                                             => 'mf',
    'Άγνωστηήμηέγκυρηπεριοχή'                         => 'zz',
    'Αίγυπτος'                                                       => 'eg',
    'ΑγίαΕλένη'                                                     => 'sh',
    'ΑγίαΛουκία'                                                   => 'lc',
    'Αζερμπαϊτζάν'                                               => 'az',
    'Αιθιοπία'                                                       => 'et',
    'ΑκτήΕλεφαντοστού'                                       => 'ci',
    'Αλβανία'                                                         => 'al',
    'Αλγερία'                                                         => 'dz',
    'ΑμερικανικέςΠαρθένοιΝήσοι'                     => 'vi',
    'ΑμερικανικήΣαμόα'                                       => 'as',
    'ΑνατολικόΤιμόρ'                                           => 'tl',
    'Ανγκουίλα'                                                     => 'ai',
    'Ανγκόλα'                                                         => 'ao',
    'Ανδόρα'                                                           => 'ad',
    'ΑντίγκουακαιΜπαρμπούντα'                         => 'ag',
    'Ανταρκτική'                                                   => 'aq',
    "ΑπομακρυσμένεςΝησίδεςΗ\.Π\.Α\."                 => 'um',
    'Αργεντινή'                                                     => 'ar',
    'Αρμενία'                                                         => 'am',
    'Αρούμπα'                                                         => 'aw',
    'Αυστρία'                                                         => 'at',
    'Αυστραλία'                                                     => 'au',
    'Αφγανιστάν'                                                   => 'af',
    'Αϊτή'                                                               => 'ht',
    'Βέλγιο'                                                           => 'be',
    'Βανουάτου'                                                     => 'vu',
    'Βατικανό'                                                       => 'va',
    'Βενεζουέλα'                                                   => 've',
    'Βερμούδες'                                                     => 'bm',
    'Βιετνάμ'                                                         => 'vn',
    'Βολιβία'                                                         => 'bo',
    'ΒοσνίαΕρζεγοβίνη'                                       => 'ba',
    'Βουλγαρία'                                                     => 'bg',
    'Βραζιλία'                                                       => 'br',
    'ΒρετανικάΕδάφηΙνδικούΩκεανού'               => 'io',
    'ΒρετανικέςΠαρθένοιΝήσοι'                         => 'vg',
    'ΒόρειαΚορέα'                                                 => 'kp',
    'ΒόρειεςΜαριάνεςΝήσοι'                               => 'mp',
    'Γαλλία'                                                           => 'fr',
    'ΓαλλικάΝότιαΕδάφη'                                     => 'tf',
    'ΓαλλικήΓουιάνα'                                           => 'gf',
    'ΓαλλικήΠολυνησία'                                       => 'pf',
    'Γερμανία'                                                       => 'de',
    'Γεωργία'                                                         => 'ge',
    'Γιβραλτάρ'                                                     => 'gi',
    'Γκάμπια'                                                         => 'gm',
    'Γκάνα'                                                             => 'gh',
    'Γκαμπόν'                                                         => 'ga',
    'Γκερνσέι'                                                       => 'gg',
    'Γκουάμ'                                                           => 'gu',
    'Γουαδελούπη'                                                 => 'gp',
    'Γουατεμάλα'                                                   => 'gt',
    'Γουιάνα'                                                         => 'gy',
    'Γουινέα'                                                         => 'gn',
    'ΓουινέαΜπισάου'                                           => 'gw',
    'Γρενάδα'                                                         => 'gd',
    'Γροιλανδία'                                                   => 'gl',
    'Δανία'                                                             => 'dk',
    'ΔομινικανήΔημοκρατία'                               => 'do',
    'ΔυτικήΣαχάρα'                                               => 'eh',
    'ΕλΣαλβαδόρ'                                                   => 'sv',
    'Ελβετία'                                                         => 'ch',
    'Ελλάδα'                                                           => 'gr',
    'Ερυθραία'                                                       => 'er',
    'Εσθονία'                                                         => 'ee',
    'ΕυρωπαϊκήΈνωση'                                           => 'qu',
    'Ζάμπια'                                                           => 'zm',
    'Ζιμπάμπουε'                                                   => 'zw',
    'ΗνωμέναΑραβικάΕμιράτα'                             => 'ae',
    'ΗνωμένεςΠολιτείεςτηςΑμερικής'               => 'us',
    'ΗνωμένοΒασίλειο'                                         => 'gb',
    'Ιαπωνία'                                                         => 'jp',
    'Ινδία'                                                             => 'in',
    'Ινδονησία'                                                     => 'id',
    'Ιορδανία'                                                       => 'jo',
    'Ιράκ'                                                               => 'iq',
    'Ιράν'                                                               => 'ir',
    'Ιρλανδία'                                                       => 'ie',
    'ΙσημερινήΓουινέα'                                       => 'gq',
    'Ισημερινός'                                                   => 'ec',
    'Ισλανδία'                                                       => 'is',
    'Ισπανία'                                                         => 'es',
    'Ισραήλ'                                                           => 'il',
    'Ιταλία'                                                           => 'it',
    'Κένυα'                                                             => 'ke',
    'Κίνα'                                                               => 'cn',
    'Καζακστάν'                                                     => 'kz',
    'Καμερούν'                                                       => 'cm',
    'Καμπότζη'                                                       => 'kh',
    'Καναδάς'                                                         => 'ca',
    'Κατάρ'                                                             => 'qa',
    'ΚεντροαφρικανικήΔημοκρατία'                   => 'cf',
    'Κιργιζία'                                                       => 'kg',
    'Κιριμπάτι'                                                     => 'ki',
    'Κολομβία'                                                       => 'co',
    'Κομόρος'                                                         => 'km',
    'ΚονγκόΚινσάσα'                                             => 'cd',
    'ΚονγκόΜπραζαβίλ'                                         => 'cg',
    'Κουβέιτ'                                                         => 'kw',
    'Κούβα'                                                             => 'cu',
    'Κροατία'                                                         => 'hr',
    'ΚόσταΡίκα'                                                     => 'cr',
    'Κύπρος'                                                           => 'cy',
    'Λάος'                                                               => 'la',
    'Λίβανος'                                                         => 'lb',
    'Λεσότο'                                                           => 'ls',
    'Λετονία'                                                         => 'lv',
    'Λευκορωσία'                                                   => 'by',
    'Λιβερία'                                                         => 'lr',
    'Λιβύη'                                                             => 'ly',
    'Λιθουανία'                                                     => 'lt',
    'Λιχτενστάιν'                                                 => 'li',
    'Λουξεμβούργο'                                               => 'lu',
    'Μάλι'                                                               => 'ml',
    'Μάλτα'                                                             => 'mt',
    'Μαγιότ'                                                           => 'yt',
    'Μαδαγασκάρη'                                                 => 'mg',
    'Μακάο'                                                             => 'mo',
    'Μαλάουι'                                                         => 'mw',
    'Μαλαισία'                                                       => 'my',
    'Μαλδίβες'                                                       => 'mv',
    'Μαρτινίκα'                                                     => 'mq',
    'Μαρόκο'                                                           => 'ma',
    'Μαυρίκιος'                                                     => 'mu',
    'Μαυριτανία'                                                   => 'mr',
    'Μαυροβούνιο'                                                 => 'me',
    'Μεξικό'                                                           => 'mx',
    'Μιανμάρ'                                                         => 'mm',
    'Μικρονησία'                                                   => 'fm',
    'Μογγολία'                                                       => 'mn',
    'Μοζαμβίκη'                                                     => 'mz',
    'Μολδαβία'                                                       => 'md',
    'Μονακό'                                                           => 'mc',
    'Μονσεράτ'                                                       => 'ms',
    'Μπανγκλαντές'                                               => 'bd',
    'Μπαρμπάντος'                                                 => 'bb',
    'Μπαχάμες'                                                       => 'bs',
    'Μπαχρέιν'                                                       => 'bh',
    'Μπελίσε'                                                         => 'bz',
    'Μπενίν'                                                           => 'bj',
    'Μποτσουάνα'                                                   => 'bw',
    'ΜπουρκίναΦάσο'                                             => 'bf',
    'Μπουρούντι'                                                   => 'bi',
    'Μπουτάν'                                                         => 'bt',
    'Μπρουνέι'                                                       => 'bn',
    'ΝέαΖηλανδία'                                                 => 'nz',
    'ΝέαΚαληδονία'                                               => 'nc',
    'ΝήσοιΆλαντ'                                                   => 'ax',
    'ΝήσοιΚέιμαν'                                                 => 'ky',
    'ΝήσοιΚουκ'                                                     => 'ck',
    'ΝήσοιΚόκος'                                                   => 'cc',
    'ΝήσοιΜάρσαλ'                                                 => 'mh',
    'ΝήσοιΟυαλλίςκαιΦουτουνά'                         => 'wf',
    'ΝήσοιΣολομώντος'                                         => 'sb',
    'ΝήσοιΤερκςκαιΚάικος'                                 => 'tc',
    'ΝήσοιΦερόε'                                                   => 'fo',
    'ΝήσοιΦώκλαντ'                                               => 'fk',
    'ΝήσοιΧερντκαιΜακντόναλντ'                       => 'hm',
    'ΝήσοςΜαν'                                                       => 'im',
    'ΝήσοςΜπουβέ'                                                 => 'bv',
    'ΝήσοςΝόρφολκ'                                               => 'nf',
    'ΝήσοςΧριστουγέννων'                                   => 'cx',
    'Νίγηρας'                                                         => 'ne',
    'Ναμίμπια'                                                       => 'na',
    'Ναούρου'                                                         => 'nr',
    'Νεπάλ'                                                             => 'np',
    'Νιγηρία'                                                         => 'ng',
    'Νικαράγουα'                                                   => 'ni',
    'Νιούε'                                                             => 'nu',
    'Νορβηγία'                                                       => 'no',
    'Ντομίνικα'                                                     => 'dm',
    'ΝότιαΑφρική'                                                 => 'za',
    'ΝότιαΓεωργίακαιΝότιεςΝήσοιΣάντουιτς' => 'gs',
    'ΝότιαΚορέα'                                                   => 'kr',
    'Ολλανδία'                                                       => 'nl',
    'ΟλλανδικέςΑντίλλες'                                   => 'an',
    'Ομάν'                                                               => 'om',
    'Ονδούρα'                                                         => 'hn',
    'Ουγγαρία'                                                       => 'hu',
    'Ουγκάντα'                                                       => 'ug',
    'Ουζμπεκιστάν'                                               => 'uz',
    'Ουκρανία'                                                       => 'ua',
    'Ουρουγουάη'                                                   => 'uy',
    'ΠΓΔΜακεδονίας'                                             => 'mk',
    'Πίτκερν'                                                         => 'pn',
    'Πακιστάν'                                                       => 'pk',
    'Παλάου'                                                           => 'pw',
    'ΠαλαιστινιακάΕδάφη'                                   => 'ps',
    'Παναμάς'                                                         => 'pa',
    'ΠαπούαΝέαΓουινέα'                                       => 'pg',
    'Παραγουάη'                                                     => 'py',
    'ΠεριφερειακήΩκεανία'                                 => 'qo',
    'Περού'                                                             => 'pe',
    'Πολωνία'                                                         => 'pl',
    'Πορτογαλία'                                                   => 'pt',
    'ΠουέρτοΡίκο'                                                 => 'pr',
    'ΠράσινοΑκρωτήριο'                                       => 'cv',
    'Ρεϋνιόν'                                                         => 're',
    'Ρουάντα'                                                         => 'rw',
    'Ρουμανία'                                                       => 'ro',
    'Ρωσία'                                                             => 'ru',
    'ΣάοΤομέκαιΠρίνσιπε'                                   => 'st',
    'ΣαιντΚιτςκαιΝέβις'                                     => 'kn',
    'ΣαιντΠιέρκαιΜικελόν'                                 => 'pm',
    'Σαμόα'                                                             => 'ws',
    'ΣαουδικήΑραβία'                                           => 'sa',
    'ΣβαλμπάρντκαιΓιανΜαγιέν'                         => 'sj',
    'Σενεγάλη'                                                       => 'sn',
    'Σερβία'                                                           => 'rs',
    'ΣερβίακαιΜαυροβούνιο'                               => 'cs',
    'Σεϋχέλλες'                                                     => 'sc',
    'ΣιέραΛεόνε'                                                   => 'sl',
    'Σιγκαπούρη'                                                   => 'sg',
    'Σλοβακία'                                                       => 'sk',
    'Σλοβενία'                                                       => 'si',
    'Σομαλία'                                                         => 'so',
    'Σουαζιλάνδη'                                                 => 'sz',
    'Σουδάν'                                                           => 'sd',
    'Σουηδία'                                                         => 'se',
    'Σουρινάμ'                                                       => 'sr',
    'ΣριΛάνκα'                                                       => 'lk',
    'Συρία'                                                             => 'sy',
    'Τανζανία'                                                       => 'tz',
    'Τατζικιστάν'                                                 => 'tj',
    'Ταϊβάν'                                                           => 'tw',
    'Ταϊλάνδη'                                                       => 'th',
    'Τζαμάικα'                                                       => 'jm',
    'Τζιμπουτί'                                                     => 'dj',
    'Τοκελάου'                                                       => 'tk',
    'Τουβαλού'                                                       => 'tv',
    'Τουρκία'                                                         => 'tr',
    'Τουρκμενιστάν'                                             => 'tm',
    'ΤρινιντάντκαιΤομπάγκο'                             => 'tt',
    'Τσαντ'                                                             => 'td',
    'Τσεχία'                                                           => 'cz',
    'Τυνησία'                                                         => 'tn',
    'Τόγκο'                                                             => 'tg',
    'Τόνγκα'                                                           => 'to',
    'Υεμένη'                                                           => 'ye',
    'Υερσέη'                                                           => 'je',
    'Φίτζι'                                                             => 'fj',
    'Φιλιππίνες'                                                   => 'ph',
    'Φινλανδία'                                                     => 'fi',
    'Χιλή'                                                               => 'cl',
    'ΧονγκΚονγκ'                                                   => 'hk',
);

1;

