package Locales::DB::Territory::bg;

# Auto generated from CLDR

$Locales::DB::Territory::bg::VERSION = '0.02';

$Locales::DB::Territory::bg::cldr_version = '1.7.1';

%Locales::DB::Territory::bg::code_to_name = (
    'ad' => 'Андора',
    'ae' => "Обединени\ арабски\ емирства",
    'af' => 'Афганистан',
    'ag' => "Антигуа\ и\ Барбуда",
    'ai' => 'Ангуила',
    'al' => 'Албания',
    'am' => 'Армения',
    'an' => "Холандски\ Антили",
    'ao' => 'Ангола',
    'aq' => 'Антарктика',
    'ar' => 'Аржентина',
    'as' => "Американско\ Самоа",
    'at' => 'Австрия',
    'au' => 'Австралия',
    'aw' => 'Аруба',
    'ax' => "Аландски\ о\-ви",
    'az' => 'Азербайджан',
    'ba' => "Босна\ и\ Херцеговина",
    'bb' => 'Барбадос',
    'bd' => 'Бангладеш',
    'be' => 'Белгия',
    'bf' => "Буркина\ Фасо",
    'bg' => 'България',
    'bh' => 'Бахрейн',
    'bi' => 'Бурунди',
    'bj' => 'Бенин',
    'bl' => "Сейнт\ Бартоломей",
    'bm' => 'Бермуда',
    'bn' => "Бруней\ Дарусалам",
    'bo' => 'Боливия',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Бразилия',
    'bs' => 'Бахами',
    'bt' => 'Бутан',
    'bv' => "Остров\ Буве",
    'bw' => 'Ботсуана',
    'by' => 'Беларус',
    'bz' => 'Белиз',
    'ca' => 'Канада',
    'cc' => "Кокосови\ \(Кийлинг\)\ острови",
    'cd' => "Демократична\ република\ Конго",
    'cf' => "Централноафриканска\ Република",
    'cg' => 'Конго',
    'ch' => 'Швейцария',
    'ci' => "Бряг\ на\ слоновата\ кост",
    'ck' => "Острови\ Кук",
    'cl' => 'Чили',
    'cm' => 'Камерун',
    'cn' => 'Китай',
    'co' => 'Колумбия',
    'cr' => "Коста\ Рика",
    'cs' => "Сърбия\ и\ Черна\ гора",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Куба',
    'cv' => "Кабо\ Верде",
    'cx' => "Остров\ Кристмас",
    'cy' => 'Кипър',
    'cz' => "Чешка\ република",
    'dd' => "East\ Germany",
    'de' => 'Германия',
    'dj' => 'Джибути',
    'dk' => 'Дания',
    'dm' => 'Доминика',
    'do' => "Доминиканска\ република",
    'dz' => 'Алжир',
    'ec' => 'Еквадор',
    'ee' => 'Естония',
    'eg' => 'Египет',
    'eh' => "Западна\ Сахара",
    'er' => 'Еритрея',
    'es' => 'Испания',
    'et' => 'Етиопия',
    'fi' => 'Финландия',
    'fj' => 'Фиджи',
    'fk' => "Фолклендски\ острови",
    'fm' => "Микронезия\,\ Обединени\ Щати",
    'fo' => "Фарьорски\ острови",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Франция',
    'fx' => "Metropolitan\ France",
    'ga' => 'Габон',
    'gb' => "Обединено\ кралство",
    'gd' => 'Гренада',
    'ge' => 'Грузия',
    'gf' => "Френска\ Гвиана",
    'gg' => "о\.\ Гърнзи",
    'gh' => 'Гана',
    'gi' => 'Гибралтар',
    'gl' => 'Гренландия',
    'gm' => 'Гамбия',
    'gn' => 'Гвинея',
    'gp' => 'Гваделупа',
    'gq' => "Екваториална\ Гвинея",
    'gr' => 'Гърция',
    'gs' => "Южна\ Джорджия\ и\ Южни\ Сандвичеви\ Острови",
    'gt' => 'Гватемала',
    'gu' => 'Гуам',
    'gw' => "Гвинея\-Бисау",
    'gy' => 'Гвиана',
    'hk' => "Хонг\-Конг",
    'hm' => "Остров\ Хърд\ и\ Острови\ Макдоналд",
    'hn' => 'Хондурас',
    'hr' => 'Хърватска',
    'ht' => 'Хаити',
    'hu' => 'Унгария',
    'id' => 'Индонезия',
    'ie' => 'Ирландия',
    'il' => 'Израел',
    'im' => "Острови\ Ман",
    'in' => 'Индия',
    'io' => "Британски\ територии\ в\ Индийския\ океан",
    'iq' => 'Ирак',
    'ir' => "Иран\,\ Ислямска\ република",
    'is' => 'Исландия',
    'it' => 'Италия',
    'je' => "о\.\ Джързи",
    'jm' => 'Ямайка',
    'jo' => 'Йордания',
    'jp' => 'Япония',
    'jt' => "Johnston\ Island",
    'ke' => 'Кения',
    'kg' => 'Киргизстан',
    'kh' => 'Камбоджа',
    'ki' => 'Кирибати',
    'km' => 'Комори',
    'kn' => "Сейнт\ Китс\ и\ Невис",
    'kp' => "Корея\,\ Северна",
    'kr' => "Корея\,\ Южна",
    'kw' => 'Кувейт',
    'ky' => "Кайманови\ острови",
    'kz' => 'Казахстан',
    'la' => "Народна\ демократична\ република\ Лаос",
    'lb' => 'Ливан',
    'lc' => "Сейнт\ Лусия",
    'li' => 'Лихтенщайн',
    'lk' => "Шри\ Ланка",
    'lr' => 'Либерия',
    'ls' => 'Лесото',
    'lt' => 'Литва',
    'lu' => 'Люксембург',
    'lv' => 'Латвия',
    'ly' => "Либийска\ арабска\ джамахирия",
    'ma' => 'Мароко',
    'mc' => 'Монако',
    'md' => "Молдова\,\ Република",
    'me' => "Черна\ гора",
    'mf' => "Сейнт\ Мартин",
    'mg' => 'Мадагаскар',
    'mh' => "Маршалови\ острови",
    'mi' => "Midway\ Islands",
    'mk' => "Македония\,\ Република",
    'ml' => 'Мали',
    'mm' => 'Мианмар',
    'mn' => 'Монголия',
    'mo' => 'Макао',
    'mp' => "Северни\ Мариански\ Острови",
    'mq' => 'Мартиника',
    'mr' => 'Мавритания',
    'ms' => 'Монсерат',
    'mt' => 'Малта',
    'mu' => 'Мавриций',
    'mv' => 'Малдиви',
    'mw' => 'Малави',
    'mx' => 'Мексико',
    'my' => 'Малайзия',
    'mz' => 'Мозамбик',
    'na' => 'Намибия',
    'nc' => "Нова\ Каледония",
    'ne' => 'Нигер',
    'nf' => "Остров\ Норфолк",
    'ng' => 'Нигерия',
    'ni' => 'Никарагуа',
    'nl' => 'Холандия',
    'no' => 'Норвегия',
    'np' => 'Непал',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Науру',
    'nt' => "Neutral\ Zone",
    'nu' => 'Ниуе',
    'nz' => "Нова\ Зеландия",
    'om' => 'Оман',
    'pa' => 'Панама',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Перу',
    'pf' => "Френска\ Полинезия",
    'pg' => "Папуа\ Нова\ Гвинея",
    'ph' => 'Филипини',
    'pk' => 'Пакистан',
    'pl' => 'Полша',
    'pm' => "Сен\ Пиер\ и\ Мигелон",
    'pn' => 'Питкайрн',
    'pr' => "Пуерто\ Рико",
    'ps' => "Палестински\ територии",
    'pt' => 'Португалия',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Палау',
    'py' => 'Парагвай',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Катар',
    'qo' => "Океания\ \[QO\]",
    'qu' => "Европейски\ съюз",
    're' => 'Реюниън',
    'ro' => 'Румъния',
    'rs' => 'Сърбия',
    'ru' => "Руска\ федерация",
    'rw' => 'Руанда',
    'sa' => "Саудитска\ Арабия",
    'sb' => "Соломонови\ острови",
    'sc' => 'Сейшели',
    'sd' => 'Судан',
    'se' => 'Швеция',
    'sg' => 'Сингапур',
    'sh' => "Света\ Елена",
    'si' => 'Словения',
    'sj' => "Свалбард\ и\ Ян\ Майен",
    'sk' => 'Словакия',
    'sl' => "Сиера\ Леоне",
    'sm' => "Сан\ Марино",
    'sn' => 'Сенегал',
    'so' => 'Сомалия',
    'sr' => 'Суринам',
    'st' => "Сао\ Томе\ и\ Принципе",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "Ел\ Салвадор",
    'sy' => "Сирийска\ арабска\ република",
    'sz' => 'Суазиленд',
    'tc' => "Острови\ Туркс\ и\ Кайкос",
    'td' => 'Чад',
    'tf' => "Френски\ южни\ територии",
    'tg' => 'Того',
    'th' => 'Тайланд',
    'tj' => 'Таджикистан',
    'tk' => 'Токелау',
    'tl' => "Източен\ Тимор",
    'tm' => 'Туркменистан',
    'tn' => 'Тунис',
    'to' => 'Тонга',
    'tr' => 'Турция',
    'tt' => "Тринидад\ и\ Тобаго",
    'tv' => 'Тувалу',
    'tw' => 'Тайван',
    'tz' => 'Танзания',
    'ua' => 'Украйна',
    'ug' => 'Уганда',
    'um' => "САЩ\ \-\ външни\ острови",
    'us' => 'САЩ',
    'uy' => 'Уругвай',
    'uz' => 'Узбекистан',
    'va' => "Свещено\ море\ \(Ватиканска\ държава\)",
    'vc' => "Сейнт\ Винсънт\ и\ Гренадини",
    'vd' => "North\ Vietnam",
    've' => 'Венецуела',
    'vg' => "Британски\ Вирджински\ острони",
    'vi' => "САЩ\,\ Вирджински\ острови",
    'vn' => 'Виетнам',
    'vu' => 'Вануату',
    'wf' => "Уолис\ и\ Футуна",
    'wk' => "Wake\ Island",
    'ws' => 'Самоа',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Йемен',
    'yt' => 'Мейот',
    'za' => "Южна\ Африка",
    'zm' => 'Замбия',
    'zw' => 'Зимбабве',
    'zz' => "Непозната\ или\ несъществуваща\ област",
);

%Locales::DB::Territory::bg::name_to_code = (
    'britishantarcticterritory'                                            => 'bq',
    'cantonandenderburyislands'                                            => 'ct',
    'dronningmaudland'                                                     => 'nq',
    'eastgermany'                                                          => 'dd',
    'frenchsouthernandantarcticterritories'                                => 'fq',
    'johnstonisland'                                                       => 'jt',
    'metropolitanfrance'                                                   => 'fx',
    'midwayislands'                                                        => 'mi',
    'neutralzone'                                                          => 'nt',
    'northvietnam'                                                         => 'vd',
    'pacificislandstrustterritory'                                         => 'pc',
    'panamacanalzone'                                                      => 'pz',
    'peoplesdemocraticrepublicofyemen'                                     => 'yd',
    "u\.s\.miscellaneouspacificislands"                                    => 'pu',
    'unionofsovietsocialistrepublics'                                      => 'su',
    'wakeisland'                                                           => 'wk',
    'Австралия'                                                   => 'au',
    'Австрия'                                                       => 'at',
    'Азербайджан'                                               => 'az',
    'Аландскиови'                                               => 'ax',
    'Албания'                                                       => 'al',
    'Алжир'                                                           => 'dz',
    'АмериканскоСамоа'                                     => 'as',
    'Ангола'                                                         => 'ao',
    'Ангуила'                                                       => 'ai',
    'Андора'                                                         => 'ad',
    'Антарктика'                                                 => 'aq',
    'АнтигуаиБарбуда'                                       => 'ag',
    'Аржентина'                                                   => 'ar',
    'Армения'                                                       => 'am',
    'Аруба'                                                           => 'aw',
    'Афганистан'                                                 => 'af',
    'Бангладеш'                                                   => 'bd',
    'Барбадос'                                                     => 'bb',
    'Бахами'                                                         => 'bs',
    'Бахрейн'                                                       => 'bh',
    'Беларус'                                                       => 'by',
    'Белгия'                                                         => 'be',
    'Белиз'                                                           => 'bz',
    'Бенин'                                                           => 'bj',
    'Бермуда'                                                       => 'bm',
    'Боливия'                                                       => 'bo',
    'БоснаиХерцеговина'                                   => 'ba',
    'Ботсуана'                                                     => 'bw',
    'Бразилия'                                                     => 'br',
    'БританскиВирджинскиострони'                 => 'vg',
    'БританскитериториивИндийскияокеан'   => 'io',
    'БрунейДарусалам'                                       => 'bn',
    'Брягнаслоноватакост'                               => 'ci',
    'БуркинаФасо'                                               => 'bf',
    'Бурунди'                                                       => 'bi',
    'Бутан'                                                           => 'bt',
    'България'                                                     => 'bg',
    'Вануату'                                                       => 'vu',
    'Венецуела'                                                   => 've',
    'Виетнам'                                                       => 'vn',
    'Габон'                                                           => 'ga',
    'Гамбия'                                                         => 'gm',
    'Гана'                                                             => 'gh',
    'Гваделупа'                                                   => 'gp',
    'Гватемала'                                                   => 'gt',
    'Гвиана'                                                         => 'gy',
    'Гвинея'                                                         => 'gn',
    'ГвинеяБисау'                                               => 'gw',
    'Германия'                                                     => 'de',
    'Гибралтар'                                                   => 'gi',
    'Гренада'                                                       => 'gd',
    'Гренландия'                                                 => 'gl',
    'Грузия'                                                         => 'ge',
    'Гуам'                                                             => 'gu',
    'Гърция'                                                         => 'gr',
    'Дания'                                                           => 'dk',
    'ДемократичнарепубликаКонго'                 => 'cd',
    'Джибути'                                                       => 'dj',
    'Доминика'                                                     => 'dm',
    'Доминиканскарепублика'                           => 'do',
    'Европейскисъюз'                                         => 'qu',
    'Египет'                                                         => 'eg',
    'Еквадор'                                                       => 'ec',
    'ЕкваториалнаГвинея'                                 => 'gq',
    'ЕлСалвадор'                                                 => 'sv',
    'Еритрея'                                                       => 'er',
    'Естония'                                                       => 'ee',
    'Етиопия'                                                       => 'et',
    'Замбия'                                                         => 'zm',
    'ЗападнаСахара'                                           => 'eh',
    'Зимбабве'                                                     => 'zw',
    'Израел'                                                         => 'il',
    'ИзточенТимор'                                             => 'tl',
    'Индия'                                                           => 'in',
    'Индонезия'                                                   => 'id',
    'Ирак'                                                             => 'iq',
    "Иран\,Ислямскарепублика"                         => 'ir',
    'Ирландия'                                                     => 'ie',
    'Исландия'                                                     => 'is',
    'Испания'                                                       => 'es',
    'Италия'                                                         => 'it',
    'Йемен'                                                           => 'ye',
    'Йордания'                                                     => 'jo',
    'КабоВерде'                                                   => 'cv',
    'Казахстан'                                                   => 'kz',
    'Каймановиострови'                                     => 'ky',
    'Камбоджа'                                                     => 'kh',
    'Камерун'                                                       => 'cm',
    'Канада'                                                         => 'ca',
    'Катар'                                                           => 'qa',
    'Кения'                                                           => 'ke',
    'Кипър'                                                           => 'cy',
    'Киргизстан'                                                 => 'kg',
    'Кирибати'                                                     => 'ki',
    'Китай'                                                           => 'cn',
    'КокосовиКийлингострови'                         => 'cc',
    'Колумбия'                                                     => 'co',
    'Комори'                                                         => 'km',
    'Конго'                                                           => 'cg',
    "Корея\,Северна"                                           => 'kp',
    "Корея\,Южна"                                                 => 'kr',
    'КостаРика'                                                   => 'cr',
    'Куба'                                                             => 'cu',
    'Кувейт'                                                         => 'kw',
    'Латвия'                                                         => 'lv',
    'Лесото'                                                         => 'ls',
    'Либерия'                                                       => 'lr',
    'Либийскаарабскаджамахирия'                   => 'ly',
    'Ливан'                                                           => 'lb',
    'Литва'                                                           => 'lt',
    'Лихтенщайн'                                                 => 'li',
    'Люксембург'                                                 => 'lu',
    'Мавритания'                                                 => 'mr',
    'Мавриций'                                                     => 'mu',
    'Мадагаскар'                                                 => 'mg',
    'Макао'                                                           => 'mo',
    "Македония\,Република"                               => 'mk',
    'Малави'                                                         => 'mw',
    'Малайзия'                                                     => 'my',
    'Малдиви'                                                       => 'mv',
    'Мали'                                                             => 'ml',
    'Малта'                                                           => 'mt',
    'Мароко'                                                         => 'ma',
    'Мартиника'                                                   => 'mq',
    'Маршаловиострови'                                     => 'mh',
    'Мейот'                                                           => 'yt',
    'Мексико'                                                       => 'mx',
    'Мианмар'                                                       => 'mm',
    "Микронезия\,ОбединениЩати"                     => 'fm',
    'Мозамбик'                                                     => 'mz',
    "Молдова\,Република"                                   => 'md',
    'Монако'                                                         => 'mc',
    'Монголия'                                                     => 'mn',
    'Монсерат'                                                     => 'ms',
    'Намибия'                                                       => 'na',
    'НароднадемократичнарепубликаЛаос'     => 'la',
    'Науру'                                                           => 'nr',
    'Непал'                                                           => 'np',
    'Непознатаилинесъществуващаобласт'     => 'zz',
    'Нигер'                                                           => 'ne',
    'Нигерия'                                                       => 'ng',
    'Никарагуа'                                                   => 'ni',
    'Ниуе'                                                             => 'nu',
    'НоваЗеландия'                                             => 'nz',
    'НоваКаледония'                                           => 'nc',
    'Норвегия'                                                     => 'no',
    'Обединениарабскиемирства'                     => 'ae',
    'Обединенокралство'                                   => 'gb',
    'Океанияqo'                                                     => 'qo',
    'Оман'                                                             => 'om',
    'ОстровБуве'                                                 => 'bv',
    'ОстровКристмас'                                         => 'cx',
    'ОстровНорфолк'                                           => 'nf',
    'ОстровХърдиОстровиМакдоналд'               => 'hm',
    'ОстровиКук'                                                 => 'ck',
    'ОстровиМан'                                                 => 'im',
    'ОстровиТурксиКайкос'                               => 'tc',
    'Пакистан'                                                     => 'pk',
    'Палау'                                                           => 'pw',
    'Палестинскитеритории'                             => 'ps',
    'Панама'                                                         => 'pa',
    'ПапуаНоваГвинея'                                       => 'pg',
    'Парагвай'                                                     => 'py',
    'Перу'                                                             => 'pe',
    'Питкайрн'                                                     => 'pn',
    'Полша'                                                           => 'pl',
    'Португалия'                                                 => 'pt',
    'ПуертоРико'                                                 => 'pr',
    'Реюниън'                                                       => 're',
    'Руанда'                                                         => 'rw',
    'Румъния'                                                       => 'ro',
    'Рускафедерация'                                         => 'ru',
    'САЩ'                                                               => 'us',
    "САЩ\,Вирджинскиострови"                           => 'vi',
    'САЩвъншниострови'                                     => 'um',
    'Самоа'                                                           => 'ws',
    'СанМарино'                                                   => 'sm',
    'СаоТомеиПринципе'                                     => 'st',
    'СаудитскаАрабия'                                       => 'sa',
    'СвалбардиЯнМайен'                                     => 'sj',
    'СветаЕлена'                                                 => 'sh',
    'СвещеномореВатиканскадържава'             => 'va',
    'СеверниМарианскиОстрови'                       => 'mp',
    'СейнтБартоломей'                                       => 'bl',
    'СейнтВинсънтиГренадини'                         => 'vc',
    'СейнтКитсиНевис'                                       => 'kn',
    'СейнтЛусия'                                                 => 'lc',
    'СейнтМартин'                                               => 'mf',
    'Сейшели'                                                       => 'sc',
    'СенПиериМигелон'                                       => 'pm',
    'Сенегал'                                                       => 'sn',
    'СиераЛеоне'                                                 => 'sl',
    'Сингапур'                                                     => 'sg',
    'Сирийскаарабскарепублика'                     => 'sy',
    'Словакия'                                                     => 'sk',
    'Словения'                                                     => 'si',
    'Соломоновиострови'                                   => 'sb',
    'Сомалия'                                                       => 'so',
    'Суазиленд'                                                   => 'sz',
    'Судан'                                                           => 'sd',
    'Суринам'                                                       => 'sr',
    'Сърбия'                                                         => 'rs',
    'СърбияиЧернагора'                                     => 'cs',
    'Таджикистан'                                               => 'tj',
    'Тайван'                                                         => 'tw',
    'Тайланд'                                                       => 'th',
    'Танзания'                                                     => 'tz',
    'Того'                                                             => 'tg',
    'Токелау'                                                       => 'tk',
    'Тонга'                                                           => 'to',
    'ТринидадиТобаго'                                       => 'tt',
    'Тувалу'                                                         => 'tv',
    'Тунис'                                                           => 'tn',
    'Туркменистан'                                             => 'tm',
    'Турция'                                                         => 'tr',
    'Уганда'                                                         => 'ug',
    'Узбекистан'                                                 => 'uz',
    'Украйна'                                                       => 'ua',
    'Унгария'                                                       => 'hu',
    'УолисиФутуна'                                             => 'wf',
    'Уругвай'                                                       => 'uy',
    'Фарьорскиострови'                                     => 'fo',
    'Фиджи'                                                           => 'fj',
    'Филипини'                                                     => 'ph',
    'Финландия'                                                   => 'fi',
    'Фолклендскиострови'                                 => 'fk',
    'Франция'                                                       => 'fr',
    'ФренскаГвиана'                                           => 'gf',
    'ФренскаПолинезия'                                     => 'pf',
    'Френскиюжнитеритории'                             => 'tf',
    'Хаити'                                                           => 'ht',
    'Холандия'                                                     => 'nl',
    'ХоландскиАнтили'                                       => 'an',
    'ХонгКонг'                                                     => 'hk',
    'Хондурас'                                                     => 'hn',
    'Хърватска'                                                   => 'hr',
    'ЦентралноафриканскаРепублика'             => 'cf',
    'Чад'                                                               => 'td',
    'Чернагора'                                                   => 'me',
    'Чешкарепублика'                                         => 'cz',
    'Чили'                                                             => 'cl',
    'Швейцария'                                                   => 'ch',
    'Швеция'                                                         => 'se',
    'ШриЛанка'                                                     => 'lk',
    'ЮжнаАфрика'                                                 => 'za',
    'ЮжнаДжорджияиЮжниСандвичевиОстрови' => 'gs',
    'Ямайка'                                                         => 'jm',
    'Япония'                                                         => 'jp',
    "о\.Гърнзи"                                                     => 'gg',
    "о\.Джързи"                                                     => 'je',
);

1;

