package Locales::DB::Territory::eu;

# Auto generated from CLDR

$Locales::DB::Territory::eu::VERSION = '0.02';

$Locales::DB::Territory::eu::cldr_version = '1.7.1';

%Locales::DB::Territory::eu::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "Arabiar\ Emirrerri\ Batuak",
    'af' => 'Afganistan',
    'ag' => "Antigua\ eta\ Barbuda",
    'ai' => 'Anguilla',
    'al' => 'Albania',
    'am' => 'Armenia',
    'an' => "Holandarren\ Antillak",
    'ao' => 'Angola',
    'aq' => 'Antartika',
    'ar' => 'Argentina',
    'as' => "Amerikar\ Samoa",
    'at' => 'Austria',
    'au' => 'Australia',
    'aw' => 'Aruba',
    'ax' => "Aland\ Uharteak",
    'az' => 'Azerbaijan',
    'ba' => "Bosnia\-Herzegovina",
    'bb' => 'Barbados',
    'bd' => 'Bangladesh',
    'be' => 'Belgika',
    'bf' => "Burkina\ Faso",
    'bg' => 'Bulgaria',
    'bh' => 'Bahrain',
    'bi' => 'Burundi',
    'bj' => 'Benin',
    'bl' => "Saint\ Barth\Ã\©lemy",
    'bm' => 'Bermuda',
    'bn' => 'Brunei',
    'bo' => 'Bolibia',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brasil',
    'bs' => 'Bahamak',
    'bt' => 'Bhutan',
    'bv' => "Bouvet\ Uhartea",
    'bw' => 'Botswana',
    'by' => 'Bielorrusia',
    'bz' => 'Belize',
    'ca' => 'Kanada',
    'cc' => "Cocos\ uharteak",
    'cd' => "Kongoko\ Errepublika\ Demokratikoa",
    'cf' => "Afrika\ Erdiko\ Errepublika",
    'cg' => 'Kongo',
    'ch' => 'Suitza',
    'ci' => "Boli\ Kosta",
    'ck' => "Cook\ uharteak",
    'cl' => 'Txile',
    'cm' => 'Kamerun',
    'cn' => 'Txina',
    'co' => 'Kolonbia',
    'cr' => "Costa\ Rica",
    'cs' => "Serbia\ eta\ Montenegro",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Kuba',
    'cv' => "Cabo\ Verde",
    'cx' => "Christmas\ uhartea",
    'cy' => 'Zipre',
    'cz' => "Txekiar\ errepublika",
    'dd' => "East\ Germany",
    'de' => 'Alemania',
    'dj' => 'Djibuti',
    'dk' => 'Danimarka',
    'dm' => 'Dominika',
    'do' => "Dominikar\ Errepublika",
    'dz' => 'Aljeria',
    'ec' => 'Ekuador',
    'ee' => 'Estonia',
    'eg' => 'Egipto',
    'eh' => "Mendebaldeko\ Sahara",
    'er' => 'Eritrea',
    'es' => 'Espainia',
    'et' => 'Etiopia',
    'fi' => 'Finlandia',
    'fj' => 'Fiji',
    'fk' => 'Malvinak',
    'fm' => 'Mikronesia',
    'fo' => "Faroe\ Uharteak",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Frantzia',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabon',
    'gb' => "Erresuma\ Batua",
    'gd' => 'Grenada',
    'ge' => 'Georgia',
    'gf' => "Guyana\ Frantsesa",
    'gg' => 'Guernsey',
    'gh' => 'Ghana',
    'gi' => 'Gibraltar',
    'gl' => 'Groenlandia',
    'gm' => 'Gambia',
    'gn' => 'Ginea',
    'gp' => 'Guadeloupe',
    'gq' => "Ekuatore\ Ginea",
    'gr' => 'Grezia',
    'gs' => "Hegoaldeko\ Georgia\ eta\ Hegoaldeko\ Sandwich\ uharteak",
    'gt' => 'Guatemala',
    'gu' => 'Guam',
    'gw' => "Ginea\-Bissau",
    'gy' => 'Guyana',
    'hk' => "Hong\ Kong",
    'hm' => "Heard\ eta\ McDonald\ Uharteak",
    'hn' => 'Honduras',
    'hr' => 'Kroazia',
    'ht' => 'Haiti',
    'hu' => 'Hungaria',
    'id' => 'Indonesia',
    'ie' => 'Irlanda',
    'il' => 'Israel',
    'im' => "Man\ uhartea",
    'in' => 'India',
    'io' => "Indiako\ Ozeanoko\ Britainiar\ Lurraldea",
    'iq' => 'Irak',
    'ir' => 'Iran',
    'is' => 'Islandia',
    'it' => 'Italia',
    'je' => 'Jersey',
    'jm' => 'Jamaika',
    'jo' => 'Jordania',
    'jp' => 'Japonia',
    'jt' => "Johnston\ Island",
    'ke' => 'Kenia',
    'kg' => 'Kirgizistan',
    'kh' => 'Kanbodia',
    'ki' => 'Kiribati',
    'km' => 'Komoreak',
    'kn' => "Saint\ Kitts\ eta\ Nevis",
    'kp' => "Ipar\ Korea",
    'kr' => "Hego\ Korea",
    'kw' => 'Kuwait',
    'ky' => "Kaiman\ Uharteak",
    'kz' => 'Kazakhstan',
    'la' => 'Laos',
    'lb' => 'Libano',
    'lc' => "Santa\ Luzia",
    'li' => 'Liechtenstein',
    'lk' => "Sri\ Lanka",
    'lr' => 'Liberia',
    'ls' => 'Lesotho',
    'lt' => 'Lituania',
    'lu' => 'Luxenburgo',
    'lv' => 'Letonia',
    'ly' => 'Libia',
    'ma' => 'Maroko',
    'mc' => 'Monako',
    'md' => 'Moldavia',
    'me' => 'Montenegro',
    'mf' => "Saint\ Martin",
    'mg' => 'Madagaskar',
    'mh' => "Marshall\ uharteak",
    'mi' => "Midway\ Islands",
    'mk' => 'Mazedonia',
    'ml' => 'Mali',
    'mm' => 'Birmania',
    'mn' => 'Mongolia',
    'mo' => 'Makau',
    'mp' => "Iparraldeko\ Mariana\ uharteak",
    'mq' => 'Martinique',
    'mr' => 'Mauritania',
    'ms' => 'Montserrat',
    'mt' => 'Malta',
    'mu' => 'Maurizio',
    'mv' => 'Maldivak',
    'mw' => 'Malawi',
    'mx' => 'Mexiko',
    'my' => 'Malasia',
    'mz' => 'Mozambike',
    'na' => 'Namibia',
    'nc' => "Kaledonia\ Berria",
    'ne' => 'Niger',
    'nf' => "Norfolk\ uhartea",
    'ng' => 'Nigeria',
    'ni' => 'Nikaragua',
    'nl' => 'Herbehereak',
    'no' => 'Norvegia',
    'np' => 'Nepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "Zeelanda\ Berria",
    'om' => 'Oman',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Peru',
    'pf' => "Polinesia\ Frantsesa",
    'pg' => "Papua\ Ginea\ Berria",
    'ph' => 'Filipinak',
    'pk' => 'Pakistan',
    'pl' => 'Polonia',
    'pm' => "Saint\-Pierre\ eta\ Mikelune",
    'pn' => "Pitcairn\ Islands",
    'pr' => "Puerto\ Rico",
    'ps' => 'Palestina',
    'pt' => 'Portugal',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paraguai',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Katar',
    'qo' => "Outlying\ Oceania",
    'qu' => "European\ Union",
    're' => "R\Ã\©union",
    'ro' => 'Errumania',
    'rs' => 'Serbia',
    'ru' => 'Errusia',
    'rw' => 'Ruanda',
    'sa' => "Saudi\ Arabia",
    'sb' => "Salomon\ uharteak",
    'sc' => 'Seychelleak',
    'sd' => 'Sudan',
    'se' => 'Suedia',
    'sg' => 'Singapur',
    'sh' => "Saint\ Helena",
    'si' => 'Eslovenia',
    'sj' => "Svalbard\ eta\ Jan\ Mayen\ uharteak",
    'sk' => 'Eslovakia',
    'sl' => "Sierra\ Leona",
    'sm' => "San\ Marino",
    'sn' => 'Senegal',
    'so' => 'Somalia',
    'sr' => 'Surinam',
    'st' => "Sao\ Tomé\ eta\ Principe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salvador",
    'sy' => 'Siria',
    'sz' => 'Swazilandia',
    'tc' => "Turk\ eta\ Caico\ uharteak",
    'td' => 'Txad',
    'tf' => "Frantziaren\ Lurralde\ Australak",
    'tg' => 'Togo',
    'th' => 'Tailandia',
    'tj' => 'Tadjikistan',
    'tk' => 'Tokelau',
    'tl' => "Ekialdeko\ Timor",
    'tm' => 'Turkmenistan',
    'tn' => 'Tunisia',
    'to' => 'Tonga',
    'tr' => 'Turkia',
    'tt' => "Trinidad\ eta\ Tobago",
    'tv' => 'Tuvalu',
    'tw' => 'Taiwan',
    'tz' => 'Tanzania',
    'ua' => 'Ukraina',
    'ug' => 'Uganda',
    'um' => "Estatu\ Batuetatik\ urruti\ dauden\ uharte\ txikiak",
    'us' => "Ameriketako\ Estatu\ Batuak",
    'uy' => 'Uruguai',
    'uz' => 'Uzbekistan',
    'va' => 'Vatikano',
    'vc' => "Saint\ Vincent\ eta\ Grenadinak",
    'vd' => "North\ Vietnam",
    've' => 'Venezuela',
    'vg' => "Birjina\ uharte\ britainiarrak",
    'vi' => "Birjina\ uharte\ amerikarrak",
    'vn' => 'Vietnam',
    'vu' => 'Vanuatu',
    'wf' => "Wallis\ eta\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Yemen',
    'yt' => 'Mayotte',
    'za' => 'Hegoafrika',
    'zm' => 'Zambia',
    'zw' => 'Zimbabwe',
    'zz' => "Unknown\ or\ Invalid\ Region",
);

%Locales::DB::Territory::eu::name_to_code = (
    'afganistan'                                     => 'af',
    'afrikaerdikoerrepublika'                        => 'cf',
    'alanduharteak'                                  => 'ax',
    'albania'                                        => 'al',
    'alemania'                                       => 'de',
    'aljeria'                                        => 'dz',
    'amerikarsamoa'                                  => 'as',
    'ameriketakoestatubatuak'                        => 'us',
    'andorra'                                        => 'ad',
    'angola'                                         => 'ao',
    'anguilla'                                       => 'ai',
    'antartika'                                      => 'aq',
    'antiguaetabarbuda'                              => 'ag',
    'arabiaremirrerribatuak'                         => 'ae',
    'argentina'                                      => 'ar',
    'armenia'                                        => 'am',
    'aruba'                                          => 'aw',
    'australia'                                      => 'au',
    'austria'                                        => 'at',
    'azerbaijan'                                     => 'az',
    'bahamak'                                        => 'bs',
    'bahrain'                                        => 'bh',
    'bangladesh'                                     => 'bd',
    'barbados'                                       => 'bb',
    'belgika'                                        => 'be',
    'belize'                                         => 'bz',
    'benin'                                          => 'bj',
    'bermuda'                                        => 'bm',
    'bhutan'                                         => 'bt',
    'bielorrusia'                                    => 'by',
    'birjinauharteamerikarrak'                       => 'vi',
    'birjinauhartebritainiarrak'                     => 'vg',
    'birmania'                                       => 'mm',
    'bolibia'                                        => 'bo',
    'bolikosta'                                      => 'ci',
    'bosniaherzegovina'                              => 'ba',
    'botswana'                                       => 'bw',
    'bouvetuhartea'                                  => 'bv',
    'brasil'                                         => 'br',
    'britishantarcticterritory'                      => 'bq',
    'brunei'                                         => 'bn',
    'bulgaria'                                       => 'bg',
    'burkinafaso'                                    => 'bf',
    'burundi'                                        => 'bi',
    'caboverde'                                      => 'cv',
    'cantonandenderburyislands'                      => 'ct',
    'christmasuhartea'                               => 'cx',
    'cocosuharteak'                                  => 'cc',
    'cookuharteak'                                   => 'ck',
    'costarica'                                      => 'cr',
    'danimarka'                                      => 'dk',
    'djibuti'                                        => 'dj',
    'dominika'                                       => 'dm',
    'dominikarerrepublika'                           => 'do',
    'dronningmaudland'                               => 'nq',
    'eastgermany'                                    => 'dd',
    'egipto'                                         => 'eg',
    'ekialdekotimor'                                 => 'tl',
    'ekuador'                                        => 'ec',
    'ekuatoreginea'                                  => 'gq',
    'elsalvador'                                     => 'sv',
    'eritrea'                                        => 'er',
    'erresumabatua'                                  => 'gb',
    'errumania'                                      => 'ro',
    'errusia'                                        => 'ru',
    'eslovakia'                                      => 'sk',
    'eslovenia'                                      => 'si',
    'espainia'                                       => 'es',
    'estatubatuetatikurrutidaudenuhartetxikiak'      => 'um',
    'estonia'                                        => 'ee',
    'etiopia'                                        => 'et',
    'europeanunion'                                  => 'qu',
    'faroeuharteak'                                  => 'fo',
    'fiji'                                           => 'fj',
    'filipinak'                                      => 'ph',
    'finlandia'                                      => 'fi',
    'frantzia'                                       => 'fr',
    'frantziarenlurraldeaustralak'                   => 'tf',
    'frenchsouthernandantarcticterritories'          => 'fq',
    'gabon'                                          => 'ga',
    'gambia'                                         => 'gm',
    'georgia'                                        => 'ge',
    'ghana'                                          => 'gh',
    'gibraltar'                                      => 'gi',
    'ginea'                                          => 'gn',
    'gineabissau'                                    => 'gw',
    'grenada'                                        => 'gd',
    'grezia'                                         => 'gr',
    'groenlandia'                                    => 'gl',
    'guadeloupe'                                     => 'gp',
    'guam'                                           => 'gu',
    'guatemala'                                      => 'gt',
    'guernsey'                                       => 'gg',
    'guyana'                                         => 'gy',
    'guyanafrantsesa'                                => 'gf',
    'haiti'                                          => 'ht',
    'heardetamcdonalduharteak'                       => 'hm',
    'hegoafrika'                                     => 'za',
    'hegoaldekogeorgiaetahegoaldekosandwichuharteak' => 'gs',
    'hegokorea'                                      => 'kr',
    'herbehereak'                                    => 'nl',
    'holandarrenantillak'                            => 'an',
    'honduras'                                       => 'hn',
    'hongkong'                                       => 'hk',
    'hungaria'                                       => 'hu',
    'india'                                          => 'in',
    'indiakoozeanokobritainiarlurraldea'             => 'io',
    'indonesia'                                      => 'id',
    'iparkorea'                                      => 'kp',
    'iparraldekomarianauharteak'                     => 'mp',
    'irak'                                           => 'iq',
    'iran'                                           => 'ir',
    'irlanda'                                        => 'ie',
    'islandia'                                       => 'is',
    'israel'                                         => 'il',
    'italia'                                         => 'it',
    'jamaika'                                        => 'jm',
    'japonia'                                        => 'jp',
    'jersey'                                         => 'je',
    'johnstonisland'                                 => 'jt',
    'jordania'                                       => 'jo',
    'kaimanuharteak'                                 => 'ky',
    'kaledoniaberria'                                => 'nc',
    'kamerun'                                        => 'cm',
    'kanada'                                         => 'ca',
    'kanbodia'                                       => 'kh',
    'katar'                                          => 'qa',
    'kazakhstan'                                     => 'kz',
    'kenia'                                          => 'ke',
    'kirgizistan'                                    => 'kg',
    'kiribati'                                       => 'ki',
    'kolonbia'                                       => 'co',
    'komoreak'                                       => 'km',
    'kongo'                                          => 'cg',
    'kongokoerrepublikademokratikoa'                 => 'cd',
    'kroazia'                                        => 'hr',
    'kuba'                                           => 'cu',
    'kuwait'                                         => 'kw',
    'laos'                                           => 'la',
    'lesotho'                                        => 'ls',
    'letonia'                                        => 'lv',
    'libano'                                         => 'lb',
    'liberia'                                        => 'lr',
    'libia'                                          => 'ly',
    'liechtenstein'                                  => 'li',
    'lituania'                                       => 'lt',
    'luxenburgo'                                     => 'lu',
    'madagaskar'                                     => 'mg',
    'makau'                                          => 'mo',
    'malasia'                                        => 'my',
    'malawi'                                         => 'mw',
    'maldivak'                                       => 'mv',
    'mali'                                           => 'ml',
    'malta'                                          => 'mt',
    'malvinak'                                       => 'fk',
    'manuhartea'                                     => 'im',
    'maroko'                                         => 'ma',
    'marshalluharteak'                               => 'mh',
    'martinique'                                     => 'mq',
    'mauritania'                                     => 'mr',
    'maurizio'                                       => 'mu',
    'mayotte'                                        => 'yt',
    'mazedonia'                                      => 'mk',
    'mendebaldekosahara'                             => 'eh',
    'metropolitanfrance'                             => 'fx',
    'mexiko'                                         => 'mx',
    'midwayislands'                                  => 'mi',
    'mikronesia'                                     => 'fm',
    'moldavia'                                       => 'md',
    'monako'                                         => 'mc',
    'mongolia'                                       => 'mn',
    'montenegro'                                     => 'me',
    'montserrat'                                     => 'ms',
    'mozambike'                                      => 'mz',
    'namibia'                                        => 'na',
    'nauru'                                          => 'nr',
    'nepal'                                          => 'np',
    'neutralzone'                                    => 'nt',
    'niger'                                          => 'ne',
    'nigeria'                                        => 'ng',
    'nikaragua'                                      => 'ni',
    'niue'                                           => 'nu',
    'norfolkuhartea'                                 => 'nf',
    'northvietnam'                                   => 'vd',
    'norvegia'                                       => 'no',
    'oman'                                           => 'om',
    'outlyingoceania'                                => 'qo',
    'pacificislandstrustterritory'                   => 'pc',
    'pakistan'                                       => 'pk',
    'palau'                                          => 'pw',
    'palestina'                                      => 'ps',
    'panama'                                         => 'pa',
    'panamacanalzone'                                => 'pz',
    'papuagineaberria'                               => 'pg',
    'paraguai'                                       => 'py',
    'peoplesdemocraticrepublicofyemen'               => 'yd',
    'peru'                                           => 'pe',
    'pitcairnislands'                                => 'pn',
    'polinesiafrantsesa'                             => 'pf',
    'polonia'                                        => 'pl',
    'portugal'                                       => 'pt',
    'puertorico'                                     => 'pr',
    'ruanda'                                         => 'rw',
    "r\Ã\©union"                                   => 're',
    "saintbarth\Ã\©lemy"                           => 'bl',
    'sainthelena'                                    => 'sh',
    'saintkittsetanevis'                             => 'kn',
    'saintmartin'                                    => 'mf',
    'saintpierreetamikelune'                         => 'pm',
    'saintvincentetagrenadinak'                      => 'vc',
    'salomonuharteak'                                => 'sb',
    'samoa'                                          => 'ws',
    'sanmarino'                                      => 'sm',
    'santaluzia'                                     => 'lc',
    'saotoméetaprincipe'                            => 'st',
    'saudiarabia'                                    => 'sa',
    'senegal'                                        => 'sn',
    'serbia'                                         => 'rs',
    'serbiaetamontenegro'                            => 'cs',
    'seychelleak'                                    => 'sc',
    'sierraleona'                                    => 'sl',
    'singapur'                                       => 'sg',
    'siria'                                          => 'sy',
    'somalia'                                        => 'so',
    'srilanka'                                       => 'lk',
    'sudan'                                          => 'sd',
    'suedia'                                         => 'se',
    'suitza'                                         => 'ch',
    'surinam'                                        => 'sr',
    'svalbardetajanmayenuharteak'                    => 'sj',
    'swazilandia'                                    => 'sz',
    'tadjikistan'                                    => 'tj',
    'tailandia'                                      => 'th',
    'taiwan'                                         => 'tw',
    'tanzania'                                       => 'tz',
    'togo'                                           => 'tg',
    'tokelau'                                        => 'tk',
    'tonga'                                          => 'to',
    'trinidadetatobago'                              => 'tt',
    'tunisia'                                        => 'tn',
    'turketacaicouharteak'                           => 'tc',
    'turkia'                                         => 'tr',
    'turkmenistan'                                   => 'tm',
    'tuvalu'                                         => 'tv',
    'txad'                                           => 'td',
    'txekiarerrepublika'                             => 'cz',
    'txile'                                          => 'cl',
    'txina'                                          => 'cn',
    "u\.s\.miscellaneouspacificislands"              => 'pu',
    'uganda'                                         => 'ug',
    'ukraina'                                        => 'ua',
    'unionofsovietsocialistrepublics'                => 'su',
    'unknownorinvalidregion'                         => 'zz',
    'uruguai'                                        => 'uy',
    'uzbekistan'                                     => 'uz',
    'vanuatu'                                        => 'vu',
    'vatikano'                                       => 'va',
    'venezuela'                                      => 've',
    'vietnam'                                        => 'vn',
    'wakeisland'                                     => 'wk',
    'wallisetafutuna'                                => 'wf',
    'yemen'                                          => 'ye',
    'zambia'                                         => 'zm',
    'zeelandaberria'                                 => 'nz',
    'zimbabwe'                                       => 'zw',
    'zipre'                                          => 'cy',
);

1;

