package Locales::DB::Territory::ar;

# Auto generated from CLDR

$Locales::DB::Territory::ar::VERSION = '0.02';

$Locales::DB::Territory::ar::cldr_version = '1.7.1';

%Locales::DB::Territory::ar::code_to_name = (
    'ad' => 'أندورا',
    'ae' => "الامارات\ العربية\ المتحدة",
    'af' => 'أفغانستان',
    'ag' => "أنتيجوا\ وبربودا",
    'ai' => 'أنجويلا',
    'al' => 'ألبانيا',
    'am' => 'أرمينيا',
    'an' => "جزر\ الأنتيل\ الهولندية",
    'ao' => 'أنجولا',
    'aq' => "القطب\ الجنوبي",
    'ar' => 'الأرجنتين',
    'as' => "ساموا\ الأمريكية",
    'at' => 'النمسا',
    'au' => 'أستراليا',
    'aw' => 'آروبا',
    'ax' => "جزر\ أولان",
    'az' => 'أذربيجان',
    'ba' => "البوسنة\ والهرسك",
    'bb' => 'بربادوس',
    'bd' => 'بنجلاديش',
    'be' => 'بلجيكا',
    'bf' => "بوركينا\ فاسو",
    'bg' => 'بلغاريا',
    'bh' => 'البحرين',
    'bi' => 'بوروندي',
    'bj' => 'بنين',
    'bl' => "Saint\ Barth\Ã\©lemy",
    'bm' => 'برمودا',
    'bn' => 'بروناي',
    'bo' => 'بوليفيا',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'البرازيل',
    'bs' => 'الباهاما',
    'bt' => 'بوتان',
    'bv' => "جزيرة\ بوفيه",
    'bw' => 'بتسوانا',
    'by' => "روسيا\ البيضاء",
    'bz' => 'بليز',
    'ca' => 'كندا',
    'cc' => "جزر\ كوكوس",
    'cd' => "جمهورية\ الكونغو\ الديمقراطية",
    'cf' => "جمهورية\ إفريقيا\ الوسطى",
    'cg' => "الكونغو\ \-\ برازافيل",
    'ch' => 'سويسرا',
    'ci' => "ساحل\ العاج",
    'ck' => "جزر\ كوك",
    'cl' => 'شيلي',
    'cm' => 'الكاميرون',
    'cn' => 'الصين',
    'co' => 'كولومبيا',
    'cr' => 'كوستاريكا',
    'cs' => "صربيا\ والجبل\ الأسود",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'كوبا',
    'cv' => "الرأس\ الأخضر",
    'cx' => "جزيرة\ الكريسماس",
    'cy' => 'قبرص',
    'cz' => "جمهورية\ التشيك",
    'dd' => "East\ Germany",
    'de' => 'ألمانيا',
    'dj' => 'جيبوتي',
    'dk' => 'الدانمرك',
    'dm' => 'دومينيكا',
    'do' => "جمهورية\ الدومينيك",
    'dz' => 'الجزائر',
    'ec' => 'الإكوادور',
    'ee' => 'استونيا',
    'eg' => 'مصر',
    'eh' => "الصحراء\ الغربية",
    'er' => 'أريتريا',
    'es' => 'أسبانيا',
    'et' => 'إثيوبيا',
    'fi' => 'فنلندا',
    'fj' => 'فيجي',
    'fk' => "جزر\ فوكلاند",
    'fm' => 'ميكرونيزيا',
    'fo' => "جزر\ فارو",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'فرنسا',
    'fx' => "Metropolitan\ France",
    'ga' => 'الجابون',
    'gb' => "المملكة\ المتحدة",
    'gd' => 'جرينادا',
    'ge' => 'جورجيا',
    'gf' => 'غويانا',
    'gg' => 'Guernsey',
    'gh' => 'غانا',
    'gi' => "جبل\ طارق",
    'gl' => 'جرينلاند',
    'gm' => 'غامبيا',
    'gn' => 'غينيا',
    'gp' => 'جوادلوب',
    'gq' => "غينيا\ الاستوائية",
    'gr' => 'اليونان',
    'gs' => "جورجيا\ الجنوبية\ وجزر\ ساندويتش\ الجنوبية",
    'gt' => 'جواتيمالا',
    'gu' => 'جوام',
    'gw' => "غينيا\ بيساو",
    'gy' => 'غيانا',
    'hk' => "هونج\ كونج",
    'hm' => "جزيرة\ هيرد\ وماكدونالد",
    'hn' => 'هندوراس',
    'hr' => 'كرواتيا',
    'ht' => 'هايتي',
    'hu' => 'المجر',
    'id' => 'اندونيسيا',
    'ie' => 'أيرلندا',
    'il' => 'إسرائيل',
    'im' => "جزيرة\ مان",
    'in' => 'الهند',
    'io' => "المحيط\ الهندي\ البريطاني",
    'iq' => 'العراق',
    'ir' => 'إيران',
    'is' => 'أيسلندا',
    'it' => 'إيطاليا',
    'je' => 'جيرسي',
    'jm' => 'جامايكا',
    'jo' => 'الأردن',
    'jp' => 'اليابان',
    'jt' => "Johnston\ Island",
    'ke' => 'كينيا',
    'kg' => 'قرغيزستان',
    'kh' => 'كمبوديا',
    'ki' => 'كيريباتي',
    'km' => "جزر\ القمر",
    'kn' => "سانت\ كيتس\ ونيفيس",
    'kp' => "كوريا\ الشمالية",
    'kr' => "كوريا\ الجنوبية",
    'kw' => 'الكويت',
    'ky' => "جزر\ الكايمن",
    'kz' => 'كازاخستان',
    'la' => 'لاوس',
    'lb' => 'لبنان',
    'lc' => "سانت\ لوسيا",
    'li' => 'ليختنشتاين',
    'lk' => 'سريلانكا',
    'lr' => 'ليبيريا',
    'ls' => 'ليسوتو',
    'lt' => 'ليتوانيا',
    'lu' => 'لوكسمبورج',
    'lv' => 'لاتفيا',
    'ly' => 'ليبيا',
    'ma' => 'المغرب',
    'mc' => 'موناكو',
    'md' => 'مولدافيا',
    'me' => "الجبل\ الأسود",
    'mf' => "سانت\ مارتين",
    'mg' => 'مدغشقر',
    'mh' => "جزر\ المارشال",
    'mi' => "Midway\ Islands",
    'mk' => 'مقدونيا',
    'ml' => 'مالي',
    'mm' => 'ميانمار',
    'mn' => 'منغوليا',
    'mo' => 'ماكاو',
    'mp' => "جزر\ ماريانا\ الشمالية",
    'mq' => 'مارتينيك',
    'mr' => 'موريتانيا',
    'ms' => 'مونتسرات',
    'mt' => 'مالطا',
    'mu' => 'موريشيوس',
    'mv' => "جزر\ الملديف",
    'mw' => 'ملاوي',
    'mx' => 'المكسيك',
    'my' => 'ماليزيا',
    'mz' => 'موزمبيق',
    'na' => 'ناميبيا',
    'nc' => "كاليدونيا\ الجديدة",
    'ne' => 'النيجر',
    'nf' => "جزيرة\ نورفوك",
    'ng' => 'نيجيريا',
    'ni' => 'نيكاراجوا',
    'nl' => 'هولندا',
    'no' => 'النرويج',
    'np' => 'نيبال',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'نورو',
    'nt' => "Neutral\ Zone",
    'nu' => 'نيوي',
    'nz' => 'نيوزيلاندا',
    'om' => 'عمان',
    'pa' => 'بنما',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'بيرو',
    'pf' => "بولينيزيا\ الفرنسية",
    'pg' => "بابوا\ غينيا\ الجديدة",
    'ph' => 'الفيلبين',
    'pk' => 'باكستان',
    'pl' => 'بولندا',
    'pm' => "سانت\ بيير\ وميكولون",
    'pn' => 'بتكايرن',
    'pr' => 'بورتوريكو',
    'ps' => 'فلسطين',
    'pt' => 'البرتغال',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'بالاو',
    'py' => 'باراجواي',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'قطر',
    'qo' => "أوقيانوسيا\ النائية",
    'qu' => "الاتحاد\ الأوروبي",
    're' => 'روينيون',
    'ro' => 'رومانيا',
    'rs' => 'صربيا',
    'ru' => 'روسيا',
    'rw' => 'رواندا',
    'sa' => "المملكة\ العربية\ السعودية",
    'sb' => "جزر\ سليمان",
    'sc' => 'سيشل',
    'sd' => 'السودان',
    'se' => 'السويد',
    'sg' => 'سنغافورة',
    'sh' => "سانت\ هيلنا",
    'si' => 'سلوفينيا',
    'sj' => "سفالبارد\ وجان\ مايان",
    'sk' => 'سلوفاكيا',
    'sl' => 'سيراليون',
    'sm' => "سان\ مارينو",
    'sn' => 'السنغال',
    'so' => 'الصومال',
    'sr' => 'سورينام',
    'st' => "ساو\ تومي\ وبرينسيبي",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => 'السلفادور',
    'sy' => 'سوريا',
    'sz' => 'سوازيلاند',
    'tc' => "جزر\ الترك\ وجايكوس",
    'td' => 'تشاد',
    'tf' => "المقاطعات\ الجنوبية\ الفرنسية",
    'tg' => 'توجو',
    'th' => 'تايلند',
    'tj' => 'طاجكستان',
    'tk' => 'توكيلو',
    'tl' => "تيمور\ الشرقية",
    'tm' => 'تركمانستان',
    'tn' => 'تونس',
    'to' => 'تونجا',
    'tr' => 'تركيا',
    'tt' => "ترينيداد\ وتوباغو",
    'tv' => 'توفالو',
    'tw' => 'تايوان',
    'tz' => 'تانزانيا',
    'ua' => 'أوكرانيا',
    'ug' => 'أوغندا',
    'um' => "جزر\ الولايات\ المتحدة\ البعيدة\ الصغيرة",
    'us' => "الولايات\ المتحدة\ الأمريكية",
    'uy' => 'أورجواي',
    'uz' => 'أوزبكستان',
    'va' => 'الفاتيكان',
    'vc' => "سانت\ فنسنت\ وغرنادين",
    'vd' => "North\ Vietnam",
    've' => 'فنزويلا',
    'vg' => "جزر\ فرجين\ البريطانية",
    'vi' => "جزر\ فرجين\ الأمريكية",
    'vn' => 'فيتنام',
    'vu' => 'فانواتو',
    'wf' => "جزر\ والس\ وفوتونا",
    'wk' => "Wake\ Island",
    'ws' => 'ساموا',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'اليمن',
    'yt' => 'مايوت',
    'za' => "جمهورية\ جنوب\ افريقيا",
    'zm' => 'زامبيا',
    'zw' => 'زيمبابوي',
    'zz' => "منطقة\ غير\ معرفة",
);

%Locales::DB::Territory::ar::name_to_code = (
    'britishantarcticterritory'                                            => 'bq',
    'cantonandenderburyislands'                                            => 'ct',
    'dronningmaudland'                                                     => 'nq',
    'eastgermany'                                                          => 'dd',
    'frenchsouthernandantarcticterritories'                                => 'fq',
    'guernsey'                                                             => 'gg',
    'johnstonisland'                                                       => 'jt',
    'metropolitanfrance'                                                   => 'fx',
    'midwayislands'                                                        => 'mi',
    'neutralzone'                                                          => 'nt',
    'northvietnam'                                                         => 'vd',
    'pacificislandstrustterritory'                                         => 'pc',
    'panamacanalzone'                                                      => 'pz',
    'peoplesdemocraticrepublicofyemen'                                     => 'yd',
    "saintbarth\Ã\©lemy"                                                 => 'bl',
    "u\.s\.miscellaneouspacificislands"                                    => 'pu',
    'unionofsovietsocialistrepublics'                                      => 'su',
    'wakeisland'                                                           => 'wk',
    'آروبا'                                                           => 'aw',
    'أذربيجان'                                                     => 'az',
    'أرمينيا'                                                       => 'am',
    'أريتريا'                                                       => 'er',
    'أسبانيا'                                                       => 'es',
    'أستراليا'                                                     => 'au',
    'أفغانستان'                                                   => 'af',
    'ألبانيا'                                                       => 'al',
    'ألمانيا'                                                       => 'de',
    'أنتيجواوبربودا'                                         => 'ag',
    'أنجولا'                                                         => 'ao',
    'أنجويلا'                                                       => 'ai',
    'أندورا'                                                         => 'ad',
    'أورجواي'                                                       => 'uy',
    'أوزبكستان'                                                   => 'uz',
    'أوغندا'                                                         => 'ug',
    'أوقيانوسياالنائية'                                   => 'qo',
    'أوكرانيا'                                                     => 'ua',
    'أيرلندا'                                                       => 'ie',
    'أيسلندا'                                                       => 'is',
    'إثيوبيا'                                                       => 'et',
    'إسرائيل'                                                       => 'il',
    'إيران'                                                           => 'ir',
    'إيطاليا'                                                       => 'it',
    'استونيا'                                                       => 'ee',
    'الأرجنتين'                                                   => 'ar',
    'الأردن'                                                         => 'jo',
    'الإكوادور'                                                   => 'ec',
    'الاتحادالأوروبي'                                       => 'qu',
    'الاماراتالعربيةالمتحدة'                         => 'ae',
    'الباهاما'                                                     => 'bs',
    'البحرين'                                                       => 'bh',
    'البرازيل'                                                     => 'br',
    'البرتغال'                                                     => 'pt',
    'البوسنةوالهرسك'                                         => 'ba',
    'الجابون'                                                       => 'ga',
    'الجبلالأسود'                                               => 'me',
    'الجزائر'                                                       => 'dz',
    'الدانمرك'                                                     => 'dk',
    'الرأسالأخضر'                                               => 'cv',
    'السلفادور'                                                   => 'sv',
    'السنغال'                                                       => 'sn',
    'السودان'                                                       => 'sd',
    'السويد'                                                         => 'se',
    'الصحراءالغربية'                                         => 'eh',
    'الصومال'                                                       => 'so',
    'الصين'                                                           => 'cn',
    'العراق'                                                         => 'iq',
    'الفاتيكان'                                                   => 'va',
    'الفيلبين'                                                     => 'ph',
    'القطبالجنوبي'                                             => 'aq',
    'الكاميرون'                                                   => 'cm',
    'الكونغوبرازافيل'                                       => 'cg',
    'الكويت'                                                         => 'kw',
    'المجر'                                                           => 'hu',
    'المحيطالهنديالبريطاني'                           => 'io',
    'المغرب'                                                         => 'ma',
    'المقاطعاتالجنوبيةالفرنسية'                   => 'tf',
    'المكسيك'                                                       => 'mx',
    'المملكةالعربيةالسعودية'                         => 'sa',
    'المملكةالمتحدة'                                         => 'gb',
    'النرويج'                                                       => 'no',
    'النمسا'                                                         => 'at',
    'النيجر'                                                         => 'ne',
    'الهند'                                                           => 'in',
    'الولاياتالمتحدةالأمريكية'                     => 'us',
    'اليابان'                                                       => 'jp',
    'اليمن'                                                           => 'ye',
    'اليونان'                                                       => 'gr',
    'اندونيسيا'                                                   => 'id',
    'بابواغينياالجديدة'                                   => 'pg',
    'باراجواي'                                                     => 'py',
    'باكستان'                                                       => 'pk',
    'بالاو'                                                           => 'pw',
    'بتسوانا'                                                       => 'bw',
    'بتكايرن'                                                       => 'pn',
    'بربادوس'                                                       => 'bb',
    'برمودا'                                                         => 'bm',
    'بروناي'                                                         => 'bn',
    'بلجيكا'                                                         => 'be',
    'بلغاريا'                                                       => 'bg',
    'بليز'                                                             => 'bz',
    'بنجلاديش'                                                     => 'bd',
    'بنما'                                                             => 'pa',
    'بنين'                                                             => 'bj',
    'بوتان'                                                           => 'bt',
    'بورتوريكو'                                                   => 'pr',
    'بوركينافاسو'                                               => 'bf',
    'بوروندي'                                                       => 'bi',
    'بولندا'                                                         => 'pl',
    'بوليفيا'                                                       => 'bo',
    'بولينيزياالفرنسية'                                   => 'pf',
    'بيرو'                                                             => 'pe',
    'تانزانيا'                                                     => 'tz',
    'تايلند'                                                         => 'th',
    'تايوان'                                                         => 'tw',
    'تركمانستان'                                                 => 'tm',
    'تركيا'                                                           => 'tr',
    'ترينيدادوتوباغو'                                       => 'tt',
    'تشاد'                                                             => 'td',
    'توجو'                                                             => 'tg',
    'توفالو'                                                         => 'tv',
    'توكيلو'                                                         => 'tk',
    'تونجا'                                                           => 'to',
    'تونس'                                                             => 'tn',
    'تيمورالشرقية'                                             => 'tl',
    'جامايكا'                                                       => 'jm',
    'جبلطارق'                                                       => 'gi',
    'جرينادا'                                                       => 'gd',
    'جرينلاند'                                                     => 'gl',
    'جزرأولان'                                                     => 'ax',
    'جزرالأنتيلالهولندية'                               => 'an',
    'جزرالتركوجايكوس'                                       => 'tc',
    'جزرالقمر'                                                     => 'km',
    'جزرالكايمن'                                                 => 'ky',
    'جزرالمارشال'                                               => 'mh',
    'جزرالملديف'                                                 => 'mv',
    'جزرالولاياتالمتحدةالبعيدةالصغيرة'     => 'um',
    'جزرسليمان'                                                   => 'sb',
    'جزرفارو'                                                       => 'fo',
    'جزرفرجينالأمريكية'                                   => 'vi',
    'جزرفرجينالبريطانية'                                 => 'vg',
    'جزرفوكلاند'                                                 => 'fk',
    'جزركوك'                                                         => 'ck',
    'جزركوكوس'                                                     => 'cc',
    'جزرمارياناالشمالية'                                 => 'mp',
    'جزروالسوفوتونا'                                         => 'wf',
    'جزيرةالكريسماس'                                         => 'cx',
    'جزيرةبوفيه'                                                 => 'bv',
    'جزيرةمان'                                                     => 'im',
    'جزيرةنورفوك'                                               => 'nf',
    'جزيرةهيردوماكدونالد'                               => 'hm',
    'جمهوريةإفريقياالوسطى'                             => 'cf',
    'جمهوريةالتشيك'                                           => 'cz',
    'جمهوريةالدومينيك'                                     => 'do',
    'جمهوريةالكونغوالديمقراطية'                   => 'cd',
    'جمهوريةجنوبافريقيا'                                 => 'za',
    'جواتيمالا'                                                   => 'gt',
    'جوادلوب'                                                       => 'gp',
    'جوام'                                                             => 'gu',
    'جورجيا'                                                         => 'ge',
    'جورجياالجنوبيةوجزرساندويتشالجنوبية' => 'gs',
    'جيبوتي'                                                         => 'dj',
    'جيرسي'                                                           => 'je',
    'دومينيكا'                                                     => 'dm',
    'رواندا'                                                         => 'rw',
    'روسيا'                                                           => 'ru',
    'روسياالبيضاء'                                             => 'by',
    'رومانيا'                                                       => 'ro',
    'روينيون'                                                       => 're',
    'زامبيا'                                                         => 'zm',
    'زيمبابوي'                                                     => 'zw',
    'ساحلالعاج'                                                   => 'ci',
    'ساموا'                                                           => 'ws',
    'سامواالأمريكية'                                         => 'as',
    'سانتبييروميكولون'                                     => 'pm',
    'سانتفنسنتوغرنادين'                                   => 'vc',
    'سانتكيتسونيفيس'                                         => 'kn',
    'سانتلوسيا'                                                   => 'lc',
    'سانتمارتين'                                                 => 'mf',
    'سانتهيلنا'                                                   => 'sh',
    'سانمارينو'                                                   => 'sm',
    'ساوتوميوبرينسيبي'                                     => 'st',
    'سريلانكا'                                                     => 'lk',
    'سفالباردوجانمايان'                                   => 'sj',
    'سلوفاكيا'                                                     => 'sk',
    'سلوفينيا'                                                     => 'si',
    'سنغافورة'                                                     => 'sg',
    'سوازيلاند'                                                   => 'sz',
    'سوريا'                                                           => 'sy',
    'سورينام'                                                       => 'sr',
    'سويسرا'                                                         => 'ch',
    'سيراليون'                                                     => 'sl',
    'سيشل'                                                             => 'sc',
    'شيلي'                                                             => 'cl',
    'صربيا'                                                           => 'rs',
    'صربياوالجبلالأسود'                                   => 'cs',
    'طاجكستان'                                                     => 'tj',
    'عمان'                                                             => 'om',
    'غامبيا'                                                         => 'gm',
    'غانا'                                                             => 'gh',
    'غويانا'                                                         => 'gf',
    'غيانا'                                                           => 'gy',
    'غينيا'                                                           => 'gn',
    'غينياالاستوائية'                                       => 'gq',
    'غينيابيساو'                                                 => 'gw',
    'فانواتو'                                                       => 'vu',
    'فرنسا'                                                           => 'fr',
    'فلسطين'                                                         => 'ps',
    'فنزويلا'                                                       => 've',
    'فنلندا'                                                         => 'fi',
    'فيتنام'                                                         => 'vn',
    'فيجي'                                                             => 'fj',
    'قبرص'                                                             => 'cy',
    'قرغيزستان'                                                   => 'kg',
    'قطر'                                                               => 'qa',
    'كازاخستان'                                                   => 'kz',
    'كاليدونياالجديدة'                                     => 'nc',
    'كرواتيا'                                                       => 'hr',
    'كمبوديا'                                                       => 'kh',
    'كندا'                                                             => 'ca',
    'كوبا'                                                             => 'cu',
    'كورياالجنوبية'                                           => 'kr',
    'كورياالشمالية'                                           => 'kp',
    'كوستاريكا'                                                   => 'cr',
    'كولومبيا'                                                     => 'co',
    'كيريباتي'                                                     => 'ki',
    'كينيا'                                                           => 'ke',
    'لاتفيا'                                                         => 'lv',
    'لاوس'                                                             => 'la',
    'لبنان'                                                           => 'lb',
    'لوكسمبورج'                                                   => 'lu',
    'ليبيا'                                                           => 'ly',
    'ليبيريا'                                                       => 'lr',
    'ليتوانيا'                                                     => 'lt',
    'ليختنشتاين'                                                 => 'li',
    'ليسوتو'                                                         => 'ls',
    'مارتينيك'                                                     => 'mq',
    'ماكاو'                                                           => 'mo',
    'مالطا'                                                           => 'mt',
    'مالي'                                                             => 'ml',
    'ماليزيا'                                                       => 'my',
    'مايوت'                                                           => 'yt',
    'مدغشقر'                                                         => 'mg',
    'مصر'                                                               => 'eg',
    'مقدونيا'                                                       => 'mk',
    'ملاوي'                                                           => 'mw',
    'منطقةغيرمعرفة'                                           => 'zz',
    'منغوليا'                                                       => 'mn',
    'موريتانيا'                                                   => 'mr',
    'موريشيوس'                                                     => 'mu',
    'موزمبيق'                                                       => 'mz',
    'مولدافيا'                                                     => 'md',
    'موناكو'                                                         => 'mc',
    'مونتسرات'                                                     => 'ms',
    'ميانمار'                                                       => 'mm',
    'ميكرونيزيا'                                                 => 'fm',
    'ناميبيا'                                                       => 'na',
    'نورو'                                                             => 'nr',
    'نيبال'                                                           => 'np',
    'نيجيريا'                                                       => 'ng',
    'نيكاراجوا'                                                   => 'ni',
    'نيوزيلاندا'                                                 => 'nz',
    'نيوي'                                                             => 'nu',
    'هايتي'                                                           => 'ht',
    'هندوراس'                                                       => 'hn',
    'هولندا'                                                         => 'nl',
    'هونجكونج'                                                     => 'hk',
);

1;

