package Locales::DB::Territory::mt;

# Auto generated from CLDR

$Locales::DB::Territory::mt::VERSION = '0.02';

$Locales::DB::Territory::mt::cldr_version = '1.7.1';

%Locales::DB::Territory::mt::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "Emirati\ Għarab\ Maqgħuda",
    'af' => 'Afganistan',
    'ag' => "Antigua\ and\ Barbuda",
    'ai' => 'Angwilla',
    'al' => 'Albanija',
    'am' => 'Armenja',
    'an' => "Antilles\ Olandiżi",
    'ao' => 'Angola',
    'aq' => 'Antartika',
    'ar' => 'Arġentina',
    'as' => "Samoa\ Amerikana",
    'at' => 'Awstrija',
    'au' => 'Awstralja',
    'aw' => 'Aruba',
    'ax' => "Gżejjer\ Aland",
    'az' => 'Ażerbajġan',
    'ba' => "Bożnija\ Ħerżegovina",
    'bb' => 'Barbados',
    'bd' => 'Bangladexx',
    'be' => 'Belġju',
    'bf' => "Burkina\ Faso",
    'bg' => 'Bulgarija',
    'bh' => 'Baħrajn',
    'bi' => 'Burundi',
    'bj' => 'Benin',
    'bl' => "Saint\ Barth\Ã\©lemy",
    'bm' => 'Bermuda',
    'bn' => 'Brunej',
    'bo' => 'Bolivja',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brażil',
    'bs' => 'Baħamas',
    'bt' => 'Butan',
    'bv' => "Bouvet\ Island",
    'bw' => 'Botswana',
    'by' => 'Bjelorussja',
    'bz' => 'Beliże',
    'ca' => 'Kanada',
    'cc' => "Cocos\ \(Keeling\)\ Islands",
    'cd' => "Democratic\ Republic\ of\ the\ Congo",
    'cf' => "Repubblika\ Afrikana\ Ċentrali",
    'cg' => 'Kongo',
    'ch' => 'Svizzera',
    'ci' => "Kosta\ ta’\ l\-Avorju",
    'ck' => "Cook\ Islands",
    'cl' => 'Ċili',
    'cm' => 'Kamerun',
    'cn' => 'Ċina',
    'co' => 'Kolumbja',
    'cr' => "Kosta\ Rika",
    'cs' => "Serbja\ u\ Montenegro",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Kuba',
    'cv' => "Kape\ Verde",
    'cx' => "Christmas\ Island",
    'cy' => 'Ċipru',
    'cz' => "Repubblika\ Ċeka",
    'dd' => "East\ Germany",
    'de' => 'Ġermanja',
    'dj' => 'Ġibuti',
    'dk' => 'Danimarka',
    'dm' => 'Dominika',
    'do' => "Republikka\ Domenikana",
    'dz' => 'Alġerija',
    'ec' => 'Ekwador',
    'ee' => 'Estonja',
    'eg' => 'Eġittu',
    'eh' => "Sahara\ tal\-Punent",
    'er' => 'Eritreja',
    'es' => 'Spanja',
    'et' => 'Etijopja',
    'fi' => 'Finlandja',
    'fj' => 'Fiġi',
    'fk' => "Falkland\ Islands",
    'fm' => 'Mikronesja',
    'fo' => "Gżejjer\ Faroe",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Franza',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabon',
    'gb' => 'Ingilterra',
    'gd' => 'Grenada',
    'ge' => 'Ġorġja',
    'gf' => "Gujana\ Franċiża",
    'gg' => 'Guernsey',
    'gh' => 'Gana',
    'gi' => 'Gibraltar',
    'gl' => 'Grinlandja',
    'gm' => 'Gambja',
    'gn' => 'Gineja',
    'gp' => 'Gwadelupe',
    'gq' => "Ginea\ Ekwatorjali",
    'gr' => 'Greċja',
    'gs' => "South\ Georgia\ and\ the\ South\ Sandwich\ Islands",
    'gt' => 'Gwatemala',
    'gu' => 'Gwam',
    'gw' => "Ginea\-Bissaw",
    'gy' => 'Gujana',
    'hk' => "Ħong\ Kong\ S\.A\.R\.\,\ Ċina",
    'hm' => "Heard\ Island\ and\ McDonald\ Islands",
    'hn' => 'Ħonduras',
    'hr' => 'Kroazja',
    'ht' => 'Ħaiti',
    'hu' => 'Ungerija',
    'id' => 'Indoneżja',
    'ie' => 'Irlanda',
    'il' => 'Iżrael',
    'im' => "Isle\ of\ Man",
    'in' => 'Indja',
    'io' => "British\ Indian\ Ocean\ Territory",
    'iq' => 'Iraq',
    'ir' => 'Iran',
    'is' => 'Islanda',
    'it' => 'Italja',
    'je' => 'Jersey',
    'jm' => 'Ġamajka',
    'jo' => 'Ġordan',
    'jp' => 'Ġappun',
    'jt' => "Johnston\ Island",
    'ke' => 'Kenja',
    'kg' => 'Kirgistan',
    'kh' => 'Kambodja',
    'ki' => 'Kiribati',
    'km' => 'Komoros',
    'kn' => "Saint\ Kitts\ and\ Nevis",
    'kp' => "Koreja\ ta’\ Fuq",
    'kr' => "Koreja\ t’Isfel",
    'kw' => 'Kuwajt',
    'ky' => "Gżejjer\ Kajmani",
    'kz' => 'Każakstan',
    'la' => 'Laos',
    'lb' => 'Libanu',
    'lc' => "Santa\ Luċija",
    'li' => 'Liechtenstein',
    'lk' => "Sri\ Lanka",
    'lr' => 'Liberja',
    'ls' => 'Lesoto',
    'lt' => 'Litwanja',
    'lu' => 'Lussemburgu',
    'lv' => 'Latvja',
    'ly' => 'Libja',
    'ma' => 'Marokk',
    'mc' => 'Monako',
    'md' => 'Maldova',
    'me' => 'Montenegro',
    'mf' => "Saint\ Martin",
    'mg' => 'Madagaskar',
    'mh' => "Gżejjer\ ta’\ Marshall",
    'mi' => "Midway\ Islands",
    'mk' => 'Maċedonja',
    'ml' => 'Mali',
    'mm' => 'Mjanmar',
    'mn' => 'Mongolja',
    'mo' => "Macao\ S\.A\.R\.\,\ China",
    'mp' => "Gżejjer\ Marjana\ ta’\ Fuq",
    'mq' => 'Martinik',
    'mr' => 'Mawritanja',
    'ms' => 'Montserrat',
    'mt' => 'Malta',
    'mu' => 'Mawrizju',
    'mv' => 'Maldives',
    'mw' => 'Malawi',
    'mx' => 'Messiku',
    'my' => 'Malasja',
    'mz' => 'Możambik',
    'na' => 'Namibja',
    'nc' => "New\ Caledonia",
    'ne' => 'Niġer',
    'nf' => "Norfolk\ Island",
    'ng' => 'Niġerja',
    'ni' => 'Nikaragwa',
    'nl' => 'Olanda',
    'no' => 'Norveġja',
    'np' => 'Nepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "New\ Zealand",
    'om' => 'Oman',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Peru',
    'pf' => "Polinesja\ Franċiża",
    'pg' => "Papwa\-Ginea\ Ġdida",
    'ph' => 'Filippini',
    'pk' => 'Pakistan',
    'pl' => 'Polonja',
    'pm' => "Saint\ Pierre\ and\ Miquelon",
    'pn' => 'Pitcairn',
    'pr' => "Puerto\ Rico",
    'ps' => "Palestinian\ Territory",
    'pt' => 'Portugall',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paragwaj',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Qatar',
    'qo' => "Outlying\ Oceania",
    'qu' => "Unjoni\ Ewropea",
    're' => 'Réunion',
    'ro' => 'Rumanija',
    'rs' => 'Serbia',
    'ru' => 'Russja',
    'rw' => 'Rwanda',
    'sa' => "Għarabja\ Sawdita",
    'sb' => "Solomon\ Islands",
    'sc' => 'Seychelles',
    'sd' => 'Sudan',
    'se' => 'Żvezja',
    'sg' => 'Singapor',
    'sh' => "Saint\ Helena",
    'si' => 'Slovenja',
    'sj' => "Svalbard\ and\ Jan\ Mayen",
    'sk' => 'Slovakkja',
    'sl' => "Sierra\ Leone",
    'sm' => "San\ Marino",
    'sn' => 'Senegal',
    'so' => 'Somalja',
    'sr' => 'Surinam',
    'st' => "Sao\ Tome\ and\ Principe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salvador",
    'sy' => 'Sirja',
    'sz' => 'Sważiland',
    'tc' => "Turks\ and\ Caicos\ Islands",
    'td' => 'Ċad',
    'tf' => "Territorji\ Franċiżi\ ta’\ Nofsinhar",
    'tg' => 'Togo',
    'th' => 'Tajlandja',
    'tj' => 'Taġikistan',
    'tk' => 'Tokelaw',
    'tl' => "Timor\ tal\-Lvant",
    'tm' => 'Turkmenistan',
    'tn' => 'Tuneż',
    'to' => 'Tonga',
    'tr' => 'Turkija',
    'tt' => "Trinidad\ u\ Tobago",
    'tv' => 'Tuvalu',
    'tw' => 'Tajwan',
    'tz' => 'Tanżanija',
    'ua' => 'Ukraina',
    'ug' => 'Uganda',
    'um' => "United\ States\ Minor\ Outlying\ Islands",
    'us' => "Stati\ Uniti",
    'uy' => 'Urugwaj',
    'uz' => 'Użbekistan',
    'va' => 'Vatikan',
    'vc' => "Saint\ Vincent\ and\ the\ Grenadines",
    'vd' => "North\ Vietnam",
    've' => 'Venezwela',
    'vg' => "British\ Virgin\ Islands",
    'vi' => "U\.S\.\ Virgin\ Islands",
    'vn' => 'Vjetnam',
    'vu' => 'Vanwatu',
    'wf' => "Wallis\ and\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Jemen',
    'yt' => 'Majotte',
    'za' => "Afrika\ t’Isfel",
    'zm' => 'Żambja',
    'zw' => 'Żimbabwe',
    'zz' => "Reġjun\ Mhux\ Magħruf\ jew\ Mhux\ Validu",
);

%Locales::DB::Territory::mt::name_to_code = (
    'afganistan'                             => 'af',
    'afrikat’isfel'                        => 'za',
    'albanija'                               => 'al',
    'alġerija'                              => 'dz',
    'andorra'                                => 'ad',
    'angola'                                 => 'ao',
    'angwilla'                               => 'ai',
    'antartika'                              => 'aq',
    'antiguaandbarbuda'                      => 'ag',
    'antillesolandiżi'                      => 'an',
    'armenja'                                => 'am',
    'aruba'                                  => 'aw',
    'arġentina'                             => 'ar',
    'awstralja'                              => 'au',
    'awstrija'                               => 'at',
    'ażerbajġan'                           => 'az',
    'bangladexx'                             => 'bd',
    'barbados'                               => 'bb',
    'baħamas'                               => 'bs',
    'baħrajn'                               => 'bh',
    'beliże'                                => 'bz',
    'belġju'                                => 'be',
    'benin'                                  => 'bj',
    'bermuda'                                => 'bm',
    'bjelorussja'                            => 'by',
    'bolivja'                                => 'bo',
    'botswana'                               => 'bw',
    'bouvetisland'                           => 'bv',
    'bożnijaĦerżegovina'                  => 'ba',
    'brażil'                                => 'br',
    'britishantarcticterritory'              => 'bq',
    'britishindianoceanterritory'            => 'io',
    'britishvirginislands'                   => 'vg',
    'brunej'                                 => 'bn',
    'bulgarija'                              => 'bg',
    'burkinafaso'                            => 'bf',
    'burundi'                                => 'bi',
    'butan'                                  => 'bt',
    'cantonandenderburyislands'              => 'ct',
    'christmasisland'                        => 'cx',
    'cocoskeelingislands'                    => 'cc',
    'cookislands'                            => 'ck',
    'danimarka'                              => 'dk',
    'democraticrepublicofthecongo'           => 'cd',
    'dominika'                               => 'dm',
    'dronningmaudland'                       => 'nq',
    'eastgermany'                            => 'dd',
    'ekwador'                                => 'ec',
    'elsalvador'                             => 'sv',
    'emiratigħarabmaqgħuda'                => 'ae',
    'eritreja'                               => 'er',
    'estonja'                                => 'ee',
    'etijopja'                               => 'et',
    'eġittu'                                => 'eg',
    'falklandislands'                        => 'fk',
    'filippini'                              => 'ph',
    'finlandja'                              => 'fi',
    'fiġi'                                  => 'fj',
    'franza'                                 => 'fr',
    'frenchsouthernandantarcticterritories'  => 'fq',
    'gabon'                                  => 'ga',
    'gambja'                                 => 'gm',
    'gana'                                   => 'gh',
    'gibraltar'                              => 'gi',
    'gineabissaw'                            => 'gw',
    'gineaekwatorjali'                       => 'gq',
    'gineja'                                 => 'gn',
    'grenada'                                => 'gd',
    'greċja'                                => 'gr',
    'grinlandja'                             => 'gl',
    'guernsey'                               => 'gg',
    'gujana'                                 => 'gy',
    'gujanafranċiża'                       => 'gf',
    'gwadelupe'                              => 'gp',
    'gwam'                                   => 'gu',
    'gwatemala'                              => 'gt',
    'għarabjasawdita'                       => 'sa',
    'gżejjeraland'                          => 'ax',
    'gżejjerfaroe'                          => 'fo',
    'gżejjerkajmani'                        => 'ky',
    'gżejjermarjanata’fuq'                => 'mp',
    'gżejjerta’marshall'                  => 'mh',
    'heardislandandmcdonaldislands'          => 'hm',
    'indja'                                  => 'in',
    'indoneżja'                             => 'id',
    'ingilterra'                             => 'gb',
    'iran'                                   => 'ir',
    'iraq'                                   => 'iq',
    'irlanda'                                => 'ie',
    'islanda'                                => 'is',
    'isleofman'                              => 'im',
    'italja'                                 => 'it',
    'iżrael'                                => 'il',
    'jemen'                                  => 'ye',
    'jersey'                                 => 'je',
    'johnstonisland'                         => 'jt',
    'kambodja'                               => 'kh',
    'kamerun'                                => 'cm',
    'kanada'                                 => 'ca',
    'kapeverde'                              => 'cv',
    'każakstan'                             => 'kz',
    'kenja'                                  => 'ke',
    'kirgistan'                              => 'kg',
    'kiribati'                               => 'ki',
    'kolumbja'                               => 'co',
    'komoros'                                => 'km',
    'kongo'                                  => 'cg',
    'korejata’fuq'                         => 'kp',
    'korejat’isfel'                        => 'kr',
    'kostarika'                              => 'cr',
    'kostata’lavorju'                      => 'ci',
    'kroazja'                                => 'hr',
    'kuba'                                   => 'cu',
    'kuwajt'                                 => 'kw',
    'laos'                                   => 'la',
    'latvja'                                 => 'lv',
    'lesoto'                                 => 'ls',
    'libanu'                                 => 'lb',
    'liberja'                                => 'lr',
    'libja'                                  => 'ly',
    'liechtenstein'                          => 'li',
    'litwanja'                               => 'lt',
    'lussemburgu'                            => 'lu',
    "macaos\.a\.r\.\,china"                  => 'mo',
    'madagaskar'                             => 'mg',
    'majotte'                                => 'yt',
    'malasja'                                => 'my',
    'malawi'                                 => 'mw',
    'maldives'                               => 'mv',
    'maldova'                                => 'md',
    'mali'                                   => 'ml',
    'malta'                                  => 'mt',
    'marokk'                                 => 'ma',
    'martinik'                               => 'mq',
    'mawritanja'                             => 'mr',
    'mawrizju'                               => 'mu',
    'maċedonja'                             => 'mk',
    'messiku'                                => 'mx',
    'metropolitanfrance'                     => 'fx',
    'midwayislands'                          => 'mi',
    'mikronesja'                             => 'fm',
    'mjanmar'                                => 'mm',
    'monako'                                 => 'mc',
    'mongolja'                               => 'mn',
    'montenegro'                             => 'me',
    'montserrat'                             => 'ms',
    'możambik'                              => 'mz',
    'namibja'                                => 'na',
    'nauru'                                  => 'nr',
    'nepal'                                  => 'np',
    'neutralzone'                            => 'nt',
    'newcaledonia'                           => 'nc',
    'newzealand'                             => 'nz',
    'nikaragwa'                              => 'ni',
    'niue'                                   => 'nu',
    'niġer'                                 => 'ne',
    'niġerja'                               => 'ng',
    'norfolkisland'                          => 'nf',
    'northvietnam'                           => 'vd',
    'norveġja'                              => 'no',
    'olanda'                                 => 'nl',
    'oman'                                   => 'om',
    'outlyingoceania'                        => 'qo',
    'pacificislandstrustterritory'           => 'pc',
    'pakistan'                               => 'pk',
    'palau'                                  => 'pw',
    'palestinianterritory'                   => 'ps',
    'panama'                                 => 'pa',
    'panamacanalzone'                        => 'pz',
    'papwagineaĠdida'                       => 'pg',
    'paragwaj'                               => 'py',
    'peoplesdemocraticrepublicofyemen'       => 'yd',
    'peru'                                   => 'pe',
    'pitcairn'                               => 'pn',
    'polinesjafranċiża'                    => 'pf',
    'polonja'                                => 'pl',
    'portugall'                              => 'pt',
    'puertorico'                             => 'pr',
    'qatar'                                  => 'qa',
    'repubblikaafrikanaĊentrali'            => 'cf',
    'repubblikaĊeka'                        => 'cz',
    'republikkadomenikana'                   => 'do',
    'reġjunmhuxmagħrufjewmhuxvalidu'       => 'zz',
    'rumanija'                               => 'ro',
    'russja'                                 => 'ru',
    'rwanda'                                 => 'rw',
    'réunion'                               => 're',
    'saharatalpunent'                        => 'eh',
    "saintbarth\Ã\©lemy"                   => 'bl',
    'sainthelena'                            => 'sh',
    'saintkittsandnevis'                     => 'kn',
    'saintmartin'                            => 'mf',
    'saintpierreandmiquelon'                 => 'pm',
    'saintvincentandthegrenadines'           => 'vc',
    'samoa'                                  => 'ws',
    'samoaamerikana'                         => 'as',
    'sanmarino'                              => 'sm',
    'santaluċija'                           => 'lc',
    'saotomeandprincipe'                     => 'st',
    'senegal'                                => 'sn',
    'serbia'                                 => 'rs',
    'serbjaumontenegro'                      => 'cs',
    'seychelles'                             => 'sc',
    'sierraleone'                            => 'sl',
    'singapor'                               => 'sg',
    'sirja'                                  => 'sy',
    'slovakkja'                              => 'sk',
    'slovenja'                               => 'si',
    'solomonislands'                         => 'sb',
    'somalja'                                => 'so',
    'southgeorgiaandthesouthsandwichislands' => 'gs',
    'spanja'                                 => 'es',
    'srilanka'                               => 'lk',
    'statiuniti'                             => 'us',
    'sudan'                                  => 'sd',
    'surinam'                                => 'sr',
    'svalbardandjanmayen'                    => 'sj',
    'svizzera'                               => 'ch',
    'sważiland'                             => 'sz',
    'tajlandja'                              => 'th',
    'tajwan'                                 => 'tw',
    'tanżanija'                             => 'tz',
    'taġikistan'                            => 'tj',
    'territorjifranċiżita’nofsinhar'     => 'tf',
    'timortallvant'                          => 'tl',
    'togo'                                   => 'tg',
    'tokelaw'                                => 'tk',
    'tonga'                                  => 'to',
    'trinidadutobago'                        => 'tt',
    'tuneż'                                 => 'tn',
    'turkija'                                => 'tr',
    'turkmenistan'                           => 'tm',
    'turksandcaicosislands'                  => 'tc',
    'tuvalu'                                 => 'tv',
    "u\.s\.miscellaneouspacificislands"      => 'pu',
    "u\.s\.virginislands"                    => 'vi',
    'uganda'                                 => 'ug',
    'ukraina'                                => 'ua',
    'ungerija'                               => 'hu',
    'unionofsovietsocialistrepublics'        => 'su',
    'unitedstatesminoroutlyingislands'       => 'um',
    'unjoniewropea'                          => 'qu',
    'urugwaj'                                => 'uy',
    'użbekistan'                            => 'uz',
    'vanwatu'                                => 'vu',
    'vatikan'                                => 'va',
    'venezwela'                              => 've',
    'vjetnam'                                => 'vn',
    'wakeisland'                             => 'wk',
    'wallisandfutuna'                        => 'wf',
    'Ċad'                                   => 'td',
    'Ċili'                                  => 'cl',
    'Ċina'                                  => 'cn',
    'Ċipru'                                 => 'cy',
    'Ġamajka'                               => 'jm',
    'Ġappun'                                => 'jp',
    'Ġermanja'                              => 'de',
    'Ġibuti'                                => 'dj',
    'Ġordan'                                => 'jo',
    'Ġorġja'                               => 'ge',
    'Ħaiti'                                 => 'ht',
    'Ħonduras'                              => 'hn',
    "Ħongkongs\.a\.r\.\,Ċina"              => 'hk',
    'Żambja'                                => 'zm',
    'Żimbabwe'                              => 'zw',
    'Żvezja'                                => 'se',
);

1;

