package Locales::DB::Territory::ro;

# Auto generated from CLDR

$Locales::DB::Territory::ro::VERSION = '0.02';

$Locales::DB::Territory::ro::cldr_version = '1.7.1';

%Locales::DB::Territory::ro::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "Emiratele\ Arabe\ Unite",
    'af' => 'Afganistan',
    'ag' => "Antigua\ și\ Barbuda",
    'ai' => 'Anguilla',
    'al' => 'Albania',
    'am' => 'Armenia',
    'an' => "Antilele\ Olandeze",
    'ao' => 'Angola',
    'aq' => 'Antarctica',
    'ar' => 'Argentina',
    'as' => "Samoa\ Americană",
    'at' => 'Austria',
    'au' => 'Australia',
    'aw' => 'Aruba',
    'ax' => "Insulele\ Aland",
    'az' => 'Azerbaidjan',
    'ba' => "Bosnia\ și\ Herțegovina",
    'bb' => 'Barbados',
    'bd' => 'Bangladesh',
    'be' => 'Belgia',
    'bf' => "Burkina\ Faso",
    'bg' => 'Bulgaria',
    'bh' => 'Bahrain',
    'bi' => 'Burundi',
    'bj' => 'Benin',
    'bl' => "Sfântul\ Bartolomeu",
    'bm' => 'Bermuda',
    'bn' => 'Brunei',
    'bo' => 'Bolivia',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brazilia',
    'bs' => 'Bahamas',
    'bt' => 'Bhutan',
    'bv' => "Insula\ Bouvet",
    'bw' => 'Botswana',
    'by' => 'Bielorusia',
    'bz' => 'Belize',
    'ca' => 'Canada',
    'cc' => "Insulele\ Cocos",
    'cd' => "Republica\ Democrată\ Congo",
    'cf' => "Republica\ Centrafricană",
    'cg' => 'Congo',
    'ch' => 'Eleveția',
    'ci' => "Coasta\ de\ Fildeș",
    'ck' => "Insulele\ Cook",
    'cl' => 'Chile',
    'cm' => 'Camerun',
    'cn' => 'China',
    'co' => 'Columbia',
    'cr' => "Costa\ Rica",
    'cs' => "Serbia\ și\ Muntenegru",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Cuba',
    'cv' => "Capul\ Verde",
    'cx' => "Insula\ Christmas",
    'cy' => 'Cipru',
    'cz' => "Republica\ Cehă",
    'dd' => "East\ Germany",
    'de' => 'Germania',
    'dj' => 'Djibouti',
    'dk' => 'Danemarca',
    'dm' => 'Dominica',
    'do' => "Republica\ Dominicană",
    'dz' => 'Algeria',
    'ec' => 'Ecuador',
    'ee' => 'Estonia',
    'eg' => 'Egipt',
    'eh' => "Sahara\ Occidentală",
    'er' => 'Eritreea',
    'es' => 'Spania',
    'et' => 'Etiopia',
    'fi' => 'Finlanda',
    'fj' => 'Fiji',
    'fk' => "Insulele\ Falkland",
    'fm' => 'Micronezia',
    'fo' => "Insulele\ Feroe",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Franța',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabon',
    'gb' => "Regatul\ Unit",
    'gd' => 'Grenada',
    'ge' => 'Georgia',
    'gf' => "Guyana\ Franceză",
    'gg' => 'Guernsey',
    'gh' => 'Ghana',
    'gi' => 'Gibraltar',
    'gl' => 'Groenlanda',
    'gm' => 'Gambia',
    'gn' => 'Guineea',
    'gp' => 'Guadelupa',
    'gq' => "Guineea\ Ecuatorială",
    'gr' => 'Grecia',
    'gs' => "Insulele\ Georgia\ de\ Sud\ și\ Sandwich\ de\ Sud",
    'gt' => 'Guatemala',
    'gu' => 'Guam',
    'gw' => "Guineea\-Bissau",
    'gy' => 'Guyana',
    'hk' => "Hong\ Kong",
    'hm' => "Insula\ Heard\ și\ Insulele\ McDonald",
    'hn' => 'Honduras',
    'hr' => 'Croația',
    'ht' => 'Haiti',
    'hu' => 'Ungaria',
    'id' => 'Indonezia',
    'ie' => 'Irlanda',
    'il' => 'Israel',
    'im' => "Insula\ Man",
    'in' => 'India',
    'io' => "Teritoriul\ Britanic\ din\ Oceanul\ Indian",
    'iq' => 'Irak',
    'ir' => 'Iran',
    'is' => 'Islanda',
    'it' => 'Italia',
    'je' => 'Jersey',
    'jm' => 'Jamaica',
    'jo' => 'Iordania',
    'jp' => 'Japonia',
    'jt' => "Johnston\ Island",
    'ke' => 'Kenya',
    'kg' => 'Kârgâzstan',
    'kh' => 'Cambodgia',
    'ki' => 'Kiribati',
    'km' => 'Comore',
    'kn' => "Sfântul\ Kitts\ și\ Nevis",
    'kp' => "Coreea\ de\ Nord",
    'kr' => "Coreea\ de\ Sud",
    'kw' => 'Kuweit',
    'ky' => "Insulele\ Cayman",
    'kz' => 'Kazahstan',
    'la' => 'Laos',
    'lb' => 'Liban',
    'lc' => "Sfânta\ Lucia",
    'li' => 'Liechtenstein',
    'lk' => "Sri\ Lanka",
    'lr' => 'Liberia',
    'ls' => 'Lesotho',
    'lt' => 'Lituania',
    'lu' => 'Luxemburg',
    'lv' => 'Letonia',
    'ly' => 'Libia',
    'ma' => 'Maroc',
    'mc' => 'Monaco',
    'md' => "Republica\ Moldova",
    'me' => 'Muntenegru',
    'mf' => "Sfântul\ Martin",
    'mg' => 'Madagascar',
    'mh' => "Insulele\ Marshall",
    'mi' => "Midway\ Islands",
    'mk' => 'Macedonia',
    'ml' => 'Mali',
    'mm' => 'Myanmar',
    'mn' => 'Mongolia',
    'mo' => 'Macao',
    'mp' => "Insulele\ Mariane\ de\ Nord",
    'mq' => 'Martinica',
    'mr' => 'Mauritania',
    'ms' => 'Montserrat',
    'mt' => 'Malta',
    'mu' => 'Mauritius',
    'mv' => 'Maldive',
    'mw' => 'Malawi',
    'mx' => 'Mexic',
    'my' => 'Malaezia',
    'mz' => 'Mozambic',
    'na' => 'Namibia',
    'nc' => "Noua\ Caledonie",
    'ne' => 'Niger',
    'nf' => "Insulele\ Norfolk",
    'ng' => 'Nigeria',
    'ni' => 'Nicaragua',
    'nl' => 'Olanda',
    'no' => 'Norvegia',
    'np' => 'Nepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "Noua\ Zeelandă",
    'om' => 'Oman',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Peru',
    'pf' => "Polinezia\ Franceză",
    'pg' => "Papua\ Noua\ Guinee",
    'ph' => 'Filipine',
    'pk' => 'Pakistan',
    'pl' => 'Polonia',
    'pm' => "Sfântul\ Petre\ și\ Miquelon",
    'pn' => 'Pitcairn',
    'pr' => "Porto\ Rico",
    'ps' => "Teritoriul\ Palestinian",
    'pt' => 'Portugalia',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paraguay',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Qatar',
    'qo' => "Oceania\ Periferică",
    'qu' => "Uniunea\ Europeană",
    're' => 'Reunion',
    'ro' => 'România',
    'rs' => 'Serbia',
    'ru' => 'Rusia',
    'rw' => 'Rwanda',
    'sa' => "Arabia\ Saudită",
    'sb' => "Insulele\ Solomon",
    'sc' => 'Seychelles',
    'sd' => 'Sudan',
    'se' => 'Suedia',
    'sg' => 'Singapore',
    'sh' => "Sfânta\ Elena",
    'si' => 'Slovenia',
    'sj' => "Svalbard\ și\ Jan\ Mayen",
    'sk' => 'Slovacia',
    'sl' => "Sierra\ Leone",
    'sm' => "San\ Marino",
    'sn' => 'Senegal',
    'so' => 'Somalia',
    'sr' => 'Surinam',
    'st' => "Sao\ Tome\ și\ Principe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salvador",
    'sy' => 'Siria',
    'sz' => 'Swaziland',
    'tc' => "Insulele\ Turks\ și\ Caicos",
    'td' => 'Ciad',
    'tf' => "Teritoriile\ Australe\ și\ Antarctice\ Franceze",
    'tg' => 'Togo',
    'th' => 'Thailanda',
    'tj' => 'Tadjikistan',
    'tk' => 'Tokelau',
    'tl' => "Timorul\ de\ Est",
    'tm' => 'Turkmenistan',
    'tn' => 'Tunisia',
    'to' => 'Tonga',
    'tr' => 'Turcia',
    'tt' => "Trinidad\-Tobago",
    'tv' => 'Tuvalu',
    'tw' => 'Taiwan',
    'tz' => 'Tanzania',
    'ua' => 'Ucraina',
    'ug' => 'Uganda',
    'um' => "Insulele\ mici\ îndepărtate\ ale\ Statelor\ Unite\ ale\ Americii",
    'us' => "Statele\ Unite\ ale\ Americii",
    'uy' => 'Uruguay',
    'uz' => 'Uzbekistan',
    'va' => 'Vatican',
    'vc' => "Sfântul\ Vincent\ și\ Grenadine",
    'vd' => "North\ Vietnam",
    've' => 'Venezuela',
    'vg' => "Insulele\ Virgine\ Britanice",
    'vi' => "Insulele\ Virgine\ S\.U\.A\.",
    'vn' => 'Vietnam',
    'vu' => 'Vanuatu',
    'wf' => "Wallis\ și\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Yemen',
    'yt' => 'Mayotte',
    'za' => "Africa\ de\ Sud",
    'zm' => 'Zambia',
    'zw' => 'Zimbabwe',
    'zz' => "Regiune\ necunoscută\ sau\ nevalidă",
);

%Locales::DB::Territory::ro::name_to_code = (
    'afganistan'                                           => 'af',
    'africadesud'                                          => 'za',
    'albania'                                              => 'al',
    'algeria'                                              => 'dz',
    'andorra'                                              => 'ad',
    'angola'                                               => 'ao',
    'anguilla'                                             => 'ai',
    'antarctica'                                           => 'aq',
    'antiguașibarbuda'                                    => 'ag',
    'antileleolandeze'                                     => 'an',
    'arabiasaudită'                                       => 'sa',
    'argentina'                                            => 'ar',
    'armenia'                                              => 'am',
    'aruba'                                                => 'aw',
    'australia'                                            => 'au',
    'austria'                                              => 'at',
    'azerbaidjan'                                          => 'az',
    'bahamas'                                              => 'bs',
    'bahrain'                                              => 'bh',
    'bangladesh'                                           => 'bd',
    'barbados'                                             => 'bb',
    'belgia'                                               => 'be',
    'belize'                                               => 'bz',
    'benin'                                                => 'bj',
    'bermuda'                                              => 'bm',
    'bhutan'                                               => 'bt',
    'bielorusia'                                           => 'by',
    'bolivia'                                              => 'bo',
    'bosniașiherțegovina'                                => 'ba',
    'botswana'                                             => 'bw',
    'brazilia'                                             => 'br',
    'britishantarcticterritory'                            => 'bq',
    'brunei'                                               => 'bn',
    'bulgaria'                                             => 'bg',
    'burkinafaso'                                          => 'bf',
    'burundi'                                              => 'bi',
    'cambodgia'                                            => 'kh',
    'camerun'                                              => 'cm',
    'canada'                                               => 'ca',
    'cantonandenderburyislands'                            => 'ct',
    'capulverde'                                           => 'cv',
    'chile'                                                => 'cl',
    'china'                                                => 'cn',
    'ciad'                                                 => 'td',
    'cipru'                                                => 'cy',
    'coastadefildeș'                                      => 'ci',
    'columbia'                                             => 'co',
    'comore'                                               => 'km',
    'congo'                                                => 'cg',
    'coreeadenord'                                         => 'kp',
    'coreeadesud'                                          => 'kr',
    'costarica'                                            => 'cr',
    'croația'                                             => 'hr',
    'cuba'                                                 => 'cu',
    'danemarca'                                            => 'dk',
    'djibouti'                                             => 'dj',
    'dominica'                                             => 'dm',
    'dronningmaudland'                                     => 'nq',
    'eastgermany'                                          => 'dd',
    'ecuador'                                              => 'ec',
    'egipt'                                                => 'eg',
    'eleveția'                                            => 'ch',
    'elsalvador'                                           => 'sv',
    'emiratelearabeunite'                                  => 'ae',
    'eritreea'                                             => 'er',
    'estonia'                                              => 'ee',
    'etiopia'                                              => 'et',
    'fiji'                                                 => 'fj',
    'filipine'                                             => 'ph',
    'finlanda'                                             => 'fi',
    'franța'                                              => 'fr',
    'frenchsouthernandantarcticterritories'                => 'fq',
    'gabon'                                                => 'ga',
    'gambia'                                               => 'gm',
    'georgia'                                              => 'ge',
    'germania'                                             => 'de',
    'ghana'                                                => 'gh',
    'gibraltar'                                            => 'gi',
    'grecia'                                               => 'gr',
    'grenada'                                              => 'gd',
    'groenlanda'                                           => 'gl',
    'guadelupa'                                            => 'gp',
    'guam'                                                 => 'gu',
    'guatemala'                                            => 'gt',
    'guernsey'                                             => 'gg',
    'guineea'                                              => 'gn',
    'guineeabissau'                                        => 'gw',
    'guineeaecuatorială'                                  => 'gq',
    'guyana'                                               => 'gy',
    'guyanafranceză'                                      => 'gf',
    'haiti'                                                => 'ht',
    'honduras'                                             => 'hn',
    'hongkong'                                             => 'hk',
    'india'                                                => 'in',
    'indonezia'                                            => 'id',
    'insulabouvet'                                         => 'bv',
    'insulachristmas'                                      => 'cx',
    'insulaheardșiinsulelemcdonald'                       => 'hm',
    'insulaman'                                            => 'im',
    'insulelealand'                                        => 'ax',
    'insulelecayman'                                       => 'ky',
    'insulelecocos'                                        => 'cc',
    'insulelecook'                                         => 'ck',
    'insulelefalkland'                                     => 'fk',
    'insuleleferoe'                                        => 'fo',
    'insulelegeorgiadesudșisandwichdesud'                 => 'gs',
    'insulelemarianedenord'                                => 'mp',
    'insulelemarshall'                                     => 'mh',
    'insulelemiciîndepărtatealestatelorunitealeamericii' => 'um',
    'insulelenorfolk'                                      => 'nf',
    'insulelesolomon'                                      => 'sb',
    'insuleleturksșicaicos'                               => 'tc',
    'insulelevirginebritanice'                             => 'vg',
    "insulelevirgines\.u\.a\."                             => 'vi',
    'iordania'                                             => 'jo',
    'irak'                                                 => 'iq',
    'iran'                                                 => 'ir',
    'irlanda'                                              => 'ie',
    'islanda'                                              => 'is',
    'israel'                                               => 'il',
    'italia'                                               => 'it',
    'jamaica'                                              => 'jm',
    'japonia'                                              => 'jp',
    'jersey'                                               => 'je',
    'johnstonisland'                                       => 'jt',
    'kazahstan'                                            => 'kz',
    'kenya'                                                => 'ke',
    'kiribati'                                             => 'ki',
    'kuweit'                                               => 'kw',
    'kârgâzstan'                                         => 'kg',
    'laos'                                                 => 'la',
    'lesotho'                                              => 'ls',
    'letonia'                                              => 'lv',
    'liban'                                                => 'lb',
    'liberia'                                              => 'lr',
    'libia'                                                => 'ly',
    'liechtenstein'                                        => 'li',
    'lituania'                                             => 'lt',
    'luxemburg'                                            => 'lu',
    'macao'                                                => 'mo',
    'macedonia'                                            => 'mk',
    'madagascar'                                           => 'mg',
    'malaezia'                                             => 'my',
    'malawi'                                               => 'mw',
    'maldive'                                              => 'mv',
    'mali'                                                 => 'ml',
    'malta'                                                => 'mt',
    'maroc'                                                => 'ma',
    'martinica'                                            => 'mq',
    'mauritania'                                           => 'mr',
    'mauritius'                                            => 'mu',
    'mayotte'                                              => 'yt',
    'metropolitanfrance'                                   => 'fx',
    'mexic'                                                => 'mx',
    'micronezia'                                           => 'fm',
    'midwayislands'                                        => 'mi',
    'monaco'                                               => 'mc',
    'mongolia'                                             => 'mn',
    'montserrat'                                           => 'ms',
    'mozambic'                                             => 'mz',
    'muntenegru'                                           => 'me',
    'myanmar'                                              => 'mm',
    'namibia'                                              => 'na',
    'nauru'                                                => 'nr',
    'nepal'                                                => 'np',
    'neutralzone'                                          => 'nt',
    'nicaragua'                                            => 'ni',
    'niger'                                                => 'ne',
    'nigeria'                                              => 'ng',
    'niue'                                                 => 'nu',
    'northvietnam'                                         => 'vd',
    'norvegia'                                             => 'no',
    'nouacaledonie'                                        => 'nc',
    'nouazeelandă'                                        => 'nz',
    'oceaniaperiferică'                                   => 'qo',
    'olanda'                                               => 'nl',
    'oman'                                                 => 'om',
    'pacificislandstrustterritory'                         => 'pc',
    'pakistan'                                             => 'pk',
    'palau'                                                => 'pw',
    'panama'                                               => 'pa',
    'panamacanalzone'                                      => 'pz',
    'papuanouaguinee'                                      => 'pg',
    'paraguay'                                             => 'py',
    'peoplesdemocraticrepublicofyemen'                     => 'yd',
    'peru'                                                 => 'pe',
    'pitcairn'                                             => 'pn',
    'polineziafranceză'                                   => 'pf',
    'polonia'                                              => 'pl',
    'portorico'                                            => 'pr',
    'portugalia'                                           => 'pt',
    'qatar'                                                => 'qa',
    'regatulunit'                                          => 'gb',
    'regiunenecunoscutăsaunevalidă'                      => 'zz',
    'republicacehă'                                       => 'cz',
    'republicacentrafricană'                              => 'cf',
    'republicademocratăcongo'                             => 'cd',
    'republicadominicană'                                 => 'do',
    'republicamoldova'                                     => 'md',
    'reunion'                                              => 're',
    'românia'                                             => 'ro',
    'rusia'                                                => 'ru',
    'rwanda'                                               => 'rw',
    'saharaoccidentală'                                   => 'eh',
    'samoa'                                                => 'ws',
    'samoaamericană'                                      => 'as',
    'sanmarino'                                            => 'sm',
    'saotomeșiprincipe'                                   => 'st',
    'senegal'                                              => 'sn',
    'serbia'                                               => 'rs',
    'serbiașimuntenegru'                                  => 'cs',
    'seychelles'                                           => 'sc',
    'sfântaelena'                                         => 'sh',
    'sfântalucia'                                         => 'lc',
    'sfântulbartolomeu'                                   => 'bl',
    'sfântulkittsșinevis'                                => 'kn',
    'sfântulmartin'                                       => 'mf',
    'sfântulpetreșimiquelon'                             => 'pm',
    'sfântulvincentșigrenadine'                          => 'vc',
    'sierraleone'                                          => 'sl',
    'singapore'                                            => 'sg',
    'siria'                                                => 'sy',
    'slovacia'                                             => 'sk',
    'slovenia'                                             => 'si',
    'somalia'                                              => 'so',
    'spania'                                               => 'es',
    'srilanka'                                             => 'lk',
    'stateleunitealeamericii'                              => 'us',
    'sudan'                                                => 'sd',
    'suedia'                                               => 'se',
    'surinam'                                              => 'sr',
    'svalbardșijanmayen'                                  => 'sj',
    'swaziland'                                            => 'sz',
    'tadjikistan'                                          => 'tj',
    'taiwan'                                               => 'tw',
    'tanzania'                                             => 'tz',
    'teritoriileaustraleșiantarcticefranceze'             => 'tf',
    'teritoriulbritanicdinoceanulindian'                   => 'io',
    'teritoriulpalestinian'                                => 'ps',
    'thailanda'                                            => 'th',
    'timoruldeest'                                         => 'tl',
    'togo'                                                 => 'tg',
    'tokelau'                                              => 'tk',
    'tonga'                                                => 'to',
    'trinidadtobago'                                       => 'tt',
    'tunisia'                                              => 'tn',
    'turcia'                                               => 'tr',
    'turkmenistan'                                         => 'tm',
    'tuvalu'                                               => 'tv',
    "u\.s\.miscellaneouspacificislands"                    => 'pu',
    'ucraina'                                              => 'ua',
    'uganda'                                               => 'ug',
    'ungaria'                                              => 'hu',
    'unionofsovietsocialistrepublics'                      => 'su',
    'uniuneaeuropeană'                                    => 'qu',
    'uruguay'                                              => 'uy',
    'uzbekistan'                                           => 'uz',
    'vanuatu'                                              => 'vu',
    'vatican'                                              => 'va',
    'venezuela'                                            => 've',
    'vietnam'                                              => 'vn',
    'wakeisland'                                           => 'wk',
    'wallisșifutuna'                                      => 'wf',
    'yemen'                                                => 'ye',
    'zambia'                                               => 'zm',
    'zimbabwe'                                             => 'zw',
);

1;

