package Locales::DB::Territory::lt;

# Auto generated from CLDR

$Locales::DB::Territory::lt::VERSION = '0.02';

$Locales::DB::Territory::lt::cldr_version = '1.7.1';

%Locales::DB::Territory::lt::code_to_name = (
    'ad' => 'Andora',
    'ae' => "Jungtiniai\ Arabų\ Emyratai",
    'af' => 'Afganistanas',
    'ag' => "Antigva\ ir\ Barbuda",
    'ai' => 'Angilija',
    'al' => 'Albanija',
    'am' => 'Armėnija',
    'an' => "Olandijos\ Antilai",
    'ao' => 'Angola',
    'aq' => 'Antarktis',
    'ar' => 'Argentina',
    'as' => "Amerikos\ Samoa",
    'at' => 'Austrija',
    'au' => 'Australija',
    'aw' => 'Aruba',
    'ax' => 'Åland',
    'az' => 'Azerbaidžanas',
    'ba' => "Bosnija\ ir\ Hercegovina",
    'bb' => 'Barbadosas',
    'bd' => 'Bangladešas',
    'be' => 'Belgija',
    'bf' => "Burkina\ Fasas",
    'bg' => 'Bulgarija',
    'bh' => 'Bahreinas',
    'bi' => 'Burundis',
    'bj' => 'Beninas',
    'bl' => "Saint\ Barthélemy",
    'bm' => 'Bermuda',
    'bn' => 'Brunėjus',
    'bo' => 'Bolivija',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brazilija',
    'bs' => 'Bahamos',
    'bt' => 'Butanas',
    'bv' => "Bouvet\ sala",
    'bw' => 'Botsvana',
    'by' => 'Baltarusija',
    'bz' => 'Belizas',
    'ca' => 'Kanada',
    'cc' => "Kokosų\ salos",
    'cd' => "Kongo\ Demokratinė\ Respublika",
    'cf' => "Centrinės\ Afrikos\ Respublika",
    'cg' => 'Kongas',
    'ch' => 'Šveicarija',
    'ci' => "Dramblio\ Kaulo\ Krantas",
    'ck' => "Kuko\ salos",
    'cl' => 'Čilė',
    'cm' => 'Kamerūnas',
    'cn' => 'Kinija',
    'co' => 'Kolumbija',
    'cr' => "Kosta\ Rika",
    'cs' => "Serbija\ ir\ Juodkalnija",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Kuba',
    'cv' => "Žaliasis\ Kyšulys",
    'cx' => "Kalėdų\ sala",
    'cy' => 'Kipras',
    'cz' => 'Čekija',
    'dd' => "East\ Germany",
    'de' => 'Vokietija',
    'dj' => 'Džibutis',
    'dk' => 'Danija',
    'dm' => 'Dominika',
    'do' => "Dominikos\ Respublika",
    'dz' => 'Alžyras',
    'ec' => 'Ekvadoras',
    'ee' => 'Estija',
    'eg' => 'Egiptas',
    'eh' => "Vakarų\ Sachara",
    'er' => 'Eritrėja',
    'es' => 'Ispanija',
    'et' => 'Etiopija',
    'fi' => 'Suomija',
    'fj' => 'Fidžis',
    'fk' => "Falklando\ salos",
    'fm' => 'Mikronezija',
    'fo' => "Farerų\ salos",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Prancūzija',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabonas',
    'gb' => "Didžioji\ Britanija",
    'gd' => 'Grenada',
    'ge' => 'Gruzija',
    'gf' => "Prancūzijos\ Gviana",
    'gg' => 'Guernsis',
    'gh' => 'Gana',
    'gi' => 'Gibraltaras',
    'gl' => 'Grenlandija',
    'gm' => 'Gambija',
    'gn' => 'Gvinėja',
    'gp' => 'Gvadelupė',
    'gq' => "Pusiaujo\ Gvinėja",
    'gr' => 'Graikija',
    'gs' => "Pietų\ Džordžija\ ir\ Pietų\ Sandvičo\ salos",
    'gt' => 'Gvatemala',
    'gu' => 'Guamas',
    'gw' => "Bisau\ Gvinėja",
    'gy' => 'Gajana',
    'hk' => 'Honkongas',
    'hm' => "Heardo\ ir\ McDonaldo\ Salų\ Sritis",
    'hn' => 'Hondūras',
    'hr' => 'Kroatija',
    'ht' => 'Haitis',
    'hu' => 'Vengrija',
    'id' => 'Indonezija',
    'ie' => 'Airija',
    'il' => 'Izraelis',
    'im' => "Meino\ sala",
    'in' => 'Indija',
    'io' => "Indijos\ vandenyno\ britų\ sritis",
    'iq' => 'Irakas',
    'ir' => 'Iranas',
    'is' => 'Islandija',
    'it' => 'Italija',
    'je' => 'Džersis',
    'jm' => 'Jamaika',
    'jo' => 'Jordanija',
    'jp' => 'Japonija',
    'jt' => "Johnston\ Island",
    'ke' => 'Kenija',
    'kg' => 'Kirgiztanas',
    'kh' => 'Kambodža',
    'ki' => 'Kiribatis',
    'km' => 'Komorai',
    'kn' => "Sent\ Kitsas\ ir\ Nevis",
    'kp' => "Šiaurės\ Korėja",
    'kr' => "Pietų\ Korėja",
    'kw' => 'Kuveitas',
    'ky' => "Kaimanų\ salos",
    'kz' => 'Kazachstanas',
    'la' => 'Laosas',
    'lb' => 'Libanas',
    'lc' => "Šventoji\ Liucija",
    'li' => 'Lichtenšteinas',
    'lk' => "Šri\ Lanka",
    'lr' => 'Liberija',
    'ls' => 'Lesotas',
    'lt' => 'Lietuva',
    'lu' => 'Liuksemburgas',
    'lv' => 'Latvija',
    'ly' => 'Libija',
    'ma' => 'Marokas',
    'mc' => 'Monakas',
    'md' => 'Moldova',
    'me' => 'Juodkalnija',
    'mf' => "Saint\ Martin",
    'mg' => 'Madagaskaras',
    'mh' => "Maršalo\ Salos",
    'mi' => "Midway\ Islands",
    'mk' => 'Makedonija',
    'ml' => 'Malis',
    'mm' => 'Mianmaras',
    'mn' => 'Mongolija',
    'mo' => 'Macao',
    'mp' => "Marianos\ šiaurinės\ salos",
    'mq' => 'Martinika',
    'mr' => 'Mauritanija',
    'ms' => 'Montserratas',
    'mt' => 'Malta',
    'mu' => 'Mauricijus',
    'mv' => 'Maldivai',
    'mw' => 'Malavis',
    'mx' => 'Meksika',
    'my' => 'Malaizija',
    'mz' => 'Mozambikas',
    'na' => 'Namibija',
    'nc' => "Naujoji\ Kaledonija",
    'ne' => 'Nigeris',
    'nf' => "Norfolko\ sala",
    'ng' => 'Nigerija',
    'ni' => 'Nikaragva',
    'nl' => 'Nyderlandai',
    'no' => 'Norvegija',
    'np' => 'Nepalas',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "Naujoji\ Zelandija",
    'om' => 'Omanas',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Peru',
    'pf' => "Prancūzų\ Polinezija",
    'pg' => "Papua\ Naujoji\ Gvinėja",
    'ph' => 'Filipinai',
    'pk' => 'Pakistanas',
    'pl' => 'Lenkija',
    'pm' => "Sen\ Pjeras\ ir\ Mikelonas",
    'pn' => 'Pitkernas',
    'pr' => "Puerto\ Rikas",
    'ps' => "Palestinos\ teritorija",
    'pt' => 'Portugalija',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paragvajus',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Kataras',
    'qo' => "Outlying\ Oceania",
    'qu' => "Europos\ Sąjunga",
    're' => 'Reunionas',
    'ro' => 'Rumunija',
    'rs' => 'Serbija',
    'ru' => "Rusijos\ Federacija",
    'rw' => 'Ruanda',
    'sa' => "Saudo\ Arabija",
    'sb' => "Saliamono\ salos",
    'sc' => 'Seišeliai',
    'sd' => 'Sudanas',
    'se' => 'Švedija',
    'sg' => 'Singapūras',
    'sh' => "Šventoji\ Elena",
    'si' => 'Slovėnija',
    'sj' => "Svalbardo\ ir\ Jan\ Majen\ salos",
    'sk' => 'Slovakija',
    'sl' => "Siera\ Leonė",
    'sm' => "San\ Marinas",
    'sn' => 'Senegalas',
    'so' => 'Somalis',
    'sr' => 'Surinamas',
    'st' => "San\ Tomė\ ir\ Principė",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => 'Salvadoras',
    'sy' => 'Sirija',
    'sz' => 'Svazilendas',
    'tc' => "Turkso\ ir\ Caicoso\ salos",
    'td' => 'Čadas',
    'tf' => "Prancūzijos\ Pietų\ sritys",
    'tg' => 'Togas',
    'th' => 'Tailandas',
    'tj' => 'Tadžikistanas',
    'tk' => 'Tokelau',
    'tl' => "Rytų\ Timoras",
    'tm' => 'Turkmėnistanas',
    'tn' => 'Tunisas',
    'to' => 'Tonga',
    'tr' => 'Turkija',
    'tt' => "Trinidadas\ ir\ Tobagas",
    'tv' => 'Tuvalu',
    'tw' => 'Taivanas',
    'tz' => 'Tanzanija',
    'ua' => 'Ukraina',
    'ug' => 'Uganda',
    'um' => "Jungtinių\ Valstijų\ mažosios\ aplinkinės\ salos",
    'us' => "Jungtinės\ Valstijos",
    'uy' => 'Urugvajus',
    'uz' => 'Uzbekistanas',
    'va' => 'Vatikanas',
    'vc' => "Šventasis\ Vincentas\ ir\ Grenadinai",
    'vd' => "North\ Vietnam",
    've' => 'Venesuela',
    'vg' => "Didžiosios\ Britanijos\ Mergelių\ salos",
    'vi' => "JAV\ Mergelių\ salos",
    'vn' => 'Vietnamas',
    'vu' => 'Vanuatu',
    'wf' => "Wallisas\ ir\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Jemenas',
    'yt' => 'Mayotte’as',
    'za' => "Pietų\ Afrika",
    'zm' => 'Zambija',
    'zw' => 'Zimbabvė',
    'zz' => "\(nežinoma\ sritis\)",
);

%Locales::DB::Territory::lt::name_to_code = (
    'afganistanas'                                 => 'af',
    'airija'                                       => 'ie',
    'albanija'                                     => 'al',
    'alžyras'                                     => 'dz',
    'amerikossamoa'                                => 'as',
    'andora'                                       => 'ad',
    'angilija'                                     => 'ai',
    'angola'                                       => 'ao',
    'antarktis'                                    => 'aq',
    'antigvairbarbuda'                             => 'ag',
    'argentina'                                    => 'ar',
    'armėnija'                                    => 'am',
    'aruba'                                        => 'aw',
    'australija'                                   => 'au',
    'austrija'                                     => 'at',
    'azerbaidžanas'                               => 'az',
    'bahamos'                                      => 'bs',
    'bahreinas'                                    => 'bh',
    'baltarusija'                                  => 'by',
    'bangladešas'                                 => 'bd',
    'barbadosas'                                   => 'bb',
    'belgija'                                      => 'be',
    'belizas'                                      => 'bz',
    'beninas'                                      => 'bj',
    'bermuda'                                      => 'bm',
    'bisaugvinėja'                                => 'gw',
    'bolivija'                                     => 'bo',
    'bosnijairhercegovina'                         => 'ba',
    'botsvana'                                     => 'bw',
    'bouvetsala'                                   => 'bv',
    'brazilija'                                    => 'br',
    'britishantarcticterritory'                    => 'bq',
    'brunėjus'                                    => 'bn',
    'bulgarija'                                    => 'bg',
    'burkinafasas'                                 => 'bf',
    'burundis'                                     => 'bi',
    'butanas'                                      => 'bt',
    'cantonandenderburyislands'                    => 'ct',
    'centrinėsafrikosrespublika'                  => 'cf',
    'danija'                                       => 'dk',
    'didžiojibritanija'                           => 'gb',
    'didžiosiosbritanijosmergeliųsalos'          => 'vg',
    'dominika'                                     => 'dm',
    'dominikosrespublika'                          => 'do',
    'drambliokaulokrantas'                         => 'ci',
    'dronningmaudland'                             => 'nq',
    'džersis'                                     => 'je',
    'džibutis'                                    => 'dj',
    'eastgermany'                                  => 'dd',
    'egiptas'                                      => 'eg',
    'ekvadoras'                                    => 'ec',
    'eritrėja'                                    => 'er',
    'estija'                                       => 'ee',
    'etiopija'                                     => 'et',
    'europossąjunga'                              => 'qu',
    'falklandosalos'                               => 'fk',
    'farerųsalos'                                 => 'fo',
    'fidžis'                                      => 'fj',
    'filipinai'                                    => 'ph',
    'frenchsouthernandantarcticterritories'        => 'fq',
    'gabonas'                                      => 'ga',
    'gajana'                                       => 'gy',
    'gambija'                                      => 'gm',
    'gana'                                         => 'gh',
    'gibraltaras'                                  => 'gi',
    'graikija'                                     => 'gr',
    'grenada'                                      => 'gd',
    'grenlandija'                                  => 'gl',
    'gruzija'                                      => 'ge',
    'guamas'                                       => 'gu',
    'guernsis'                                     => 'gg',
    'gvadelupė'                                   => 'gp',
    'gvatemala'                                    => 'gt',
    'gvinėja'                                     => 'gn',
    'haitis'                                       => 'ht',
    'heardoirmcdonaldosalųsritis'                 => 'hm',
    'hondūras'                                    => 'hn',
    'honkongas'                                    => 'hk',
    'indija'                                       => 'in',
    'indijosvandenynobritųsritis'                 => 'io',
    'indonezija'                                   => 'id',
    'irakas'                                       => 'iq',
    'iranas'                                       => 'ir',
    'islandija'                                    => 'is',
    'ispanija'                                     => 'es',
    'italija'                                      => 'it',
    'izraelis'                                     => 'il',
    'jamaika'                                      => 'jm',
    'japonija'                                     => 'jp',
    'javmergeliųsalos'                            => 'vi',
    'jemenas'                                      => 'ye',
    'johnstonisland'                               => 'jt',
    'jordanija'                                    => 'jo',
    'jungtiniaiarabųemyratai'                     => 'ae',
    'jungtiniųvalstijųmažosiosaplinkinėssalos' => 'um',
    'jungtinėsvalstijos'                          => 'us',
    'juodkalnija'                                  => 'me',
    'kaimanųsalos'                                => 'ky',
    'kalėdųsala'                                 => 'cx',
    'kambodža'                                    => 'kh',
    'kamerūnas'                                   => 'cm',
    'kanada'                                       => 'ca',
    'kataras'                                      => 'qa',
    'kazachstanas'                                 => 'kz',
    'kenija'                                       => 'ke',
    'kinija'                                       => 'cn',
    'kipras'                                       => 'cy',
    'kirgiztanas'                                  => 'kg',
    'kiribatis'                                    => 'ki',
    'kokosųsalos'                                 => 'cc',
    'kolumbija'                                    => 'co',
    'komorai'                                      => 'km',
    'kongas'                                       => 'cg',
    'kongodemokratinėrespublika'                  => 'cd',
    'kostarika'                                    => 'cr',
    'kroatija'                                     => 'hr',
    'kuba'                                         => 'cu',
    'kukosalos'                                    => 'ck',
    'kuveitas'                                     => 'kw',
    'laosas'                                       => 'la',
    'latvija'                                      => 'lv',
    'lenkija'                                      => 'pl',
    'lesotas'                                      => 'ls',
    'libanas'                                      => 'lb',
    'liberija'                                     => 'lr',
    'libija'                                       => 'ly',
    'lichtenšteinas'                              => 'li',
    'lietuva'                                      => 'lt',
    'liuksemburgas'                                => 'lu',
    'macao'                                        => 'mo',
    'madagaskaras'                                 => 'mg',
    'makedonija'                                   => 'mk',
    'malaizija'                                    => 'my',
    'malavis'                                      => 'mw',
    'maldivai'                                     => 'mv',
    'malis'                                        => 'ml',
    'malta'                                        => 'mt',
    'marianosšiaurinėssalos'                     => 'mp',
    'marokas'                                      => 'ma',
    'martinika'                                    => 'mq',
    'maršalosalos'                                => 'mh',
    'mauricijus'                                   => 'mu',
    'mauritanija'                                  => 'mr',
    'mayotte’as'                                 => 'yt',
    'meinosala'                                    => 'im',
    'meksika'                                      => 'mx',
    'metropolitanfrance'                           => 'fx',
    'mianmaras'                                    => 'mm',
    'midwayislands'                                => 'mi',
    'mikronezija'                                  => 'fm',
    'moldova'                                      => 'md',
    'monakas'                                      => 'mc',
    'mongolija'                                    => 'mn',
    'montserratas'                                 => 'ms',
    'mozambikas'                                   => 'mz',
    'namibija'                                     => 'na',
    'naujojikaledonija'                            => 'nc',
    'naujojizelandija'                             => 'nz',
    'nauru'                                        => 'nr',
    'nepalas'                                      => 'np',
    'neutralzone'                                  => 'nt',
    'nežinomasritis'                              => 'zz',
    'nigerija'                                     => 'ng',
    'nigeris'                                      => 'ne',
    'nikaragva'                                    => 'ni',
    'niue'                                         => 'nu',
    'norfolkosala'                                 => 'nf',
    'northvietnam'                                 => 'vd',
    'norvegija'                                    => 'no',
    'nyderlandai'                                  => 'nl',
    'olandijosantilai'                             => 'an',
    'omanas'                                       => 'om',
    'outlyingoceania'                              => 'qo',
    'pacificislandstrustterritory'                 => 'pc',
    'pakistanas'                                   => 'pk',
    'palau'                                        => 'pw',
    'palestinosteritorija'                         => 'ps',
    'panama'                                       => 'pa',
    'panamacanalzone'                              => 'pz',
    'papuanaujojigvinėja'                         => 'pg',
    'paragvajus'                                   => 'py',
    'peoplesdemocraticrepublicofyemen'             => 'yd',
    'peru'                                         => 'pe',
    'pietųafrika'                                 => 'za',
    'pietųdžordžijairpietųsandvičosalos'      => 'gs',
    'pietųkorėja'                                => 'kr',
    'pitkernas'                                    => 'pn',
    'portugalija'                                  => 'pt',
    'prancūzija'                                  => 'fr',
    'prancūzijosgviana'                           => 'gf',
    'prancūzijospietųsritys'                     => 'tf',
    'prancūzųpolinezija'                         => 'pf',
    'puertorikas'                                  => 'pr',
    'pusiaujogvinėja'                             => 'gq',
    'reunionas'                                    => 're',
    'ruanda'                                       => 'rw',
    'rumunija'                                     => 'ro',
    'rusijosfederacija'                            => 'ru',
    'rytųtimoras'                                 => 'tl',
    'saintbarthélemy'                             => 'bl',
    'saintmartin'                                  => 'mf',
    'saliamonosalos'                               => 'sb',
    'salvadoras'                                   => 'sv',
    'samoa'                                        => 'ws',
    'sanmarinas'                                   => 'sm',
    'santomėirprincipė'                          => 'st',
    'saudoarabija'                                 => 'sa',
    'seišeliai'                                   => 'sc',
    'senegalas'                                    => 'sn',
    'senpjerasirmikelonas'                         => 'pm',
    'sentkitsasirnevis'                            => 'kn',
    'serbija'                                      => 'rs',
    'serbijairjuodkalnija'                         => 'cs',
    'sieraleonė'                                  => 'sl',
    'singapūras'                                  => 'sg',
    'sirija'                                       => 'sy',
    'slovakija'                                    => 'sk',
    'slovėnija'                                   => 'si',
    'somalis'                                      => 'so',
    'sudanas'                                      => 'sd',
    'suomija'                                      => 'fi',
    'surinamas'                                    => 'sr',
    'svalbardoirjanmajensalos'                     => 'sj',
    'svazilendas'                                  => 'sz',
    'tadžikistanas'                               => 'tj',
    'tailandas'                                    => 'th',
    'taivanas'                                     => 'tw',
    'tanzanija'                                    => 'tz',
    'togas'                                        => 'tg',
    'tokelau'                                      => 'tk',
    'tonga'                                        => 'to',
    'trinidadasirtobagas'                          => 'tt',
    'tunisas'                                      => 'tn',
    'turkija'                                      => 'tr',
    'turkmėnistanas'                              => 'tm',
    'turksoircaicososalos'                         => 'tc',
    'tuvalu'                                       => 'tv',
    "u\.s\.miscellaneouspacificislands"            => 'pu',
    'uganda'                                       => 'ug',
    'ukraina'                                      => 'ua',
    'unionofsovietsocialistrepublics'              => 'su',
    'urugvajus'                                    => 'uy',
    'uzbekistanas'                                 => 'uz',
    'vakarųsachara'                               => 'eh',
    'vanuatu'                                      => 'vu',
    'vatikanas'                                    => 'va',
    'venesuela'                                    => 've',
    'vengrija'                                     => 'hu',
    'vietnamas'                                    => 'vn',
    'vokietija'                                    => 'de',
    'wakeisland'                                   => 'wk',
    'wallisasirfutuna'                             => 'wf',
    'zambija'                                      => 'zm',
    'zimbabvė'                                    => 'zw',
    'Åland'                                       => 'ax',
    'Čadas'                                       => 'td',
    'Čekija'                                      => 'cz',
    'Čilė'                                       => 'cl',
    'Šiaurėskorėja'                             => 'kp',
    'Šrilanka'                                    => 'lk',
    'Švedija'                                     => 'se',
    'Šveicarija'                                  => 'ch',
    'Šventasisvincentasirgrenadinai'              => 'vc',
    'Šventojielena'                               => 'sh',
    'Šventojiliucija'                             => 'lc',
    'Žaliasiskyšulys'                            => 'cv',
);

1;

