package Locales::DB::Territory::az;

# Auto generated from CLDR

$Locales::DB::Territory::az::VERSION = '0.02';

$Locales::DB::Territory::az::cldr_version = '1.7.1';

%Locales::DB::Territory::az::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "Birləşmiş\ Ərəb\ Emiratları",
    'af' => 'Əfqənistan',
    'ag' => "Antiqua\ və\ Barbuda",
    'ai' => 'Anquila',
    'al' => 'Albaniya',
    'am' => 'Ermənistan',
    'an' => "Hollandiya\ antilleri",
    'ao' => 'Angola',
    'aq' => 'Antarktika',
    'ar' => 'Arqentina',
    'as' => "Amerika\ Samoası",
    'at' => 'Avstriya',
    'au' => 'Avstraliya',
    'aw' => 'Aruba',
    'ax' => "Aland\ Adaları",
    'az' => 'Azərbaycan',
    'ba' => "Bosniya\ və\ Herzokovina",
    'bb' => 'Barbados',
    'bd' => 'Banqladeş',
    'be' => 'Belçika',
    'bf' => "Burkina\ Faso",
    'bg' => 'Bolqariya',
    'bh' => 'Bahreyn',
    'bi' => 'Burundi',
    'bj' => 'Benin',
    'bl' => "Seynt\ Bartelemey",
    'bm' => 'Bermuda',
    'bn' => 'Bruney',
    'bo' => 'Boliviya',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Braziliya',
    'bs' => 'Bahamalar',
    'bt' => 'Butan',
    'bv' => "Bove\ Adası",
    'bw' => 'Botsvana',
    'by' => 'Belarus',
    'bz' => 'Beliz',
    'ca' => 'Kanada',
    'cc' => "Kokos\ Adaları",
    'cd' => "Konqo\ \-\ Kinşasa",
    'cf' => "Orta\ Afrika\ respublikası",
    'cg' => "Konqo\ \-\ Brazavil",
    'ch' => 'isveçriya',
    'ci' => "İvori\ Sahili",
    'ck' => "Kuk\ Adaları",
    'cl' => 'Çile',
    'cm' => 'Kamerun',
    'cn' => 'Çin',
    'co' => 'Kolumbiya',
    'cr' => "Kosta\ Rika",
    'cs' => "Serbia\ and\ Montenegro",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Kuba',
    'cv' => "Kape\ Verde",
    'cx' => "Çristmas\ Adası",
    'cy' => 'Kipr',
    'cz' => "Çex\ respublikası",
    'dd' => "East\ Germany",
    'de' => 'Almaniya',
    'dj' => 'Ciboti',
    'dk' => 'Danemarka',
    'dm' => 'Dominika',
    'do' => "Dominik\ Respublikası",
    'dz' => 'Cezayır',
    'ec' => 'Ekvador',
    'ee' => 'Estoniya',
    'eg' => 'Misir',
    'eh' => "Qərb\ Sahara",
    'er' => 'Eritreya',
    'es' => 'İspaniya',
    'et' => 'Efiopiya',
    'fi' => 'Finlandiya',
    'fj' => 'Fici',
    'fk' => "Folkland\ Adaları",
    'fm' => 'Mikronesiya',
    'fo' => "Faro\ Adaları",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Fransa',
    'fx' => "Metropolitan\ France",
    'ga' => 'Qabon',
    'gb' => "Birləşmiş\ Krallıq",
    'gd' => 'Qrenada',
    'ge' => 'Gürcüstan',
    'gf' => "Fransız\ Quyanası",
    'gg' => 'Görnsey',
    'gh' => 'Qana',
    'gi' => 'Gibraltar',
    'gl' => 'Qrinland',
    'gm' => 'Qambiya',
    'gn' => 'Qvineya',
    'gp' => 'Qvadalup',
    'gq' => "Ekvator\ Qineya",
    'gr' => 'Yunanıstan',
    'gs' => "Cənub\ Gürcüstan\ və\ Cənub\ Sandvilç\ Adaları",
    'gt' => 'Qvatemala',
    'gu' => 'Quam',
    'gw' => "Qvineya\-Bisau",
    'gy' => 'Quyana',
    'hk' => "Honk\ Konq",
    'hm' => "Hörd\ və\ Makdonald\ Adaları",
    'hn' => 'Qonduras',
    'hr' => 'Xorvatiya',
    'ht' => 'Haiti',
    'hu' => 'Macaristan',
    'id' => 'İndoneziya',
    'ie' => 'İrlandiya',
    'il' => 'İzrail',
    'im' => "Man\ Adası",
    'in' => 'Hindistan',
    'io' => "Britaniya\-Hindistan\ Okeanik\ territoriyası",
    'iq' => 'İrak',
    'ir' => 'İran',
    'is' => 'İslandiya',
    'it' => 'İtaliya',
    'je' => 'Cörsi',
    'jm' => 'Yamayka',
    'jo' => 'Ürdün',
    'jp' => 'Yaponiya',
    'jt' => "Johnston\ Island",
    'ke' => 'Kenya',
    'kg' => 'Kırqızstan',
    'kh' => 'Kambodiya',
    'ki' => 'Kiribati',
    'km' => 'Komoros',
    'kn' => "Seynt\ Kits\ və\ Nevis",
    'kp' => "Şimal\ Koreya",
    'kr' => "Cənub\ Koreya",
    'kw' => 'Kuveyt',
    'ky' => "Kayman\ Adaları",
    'kz' => 'Kazaxstan',
    'la' => 'Laos',
    'lb' => 'Lebanon',
    'lc' => "Seynt\ Lusiya",
    'li' => 'Lixtenşteyn',
    'lk' => "Şri\ Lanka",
    'lr' => 'Liberiya',
    'ls' => 'Lesoto',
    'lt' => 'Litva',
    'lu' => 'Lüksemburq',
    'lv' => 'Latviya',
    'ly' => 'Libya',
    'ma' => 'Morokko',
    'mc' => 'Monako',
    'md' => 'Moldova',
    'me' => 'Monteneqro',
    'mf' => "Seynt\ Martin",
    'mg' => 'Madaqaskar',
    'mh' => "Marşal\ Adaları",
    'mi' => "Midway\ Islands",
    'mk' => 'Masedoniya',
    'ml' => 'Mali',
    'mm' => 'Myanmar',
    'mn' => 'Monqoliya',
    'mo' => 'Makao',
    'mp' => "Şimal\ Mariana\ Adaları",
    'mq' => 'Martiniqu',
    'mr' => 'Mavritaniya',
    'ms' => 'Montserat',
    'mt' => 'Malta',
    'mu' => 'Mavritis',
    'mv' => 'Maldiv',
    'mw' => 'Malavi',
    'mx' => 'Meksika',
    'my' => 'Malaysiya',
    'mz' => 'Mazambik',
    'na' => 'Namibiya',
    'nc' => "Yeni\ Kaledoniya",
    'ne' => 'nijer',
    'nf' => "Norfolk\ Adası",
    'ng' => 'Nijeriya',
    'ni' => 'Nikaraqua',
    'nl' => 'Hollandiya',
    'no' => 'Norvec',
    'np' => 'Nepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niye',
    'nz' => "Yeni\ Zelandiya",
    'om' => 'Oman',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Peru',
    'pf' => "Fransız\ Polineziya",
    'pg' => "Papua\ Yeni\ Qvineya",
    'ph' => 'Filipin',
    'pk' => 'Pakistan',
    'pl' => 'Polşa',
    'pm' => "Seynt\ Piyer\ və\ Mikelon",
    'pn' => 'Pitkarn',
    'pr' => "Puerto\ Riko",
    'ps' => "Fələstin\ Bölqüsü",
    'pt' => 'Portuqal',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palav',
    'py' => 'Paraqvay',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Qatar',
    'qo' => "Uzak\ Okeyaniya",
    'qu' => "Avropa\ Birləşliyi",
    're' => 'Reyunion',
    'ro' => 'Romaniya',
    'rs' => 'Serbiya',
    'ru' => 'Rusiya',
    'rw' => 'Rvanda',
    'sa' => "Saudi\ Ərəbistan",
    'sb' => "Solomon\ Adaları",
    'sc' => 'Seyçels',
    'sd' => 'sudan',
    'se' => 'isveç',
    'sg' => 'Sinqapur',
    'sh' => "Seynt\ Elena",
    'si' => 'Sloveniya',
    'sj' => "svalbard\ və\ yan\ mayen",
    'sk' => 'Slovakiya',
    'sl' => "Siyera\ Leon",
    'sm' => "San\ Marino",
    'sn' => 'Seneqal',
    'so' => 'Somaliya',
    'sr' => 'surinamə',
    'st' => "Sao\ Tom\ və\ Prinsip",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salvador",
    'sy' => 'siriya',
    'sz' => 'svazilənd',
    'tc' => "Türk\ və\ Kaykos\ Adaları",
    'td' => 'Çad',
    'tf' => "Fransız\ Cənub\ teritoriyası",
    'tg' => 'Toqo',
    'th' => 'tayland',
    'tj' => 'tacikistan',
    'tk' => 'Tokelau',
    'tl' => "Şərq\ Timor",
    'tm' => 'Türkmənistan',
    'tn' => 'Tunisiya',
    'to' => 'Tonqa',
    'tr' => 'Türkiya',
    'tt' => "Trinidan\ və\ Tobaqo",
    'tv' => 'Tuvalu',
    'tw' => 'tayvan',
    'tz' => 'tanzaniya',
    'ua' => 'Ukraina',
    'ug' => 'Uqanda',
    'um' => "Birləşmiş\ Ştatların\ uzaq\ adaları",
    'us' => "Amerika\ Birləşmiş\ Ştatları",
    'uy' => 'Uruqvay',
    'uz' => 'Özbəkistan',
    'va' => 'Vatikan',
    'vc' => "Seynt\ Vinsent\ və\ Qrenada",
    'vd' => "North\ Vietnam",
    've' => 'Venesuela',
    'vg' => "Britaniya\ Virgin\ Adaları",
    'vi' => "ABŞ\ Virqin\ Adaları",
    'vn' => 'Vyetnam',
    'vu' => 'Vanuatu',
    'wf' => "Valis\ və\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Yemen',
    'yt' => 'Mayot',
    'za' => "Cənub\ Afrika",
    'zm' => 'Zambiya',
    'zw' => 'Zimbabve',
    'zz' => 'bilinmir',
);

%Locales::DB::Territory::az::name_to_code = (
    'abŞvirqinadaları'                          => 'vi',
    'alandadaları'                               => 'ax',
    'albaniya'                                    => 'al',
    'almaniya'                                    => 'de',
    'amerikabirləşmişŞtatları'               => 'us',
    'amerikasamoası'                             => 'as',
    'andorra'                                     => 'ad',
    'angola'                                      => 'ao',
    'anquila'                                     => 'ai',
    'antarktika'                                  => 'aq',
    'antiquavəbarbuda'                           => 'ag',
    'arqentina'                                   => 'ar',
    'aruba'                                       => 'aw',
    'avropabirləşliyi'                          => 'qu',
    'avstraliya'                                  => 'au',
    'avstriya'                                    => 'at',
    'azərbaycan'                                 => 'az',
    'bahamalar'                                   => 'bs',
    'bahreyn'                                     => 'bh',
    'banqladeş'                                  => 'bd',
    'barbados'                                    => 'bb',
    'belarus'                                     => 'by',
    'beliz'                                       => 'bz',
    'belçika'                                    => 'be',
    'benin'                                       => 'bj',
    'bermuda'                                     => 'bm',
    'bilinmir'                                    => 'zz',
    'birləşmişkrallıq'                        => 'gb',
    'birləşmişŞtatlarınuzaqadaları'         => 'um',
    'birləşmişƏrəbemiratları'               => 'ae',
    'boliviya'                                    => 'bo',
    'bolqariya'                                   => 'bg',
    'bosniyavəherzokovina'                       => 'ba',
    'botsvana'                                    => 'bw',
    'boveadası'                                  => 'bv',
    'braziliya'                                   => 'br',
    'britaniyahindistanokeanikterritoriyası'     => 'io',
    'britaniyavirginadaları'                     => 'vg',
    'britishantarcticterritory'                   => 'bq',
    'bruney'                                      => 'bn',
    'burkinafaso'                                 => 'bf',
    'burundi'                                     => 'bi',
    'butan'                                       => 'bt',
    'cantonandenderburyislands'                   => 'ct',
    'cezayır'                                    => 'dz',
    'ciboti'                                      => 'dj',
    'cörsi'                                      => 'je',
    'cənubafrika'                                => 'za',
    'cənubgürcüstanvəcənubsandvilçadaları' => 'gs',
    'cənubkoreya'                                => 'kr',
    'danemarka'                                   => 'dk',
    'dominika'                                    => 'dm',
    'dominikrespublikası'                        => 'do',
    'dronningmaudland'                            => 'nq',
    'eastgermany'                                 => 'dd',
    'efiopiya'                                    => 'et',
    'ekvador'                                     => 'ec',
    'ekvatorqineya'                               => 'gq',
    'elsalvador'                                  => 'sv',
    'eritreya'                                    => 'er',
    'ermənistan'                                 => 'am',
    'estoniya'                                    => 'ee',
    'faroadaları'                                => 'fo',
    'fici'                                        => 'fj',
    'filipin'                                     => 'ph',
    'finlandiya'                                  => 'fi',
    'folklandadaları'                            => 'fk',
    'fransa'                                      => 'fr',
    'fransızcənubteritoriyası'                 => 'tf',
    'fransızpolineziya'                          => 'pf',
    'fransızquyanası'                           => 'gf',
    'frenchsouthernandantarcticterritories'       => 'fq',
    'fələstinbölqüsü'                        => 'ps',
    'gibraltar'                                   => 'gi',
    'görnsey'                                    => 'gg',
    'gürcüstan'                                 => 'ge',
    'haiti'                                       => 'ht',
    'hindistan'                                   => 'in',
    'hollandiya'                                  => 'nl',
    'hollandiyaantilleri'                         => 'an',
    'honkkonq'                                    => 'hk',
    'hördvəmakdonaldadaları'                   => 'hm',
    'isveç'                                      => 'se',
    'isveçriya'                                  => 'ch',
    'johnstonisland'                              => 'jt',
    'kambodiya'                                   => 'kh',
    'kamerun'                                     => 'cm',
    'kanada'                                      => 'ca',
    'kapeverde'                                   => 'cv',
    'kaymanadaları'                              => 'ky',
    'kazaxstan'                                   => 'kz',
    'kenya'                                       => 'ke',
    'kipr'                                        => 'cy',
    'kiribati'                                    => 'ki',
    'kokosadaları'                               => 'cc',
    'kolumbiya'                                   => 'co',
    'komoros'                                     => 'km',
    'konqobrazavil'                               => 'cg',
    'konqokinşasa'                               => 'cd',
    'kostarika'                                   => 'cr',
    'kuba'                                        => 'cu',
    'kukadaları'                                 => 'ck',
    'kuveyt'                                      => 'kw',
    'kırqızstan'                                => 'kg',
    'laos'                                        => 'la',
    'latviya'                                     => 'lv',
    'lebanon'                                     => 'lb',
    'lesoto'                                      => 'ls',
    'liberiya'                                    => 'lr',
    'libya'                                       => 'ly',
    'litva'                                       => 'lt',
    'lixtenşteyn'                                => 'li',
    'lüksemburq'                                 => 'lu',
    'macaristan'                                  => 'hu',
    'madaqaskar'                                  => 'mg',
    'makao'                                       => 'mo',
    'malavi'                                      => 'mw',
    'malaysiya'                                   => 'my',
    'maldiv'                                      => 'mv',
    'mali'                                        => 'ml',
    'malta'                                       => 'mt',
    'manadası'                                   => 'im',
    'martiniqu'                                   => 'mq',
    'marşaladaları'                             => 'mh',
    'masedoniya'                                  => 'mk',
    'mavritaniya'                                 => 'mr',
    'mavritis'                                    => 'mu',
    'mayot'                                       => 'yt',
    'mazambik'                                    => 'mz',
    'meksika'                                     => 'mx',
    'metropolitanfrance'                          => 'fx',
    'midwayislands'                               => 'mi',
    'mikronesiya'                                 => 'fm',
    'misir'                                       => 'eg',
    'moldova'                                     => 'md',
    'monako'                                      => 'mc',
    'monqoliya'                                   => 'mn',
    'monteneqro'                                  => 'me',
    'montserat'                                   => 'ms',
    'morokko'                                     => 'ma',
    'myanmar'                                     => 'mm',
    'namibiya'                                    => 'na',
    'nauru'                                       => 'nr',
    'nepal'                                       => 'np',
    'neutralzone'                                 => 'nt',
    'nijer'                                       => 'ne',
    'nijeriya'                                    => 'ng',
    'nikaraqua'                                   => 'ni',
    'niye'                                        => 'nu',
    'norfolkadası'                               => 'nf',
    'northvietnam'                                => 'vd',
    'norvec'                                      => 'no',
    'oman'                                        => 'om',
    'ortaafrikarespublikası'                     => 'cf',
    'pacificislandstrustterritory'                => 'pc',
    'pakistan'                                    => 'pk',
    'palav'                                       => 'pw',
    'panama'                                      => 'pa',
    'panamacanalzone'                             => 'pz',
    'papuayeniqvineya'                            => 'pg',
    'paraqvay'                                    => 'py',
    'peoplesdemocraticrepublicofyemen'            => 'yd',
    'peru'                                        => 'pe',
    'pitkarn'                                     => 'pn',
    'polşa'                                      => 'pl',
    'portuqal'                                    => 'pt',
    'puertoriko'                                  => 'pr',
    'qabon'                                       => 'ga',
    'qambiya'                                     => 'gm',
    'qana'                                        => 'gh',
    'qatar'                                       => 'qa',
    'qonduras'                                    => 'hn',
    'qrenada'                                     => 'gd',
    'qrinland'                                    => 'gl',
    'quam'                                        => 'gu',
    'quyana'                                      => 'gy',
    'qvadalup'                                    => 'gp',
    'qvatemala'                                   => 'gt',
    'qvineya'                                     => 'gn',
    'qvineyabisau'                                => 'gw',
    'qərbsahara'                                 => 'eh',
    'reyunion'                                    => 're',
    'romaniya'                                    => 'ro',
    'rusiya'                                      => 'ru',
    'rvanda'                                      => 'rw',
    'samoa'                                       => 'ws',
    'sanmarino'                                   => 'sm',
    'saotomvəprinsip'                            => 'st',
    'saudiƏrəbistan'                            => 'sa',
    'seneqal'                                     => 'sn',
    'serbiaandmontenegro'                         => 'cs',
    'serbiya'                                     => 'rs',
    'seyntbartelemey'                             => 'bl',
    'seyntelena'                                  => 'sh',
    'seyntkitsvənevis'                           => 'kn',
    'seyntlusiya'                                 => 'lc',
    'seyntmartin'                                 => 'mf',
    'seyntpiyervəmikelon'                        => 'pm',
    'seyntvinsentvəqrenada'                      => 'vc',
    'seyçels'                                    => 'sc',
    'sinqapur'                                    => 'sg',
    'siriya'                                      => 'sy',
    'siyeraleon'                                  => 'sl',
    'slovakiya'                                   => 'sk',
    'sloveniya'                                   => 'si',
    'solomonadaları'                             => 'sb',
    'somaliya'                                    => 'so',
    'sudan'                                       => 'sd',
    'surinamə'                                   => 'sr',
    'svalbardvəyanmayen'                         => 'sj',
    'svazilənd'                                  => 'sz',
    'tacikistan'                                  => 'tj',
    'tanzaniya'                                   => 'tz',
    'tayland'                                     => 'th',
    'tayvan'                                      => 'tw',
    'tokelau'                                     => 'tk',
    'tonqa'                                       => 'to',
    'toqo'                                        => 'tg',
    'trinidanvətobaqo'                           => 'tt',
    'tunisiya'                                    => 'tn',
    'tuvalu'                                      => 'tv',
    'türkiya'                                    => 'tr',
    'türkmənistan'                              => 'tm',
    'türkvəkaykosadaları'                      => 'tc',
    "u\.s\.miscellaneouspacificislands"           => 'pu',
    'ukraina'                                     => 'ua',
    'unionofsovietsocialistrepublics'             => 'su',
    'uqanda'                                      => 'ug',
    'uruqvay'                                     => 'uy',
    'uzakokeyaniya'                               => 'qo',
    'valisvəfutuna'                              => 'wf',
    'vanuatu'                                     => 'vu',
    'vatikan'                                     => 'va',
    'venesuela'                                   => 've',
    'vyetnam'                                     => 'vn',
    'wakeisland'                                  => 'wk',
    'xorvatiya'                                   => 'hr',
    'yamayka'                                     => 'jm',
    'yaponiya'                                    => 'jp',
    'yemen'                                       => 'ye',
    'yenikaledoniya'                              => 'nc',
    'yenizelandiya'                               => 'nz',
    'yunanıstan'                                 => 'gr',
    'zambiya'                                     => 'zm',
    'zimbabve'                                    => 'zw',
    'Çad'                                        => 'td',
    'Çexrespublikası'                           => 'cz',
    'Çile'                                       => 'cl',
    'Çin'                                        => 'cn',
    'Çristmasadası'                             => 'cx',
    'Özbəkistan'                                => 'uz',
    'Ürdün'                                     => 'jo',
    'İndoneziya'                                 => 'id',
    'İrak'                                       => 'iq',
    'İran'                                       => 'ir',
    'İrlandiya'                                  => 'ie',
    'İslandiya'                                  => 'is',
    'İspaniya'                                   => 'es',
    'İtaliya'                                    => 'it',
    'İvorisahili'                                => 'ci',
    'İzrail'                                     => 'il',
    'Şimalkoreya'                                => 'kp',
    'Şimalmarianaadaları'                       => 'mp',
    'Şrilanka'                                   => 'lk',
    'Şərqtimor'                                 => 'tl',
    'Əfqənistan'                                => 'af',
);

1;

