package Locales::DB::Territory::he;

# Auto generated from CLDR

$Locales::DB::Territory::he::VERSION = '0.02';

$Locales::DB::Territory::he::cldr_version = '1.7.1';

%Locales::DB::Territory::he::code_to_name = (
    'ad' => 'אנדורה',
    'ae' => "איחוד\ האמירויות\ הערביות",
    'af' => 'אפגניסטן',
    'ag' => "אנטיגואה\ וברבודה",
    'ai' => 'אנגילה',
    'al' => 'אלבניה',
    'am' => 'ארמניה',
    'an' => "אנטילים\ הולנדיים",
    'ao' => 'אנגולה',
    'aq' => 'אנטארקטיקה',
    'ar' => 'ארגנטינה',
    'as' => "סמואה\ האמריקנית",
    'at' => 'אוסטריה',
    'au' => 'אוסטרליה',
    'aw' => 'ארובה',
    'ax' => "איי\ אלנד",
    'az' => "אזרביג\'ן",
    'ba' => "בוסניה\ והרצגובינה",
    'bb' => 'ברבדוס',
    'bd' => 'בנגלדש',
    'be' => 'בלגיה',
    'bf' => "בורקינה\ פאסו",
    'bg' => 'בולגריה',
    'bh' => 'בחריין',
    'bi' => 'בורונדי',
    'bj' => 'בנין',
    'bl' => "סנט\ ברתולומיאו",
    'bm' => 'ברמודה',
    'bn' => 'ברוניי',
    'bo' => 'בוליביה',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'ברזיל',
    'bs' => "איי\ בהאמה",
    'bt' => 'בהוטן',
    'bv' => "איי\ בובה",
    'bw' => 'בוטסוואנה',
    'by' => 'בלארוס',
    'bz' => 'בליז',
    'ca' => 'קנדה',
    'cc' => "איי\ קוקוס",
    'cd' => "קונגו\ \-\ קינשאסה",
    'cf' => "הרפובליקה\ של\ מרכז\ אפריקה",
    'cg' => "קונגו\ \-\ ברזאויל",
    'ch' => 'שווייץ',
    'ci' => "חוף\ השנהב",
    'ck' => "איי\ קוק",
    'cl' => 'צ׳ילה',
    'cm' => 'קמרון',
    'cn' => 'סין',
    'co' => 'קולומביה',
    'cr' => "קוסטה\ ריקה",
    'cs' => "סרביה\ ומונטנגרו",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'קובה',
    'cv' => "כף\ ורדה",
    'cx' => "איי\ כריסטמס",
    'cy' => 'קפריסין',
    'cz' => 'צ׳כיה',
    'dd' => "East\ Germany",
    'de' => 'גרמניה',
    'dj' => 'ג׳יבוטי',
    'dk' => 'דנמרק',
    'dm' => 'דומיניקה',
    'do' => "הרפובליקה\ הדומיניקנית",
    'dz' => 'אלג׳יריה',
    'ec' => 'אקוודור',
    'ee' => 'אסטוניה',
    'eg' => 'מצרים',
    'eh' => "סהרה\ המערבית",
    'er' => 'אריתראה',
    'es' => 'ספרד',
    'et' => 'אתיופיה',
    'fi' => 'פינלנד',
    'fj' => 'פיג׳י',
    'fk' => "איי\ פוקלנד",
    'fm' => 'מיקרונזיה',
    'fo' => "איי\ פארו",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'צרפת',
    'fx' => "Metropolitan\ France",
    'ga' => 'גאבון',
    'gb' => 'בריטניה',
    'gd' => 'גרנדה',
    'ge' => 'גאורגיה',
    'gf' => "גיאנה\ הצרפתית",
    'gg' => 'גרנסי',
    'gh' => 'גאנה',
    'gi' => 'גיברלטר',
    'gl' => 'גרינלנד',
    'gm' => 'גמביה',
    'gn' => 'גיניאה',
    'gp' => 'גוואדלופ',
    'gq' => "גיניאה\ המשוונית",
    'gr' => 'יוון',
    'gs' => "ג׳ורג׳יה\ הדרומית\ ואיי\ סנדוויץ׳\ הדרומיים",
    'gt' => 'גואטמלה',
    'gu' => 'גואם',
    'gw' => "גיניאה\-ביסאו",
    'gy' => 'גיאנה',
    'hk' => "הונג\ קונג",
    'hm' => "איי\ הרד\ ואיי\ מקדונלנד",
    'hn' => 'הונדורס',
    'hr' => 'קרואטיה',
    'ht' => 'האיטי',
    'hu' => 'הונגריה',
    'id' => 'אינדונזיה',
    'ie' => 'אירלנד',
    'il' => 'ישראל',
    'im' => "האי\ מאן",
    'in' => 'הודו',
    'io' => "טריטוריה\ בריטית\ באוקיאנוס\ ההודי",
    'iq' => 'עיראק',
    'ir' => 'איראן',
    'is' => 'איסלנד',
    'it' => 'איטליה',
    'je' => "ג\'רסי",
    'jm' => 'ג׳מייקה',
    'jo' => 'ירדן',
    'jp' => 'יפן',
    'jt' => "Johnston\ Island",
    'ke' => 'קניה',
    'kg' => 'קירגיזסטן',
    'kh' => 'קמבודיה',
    'ki' => 'קיריבאטי',
    'km' => 'קומורוס',
    'kn' => "סנט\ קיטס\ ונוויס",
    'kp' => "צפון\ קוריאה",
    'kr' => "דרום\ קוריאה",
    'kw' => 'כווית',
    'ky' => "איי\ קיימן",
    'kz' => 'קזחסטן',
    'la' => 'לאוס',
    'lb' => 'לבנון',
    'lc' => "סנט\ לוסיה",
    'li' => 'ליכטנשטיין',
    'lk' => "סרי\ לנקה",
    'lr' => 'ליבריה',
    'ls' => 'לסוטו',
    'lt' => 'ליטא',
    'lu' => 'לוקסמבורג',
    'lv' => 'לטביה',
    'ly' => 'לוב',
    'ma' => 'מרוקו',
    'mc' => 'מונקו',
    'md' => 'מולדובה',
    'me' => 'מונטנגרו',
    'mf' => "סנט\ מרטין",
    'mg' => 'מדגסקר',
    'mh' => "איי\ מרשל",
    'mi' => "Midway\ Islands",
    'mk' => 'מקדוניה',
    'ml' => 'מאלי',
    'mm' => 'מייאנמאר',
    'mn' => 'מונגוליה',
    'mo' => 'מקאו',
    'mp' => "איי\ מריאנה\ הצפוניים",
    'mq' => 'מרטיניק',
    'mr' => 'מאוריטניה',
    'ms' => 'מונסראט',
    'mt' => 'מלטה',
    'mu' => 'מאוריציוס',
    'mv' => 'מלדיבים',
    'mw' => 'מלאווי',
    'mx' => 'מקסיקו',
    'my' => 'מלזיה',
    'mz' => 'מוזמביק',
    'na' => 'נמיביה',
    'nc' => "קלדוניה\ החדשה",
    'ne' => 'ניז׳ר',
    'nf' => "איי\ נורפוק",
    'ng' => 'ניגריה',
    'ni' => 'ניקרגואה',
    'nl' => 'הולנד',
    'no' => 'נורווגיה',
    'np' => 'נפאל',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'נאורו',
    'nt' => "Neutral\ Zone",
    'nu' => 'ניווה',
    'nz' => "ניו\ זילנד",
    'om' => 'עומאן',
    'pa' => 'פנמה',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'פרו',
    'pf' => "פולינזיה\ הצרפתית",
    'pg' => "פפואה\ גיניאה\ החדשה",
    'ph' => 'פיליפינים',
    'pk' => 'פקיסטן',
    'pl' => 'פולין',
    'pm' => "סנט\ פייר\ ומיקלון",
    'pn' => 'פיטקרן',
    'pr' => "פורטו\ ריקו",
    'ps' => "שטחי\ הרשות\ הפלשתינית",
    'pt' => 'פורטוגל',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'פאלאו',
    'py' => 'פרגוואי',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'קטאר',
    'qo' => "Outlying\ Oceania",
    'qu' => "האיחוד\ האירופי",
    're' => 'ראוניון',
    'ro' => 'רומניה',
    'rs' => 'סרביה',
    'ru' => 'רוסיה',
    'rw' => 'רואנדה',
    'sa' => "ערב\ הסעודית",
    'sb' => "איי\ שלמה",
    'sc' => "איי\ סיישל",
    'sd' => 'סודן',
    'se' => 'שוודיה',
    'sg' => 'סינגפור',
    'sh' => "סנט\ הלנה",
    'si' => 'סלובניה',
    'sj' => "סוולבארד\ וז׳אן\ מאיין",
    'sk' => 'סלובקיה',
    'sl' => "סיירה\ לאונה",
    'sm' => "סן\ מרינו",
    'sn' => 'סנגל',
    'so' => 'סומליה',
    'sr' => 'סורינם',
    'st' => "סאו\ טומה\ ופרינסיפה",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "אל\ סלבדור",
    'sy' => 'סוריה',
    'sz' => 'סווזילנד',
    'tc' => "איי\ טורקס\ וקאיקוס",
    'td' => 'צ׳אד',
    'tf' => "טריטוריות\ דרומיות\ של\ צרפת",
    'tg' => 'טוגו',
    'th' => 'תאילנד',
    'tj' => 'טג׳יקיסטן',
    'tk' => 'טוקלאו',
    'tl' => "מזרח\ טימור",
    'tm' => 'טורקמניסטן',
    'tn' => 'תוניסיה',
    'to' => 'טונגה',
    'tr' => 'טורקיה',
    'tt' => "טרינידד\ וטובגו",
    'tv' => 'טובלו',
    'tw' => 'טייוואן',
    'tz' => 'טנזניה',
    'ua' => 'אוקראינה',
    'ug' => 'אוגנדה',
    'um' => "איים\ קטנים\ שלחוף\ ארצות\ הברית",
    'us' => "ארצות\ הברית",
    'uy' => 'אורוגוואי',
    'uz' => 'אוזבקיסטן',
    'va' => 'הוותיקן',
    'vc' => "סנט\ וינסנט\ והגרנדינים",
    'vd' => "North\ Vietnam",
    've' => 'ונצואלה',
    'vg' => "איי\ הבתולה\ הבריטיים",
    'vi' => "איי\ הבתולה\ האמריקניים",
    'vn' => 'וייטנאם',
    'vu' => 'ונואטו',
    'wf' => "איי\ ווליס\ ופוטונה",
    'wk' => "Wake\ Island",
    'ws' => 'סמואה',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'תימן',
    'yt' => 'מאיוט',
    'za' => "דרום\ אפריקה",
    'zm' => 'זמביה',
    'zw' => 'זימבאבווה',
    'zz' => "אזור\ לא\ ידוע\ או\ לא\ תקין",
);

%Locales::DB::Territory::he::name_to_code = (
    'britishantarcticterritory'                                              => 'bq',
    'cantonandenderburyislands'                                              => 'ct',
    'dronningmaudland'                                                       => 'nq',
    'eastgermany'                                                            => 'dd',
    'frenchsouthernandantarcticterritories'                                  => 'fq',
    'johnstonisland'                                                         => 'jt',
    'metropolitanfrance'                                                     => 'fx',
    'midwayislands'                                                          => 'mi',
    'neutralzone'                                                            => 'nt',
    'northvietnam'                                                           => 'vd',
    'outlyingoceania'                                                        => 'qo',
    'pacificislandstrustterritory'                                           => 'pc',
    'panamacanalzone'                                                        => 'pz',
    'peoplesdemocraticrepublicofyemen'                                       => 'yd',
    "u\.s\.miscellaneouspacificislands"                                      => 'pu',
    'unionofsovietsocialistrepublics'                                        => 'su',
    'wakeisland'                                                             => 'wk',
    'אוגנדה'                                                           => 'ug',
    'אוזבקיסטן'                                                     => 'uz',
    'אוסטריה'                                                         => 'at',
    'אוסטרליה'                                                       => 'au',
    'אוקראינה'                                                       => 'ua',
    'אורוגוואי'                                                     => 'uy',
    'אזורלאידועאולאתקין'                                   => 'zz',
    'אזרביגן'                                                         => 'az',
    'איחודהאמירויותהערביות'                             => 'ae',
    'איטליה'                                                           => 'it',
    'אייאלנד'                                                         => 'ax',
    'אייבהאמה'                                                       => 'bs',
    'אייבובה'                                                         => 'bv',
    'אייהבתולההאמריקניים'                                 => 'vi',
    'אייהבתולההבריטיים'                                     => 'vg',
    'אייהרדואיימקדונלנד'                                   => 'hm',
    'אייווליסופוטונה'                                         => 'wf',
    'אייטורקסוקאיקוס'                                         => 'tc',
    'אייכריסטמס'                                                   => 'cx',
    'אייםקטניםשלחוףארצותהברית'                       => 'um',
    'איימריאנההצפוניים'                                     => 'mp',
    'איימרשל'                                                         => 'mh',
    'איינורפוק'                                                     => 'nf',
    'אייסיישל'                                                       => 'sc',
    'אייפארו'                                                         => 'fo',
    'אייפוקלנד'                                                     => 'fk',
    'אייקוק'                                                           => 'ck',
    'אייקוקוס'                                                       => 'cc',
    'אייקיימן'                                                       => 'ky',
    'איישלמה'                                                         => 'sb',
    'אינדונזיה'                                                     => 'id',
    'איסלנד'                                                           => 'is',
    'איראן'                                                             => 'ir',
    'אירלנד'                                                           => 'ie',
    'אלבניה'                                                           => 'al',
    'אלג׳יריה'                                                       => 'dz',
    'אלסלבדור'                                                       => 'sv',
    'אנגולה'                                                           => 'ao',
    'אנגילה'                                                           => 'ai',
    'אנדורה'                                                           => 'ad',
    'אנטארקטיקה'                                                   => 'aq',
    'אנטיגואהוברבודה'                                         => 'ag',
    'אנטיליםהולנדיים'                                         => 'an',
    'אסטוניה'                                                         => 'ee',
    'אפגניסטן'                                                       => 'af',
    'אקוודור'                                                         => 'ec',
    'ארגנטינה'                                                       => 'ar',
    'ארובה'                                                             => 'aw',
    'אריתראה'                                                         => 'er',
    'ארמניה'                                                           => 'am',
    'ארצותהברית'                                                   => 'us',
    'אתיופיה'                                                         => 'et',
    'בהוטן'                                                             => 'bt',
    'בוטסוואנה'                                                     => 'bw',
    'בולגריה'                                                         => 'bg',
    'בוליביה'                                                         => 'bo',
    'בוסניהוהרצגובינה'                                       => 'ba',
    'בורונדי'                                                         => 'bi',
    'בורקינהפאסו'                                                 => 'bf',
    'בחריין'                                                           => 'bh',
    'בלארוס'                                                           => 'by',
    'בלגיה'                                                             => 'be',
    'בליז'                                                               => 'bz',
    'בנגלדש'                                                           => 'bd',
    'בנין'                                                               => 'bj',
    'ברבדוס'                                                           => 'bb',
    'ברוניי'                                                           => 'bn',
    'ברזיל'                                                             => 'br',
    'בריטניה'                                                         => 'gb',
    'ברמודה'                                                           => 'bm',
    'גאבון'                                                             => 'ga',
    'גאורגיה'                                                         => 'ge',
    'גאנה'                                                               => 'gh',
    'גואטמלה'                                                         => 'gt',
    'גואם'                                                               => 'gu',
    'גוואדלופ'                                                       => 'gp',
    'גיאנה'                                                             => 'gy',
    'גיאנההצרפתית'                                               => 'gf',
    'גיברלטר'                                                         => 'gi',
    'גיניאה'                                                           => 'gn',
    'גיניאהביסאו'                                                 => 'gw',
    'גיניאההמשוונית'                                           => 'gq',
    'גמביה'                                                             => 'gm',
    'גרינלנד'                                                         => 'gl',
    'גרמניה'                                                           => 'de',
    'גרנדה'                                                             => 'gd',
    'גרנסי'                                                             => 'gg',
    'גרסי'                                                               => 'je',
    'ג׳ורג׳יההדרומיתואייסנדוויץ׳הדרומיים' => 'gs',
    'ג׳יבוטי'                                                         => 'dj',
    'ג׳מייקה'                                                         => 'jm',
    'דומיניקה'                                                       => 'dm',
    'דנמרק'                                                             => 'dk',
    'דרוםאפריקה'                                                   => 'za',
    'דרוםקוריאה'                                                   => 'kr',
    'האיחודהאירופי'                                             => 'qu',
    'האיטי'                                                             => 'ht',
    'האימאן'                                                           => 'im',
    'הודו'                                                               => 'in',
    'הוותיקן'                                                         => 'va',
    'הולנד'                                                             => 'nl',
    'הונגקונג'                                                       => 'hk',
    'הונגריה'                                                         => 'hu',
    'הונדורס'                                                         => 'hn',
    'הרפובליקההדומיניקנית'                               => 'do',
    'הרפובליקהשלמרכזאפריקה'                             => 'cf',
    'וייטנאם'                                                         => 'vn',
    'ונואטו'                                                           => 'vu',
    'ונצואלה'                                                         => 've',
    'זימבאבווה'                                                     => 'zw',
    'זמביה'                                                             => 'zm',
    'חוףהשנהב'                                                       => 'ci',
    'טג׳יקיסטן'                                                     => 'tj',
    'טובלו'                                                             => 'tv',
    'טוגו'                                                               => 'tg',
    'טונגה'                                                             => 'to',
    'טוקלאו'                                                           => 'tk',
    'טורקיה'                                                           => 'tr',
    'טורקמניסטן'                                                   => 'tm',
    'טייוואן'                                                         => 'tw',
    'טנזניה'                                                           => 'tz',
    'טריטוריהבריטיתבאוקיאנוסההודי'               => 'io',
    'טריטוריותדרומיותשלצרפת'                           => 'tf',
    'טרינידדוטובגו'                                             => 'tt',
    'יוון'                                                               => 'gr',
    'יפן'                                                                 => 'jp',
    'ירדן'                                                               => 'jo',
    'ישראל'                                                             => 'il',
    'כווית'                                                             => 'kw',
    'כףורדה'                                                           => 'cv',
    'לאוס'                                                               => 'la',
    'לבנון'                                                             => 'lb',
    'לוב'                                                                 => 'ly',
    'לוקסמבורג'                                                     => 'lu',
    'לטביה'                                                             => 'lv',
    'ליבריה'                                                           => 'lr',
    'ליטא'                                                               => 'lt',
    'ליכטנשטיין'                                                   => 'li',
    'לסוטו'                                                             => 'ls',
    'מאוריטניה'                                                     => 'mr',
    'מאוריציוס'                                                     => 'mu',
    'מאיוט'                                                             => 'yt',
    'מאלי'                                                               => 'ml',
    'מדגסקר'                                                           => 'mg',
    'מוזמביק'                                                         => 'mz',
    'מולדובה'                                                         => 'md',
    'מונגוליה'                                                       => 'mn',
    'מונטנגרו'                                                       => 'me',
    'מונסראט'                                                         => 'ms',
    'מונקו'                                                             => 'mc',
    'מזרחטימור'                                                     => 'tl',
    'מייאנמאר'                                                       => 'mm',
    'מיקרונזיה'                                                     => 'fm',
    'מלאווי'                                                           => 'mw',
    'מלדיבים'                                                         => 'mv',
    'מלזיה'                                                             => 'my',
    'מלטה'                                                               => 'mt',
    'מצרים'                                                             => 'eg',
    'מקאו'                                                               => 'mo',
    'מקדוניה'                                                         => 'mk',
    'מקסיקו'                                                           => 'mx',
    'מרוקו'                                                             => 'ma',
    'מרטיניק'                                                         => 'mq',
    'נאורו'                                                             => 'nr',
    'נורווגיה'                                                       => 'no',
    'ניגריה'                                                           => 'ng',
    'ניווה'                                                             => 'nu',
    'ניוזילנד'                                                       => 'nz',
    'ניז׳ר'                                                             => 'ne',
    'ניקרגואה'                                                       => 'ni',
    'נמיביה'                                                           => 'na',
    'נפאל'                                                               => 'np',
    'סאוטומהופרינסיפה'                                       => 'st',
    'סהרההמערבית'                                                 => 'eh',
    'סודן'                                                               => 'sd',
    'סווזילנד'                                                       => 'sz',
    'סוולבארדוז׳אןמאיין'                                   => 'sj',
    'סומליה'                                                           => 'so',
    'סוריה'                                                             => 'sy',
    'סורינם'                                                           => 'sr',
    'סיירהלאונה'                                                   => 'sl',
    'סין'                                                                 => 'cn',
    'סינגפור'                                                         => 'sg',
    'סלובניה'                                                         => 'si',
    'סלובקיה'                                                         => 'sk',
    'סמואה'                                                             => 'ws',
    'סמואההאמריקנית'                                           => 'as',
    'סןמרינו'                                                         => 'sm',
    'סנגל'                                                               => 'sn',
    'סנטברתולומיאו'                                             => 'bl',
    'סנטהלנה'                                                         => 'sh',
    'סנטוינסנטוהגרנדינים'                                 => 'vc',
    'סנטלוסיה'                                                       => 'lc',
    'סנטמרטין'                                                       => 'mf',
    'סנטפיירומיקלון'                                           => 'pm',
    'סנטקיטסונוויס'                                             => 'kn',
    'ספרד'                                                               => 'es',
    'סרביה'                                                             => 'rs',
    'סרביהומונטנגרו'                                           => 'cs',
    'סרילנקה'                                                         => 'lk',
    'עומאן'                                                             => 'om',
    'עיראק'                                                             => 'iq',
    'ערבהסעודית'                                                   => 'sa',
    'פאלאו'                                                             => 'pw',
    'פולין'                                                             => 'pl',
    'פולינזיההצרפתית'                                         => 'pf',
    'פורטוגל'                                                         => 'pt',
    'פורטוריקו'                                                     => 'pr',
    'פיג׳י'                                                             => 'fj',
    'פיטקרן'                                                           => 'pn',
    'פיליפינים'                                                     => 'ph',
    'פינלנד'                                                           => 'fi',
    'פנמה'                                                               => 'pa',
    'פפואהגיניאההחדשה'                                       => 'pg',
    'פקיסטן'                                                           => 'pk',
    'פרגוואי'                                                         => 'py',
    'פרו'                                                                 => 'pe',
    'צפוןקוריאה'                                                   => 'kp',
    'צרפת'                                                               => 'fr',
    'צ׳אד'                                                               => 'td',
    'צ׳ילה'                                                             => 'cl',
    'צ׳כיה'                                                             => 'cz',
    'קובה'                                                               => 'cu',
    'קולומביה'                                                       => 'co',
    'קומורוס'                                                         => 'km',
    'קונגוברזאויל'                                               => 'cg',
    'קונגוקינשאסה'                                               => 'cd',
    'קוסטהריקה'                                                     => 'cr',
    'קזחסטן'                                                           => 'kz',
    'קטאר'                                                               => 'qa',
    'קירגיזסטן'                                                     => 'kg',
    'קיריבאטי'                                                       => 'ki',
    'קלדוניההחדשה'                                               => 'nc',
    'קמבודיה'                                                         => 'kh',
    'קמרון'                                                             => 'cm',
    'קנדה'                                                               => 'ca',
    'קניה'                                                               => 'ke',
    'קפריסין'                                                         => 'cy',
    'קרואטיה'                                                         => 'hr',
    'ראוניון'                                                         => 're',
    'רואנדה'                                                           => 'rw',
    'רומניה'                                                           => 'ro',
    'רוסיה'                                                             => 'ru',
    'שוודיה'                                                           => 'se',
    'שווייץ'                                                           => 'ch',
    'שטחיהרשותהפלשתינית'                                   => 'ps',
    'תאילנד'                                                           => 'th',
    'תוניסיה'                                                         => 'tn',
    'תימן'                                                               => 'ye',
);

1;

