package Locales::DB::Territory::be;

# Auto generated from CLDR

$Locales::DB::Territory::be::VERSION = '0.02';

$Locales::DB::Territory::be::cldr_version = '1.7.1';

%Locales::DB::Territory::be::code_to_name = (
    'ad' => 'Андора',
    'ae' => "Аб\'яднаныя\ Арабскія\ Эміраты",
    'af' => 'Афганістан',
    'ag' => "Антыгуа\ і\ Барбуда",
    'ai' => 'Ангуілля',
    'al' => 'Албанія',
    'am' => 'Арменія',
    'an' => "Нідэрландскія\ Антылы",
    'ao' => 'Ангола',
    'aq' => 'Антарктыка',
    'ar' => 'Аргенціна',
    'as' => "Амерыканскае\ Самоа",
    'at' => 'Аўстрыя',
    'au' => 'Аўстралія',
    'aw' => 'Аруба',
    'ax' => "Аландскія\ астравы",
    'az' => 'Азербайджан',
    'ba' => "Боснія\ і\ Герцагавіна",
    'bb' => 'Барбадас',
    'bd' => 'Бангладэш',
    'be' => 'Бельгія',
    'bf' => "Буркіна\-Фасо",
    'bg' => 'Балгарыя',
    'bh' => 'Бахрэйн',
    'bi' => 'Бурундзі',
    'bj' => 'Бенін',
    'bl' => "Saint\ Barth\Ã\©lemy",
    'bm' => "Бермудскія\ астравы",
    'bn' => "Бруней\-Дарусалам",
    'bo' => 'Балівія',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Бразілія',
    'bs' => "Багамскія\ Астравы",
    'bt' => 'Бутан',
    'bv' => "Бувэ\ востраў",
    'bw' => 'Батсвана',
    'by' => 'Беларусь',
    'bz' => 'Беліз',
    'ca' => 'Канада',
    'cc' => "Какосавыя\ астравы",
    'cd' => "Конга\,\ Дэмакратычная\ Рэспубліка",
    'cf' => "Цэнтральна\-Афрыканская\ Рэспубліка",
    'cg' => 'Конга',
    'ch' => 'Швейцарыя',
    'ci' => "Ivory\ Coast",
    'ck' => "Кука\ астравы",
    'cl' => 'Чылі',
    'cm' => 'Камерун',
    'cn' => 'Кітай',
    'co' => 'Калумбія',
    'cr' => "Коста\-Рыка",
    'cs' => "Serbia\ and\ Montenegro",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Куба',
    'cv' => "Каба\-Вердэ",
    'cx' => "Калядаў\ востраў",
    'cy' => 'Кіпр',
    'cz' => 'Чэхія',
    'dd' => "East\ Germany",
    'de' => 'Германія',
    'dj' => 'Джыбуці',
    'dk' => 'Данія',
    'dm' => 'Дамініка',
    'do' => "Дамініканская\ Рэспубліка",
    'dz' => 'Алжыр',
    'ec' => 'Эквадор',
    'ee' => 'Эстонія',
    'eg' => 'Егіпет',
    'eh' => "Заходняя\ Сахара",
    'er' => 'Эрытрэя',
    'es' => 'Іспанія',
    'et' => 'Эфіопія',
    'fi' => 'Фінляндыя',
    'fj' => 'Фіджы',
    'fk' => "Фолклэндскія\ астравы",
    'fm' => 'Мікранезія',
    'fo' => "Faroe\ Islands",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Францыя',
    'fx' => "Metropolitan\ France",
    'ga' => 'Габон',
    'gb' => 'Велікабрытанія',
    'gd' => 'Грэнада',
    'ge' => 'Грузія',
    'gf' => "Французская\ Гвіяна",
    'gg' => 'Guernsey',
    'gh' => 'Гана',
    'gi' => 'Гібралтар',
    'gl' => 'Грэнландыя',
    'gm' => 'Гамбія',
    'gn' => 'Гвінея',
    'gp' => 'Гвадэлупа',
    'gq' => "Экватарыяльная\ Гвінея",
    'gr' => 'Грэцыя',
    'gs' => "Паўднёвая\ Джорджыя\ і\ Паўднёвыя\ Сандвічавы\ астравы",
    'gt' => 'Гватэмала',
    'gu' => 'Guam',
    'gw' => "Гвінея\-Бісаў",
    'gy' => 'Гаяна',
    'hk' => "Гон\-Конг",
    'hm' => "Гэрда\ востраў\ і\ МакДоналда\ астравы",
    'hn' => 'Гандурас',
    'hr' => 'Харватыя',
    'ht' => 'Гаіці',
    'hu' => 'Венгрыя',
    'id' => 'Інданезія',
    'ie' => 'Ірландыя',
    'il' => 'Ізраіль',
    'im' => "Isle\ of\ Man",
    'in' => 'Індыя',
    'io' => "Брытанская\ тэрыторыя\ Індыйскага\ акіяну",
    'iq' => 'Ірак',
    'ir' => "Іран\,\ Ісламская\ Рэспубліка",
    'is' => 'Ісландыя',
    'it' => 'Італія',
    'je' => 'Jersey',
    'jm' => 'Ямайка',
    'jo' => 'Іарданія',
    'jp' => 'Японія',
    'jt' => "Johnston\ Island",
    'ke' => 'Кенія',
    'kg' => 'Кыргызстан',
    'kh' => 'Камбоджа',
    'ki' => 'Кірыбаці',
    'km' => "Каморскія\ Астравы",
    'kn' => "Сэнт\-Кітс\ і\ Нэвіс",
    'kp' => "Паўночная\ Карэя",
    'kr' => "Паўднёвая\ Карэя",
    'kw' => 'Кувейт',
    'ky' => "Кайманавы\ астравы",
    'kz' => 'Казахстан',
    'la' => "Лаоская\ Народна\-Дэмакратычная\ Рэспубліка",
    'lb' => 'Ліван',
    'lc' => "Сэнт\-Люсія",
    'li' => 'Ліхтэнштэйн',
    'lk' => "Шры\-Ланка",
    'lr' => 'Ліберыя',
    'ls' => 'Лесота',
    'lt' => 'Літва',
    'lu' => 'Люксембург',
    'lv' => 'Латвія',
    'ly' => "Лівійская\ Арабская\ Джамахірыя",
    'ma' => 'Марока',
    'mc' => 'Манака',
    'md' => 'Малдова',
    'me' => 'Чарнагорыя',
    'mf' => "Saint\ Martin",
    'mg' => 'Мадагаскар',
    'mh' => "Маршалавы\ Астравы",
    'mi' => "Midway\ Islands",
    'mk' => "Македонія\,\ БЮР",
    'ml' => 'Малі',
    'mm' => "М\'янма",
    'mn' => 'Манголія',
    'mo' => 'Макао',
    'mp' => "Паўночныя\ Марыянскія\ астравы",
    'mq' => 'Марцініка',
    'mr' => 'Маўрытанія',
    'ms' => 'Монсэрат',
    'mt' => 'Мальта',
    'mu' => 'Маўрыкій',
    'mv' => "Мальдыўскія\ Астравы",
    'mw' => 'Малаві',
    'mx' => 'Мексіка',
    'my' => 'Малайзія',
    'mz' => 'Мазамбік',
    'na' => 'Намібія',
    'nc' => "Новая\ Каледонія",
    'ne' => 'Нігер',
    'nf' => "Норфалкскія\ астравы",
    'ng' => 'Нігерыя',
    'ni' => 'Нікарагуа',
    'nl' => 'Нідэрланды',
    'no' => 'Нарвегія',
    'np' => 'Непал',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Науру',
    'nt' => "Neutral\ Zone",
    'nu' => 'Ніуэ',
    'nz' => "Новая\ Зеландыя",
    'om' => 'Аман',
    'pa' => 'Панама',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Перу',
    'pf' => "Франузская\ Палінэзія",
    'pg' => "Папуа\-Новая\ Гвінея",
    'ph' => 'Філіпіны',
    'pk' => 'Пакістан',
    'pl' => 'Польшча',
    'pm' => "Saint\ Pierre\ and\ Miquelon",
    'pn' => "Pitcairn\ Islands",
    'pr' => "Puerto\ Rico",
    'ps' => "Палестынскія\ тэрыторыі",
    'pt' => 'Партугалія',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Палаў',
    'py' => 'Парагвай',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Катар',
    'qo' => "Вонкавая\ Акіянія",
    'qu' => "Еўрапейскі\ Звяз",
    're' => 'Рэюньён',
    'ro' => 'Румынія',
    'rs' => 'Сербія',
    'ru' => 'Расія',
    'rw' => 'Руанда',
    'sa' => "Саудаўская\ Аравія",
    'sb' => "Саламонавы\ Астравы",
    'sc' => "Сейшэльскія\ Астравы",
    'sd' => 'Судан',
    'se' => 'Швецыя',
    'sg' => 'Сінгапур',
    'sh' => "Святой\ Алены\,\ Востраў",
    'si' => 'Славенія',
    'sj' => "Свальбард\ \(Паўночна\-Усходняя\ Зямля\)\ і\ Ян\-Маен",
    'sk' => 'Славакія',
    'sl' => "Сьера\-Леонэ",
    'sm' => "San\ Marino",
    'sn' => 'Сенегал',
    'so' => 'Самалі',
    'sr' => 'Сурынам',
    'st' => "Сан\-Томэ\ і\ Прынсіпі",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => 'Сальвадор',
    'sy' => "Сірыйская\ Арабская\ Рэспубліка",
    'sz' => 'Свазіленд',
    'tc' => "Тэркс\ і\ Кайкас\ астравы",
    'td' => 'Чад',
    'tf' => "Французскія\ Паўднёвыя\ тэрыторыі",
    'tg' => 'Тога',
    'th' => 'Тайланд',
    'tj' => 'Таджыкістан',
    'tk' => 'Такелаў',
    'tl' => "Усходні\ Тымор",
    'tm' => 'Туркменістан',
    'tn' => 'Туніс',
    'to' => 'Тангійская',
    'tr' => 'Турцыя',
    'tt' => "Трынідад\ і\ Табага",
    'tv' => 'Тувалу',
    'tw' => 'Тайвань',
    'tz' => "Танзанія\,\ Аб\'яднаная\ Рэспубліка",
    'ua' => 'Украіна',
    'ug' => 'Уганда',
    'um' => "U\.S\.\ Minor\ Outlying\ Islands",
    'us' => "Злучаныя\ Штаты",
    'uy' => 'Уругвай',
    'uz' => 'Узбекістан',
    'va' => 'Ватыкан',
    'vc' => "Сэнт\-Вінсэнт\ і\ Грэнадыны",
    'vd' => "North\ Vietnam",
    've' => 'Венесуэла',
    'vg' => "Віргінскія\ астравы",
    'vi' => "Віргінскія\ астравы\,\ ЗША",
    'vn' => "В\'етнам",
    'vu' => 'Вануату',
    'wf' => "Уоліс\ і\ Футуна",
    'wk' => "Wake\ Island",
    'ws' => "Самоа\ \(Заходняе\)",
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Емен',
    'yt' => 'Mayotte',
    'za' => "Паўднёва\-Афрыканская\ Рэспубліка",
    'zm' => 'Замбія',
    'zw' => 'Зімбабвэ',
    'zz' => "Невядомы\ рэгіён",
);

%Locales::DB::Territory::be::name_to_code = (
    'britishantarcticterritory'                                                                => 'bq',
    'cantonandenderburyislands'                                                                => 'ct',
    'dronningmaudland'                                                                         => 'nq',
    'eastgermany'                                                                              => 'dd',
    'faroeislands'                                                                             => 'fo',
    'frenchsouthernandantarcticterritories'                                                    => 'fq',
    'guam'                                                                                     => 'gu',
    'guernsey'                                                                                 => 'gg',
    'isleofman'                                                                                => 'im',
    'ivorycoast'                                                                               => 'ci',
    'jersey'                                                                                   => 'je',
    'johnstonisland'                                                                           => 'jt',
    'mayotte'                                                                                  => 'yt',
    'metropolitanfrance'                                                                       => 'fx',
    'midwayislands'                                                                            => 'mi',
    'neutralzone'                                                                              => 'nt',
    'northvietnam'                                                                             => 'vd',
    'pacificislandstrustterritory'                                                             => 'pc',
    'panamacanalzone'                                                                          => 'pz',
    'peoplesdemocraticrepublicofyemen'                                                         => 'yd',
    'pitcairnislands'                                                                          => 'pn',
    'puertorico'                                                                               => 'pr',
    "saintbarth\Ã\©lemy"                                                                     => 'bl',
    'saintmartin'                                                                              => 'mf',
    'saintpierreandmiquelon'                                                                   => 'pm',
    'sanmarino'                                                                                => 'sm',
    'serbiaandmontenegro'                                                                      => 'cs',
    "u\.s\.minoroutlyingislands"                                                               => 'um',
    "u\.s\.miscellaneouspacificislands"                                                        => 'pu',
    'unionofsovietsocialistrepublics'                                                          => 'su',
    'wakeisland'                                                                               => 'wk',
    'Іарданія'                                                                         => 'jo',
    'Ізраіль'                                                                           => 'il',
    'Інданезія'                                                                       => 'id',
    'Індыя'                                                                               => 'in',
    'Ірак'                                                                                 => 'iq',
    "Іран\,ІсламскаяРэспубліка"                                         => 'ir',
    'Ірландыя'                                                                         => 'ie',
    'Ісландыя'                                                                         => 'is',
    'Іспанія'                                                                           => 'es',
    'Італія'                                                                             => 'it',
    'АбяднаныяАрабскіяЭміраты'                                         => 'ae',
    'Азербайджан'                                                                   => 'az',
    'Аландскіяастравы'                                                         => 'ax',
    'Албанія'                                                                           => 'al',
    'Алжыр'                                                                               => 'dz',
    'Аман'                                                                                 => 'om',
    'АмерыканскаеСамоа'                                                       => 'as',
    'Ангола'                                                                             => 'ao',
    'Ангуілля'                                                                         => 'ai',
    'Андора'                                                                             => 'ad',
    'Антарктыка'                                                                     => 'aq',
    'АнтыгуаіБарбуда'                                                           => 'ag',
    'Аргенціна'                                                                       => 'ar',
    'Арменія'                                                                           => 'am',
    'Аруба'                                                                               => 'aw',
    'Афганістан'                                                                     => 'af',
    'Аўстралія'                                                                       => 'au',
    'Аўстрыя'                                                                           => 'at',
    'БагамскіяАстравы'                                                         => 'bs',
    'Балгарыя'                                                                         => 'bg',
    'Балівія'                                                                           => 'bo',
    'Бангладэш'                                                                       => 'bd',
    'Барбадас'                                                                         => 'bb',
    'Батсвана'                                                                         => 'bw',
    'Бахрэйн'                                                                           => 'bh',
    'Беларусь'                                                                         => 'by',
    'Бельгія'                                                                           => 'be',
    'Беліз'                                                                               => 'bz',
    'Бенін'                                                                               => 'bj',
    'Бермудскіяастравы'                                                       => 'bm',
    'БосніяіГерцагавіна'                                                     => 'ba',
    'Бразілія'                                                                         => 'br',
    'БрунейДарусалам'                                                           => 'bn',
    'БрытанскаятэрыторыяІндыйскагаакіяну'                   => 'io',
    'Бувэвостраў'                                                                   => 'bv',
    'БуркінаФасо'                                                                   => 'bf',
    'Бурундзі'                                                                         => 'bi',
    'Бутан'                                                                               => 'bt',
    'Вануату'                                                                           => 'vu',
    'Ватыкан'                                                                           => 'va',
    'Велікабрытанія'                                                             => 'gb',
    'Венгрыя'                                                                           => 'hu',
    'Венесуэла'                                                                       => 've',
    'Ветнам'                                                                             => 'vn',
    'ВонкаваяАкіянія'                                                           => 'qo',
    'Віргінскіяастравы'                                                       => 'vg',
    "Віргінскіяастравы\,ЗША"                                               => 'vi',
    'Габон'                                                                               => 'ga',
    'Гамбія'                                                                             => 'gm',
    'Гана'                                                                                 => 'gh',
    'Гандурас'                                                                         => 'hn',
    'Гаяна'                                                                               => 'gy',
    'Гаіці'                                                                               => 'ht',
    'Гвадэлупа'                                                                       => 'gp',
    'Гватэмала'                                                                       => 'gt',
    'Гвінея'                                                                             => 'gn',
    'ГвінеяБісаў'                                                                   => 'gw',
    'Германія'                                                                         => 'de',
    'ГонКонг'                                                                           => 'hk',
    'Грузія'                                                                             => 'ge',
    'Грэнада'                                                                           => 'gd',
    'Грэнландыя'                                                                     => 'gl',
    'Грэцыя'                                                                             => 'gr',
    'ГэрдавостраўіМакДоналдаастравы'                             => 'hm',
    'Гібралтар'                                                                       => 'gi',
    'Дамініка'                                                                         => 'dm',
    'ДамініканскаяРэспубліка'                                           => 'do',
    'Данія'                                                                               => 'dk',
    'Джыбуці'                                                                           => 'dj',
    'Егіпет'                                                                             => 'eg',
    'Емен'                                                                                 => 'ye',
    'ЕўрапейскіЗвяз'                                                             => 'qu',
    'Замбія'                                                                             => 'zm',
    'ЗаходняяСахара'                                                             => 'eh',
    'ЗлучаныяШтаты'                                                               => 'us',
    'Зімбабвэ'                                                                         => 'zw',
    'КабаВердэ'                                                                       => 'cv',
    'Казахстан'                                                                       => 'kz',
    'Кайманавыастравы'                                                         => 'ky',
    'Какосавыяастравы'                                                         => 'cc',
    'Калумбія'                                                                         => 'co',
    'Калядаўвостраў'                                                             => 'cx',
    'Камбоджа'                                                                         => 'kh',
    'Камерун'                                                                           => 'cm',
    'КаморскіяАстравы'                                                         => 'km',
    'Канада'                                                                             => 'ca',
    'Катар'                                                                               => 'qa',
    'Кенія'                                                                               => 'ke',
    'Конга'                                                                               => 'cg',
    "Конга\,ДэмакратычнаяРэспубліка"                               => 'cd',
    'КостаРыка'                                                                       => 'cr',
    'Куба'                                                                                 => 'cu',
    'Кувейт'                                                                             => 'kw',
    'Кукаастравы'                                                                   => 'ck',
    'Кыргызстан'                                                                     => 'kg',
    'Кіпр'                                                                                 => 'cy',
    'Кірыбаці'                                                                         => 'ki',
    'Кітай'                                                                               => 'cn',
    'ЛаоскаяНароднаДэмакратычнаяРэспубліка'               => 'la',
    'Латвія'                                                                             => 'lv',
    'Лесота'                                                                             => 'ls',
    'Люксембург'                                                                     => 'lu',
    'Ліберыя'                                                                           => 'lr',
    'Ліван'                                                                               => 'lb',
    'ЛівійскаяАрабскаяДжамахірыя'                                   => 'ly',
    'Літва'                                                                               => 'lt',
    'Ліхтэнштэйн'                                                                   => 'li',
    'Мадагаскар'                                                                     => 'mg',
    'Мазамбік'                                                                         => 'mz',
    'Макао'                                                                               => 'mo',
    "Македонія\,БЮР"                                                               => 'mk',
    'Малаві'                                                                             => 'mw',
    'Малайзія'                                                                         => 'my',
    'Малдова'                                                                           => 'md',
    'МальдыўскіяАстравы'                                                     => 'mv',
    'Мальта'                                                                             => 'mt',
    'Малі'                                                                                 => 'ml',
    'Манака'                                                                             => 'mc',
    'Манголія'                                                                         => 'mn',
    'Марока'                                                                             => 'ma',
    'Марцініка'                                                                       => 'mq',
    'МаршалавыАстравы'                                                         => 'mh',
    'Маўрыкій'                                                                         => 'mu',
    'Маўрытанія'                                                                     => 'mr',
    'Мексіка'                                                                           => 'mx',
    'Монсэрат'                                                                         => 'ms',
    'Мянма'                                                                               => 'mm',
    'Мікранезія'                                                                     => 'fm',
    'Намібія'                                                                           => 'na',
    'Нарвегія'                                                                         => 'no',
    'Науру'                                                                               => 'nr',
    'Невядомырэгіён'                                                             => 'zz',
    'Непал'                                                                               => 'np',
    'НоваяЗеландыя'                                                               => 'nz',
    'НоваяКаледонія'                                                             => 'nc',
    'Норфалкскіяастравы'                                                     => 'nf',
    'Нігер'                                                                               => 'ne',
    'Нігерыя'                                                                           => 'ng',
    'НідэрландскіяАнтылы'                                                   => 'an',
    'Нідэрланды'                                                                     => 'nl',
    'Нікарагуа'                                                                       => 'ni',
    'Ніуэ'                                                                                 => 'nu',
    'Пакістан'                                                                         => 'pk',
    'Палаў'                                                                               => 'pw',
    'Палестынскіятэрыторыі'                                               => 'ps',
    'Панама'                                                                             => 'pa',
    'ПапуаНоваяГвінея'                                                         => 'pg',
    'Парагвай'                                                                         => 'py',
    'Партугалія'                                                                     => 'pt',
    'ПаўднёваАфрыканскаяРэспубліка'                               => 'za',
    'ПаўднёваяДжорджыяіПаўднёвыяСандвічавыастравы' => 'gs',
    'ПаўднёваяКарэя'                                                             => 'kr',
    'ПаўночнаяКарэя'                                                             => 'kp',
    'ПаўночныяМарыянскіяастравы'                                     => 'mp',
    'Перу'                                                                                 => 'pe',
    'Польшча'                                                                           => 'pl',
    'Расія'                                                                               => 'ru',
    'Руанда'                                                                             => 'rw',
    'Румынія'                                                                           => 'ro',
    'Рэюньён'                                                                           => 're',
    'СаламонавыАстравы'                                                       => 'sb',
    'Сальвадор'                                                                       => 'sv',
    'Самалі'                                                                             => 'so',
    'СамоаЗаходняе'                                                               => 'ws',
    'СанТомэіПрынсіпі'                                                         => 'st',
    'СаудаўскаяАравія'                                                         => 'sa',
    'Свазіленд'                                                                       => 'sz',
    'СвальбардПаўночнаУсходняяЗямляіЯнМаен'               => 'sj',
    "СвятойАлены\,Востраў"                                                   => 'sh',
    'СейшэльскіяАстравы'                                                     => 'sc',
    'Сенегал'                                                                           => 'sn',
    'Сербія'                                                                             => 'rs',
    'Славакія'                                                                         => 'sk',
    'Славенія'                                                                         => 'si',
    'Судан'                                                                               => 'sd',
    'Сурынам'                                                                           => 'sr',
    'СьераЛеонэ'                                                                     => 'sl',
    'СэнтВінсэнтіГрэнадыны'                                               => 'vc',
    'СэнтКітсіНэвіс'                                                             => 'kn',
    'СэнтЛюсія'                                                                       => 'lc',
    'Сінгапур'                                                                         => 'sg',
    'СірыйскаяАрабскаяРэспубліка'                                   => 'sy',
    'Таджыкістан'                                                                   => 'tj',
    'Тайвань'                                                                           => 'tw',
    'Тайланд'                                                                           => 'th',
    'Такелаў'                                                                           => 'tk',
    'Тангійская'                                                                     => 'to',
    "Танзанія\,АбяднанаяРэспубліка"                                 => 'tz',
    'Тога'                                                                                 => 'tg',
    'ТрынідадіТабага'                                                           => 'tt',
    'Тувалу'                                                                             => 'tv',
    'Туніс'                                                                               => 'tn',
    'Туркменістан'                                                                 => 'tm',
    'Турцыя'                                                                             => 'tr',
    'ТэрксіКайкасастравы'                                                   => 'tc',
    'Уганда'                                                                             => 'ug',
    'Узбекістан'                                                                     => 'uz',
    'Украіна'                                                                           => 'ua',
    'УолісіФутуна'                                                                 => 'wf',
    'Уругвай'                                                                           => 'uy',
    'УсходніТымор'                                                                 => 'tl',
    'Фолклэндскіяастравы'                                                   => 'fk',
    'ФранузскаяПалінэзія'                                                   => 'pf',
    'ФранцузскаяГвіяна'                                                       => 'gf',
    'ФранцузскіяПаўднёвыятэрыторыі'                               => 'tf',
    'Францыя'                                                                           => 'fr',
    'Фіджы'                                                                               => 'fj',
    'Філіпіны'                                                                         => 'ph',
    'Фінляндыя'                                                                       => 'fi',
    'Харватыя'                                                                         => 'hr',
    'ЦэнтральнаАфрыканскаяРэспубліка'                           => 'cf',
    'Чад'                                                                                   => 'td',
    'Чарнагорыя'                                                                     => 'me',
    'Чылі'                                                                                 => 'cl',
    'Чэхія'                                                                               => 'cz',
    'Швейцарыя'                                                                       => 'ch',
    'Швецыя'                                                                             => 'se',
    'ШрыЛанка'                                                                         => 'lk',
    'Эквадор'                                                                           => 'ec',
    'ЭкватарыяльнаяГвінея'                                                 => 'gq',
    'Эрытрэя'                                                                           => 'er',
    'Эстонія'                                                                           => 'ee',
    'Эфіопія'                                                                           => 'et',
    'Ямайка'                                                                             => 'jm',
    'Японія'                                                                             => 'jp',
);

1;

