package Locales::DB::Territory::pt_pt;

# Auto generated from CLDR

$Locales::DB::Territory::pt_pt::VERSION = '0.02';

$Locales::DB::Territory::pt_pt::cldr_version = '1.7.1';

%Locales::DB::Territory::pt_pt::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "Emiratos\ Árabes\ Unidos",
    'af' => 'Afeganistão',
    'ag' => "Antígua\ e\ Barbuda",
    'ai' => 'Anguilha',
    'al' => 'Albânia',
    'am' => 'Arménia',
    'an' => "Antilhas\ Holandesas",
    'ao' => 'Angola',
    'aq' => 'Antárctica',
    'ar' => 'Argentina',
    'as' => "Samoa\ Americana",
    'at' => 'Áustria',
    'au' => 'Austrália',
    'aw' => 'Aruba',
    'ax' => "Ilhas\ Alanda",
    'az' => 'Azerbeijão',
    'ba' => "Bósnia\-Herzegovina",
    'bb' => 'Barbados',
    'bd' => 'Bangladeche',
    'be' => 'Bélgica',
    'bf' => "Burkina\-Faso",
    'bg' => 'Bulgária',
    'bh' => 'Bahrein',
    'bi' => 'Burundi',
    'bj' => 'Benim',
    'bl' => "São\ Bartolomeu",
    'bm' => 'Bermudas',
    'bn' => 'Brunei',
    'bo' => 'Bolívia',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brasil',
    'bs' => 'Baamas',
    'bt' => 'Butão',
    'bv' => "Ilha\ Bouvet",
    'bw' => 'Botswana',
    'by' => 'Bielorrússia',
    'bz' => 'Belize',
    'ca' => 'Canadá',
    'cc' => "Ilhas\ Cocos",
    'cd' => "República\ Democrática\ do\ Congo",
    'cf' => "República\ Centro\-Africana",
    'cg' => "Congo\-Brazzaville",
    'ch' => 'Suíça',
    'ci' => "Costa\ do\ Marfim",
    'ck' => "Ilhas\ Cook",
    'cl' => 'Chile',
    'cm' => "República\ dos\ Camarões",
    'cn' => 'China',
    'co' => 'Colômbia',
    'cr' => "Costa\ Rica",
    'cs' => "Sérvia\ e\ Montenegro",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Cuba',
    'cv' => "Cabo\ Verde",
    'cx' => "Ilha\ do\ Natal",
    'cy' => 'Chipre',
    'cz' => "República\ Checa",
    'dd' => "East\ Germany",
    'de' => 'Alemanha',
    'dj' => 'Djibuti',
    'dk' => 'Dinamarca',
    'dm' => 'Dominica',
    'do' => "República\ Dominicana",
    'dz' => 'Argélia',
    'ec' => 'Equador',
    'ee' => 'Estónia',
    'eg' => 'Egipto',
    'eh' => "Sara\ Ocidental",
    'er' => 'Eritreia',
    'es' => 'Espanha',
    'et' => 'Etiópia',
    'fi' => 'Finlândia',
    'fj' => 'Fiji',
    'fk' => "Ilhas\ Falkland\ ou\ Malvinas",
    'fm' => "Estados\ Federados\ da\ Micronésia",
    'fo' => "Ilhas\ Faroé",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'França',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabão',
    'gb' => "Reino\ Unido",
    'gd' => 'Granada',
    'ge' => 'Geórgia',
    'gf' => "Guiana\ Francesa",
    'gg' => 'Guernsey',
    'gh' => 'Gana',
    'gi' => 'Gibraltar',
    'gl' => 'Gronelândia',
    'gm' => 'Gâmbia',
    'gn' => 'Guiné',
    'gp' => 'Guadalupe',
    'gq' => "Guiné\ Equatorial",
    'gr' => 'Grécia',
    'gs' => "Geórgia\ do\ Sul\ e\ Ilhas\ Sandwich\ do\ Sul",
    'gt' => 'Guatemala',
    'gu' => 'Guam',
    'gw' => "Guiné\-Bissau",
    'gy' => 'Guiana',
    'hk' => "Hong\ Kong\ \-\ Região\ Administrativa\ Especial\ da\ China",
    'hm' => "Ilha\ Heard\ e\ Ilhas\ McDonald",
    'hn' => 'Honduras',
    'hr' => 'Croácia',
    'ht' => 'Haiti',
    'hu' => 'Hungria',
    'id' => 'Indonésia',
    'ie' => 'Irlanda',
    'il' => 'Israel',
    'im' => "Ilha\ de\ Man",
    'in' => 'Índia',
    'io' => "Território\ Britânico\ do\ Oceano\ Índico",
    'iq' => 'Iraque',
    'ir' => 'Irão',
    'is' => 'Islândia',
    'it' => 'Itália',
    'je' => 'Jersey',
    'jm' => 'Jamaica',
    'jo' => 'Jordânia',
    'jp' => 'Japão',
    'jt' => "Johnston\ Island",
    'ke' => 'Quénia',
    'kg' => 'Quirguizistão',
    'kh' => 'Camboja',
    'ki' => 'Quiribati',
    'km' => 'Comores',
    'kn' => "Saint\ Kitts\ e\ Nevis",
    'kp' => "Coreia\ do\ Norte",
    'kr' => "Coreia\ do\ Sul",
    'kw' => 'Cuaite',
    'ky' => "Ilhas\ Caimão",
    'kz' => 'Cazaquistão',
    'la' => "Laos\,\ República\ Popular\ Democrática\ do",
    'lb' => 'Líbano',
    'lc' => "Santa\ Lúcia",
    'li' => 'Liechtenstein',
    'lk' => "Sri\ Lanka",
    'lr' => 'Libéria',
    'ls' => 'Lesoto',
    'lt' => 'Lituânia',
    'lu' => 'Luxemburgo',
    'lv' => 'Letónia',
    'ly' => 'Líbia',
    'ma' => 'Marrocos',
    'mc' => 'Mónaco',
    'md' => "Moldávia\,\ República\ da",
    'me' => 'Montenegro',
    'mf' => "São\ Martinho",
    'mg' => 'Madagáscar',
    'mh' => "Ilhas\ Marshall",
    'mi' => "Midway\ Islands",
    'mk' => "Macedónia\,\ República\ da",
    'ml' => 'Mali',
    'mm' => 'Mianmar',
    'mn' => 'Mongólia',
    'mo' => "Macau\ \-\ Região\ Administrativa\ Especial\ da\ China",
    'mp' => "Ilhas\ Mariana\ do\ Norte",
    'mq' => 'Martinica',
    'mr' => 'Mauritânia',
    'ms' => 'Monserrate',
    'mt' => 'Malta',
    'mu' => 'Maurícias',
    'mv' => 'Maldivas',
    'mw' => 'Malaui',
    'mx' => 'México',
    'my' => 'Malásia',
    'mz' => 'Moçambique',
    'na' => 'Namíbia',
    'nc' => "Nova\ Caledónia",
    'ne' => 'Níger',
    'nf' => "Ilha\ Norfolque",
    'ng' => 'Nigéria',
    'ni' => 'Nicarágua',
    'nl' => "Países\ Baixos",
    'no' => 'Noruega',
    'np' => 'Nepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "Nova\ Zelândia",
    'om' => 'Omã',
    'pa' => 'Panamá',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Peru',
    'pf' => "Polinésia\ Francesa",
    'pg' => "Papua\ Nova\ Guiné",
    'ph' => 'Filipinas',
    'pk' => 'Paquistão',
    'pl' => 'Polónia',
    'pm' => "Saint\ Pierre\ e\ Miquelon",
    'pn' => 'Pitcairn',
    'pr' => "Porto\ Rico",
    'ps' => "Território\ Palestiniano",
    'pt' => 'Portugal',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paraguai',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Qatar',
    'qo' => "Oceânia\ Insular",
    'qu' => "União\ Europeia",
    're' => 'Reunião',
    'ro' => 'Roménia',
    'rs' => 'Sérvia',
    'ru' => 'Rússia',
    'rw' => 'Ruanda',
    'sa' => "Arábia\ Saudita",
    'sb' => "Ilhas\ Salomão",
    'sc' => 'Seicheles',
    'sd' => 'Sudão',
    'se' => 'Suécia',
    'sg' => 'Singapura',
    'sh' => "Santa\ Helena",
    'si' => 'Eslovénia',
    'sj' => "Esvalbarda\ e\ Jan\ Mayen",
    'sk' => 'Eslováquia',
    'sl' => "Serra\ Leoa",
    'sm' => "São\ Marino",
    'sn' => 'Senegal',
    'so' => 'Somália',
    'sr' => 'Suriname',
    'st' => "São\ Tomé\ e\ Príncipe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salvador",
    'sy' => 'Síria',
    'sz' => 'Suazilândia',
    'tc' => "Ilhas\ Turcas\ e\ Caicos",
    'td' => 'Chade',
    'tf' => "Territórios\ Franceses\ do\ Sul",
    'tg' => 'Togo',
    'th' => 'Tailândia',
    'tj' => 'Tajiquistão',
    'tk' => 'Toquelau',
    'tl' => "Timor\ Leste",
    'tm' => 'Turquemenistão',
    'tn' => 'Tunísia',
    'to' => 'Tonga',
    'tr' => 'Turquia',
    'tt' => "Trindade\ e\ Tobago",
    'tv' => 'Tuvalu',
    'tw' => 'Taiwan',
    'tz' => 'Tanzânia',
    'ua' => 'Ucrânia',
    'ug' => 'Uganda',
    'um' => "Ilhas\ Minor\ Outlying\ \(E\.U\.A\)",
    'us' => "Estados\ Unidos",
    'uy' => 'Uruguai',
    'uz' => 'Usbequistão',
    'va' => 'Vaticano',
    'vc' => "São\ Vicente\ e\ Granadinas",
    'vd' => "North\ Vietnam",
    've' => 'Venezuela',
    'vg' => "Ilhas\ Virgens\ Britânicas",
    'vi' => "Ilhas\ Virgin\ E\.U\.A\.",
    'vn' => 'Vietname',
    'vu' => 'Vanuatu',
    'wf' => "Wallis\ e\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Iémen',
    'yt' => 'Mayotte',
    'za' => "África\ do\ Sul",
    'zm' => 'Zâmbia',
    'zw' => 'Zimbabwe',
    'zz' => "Região\ desconhecida\ ou\ inválida",
);

%Locales::DB::Territory::pt_pt::name_to_code = (
    'afeganistão'                                 => 'af',
    'albânia'                                     => 'al',
    'alemanha'                                     => 'de',
    'andorra'                                      => 'ad',
    'angola'                                       => 'ao',
    'anguilha'                                     => 'ai',
    'antilhasholandesas'                           => 'an',
    'antárctica'                                  => 'aq',
    'antíguaebarbuda'                             => 'ag',
    'argentina'                                    => 'ar',
    'argélia'                                     => 'dz',
    'arménia'                                     => 'am',
    'aruba'                                        => 'aw',
    'arábiasaudita'                               => 'sa',
    'austrália'                                   => 'au',
    'azerbeijão'                                  => 'az',
    'baamas'                                       => 'bs',
    'bahrein'                                      => 'bh',
    'bangladeche'                                  => 'bd',
    'barbados'                                     => 'bb',
    'belize'                                       => 'bz',
    'benim'                                        => 'bj',
    'bermudas'                                     => 'bm',
    'bielorrússia'                                => 'by',
    'bolívia'                                     => 'bo',
    'botswana'                                     => 'bw',
    'brasil'                                       => 'br',
    'britishantarcticterritory'                    => 'bq',
    'brunei'                                       => 'bn',
    'bulgária'                                    => 'bg',
    'burkinafaso'                                  => 'bf',
    'burundi'                                      => 'bi',
    'butão'                                       => 'bt',
    'bélgica'                                     => 'be',
    'bósniaherzegovina'                           => 'ba',
    'caboverde'                                    => 'cv',
    'camboja'                                      => 'kh',
    'canadá'                                      => 'ca',
    'cantonandenderburyislands'                    => 'ct',
    'cazaquistão'                                 => 'kz',
    'chade'                                        => 'td',
    'chile'                                        => 'cl',
    'china'                                        => 'cn',
    'chipre'                                       => 'cy',
    'colômbia'                                    => 'co',
    'comores'                                      => 'km',
    'congobrazzaville'                             => 'cg',
    'coreiadonorte'                                => 'kp',
    'coreiadosul'                                  => 'kr',
    'costadomarfim'                                => 'ci',
    'costarica'                                    => 'cr',
    'croácia'                                     => 'hr',
    'cuaite'                                       => 'kw',
    'cuba'                                         => 'cu',
    'dinamarca'                                    => 'dk',
    'djibuti'                                      => 'dj',
    'dominica'                                     => 'dm',
    'dronningmaudland'                             => 'nq',
    'eastgermany'                                  => 'dd',
    'egipto'                                       => 'eg',
    'elsalvador'                                   => 'sv',
    'emiratosÁrabesunidos'                        => 'ae',
    'equador'                                      => 'ec',
    'eritreia'                                     => 'er',
    'eslováquia'                                  => 'sk',
    'eslovénia'                                   => 'si',
    'espanha'                                      => 'es',
    'estadosfederadosdamicronésia'                => 'fm',
    'estadosunidos'                                => 'us',
    'estónia'                                     => 'ee',
    'esvalbardaejanmayen'                          => 'sj',
    'etiópia'                                     => 'et',
    'fiji'                                         => 'fj',
    'filipinas'                                    => 'ph',
    'finlândia'                                   => 'fi',
    'frança'                                      => 'fr',
    'frenchsouthernandantarcticterritories'        => 'fq',
    'gabão'                                       => 'ga',
    'gana'                                         => 'gh',
    'geórgia'                                     => 'ge',
    'geórgiadosuleilhassandwichdosul'             => 'gs',
    'gibraltar'                                    => 'gi',
    'granada'                                      => 'gd',
    'gronelândia'                                 => 'gl',
    'grécia'                                      => 'gr',
    'guadalupe'                                    => 'gp',
    'guam'                                         => 'gu',
    'guatemala'                                    => 'gt',
    'guernsey'                                     => 'gg',
    'guiana'                                       => 'gy',
    'guianafrancesa'                               => 'gf',
    'guiné'                                       => 'gn',
    'guinébissau'                                 => 'gw',
    'guinéequatorial'                             => 'gq',
    'gâmbia'                                      => 'gm',
    'haiti'                                        => 'ht',
    'honduras'                                     => 'hn',
    'hongkongregiãoadministrativaespecialdachina' => 'hk',
    'hungria'                                      => 'hu',
    'ilhabouvet'                                   => 'bv',
    'ilhademan'                                    => 'im',
    'ilhadonatal'                                  => 'cx',
    'ilhaheardeilhasmcdonald'                      => 'hm',
    'ilhanorfolque'                                => 'nf',
    'ilhasalanda'                                  => 'ax',
    'ilhascaimão'                                 => 'ky',
    'ilhascocos'                                   => 'cc',
    'ilhascook'                                    => 'ck',
    'ilhasfalklandoumalvinas'                      => 'fk',
    'ilhasfaroé'                                  => 'fo',
    'ilhasmarianadonorte'                          => 'mp',
    'ilhasmarshall'                                => 'mh',
    "ilhasminoroutlyinge\.u\.a"                    => 'um',
    'ilhassalomão'                                => 'sb',
    'ilhasturcasecaicos'                           => 'tc',
    'ilhasvirgensbritânicas'                      => 'vg',
    "ilhasvirgine\.u\.a\."                         => 'vi',
    'indonésia'                                   => 'id',
    'iraque'                                       => 'iq',
    'irlanda'                                      => 'ie',
    'irão'                                        => 'ir',
    'islândia'                                    => 'is',
    'israel'                                       => 'il',
    'itália'                                      => 'it',
    'iémen'                                       => 'ye',
    'jamaica'                                      => 'jm',
    'japão'                                       => 'jp',
    'jersey'                                       => 'je',
    'johnstonisland'                               => 'jt',
    'jordânia'                                    => 'jo',
    "laos\,repúblicapopulardemocráticado"        => 'la',
    'lesoto'                                       => 'ls',
    'letónia'                                     => 'lv',
    'libéria'                                     => 'lr',
    'liechtenstein'                                => 'li',
    'lituânia'                                    => 'lt',
    'luxemburgo'                                   => 'lu',
    'líbano'                                      => 'lb',
    'líbia'                                       => 'ly',
    'macauregiãoadministrativaespecialdachina'    => 'mo',
    "macedónia\,repúblicada"                     => 'mk',
    'madagáscar'                                  => 'mg',
    'malaui'                                       => 'mw',
    'maldivas'                                     => 'mv',
    'mali'                                         => 'ml',
    'malta'                                        => 'mt',
    'malásia'                                     => 'my',
    'marrocos'                                     => 'ma',
    'martinica'                                    => 'mq',
    'mauritânia'                                  => 'mr',
    'maurícias'                                   => 'mu',
    'mayotte'                                      => 'yt',
    'metropolitanfrance'                           => 'fx',
    'mianmar'                                      => 'mm',
    'midwayislands'                                => 'mi',
    "moldávia\,repúblicada"                      => 'md',
    'mongólia'                                    => 'mn',
    'monserrate'                                   => 'ms',
    'montenegro'                                   => 'me',
    'moçambique'                                  => 'mz',
    'méxico'                                      => 'mx',
    'mónaco'                                      => 'mc',
    'namíbia'                                     => 'na',
    'nauru'                                        => 'nr',
    'nepal'                                        => 'np',
    'neutralzone'                                  => 'nt',
    'nicarágua'                                   => 'ni',
    'nigéria'                                     => 'ng',
    'niue'                                         => 'nu',
    'northvietnam'                                 => 'vd',
    'noruega'                                      => 'no',
    'novacaledónia'                               => 'nc',
    'novazelândia'                                => 'nz',
    'níger'                                       => 'ne',
    'oceâniainsular'                              => 'qo',
    'omã'                                         => 'om',
    'pacificislandstrustterritory'                 => 'pc',
    'palau'                                        => 'pw',
    'panamacanalzone'                              => 'pz',
    'panamá'                                      => 'pa',
    'papuanovaguiné'                              => 'pg',
    'paquistão'                                   => 'pk',
    'paraguai'                                     => 'py',
    'paísesbaixos'                                => 'nl',
    'peoplesdemocraticrepublicofyemen'             => 'yd',
    'peru'                                         => 'pe',
    'pitcairn'                                     => 'pn',
    'polinésiafrancesa'                           => 'pf',
    'polónia'                                     => 'pl',
    'portorico'                                    => 'pr',
    'portugal'                                     => 'pt',
    'qatar'                                        => 'qa',
    'quirguizistão'                               => 'kg',
    'quiribati'                                    => 'ki',
    'quénia'                                      => 'ke',
    'regiãodesconhecidaouinválida'               => 'zz',
    'reinounido'                                   => 'gb',
    'repúblicacentroafricana'                     => 'cf',
    'repúblicacheca'                              => 'cz',
    'repúblicademocráticadocongo'                => 'cd',
    'repúblicadominicana'                         => 'do',
    'repúblicadoscamarões'                       => 'cm',
    'reunião'                                     => 're',
    'roménia'                                     => 'ro',
    'ruanda'                                       => 'rw',
    'rússia'                                      => 'ru',
    'saintkittsenevis'                             => 'kn',
    'saintpierreemiquelon'                         => 'pm',
    'samoa'                                        => 'ws',
    'samoaamericana'                               => 'as',
    'santahelena'                                  => 'sh',
    'santalúcia'                                  => 'lc',
    'saraocidental'                                => 'eh',
    'seicheles'                                    => 'sc',
    'senegal'                                      => 'sn',
    'serraleoa'                                    => 'sl',
    'singapura'                                    => 'sg',
    'somália'                                     => 'so',
    'srilanka'                                     => 'lk',
    'suazilândia'                                 => 'sz',
    'sudão'                                       => 'sd',
    'suriname'                                     => 'sr',
    'suécia'                                      => 'se',
    'suíça'                                      => 'ch',
    'sãobartolomeu'                               => 'bl',
    'sãomarino'                                   => 'sm',
    'sãomartinho'                                 => 'mf',
    'sãotoméepríncipe'                          => 'st',
    'sãovicenteegranadinas'                       => 'vc',
    'sérvia'                                      => 'rs',
    'sérviaemontenegro'                           => 'cs',
    'síria'                                       => 'sy',
    'tailândia'                                   => 'th',
    'taiwan'                                       => 'tw',
    'tajiquistão'                                 => 'tj',
    'tanzânia'                                    => 'tz',
    'territóriobritânicodooceanoÍndico'         => 'io',
    'territóriopalestiniano'                      => 'ps',
    'territóriosfrancesesdosul'                   => 'tf',
    'timorleste'                                   => 'tl',
    'togo'                                         => 'tg',
    'tonga'                                        => 'to',
    'toquelau'                                     => 'tk',
    'trindadeetobago'                              => 'tt',
    'tunísia'                                     => 'tn',
    'turquemenistão'                              => 'tm',
    'turquia'                                      => 'tr',
    'tuvalu'                                       => 'tv',
    "u\.s\.miscellaneouspacificislands"            => 'pu',
    'ucrânia'                                     => 'ua',
    'uganda'                                       => 'ug',
    'unionofsovietsocialistrepublics'              => 'su',
    'uniãoeuropeia'                               => 'qu',
    'uruguai'                                      => 'uy',
    'usbequistão'                                 => 'uz',
    'vanuatu'                                      => 'vu',
    'vaticano'                                     => 'va',
    'venezuela'                                    => 've',
    'vietname'                                     => 'vn',
    'wakeisland'                                   => 'wk',
    'wallisefutuna'                                => 'wf',
    'zimbabwe'                                     => 'zw',
    'zâmbia'                                      => 'zm',
    'Áfricadosul'                                 => 'za',
    'Áustria'                                     => 'at',
    'Índia'                                       => 'in',
);

1;

