package Locales::DB::Territory::am;

# Auto generated from CLDR

$Locales::DB::Territory::am::VERSION = '0.02';

$Locales::DB::Territory::am::cldr_version = '1.7.1';

%Locales::DB::Territory::am::code_to_name = (
    'ad' => 'አንዶራ',
    'ae' => "የተባበሩት\ አረብ\ ኤምሬትስ",
    'af' => 'አፍጋኒስታን',
    'ag' => "አንቲጓ\ እና\ ባሩዳ",
    'ai' => 'አንጉኢላ',
    'al' => 'አልባኒያ',
    'am' => 'አርሜኒያ',
    'an' => "ኔዘርላንድስ\ አንቲልስ",
    'ao' => 'አንጐላ',
    'aq' => 'አንታርክቲካ',
    'ar' => 'አርጀንቲና',
    'as' => "የአሜሪካ\ ሳሞአ",
    'at' => 'ኦስትሪያ',
    'au' => 'አውስትሬሊያ',
    'aw' => 'አሩባ',
    'ax' => "የአላንድ\ ደሴቶች",
    'az' => 'አዘርባጃን',
    'ba' => "ቦስኒያ\ እና\ ሄርዞጎቪኒያ",
    'bb' => 'ባርቤዶስ',
    'bd' => 'ባንግላዲሽ',
    'be' => 'ቤልጄም',
    'bf' => "ቡርኪና\ ፋሶ",
    'bg' => 'ቡልጌሪያ',
    'bh' => 'ባህሬን',
    'bi' => 'ብሩንዲ',
    'bj' => 'ቤኒን',
    'bl' => "Saint\ Barth\Ã\©lemy",
    'bm' => 'ቤርሙዳ',
    'bn' => 'ብሩኒ',
    'bo' => 'ቦሊቪያ',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'ብራዚል',
    'bs' => 'ባሃማስ',
    'bt' => 'ቡህታን',
    'bv' => "የቦውቬት\ ደሴት",
    'bw' => 'ቦትስዋና',
    'by' => 'ቤላሩስ',
    'bz' => 'ቤሊዘ',
    'ca' => 'ካናዳ',
    'cc' => "ኮኮስ\ ኬሊንግ\ ደሴቶች",
    'cd' => 'ኮንጎ',
    'cf' => "የመካከለኛው\ አፍሪካ\ ሪፐብሊክ",
    'cg' => 'ኮንጐ',
    'ch' => 'ስዊዘርላንድ',
    'ci' => "ኮት\ ዲቯር",
    'ck' => "ኩክ\ ደሴቶች",
    'cl' => 'ቺሊ',
    'cm' => 'ካሜሩን',
    'cn' => 'ቻይና',
    'co' => 'ኮሎምቢያ',
    'cr' => "ኮስታ\ ሪካ",
    'cs' => 'ሰርቢያ',
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'ኩባ',
    'cv' => "ኬፕ\ ቬርዴ",
    'cx' => "የገና\ ደሴቶች",
    'cy' => 'ሳይፕረስ',
    'cz' => "ቼክ\ ሪፑብሊክ",
    'dd' => "East\ Germany",
    'de' => 'ጀርመን',
    'dj' => 'ጂቡቲ',
    'dk' => 'ዴንማርክ',
    'dm' => 'ዶሚኒካ',
    'do' => "ዶሚኒክ\ ሪፑብሊክ",
    'dz' => 'አልጄሪያ',
    'ec' => 'ኢኳዶር',
    'ee' => 'ኤስቶኒያ',
    'eg' => 'ግብጽ',
    'eh' => "ምዕራባዊ\ ሳህራ",
    'er' => 'ኤርትራ',
    'es' => 'ስፔን',
    'et' => 'ኢትዮጵያ',
    'fi' => 'ፊንላንድ',
    'fj' => 'ፊጂ',
    'fk' => "የፎልክላንድ\ ደሴቶች",
    'fm' => 'ሚክሮኔዢያ',
    'fo' => "የፋሮይ\ ደሴቶች",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'ፈረንሳይ',
    'fx' => "Metropolitan\ France",
    'ga' => 'ጋቦን',
    'gb' => 'እንግሊዝ',
    'gd' => 'ግሬናዳ',
    'ge' => 'ጆርጂያ',
    'gf' => "የፈረንሳይ\ ጉዊአና",
    'gg' => 'Guernsey',
    'gh' => 'ጋና',
    'gi' => 'ጊብራልታር',
    'gl' => 'ግሪንላንድ',
    'gm' => 'ጋምቢያ',
    'gn' => 'ጊኒ',
    'gp' => 'ጉዋደሉፕ',
    'gq' => "ኢኳቶሪያል\ ጊኒ",
    'gr' => 'ግሪክ',
    'gs' => "ደቡብ\ ጆርጂያ\ እና\ የደቡድ\ ሳንድዊች\ ደሴቶች",
    'gt' => 'ጉዋቲማላ',
    'gu' => 'ጉዋም',
    'gw' => 'ቢሳዎ',
    'gy' => 'ጉያና',
    'hk' => "ሆንግ\ ኮንግ",
    'hm' => "የኧርድ\ እና\ የማክዶናልድ\ ደሴቶች",
    'hn' => 'ሆንዱራስ',
    'hr' => 'ክሮኤሽያ',
    'ht' => 'ሀይቲ',
    'hu' => 'ሀንጋሪ',
    'id' => 'ኢንዶኔዢያ',
    'ie' => 'አየርላንድ',
    'il' => 'እስራኤል',
    'im' => "Isle\ of\ Man",
    'in' => 'ህንድ',
    'io' => "የብሪታኒያ\ ህንድ\ ውቂያኖስ\ ግዛት",
    'iq' => 'ኢራቅ',
    'ir' => 'ኢራን',
    'is' => 'አይስላንድ',
    'it' => 'ጣሊያን',
    'je' => 'Jersey',
    'jm' => 'ጃማይካ',
    'jo' => 'ጆርዳን',
    'jp' => 'ጃፓን',
    'jt' => "Johnston\ Island",
    'ke' => 'ኬንያ',
    'kg' => 'Kyrgyzstan',
    'kh' => 'ካምቦዲያ',
    'ki' => 'ኪሪባቲ',
    'km' => 'ኮሞሮስ',
    'kn' => "ቅዱስ\ ኪትስ\ እና\ ኔቪስ",
    'kp' => "ሰሜን\ ኮሪያ",
    'kr' => "ደቡብ\ ኮሪያ",
    'kw' => 'ክዌት',
    'ky' => "ካይማን\ ደሴቶች",
    'kz' => 'Kazakhstan',
    'la' => 'ላኦስ',
    'lb' => 'ሊባኖስ',
    'lc' => "ሴንት\ ሉቺያ",
    'li' => 'ሊችተንስታይን',
    'lk' => 'ሲሪላንካ',
    'lr' => 'ላይቤሪያ',
    'ls' => 'ሌሶቶ',
    'lt' => 'ሊቱዌኒያ',
    'lu' => 'ሉክሰምበርግ',
    'lv' => 'ላትቪያ',
    'ly' => 'ሊቢያ',
    'ma' => 'ሞሮኮ',
    'mc' => 'ሞናኮ',
    'md' => 'ሞልዶቫ',
    'me' => 'Montenegro',
    'mf' => "Saint\ Martin",
    'mg' => 'ማዳጋስካር',
    'mh' => "ማርሻል\ አይላንድ",
    'mi' => "Midway\ Islands",
    'mk' => 'ማከዶኒያ',
    'ml' => 'ማሊ',
    'mm' => 'ማያንማር',
    'mn' => 'ሞንጎሊያ',
    'mo' => 'ማካዎ',
    'mp' => "የሰሜናዊ\ ማሪያና\ ደሴቶች",
    'mq' => 'ማርቲኒክ',
    'mr' => 'ሞሪቴኒያ',
    'ms' => 'ሞንትሴራት',
    'mt' => 'ማልታ',
    'mu' => 'ማሩሸስ',
    'mv' => 'ማልዲቭስ',
    'mw' => 'ማላዊ',
    'mx' => 'ሜክሲኮ',
    'my' => 'ማሌዢያ',
    'mz' => 'ሞዛምቢክ',
    'na' => 'ናሚቢያ',
    'nc' => "ኒው\ ካሌዶኒያ",
    'ne' => 'ኒጀር',
    'nf' => "ኖርፎልክ\ ደሴት",
    'ng' => 'ናይጄሪያ',
    'ni' => 'ኒካራጓ',
    'nl' => 'ኔዘርላንድ',
    'no' => 'ኖርዌ',
    'np' => 'ኔፓል',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'ናኡሩ',
    'nt' => "Neutral\ Zone",
    'nu' => 'ኒኡይ',
    'nz' => "ኒው\ ዚላንድ",
    'om' => 'ኦማን',
    'pa' => 'ፓናማ',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'ፔሩ',
    'pf' => "የፈረንሳይ\ ፖሊኔዢያ",
    'pg' => "ፓፑዋ\ ኒው\ ጊኒ",
    'ph' => 'ፊሊፒንስ',
    'pk' => 'ፓኪስታን',
    'pl' => 'ፖላንድ',
    'pm' => "ቅዱስ\ ፒዬር\ እና\ ሚኩኤሎን",
    'pn' => 'ፒትካኢርን',
    'pr' => "ፖርታ\ ሪኮ",
    'ps' => "የፍልስጤም\ ግዛት",
    'pt' => 'ፖርቱጋል',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'ፓላው',
    'py' => 'ፓራጓይ',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'ኳታር',
    'qo' => "ወጣ\ ያለ\ ኦሽኒያ",
    'qu' => "European\ Union",
    're' => 'ሪዩኒየን',
    'ro' => 'ሮሜኒያ',
    'rs' => 'Serbia',
    'ru' => 'ራሺያ',
    'rw' => 'ሩዋንዳ',
    'sa' => 'ሳውድአረቢያ',
    'sb' => "ሰሎሞን\ ደሴት",
    'sc' => 'ሲሼልስ',
    'sd' => 'ሱዳን',
    'se' => 'ስዊድን',
    'sg' => 'ሲንጋፖር',
    'sh' => "ሴንት\ ሄለና",
    'si' => 'ስሎቬኒያ',
    'sj' => "የስቫልባርድ\ እና\ ዣን\ ማየን\ ደሴቶች",
    'sk' => 'ስሎቫኪያ',
    'sl' => 'ሴራሊዮን',
    'sm' => "ሳን\ ማሪኖ",
    'sn' => 'ሴኔጋል',
    'so' => 'ሱማሌ',
    'sr' => 'ሱሪናም',
    'st' => "ሳኦ\ ቶሜ\ እና\ ፕሪንሲፔ",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "ኤል\ ሳልቫዶር",
    'sy' => 'ሲሪያ',
    'sz' => 'ሱዋዚላንድ',
    'tc' => "የቱርኮችና\ የካኢኮስ\ ደሴቶች",
    'td' => 'ቻድ',
    'tf' => "የፈረንሳይ\ ደቡባዊ\ ግዛቶች",
    'tg' => 'ቶጐ',
    'th' => 'ታይላንድ',
    'tj' => 'ታጃኪስታን',
    'tk' => 'ቶክላው',
    'tl' => "ምስራቅ\ ቲሞር",
    'tm' => 'ቱርክሜኒስታን',
    'tn' => 'ቱኒዚያ',
    'to' => 'ቶንጋ',
    'tr' => 'ቱርክ',
    'tt' => "ትሪኒዳድ\ እና\ ቶባጎ",
    'tv' => 'ቱቫሉ',
    'tw' => 'ታይዋን',
    'tz' => 'ታንዛኒያ',
    'ua' => 'ዩክሬን',
    'ug' => 'ዩጋንዳ',
    'um' => "የአሜሪካ\ ራቅ\ ያሉ\ አናሳ\ ደሴቶች",
    'us' => 'አሜሪካ',
    'uy' => 'ኡራጓይ',
    'uz' => 'ዩዝበኪስታን',
    'va' => 'ቫቲካን',
    'vc' => "ቅዱስ\ ቪንሴንት\ እና\ ግሬናዲንስ",
    'vd' => "North\ Vietnam",
    've' => 'ቬንዙዌላ',
    'vg' => "የእንግሊዝ\ ድንግል\ ደሴቶች",
    'vi' => "የአሜሪካ\ ቨርጂን\ ደሴቶች",
    'vn' => 'ቬትናም',
    'vu' => 'ቫኑአቱ',
    'wf' => "ዋሊስ\ እና\ ፉቱና\ ደሴቶች",
    'wk' => "Wake\ Island",
    'ws' => 'ሳሞአ',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'የመን',
    'yt' => 'ሜይኦቴ',
    'za' => "ደቡብ\ አፍሪካ",
    'zm' => 'ዛምቢያ',
    'zw' => 'ዚምቧቤ',
    'zz' => "Unknown\ or\ Invalid\ Region",
);

%Locales::DB::Territory::am::name_to_code = (
    'britishantarcticterritory'                                          => 'bq',
    'cantonandenderburyislands'                                          => 'ct',
    'dronningmaudland'                                                   => 'nq',
    'eastgermany'                                                        => 'dd',
    'europeanunion'                                                      => 'qu',
    'frenchsouthernandantarcticterritories'                              => 'fq',
    'guernsey'                                                           => 'gg',
    'isleofman'                                                          => 'im',
    'jersey'                                                             => 'je',
    'johnstonisland'                                                     => 'jt',
    'kazakhstan'                                                         => 'kz',
    'kyrgyzstan'                                                         => 'kg',
    'metropolitanfrance'                                                 => 'fx',
    'midwayislands'                                                      => 'mi',
    'montenegro'                                                         => 'me',
    'neutralzone'                                                        => 'nt',
    'northvietnam'                                                       => 'vd',
    'pacificislandstrustterritory'                                       => 'pc',
    'panamacanalzone'                                                    => 'pz',
    'peoplesdemocraticrepublicofyemen'                                   => 'yd',
    "saintbarth\Ã\©lemy"                                               => 'bl',
    'saintmartin'                                                        => 'mf',
    'serbia'                                                             => 'rs',
    "u\.s\.miscellaneouspacificislands"                                  => 'pu',
    'unionofsovietsocialistrepublics'                                    => 'su',
    'unknownorinvalidregion'                                             => 'zz',
    'wakeisland'                                                         => 'wk',
    'ሀንጋሪ'                                                       => 'hu',
    'ሀይቲ'                                                          => 'ht',
    'ህንድ'                                                          => 'in',
    'ሆንዱራስ'                                                    => 'hn',
    'ሆንግኮንግ'                                                 => 'hk',
    'ሉክሰምበርግ'                                              => 'lu',
    'ሊቢያ'                                                          => 'ly',
    'ሊባኖስ'                                                       => 'lb',
    'ሊቱዌኒያ'                                                    => 'lt',
    'ሊችተንስታይን'                                           => 'li',
    'ላትቪያ'                                                       => 'lv',
    'ላኦስ'                                                          => 'la',
    'ላይቤሪያ'                                                    => 'lr',
    'ሌሶቶ'                                                          => 'ls',
    'ሚክሮኔዢያ'                                                 => 'fm',
    'ማሊ'                                                             => 'ml',
    'ማላዊ'                                                          => 'mw',
    'ማሌዢያ'                                                       => 'my',
    'ማልታ'                                                          => 'mt',
    'ማልዲቭስ'                                                    => 'mv',
    'ማሩሸስ'                                                       => 'mu',
    'ማርሻልአይላንድ'                                        => 'mh',
    'ማርቲኒክ'                                                    => 'mq',
    'ማከዶኒያ'                                                    => 'mk',
    'ማካዎ'                                                          => 'mo',
    'ማያንማር'                                                    => 'mm',
    'ማዳጋስካር'                                                 => 'mg',
    'ሜክሲኮ'                                                       => 'mx',
    'ሜይኦቴ'                                                       => 'yt',
    'ምስራቅቲሞር'                                              => 'tl',
    'ምዕራባዊሳህራ'                                           => 'eh',
    'ሞልዶቫ'                                                       => 'md',
    'ሞሪቴኒያ'                                                    => 'mr',
    'ሞሮኮ'                                                          => 'ma',
    'ሞናኮ'                                                          => 'mc',
    'ሞንትሴራት'                                                 => 'ms',
    'ሞንጎሊያ'                                                    => 'mn',
    'ሞዛምቢክ'                                                    => 'mz',
    'ሩዋንዳ'                                                       => 'rw',
    'ሪዩኒየን'                                                    => 're',
    'ራሺያ'                                                          => 'ru',
    'ሮሜኒያ'                                                       => 'ro',
    'ሰሎሞንደሴት'                                              => 'sb',
    'ሰሜንኮሪያ'                                                 => 'kp',
    'ሰርቢያ'                                                       => 'cs',
    'ሱማሌ'                                                          => 'so',
    'ሱሪናም'                                                       => 'sr',
    'ሱዋዚላንድ'                                                 => 'sz',
    'ሱዳን'                                                          => 'sd',
    'ሲሪላንካ'                                                    => 'lk',
    'ሲሪያ'                                                          => 'sy',
    'ሲሼልስ'                                                       => 'sc',
    'ሲንጋፖር'                                                    => 'sg',
    'ሳሞአ'                                                          => 'ws',
    'ሳንማሪኖ'                                                    => 'sm',
    'ሳኦቶሜእናፕሪንሲፔ'                                  => 'st',
    'ሳውድአረቢያ'                                              => 'sa',
    'ሳይፕረስ'                                                    => 'cy',
    'ሴራሊዮን'                                                    => 'sl',
    'ሴኔጋል'                                                       => 'sn',
    'ሴንትሄለና'                                                 => 'sh',
    'ሴንትሉቺያ'                                                 => 'lc',
    'ስሎቫኪያ'                                                    => 'sk',
    'ስሎቬኒያ'                                                    => 'si',
    'ስዊዘርላንድ'                                              => 'ch',
    'ስዊድን'                                                       => 'se',
    'ስፔን'                                                          => 'es',
    'ቅዱስቪንሴንትእናግሬናዲንስ'                   => 'vc',
    'ቅዱስኪትስእናኔቪስ'                                  => 'kn',
    'ቅዱስፒዬርእናሚኩኤሎን'                            => 'pm',
    'ቡህታን'                                                       => 'bt',
    'ቡልጌሪያ'                                                    => 'bg',
    'ቡርኪናፋሶ'                                                 => 'bf',
    'ቢሳዎ'                                                          => 'gw',
    'ባሃማስ'                                                       => 'bs',
    'ባህሬን'                                                       => 'bh',
    'ባርቤዶስ'                                                    => 'bb',
    'ባንግላዲሽ'                                                 => 'bd',
    'ቤሊዘ'                                                          => 'bz',
    'ቤላሩስ'                                                       => 'by',
    'ቤልጄም'                                                       => 'be',
    'ቤርሙዳ'                                                       => 'bm',
    'ቤኒን'                                                          => 'bj',
    'ብሩኒ'                                                          => 'bn',
    'ብሩንዲ'                                                       => 'bi',
    'ብራዚል'                                                       => 'br',
    'ቦሊቪያ'                                                       => 'bo',
    'ቦስኒያእናሄርዞጎቪኒያ'                            => 'ba',
    'ቦትስዋና'                                                    => 'bw',
    'ቫቲካን'                                                       => 'va',
    'ቫኑአቱ'                                                       => 'vu',
    'ቬትናም'                                                       => 'vn',
    'ቬንዙዌላ'                                                    => 've',
    'ቱርክ'                                                          => 'tr',
    'ቱርክሜኒስታን'                                           => 'tm',
    'ቱቫሉ'                                                          => 'tv',
    'ቱኒዚያ'                                                       => 'tn',
    'ታንዛኒያ'                                                    => 'tz',
    'ታይላንድ'                                                    => 'th',
    'ታይዋን'                                                       => 'tw',
    'ታጃኪስታን'                                                 => 'tj',
    'ትሪኒዳድእናቶባጎ'                                     => 'tt',
    'ቶንጋ'                                                          => 'to',
    'ቶክላው'                                                       => 'tk',
    'ቶጐ'                                                             => 'tg',
    'ቺሊ'                                                             => 'cl',
    'ቻይና'                                                          => 'cn',
    'ቻድ'                                                             => 'td',
    'ቼክሪፑብሊክ'                                              => 'cz',
    'ኒኡይ'                                                          => 'nu',
    'ኒካራጓ'                                                       => 'ni',
    'ኒውካሌዶኒያ'                                              => 'nc',
    'ኒውዚላንድ'                                                 => 'nz',
    'ኒጀር'                                                          => 'ne',
    'ናሚቢያ'                                                       => 'na',
    'ናኡሩ'                                                          => 'nr',
    'ናይጄሪያ'                                                    => 'ng',
    'ኔዘርላንድ'                                                 => 'nl',
    'ኔዘርላንድስአንቲልስ'                               => 'an',
    'ኔፓል'                                                          => 'np',
    'ኖርዌ'                                                          => 'no',
    'ኖርፎልክደሴት'                                           => 'nf',
    'አልባኒያ'                                                    => 'al',
    'አልጄሪያ'                                                    => 'dz',
    'አሜሪካ'                                                       => 'us',
    'አሩባ'                                                          => 'aw',
    'አርሜኒያ'                                                    => 'am',
    'አርጀንቲና'                                                 => 'ar',
    'አንቲጓእናባሩዳ'                                        => 'ag',
    'አንታርክቲካ'                                              => 'aq',
    'አንዶራ'                                                       => 'ad',
    'አንጉኢላ'                                                    => 'ai',
    'አንጐላ'                                                       => 'ao',
    'አውስትሬሊያ'                                              => 'au',
    'አዘርባጃን'                                                 => 'az',
    'አየርላንድ'                                                 => 'ie',
    'አይስላንድ'                                                 => 'is',
    'አፍጋኒስታን'                                              => 'af',
    'ኡራጓይ'                                                       => 'uy',
    'ኢራቅ'                                                          => 'iq',
    'ኢራን'                                                          => 'ir',
    'ኢትዮጵያ'                                                    => 'et',
    'ኢንዶኔዢያ'                                                 => 'id',
    'ኢኳቶሪያልጊኒ'                                           => 'gq',
    'ኢኳዶር'                                                       => 'ec',
    'ኤልሳልቫዶር'                                              => 'sv',
    'ኤርትራ'                                                       => 'er',
    'ኤስቶኒያ'                                                    => 'ee',
    'እስራኤል'                                                    => 'il',
    'እንግሊዝ'                                                    => 'gb',
    'ኦማን'                                                          => 'om',
    'ኦስትሪያ'                                                    => 'at',
    'ኩባ'                                                             => 'cu',
    'ኩክደሴቶች'                                                 => 'ck',
    'ኪሪባቲ'                                                       => 'ki',
    'ካሜሩን'                                                       => 'cm',
    'ካምቦዲያ'                                                    => 'kh',
    'ካናዳ'                                                          => 'ca',
    'ካይማንደሴቶች'                                           => 'ky',
    'ኬንያ'                                                          => 'ke',
    'ኬፕቬርዴ'                                                    => 'cv',
    'ክሮኤሽያ'                                                    => 'hr',
    'ክዌት'                                                          => 'kw',
    'ኮሎምቢያ'                                                    => 'co',
    'ኮሞሮስ'                                                       => 'km',
    'ኮስታሪካ'                                                    => 'cr',
    'ኮትዲቯር'                                                    => 'ci',
    'ኮንጎ'                                                          => 'cd',
    'ኮንጐ'                                                          => 'cg',
    'ኮኮስኬሊንግደሴቶች'                                  => 'cc',
    'ኳታር'                                                          => 'qa',
    'ወጣያለኦሽኒያ'                                           => 'qo',
    'ዋሊስእናፉቱናደሴቶች'                               => 'wf',
    'ዚምቧቤ'                                                       => 'zw',
    'ዛምቢያ'                                                       => 'zm',
    'የመን'                                                          => 'ye',
    'የመካከለኛውአፍሪካሪፐብሊክ'                   => 'cf',
    'የሰሜናዊማሪያናደሴቶች'                            => 'mp',
    'የስቫልባርድእናዣንማየንደሴቶች'             => 'sj',
    'የብሪታኒያህንድውቂያኖስግዛት'                => 'io',
    'የቦውቬትደሴት'                                           => 'bv',
    'የተባበሩትአረብኤምሬትስ'                         => 'ae',
    'የቱርኮችናየካኢኮስደሴቶች'                      => 'tc',
    'የአላንድደሴቶች'                                        => 'ax',
    'የአሜሪካራቅያሉአናሳደሴቶች'                   => 'um',
    'የአሜሪካሳሞአ'                                           => 'as',
    'የአሜሪካቨርጂንደሴቶች'                            => 'vi',
    'የእንግሊዝድንግልደሴቶች'                         => 'vg',
    'የኧርድእናየማክዶናልድደሴቶች'                => 'hm',
    'የገናደሴቶች'                                              => 'cx',
    'የፈረንሳይደቡባዊግዛቶች'                         => 'tf',
    'የፈረንሳይጉዊአና'                                     => 'gf',
    'የፈረንሳይፖሊኔዢያ'                                  => 'pf',
    'የፋሮይደሴቶች'                                           => 'fo',
    'የፍልስጤምግዛት'                                        => 'ps',
    'የፎልክላንድደሴቶች'                                  => 'fk',
    'ዩክሬን'                                                       => 'ua',
    'ዩዝበኪስታን'                                              => 'uz',
    'ዩጋንዳ'                                                       => 'ug',
    'ደቡብአፍሪካ'                                              => 'za',
    'ደቡብኮሪያ'                                                 => 'kr',
    'ደቡብጆርጂያእናየደቡድሳንድዊችደሴቶች' => 'gs',
    'ዴንማርክ'                                                    => 'dk',
    'ዶሚኒካ'                                                       => 'dm',
    'ዶሚኒክሪፑብሊክ'                                        => 'do',
    'ጀርመን'                                                       => 'de',
    'ጂቡቲ'                                                          => 'dj',
    'ጃማይካ'                                                       => 'jm',
    'ጃፓን'                                                          => 'jp',
    'ጆርዳን'                                                       => 'jo',
    'ጆርጂያ'                                                       => 'ge',
    'ጉዋም'                                                          => 'gu',
    'ጉዋቲማላ'                                                    => 'gt',
    'ጉዋደሉፕ'                                                    => 'gp',
    'ጉያና'                                                          => 'gy',
    'ጊብራልታር'                                                 => 'gi',
    'ጊኒ'                                                             => 'gn',
    'ጋምቢያ'                                                       => 'gm',
    'ጋቦን'                                                          => 'ga',
    'ጋና'                                                             => 'gh',
    'ግሪንላንድ'                                                 => 'gl',
    'ግሪክ'                                                          => 'gr',
    'ግሬናዳ'                                                       => 'gd',
    'ግብጽ'                                                          => 'eg',
    'ጣሊያን'                                                       => 'it',
    'ፈረንሳይ'                                                    => 'fr',
    'ፊሊፒንስ'                                                    => 'ph',
    'ፊንላንድ'                                                    => 'fi',
    'ፊጂ'                                                             => 'fj',
    'ፒትካኢርን'                                                 => 'pn',
    'ፓላው'                                                          => 'pw',
    'ፓራጓይ'                                                       => 'py',
    'ፓናማ'                                                          => 'pa',
    'ፓኪስታን'                                                    => 'pk',
    'ፓፑዋኒውጊኒ'                                              => 'pg',
    'ፔሩ'                                                             => 'pe',
    'ፖላንድ'                                                       => 'pl',
    'ፖርቱጋል'                                                    => 'pt',
    'ፖርታሪኮ'                                                    => 'pr',
);

1;

