package Locales::DB::Territory::nl;

# Auto generated from CLDR

$Locales::DB::Territory::nl::VERSION = '0.02';

$Locales::DB::Territory::nl::cldr_version = '1.7.1';

%Locales::DB::Territory::nl::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "Verenigde\ Arabische\ Emiraten",
    'af' => 'Afghanistan',
    'ag' => "Antigua\ en\ Barbuda",
    'ai' => 'Anguilla',
    'al' => 'Albanië',
    'am' => 'Armenië',
    'an' => "Nederlandse\ Antillen",
    'ao' => 'Angola',
    'aq' => 'Antarctica',
    'ar' => 'Argentinië',
    'as' => "Amerikaans\ Samoa",
    'at' => 'Oostenrijk',
    'au' => 'Australië',
    'aw' => 'Aruba',
    'ax' => 'Åland',
    'az' => 'Azerbeidzjan',
    'ba' => "Bosnië\ en\ Herzegovina",
    'bb' => 'Barbados',
    'bd' => 'Bangladesh',
    'be' => 'België',
    'bf' => "Burkina\ Faso",
    'bg' => 'Bulgarije',
    'bh' => 'Bahrein',
    'bi' => 'Burundi',
    'bj' => 'Benin',
    'bl' => "Saint\ Barthélemy",
    'bm' => 'Bermuda',
    'bn' => 'Brunei',
    'bo' => 'Bolivia',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brazilië',
    'bs' => 'Bahamas',
    'bt' => 'Bhutan',
    'bv' => 'Bouveteiland',
    'bw' => 'Botswana',
    'by' => "Wit\-Rusland",
    'bz' => 'Belize',
    'ca' => 'Canada',
    'cc' => 'Cocoseilanden',
    'cd' => "Congo\-Kinshasa",
    'cf' => "Centraal\-Afrikaanse\ Republiek",
    'cg' => "Congo\-Brazzaville",
    'ch' => 'Zwitserland',
    'ci' => 'Ivoorkust',
    'ck' => 'Cookeilanden',
    'cl' => 'Chili',
    'cm' => 'Kameroen',
    'cn' => 'China',
    'co' => 'Colombia',
    'cr' => "Costa\ Rica",
    'cs' => "Servië\ en\ Montenegro",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Cuba',
    'cv' => 'Kaapverdië',
    'cx' => 'Christmaseiland',
    'cy' => 'Cyprus',
    'cz' => 'Tsjechië',
    'dd' => "East\ Germany",
    'de' => 'Duitsland',
    'dj' => 'Djibouti',
    'dk' => 'Denemarken',
    'dm' => 'Dominica',
    'do' => "Dominicaanse\ Republiek",
    'dz' => 'Algerije',
    'ec' => 'Ecuador',
    'ee' => 'Estland',
    'eg' => 'Egypte',
    'eh' => "Westelijke\ Sahara",
    'er' => 'Eritrea',
    'es' => 'Spanje',
    'et' => 'Ethiopië',
    'fi' => 'Finland',
    'fj' => 'Fiji',
    'fk' => 'Falklandeilanden',
    'fm' => 'Micronesië',
    'fo' => 'Faeröer',
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Frankrijk',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabon',
    'gb' => "Verenigd\ Koninkrijk",
    'gd' => 'Grenada',
    'ge' => 'Georgië',
    'gf' => "Frans\-Guyana",
    'gg' => 'Guernsey',
    'gh' => 'Ghana',
    'gi' => 'Gibraltar',
    'gl' => 'Groenland',
    'gm' => 'Gambia',
    'gn' => 'Guinee',
    'gp' => 'Guadeloupe',
    'gq' => "Equatoriaal\-Guinea",
    'gr' => 'Griekenland',
    'gs' => "Zuid\-Georgië\ en\ Zuidelijke\ Sandwicheilanden",
    'gt' => 'Guatemala',
    'gu' => 'Guam',
    'gw' => "Guinee\-Bissau",
    'gy' => 'Guyana',
    'hk' => 'Hongkong',
    'hm' => "Heard\-\ en\ McDonaldeilanden",
    'hn' => 'Honduras',
    'hr' => 'Kroatië',
    'ht' => 'Haïti',
    'hu' => 'Hongarije',
    'id' => 'Indonesië',
    'ie' => 'Ierland',
    'il' => 'Israël',
    'im' => "Isle\ of\ Man",
    'in' => 'India',
    'io' => "Brits\ Territorium\ in\ de\ Indische\ Oceaan",
    'iq' => 'Irak',
    'ir' => 'Iran',
    'is' => 'IJsland',
    'it' => 'Italië',
    'je' => 'Jersey',
    'jm' => 'Jamaica',
    'jo' => 'Jordanië',
    'jp' => 'Japan',
    'jt' => "Johnston\ Island",
    'ke' => 'Kenia',
    'kg' => 'Kirgizië',
    'kh' => 'Cambodja',
    'ki' => 'Kiribati',
    'km' => 'Comoren',
    'kn' => "Saint\ Kitts\ en\ Nevis",
    'kp' => "Noord\-Korea",
    'kr' => "Zuid\-Korea",
    'kw' => 'Koeweit',
    'ky' => 'Caymaneilanden',
    'kz' => 'Kazachstan',
    'la' => 'Laos',
    'lb' => 'Libanon',
    'lc' => "Saint\ Lucia",
    'li' => 'Liechtenstein',
    'lk' => "Sri\ Lanka",
    'lr' => 'Liberia',
    'ls' => 'Lesotho',
    'lt' => 'Litouwen',
    'lu' => 'Luxemburg',
    'lv' => 'Letland',
    'ly' => 'Libië',
    'ma' => 'Marokko',
    'mc' => 'Monaco',
    'md' => 'Moldavië',
    'me' => 'Montenegro',
    'mf' => "Sint\-Maarten",
    'mg' => 'Madagaskar',
    'mh' => 'Marshalleilanden',
    'mi' => "Midway\ Islands",
    'mk' => 'Macedonië',
    'ml' => 'Mali',
    'mm' => 'Myanmar',
    'mn' => 'Mongolië',
    'mo' => 'Macao',
    'mp' => "Noordelijke\ Marianeneilanden",
    'mq' => 'Martinique',
    'mr' => 'Mauritanië',
    'ms' => 'Montserrat',
    'mt' => 'Malta',
    'mu' => 'Mauritius',
    'mv' => 'Maldiven',
    'mw' => 'Malawi',
    'mx' => 'Mexico',
    'my' => 'Maleisië',
    'mz' => 'Mozambique',
    'na' => 'Namibië',
    'nc' => "Nieuw\-Caledonië",
    'ne' => 'Niger',
    'nf' => 'Norfolkeiland',
    'ng' => 'Nigeria',
    'ni' => 'Nicaragua',
    'nl' => 'Nederland',
    'no' => 'Noorwegen',
    'np' => 'Nepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "Nieuw\-Zeeland",
    'om' => 'Oman',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Peru',
    'pf' => "Frans\-Polynesië",
    'pg' => "Papoea\-Nieuw\-Guinea",
    'ph' => 'Filipijnen',
    'pk' => 'Pakistan',
    'pl' => 'Polen',
    'pm' => "Saint\ Pierre\ en\ Miquelon",
    'pn' => 'Pitcairn',
    'pr' => "Puerto\ Rico",
    'ps' => "Palestijns\ Gebied",
    'pt' => 'Portugal',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paraguay',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Qatar',
    'qo' => "Oceanië\ \(overige\)",
    'qu' => "Europese\ Unie",
    're' => 'Réunion',
    'ro' => 'Roemenië',
    'rs' => 'Servië',
    'ru' => 'Rusland',
    'rw' => 'Rwanda',
    'sa' => "Saoedi\-Arabië",
    'sb' => 'Salomonseilanden',
    'sc' => 'Seychellen',
    'sd' => 'Soedan',
    'se' => 'Zweden',
    'sg' => 'Singapore',
    'sh' => "Sint\-Helena",
    'si' => 'Slovenië',
    'sj' => "Svalbard\ en\ Jan\ Mayen",
    'sk' => 'Slowakije',
    'sl' => "Sierra\ Leone",
    'sm' => "San\ Marino",
    'sn' => 'Senegal',
    'so' => 'Somalië',
    'sr' => 'Suriname',
    'st' => "Sao\ Tomé\ en\ Principe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salvador",
    'sy' => 'Syrië',
    'sz' => 'Swaziland',
    'tc' => "Turks\-\ en\ Caicoseilanden",
    'td' => 'Tsjaad',
    'tf' => "Franse\ Gebieden\ in\ de\ zuidelijke\ Indische\ Oceaan",
    'tg' => 'Togo',
    'th' => 'Thailand',
    'tj' => 'Tadzjikistan',
    'tk' => 'Tokelau',
    'tl' => "Oost\-Timor",
    'tm' => 'Turkmenistan',
    'tn' => 'Tunesië',
    'to' => 'Tonga',
    'tr' => 'Turkije',
    'tt' => "Trinidad\ en\ Tobago",
    'tv' => 'Tuvalu',
    'tw' => 'Taiwan',
    'tz' => 'Tanzania',
    'ua' => 'Oekraïne',
    'ug' => 'Oeganda',
    'um' => "Amerikaanse\ kleinere\ afgelegen\ eilanden",
    'us' => "Verenigde\ Staten",
    'uy' => 'Uruguay',
    'uz' => 'Oezbekistan',
    'va' => 'Vaticaanstad',
    'vc' => "Saint\ Vincent\ en\ de\ Grenadines",
    'vd' => "North\ Vietnam",
    've' => 'Venezuela',
    'vg' => "Britse\ Maagdeneilanden",
    'vi' => "Amerikaanse\ Maagdeneilanden",
    'vn' => 'Vietnam',
    'vu' => 'Vanuatu',
    'wf' => "Wallis\ en\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Jemen',
    'yt' => 'Mayotte',
    'za' => "Zuid\-Afrika",
    'zm' => 'Zambia',
    'zw' => 'Zimbabwe',
    'zz' => "Onbekend\ of\ onjuist\ gebied",
);

%Locales::DB::Territory::nl::name_to_code = (
    'afghanistan'                                => 'af',
    'albanië'                                   => 'al',
    'algerije'                                   => 'dz',
    'amerikaansekleinereafgelegeneilanden'       => 'um',
    'amerikaansemaagdeneilanden'                 => 'vi',
    'amerikaanssamoa'                            => 'as',
    'andorra'                                    => 'ad',
    'angola'                                     => 'ao',
    'anguilla'                                   => 'ai',
    'antarctica'                                 => 'aq',
    'antiguaenbarbuda'                           => 'ag',
    'argentinië'                                => 'ar',
    'armenië'                                   => 'am',
    'aruba'                                      => 'aw',
    'australië'                                 => 'au',
    'azerbeidzjan'                               => 'az',
    'bahamas'                                    => 'bs',
    'bahrein'                                    => 'bh',
    'bangladesh'                                 => 'bd',
    'barbados'                                   => 'bb',
    'belgië'                                    => 'be',
    'belize'                                     => 'bz',
    'benin'                                      => 'bj',
    'bermuda'                                    => 'bm',
    'bhutan'                                     => 'bt',
    'bolivia'                                    => 'bo',
    'bosniëenherzegovina'                       => 'ba',
    'botswana'                                   => 'bw',
    'bouveteiland'                               => 'bv',
    'brazilië'                                  => 'br',
    'britishantarcticterritory'                  => 'bq',
    'britsemaagdeneilanden'                      => 'vg',
    'britsterritoriumindeindischeoceaan'         => 'io',
    'brunei'                                     => 'bn',
    'bulgarije'                                  => 'bg',
    'burkinafaso'                                => 'bf',
    'burundi'                                    => 'bi',
    'cambodja'                                   => 'kh',
    'canada'                                     => 'ca',
    'cantonandenderburyislands'                  => 'ct',
    'caymaneilanden'                             => 'ky',
    'centraalafrikaanserepubliek'                => 'cf',
    'chili'                                      => 'cl',
    'china'                                      => 'cn',
    'christmaseiland'                            => 'cx',
    'cocoseilanden'                              => 'cc',
    'colombia'                                   => 'co',
    'comoren'                                    => 'km',
    'congobrazzaville'                           => 'cg',
    'congokinshasa'                              => 'cd',
    'cookeilanden'                               => 'ck',
    'costarica'                                  => 'cr',
    'cuba'                                       => 'cu',
    'cyprus'                                     => 'cy',
    'denemarken'                                 => 'dk',
    'djibouti'                                   => 'dj',
    'dominica'                                   => 'dm',
    'dominicaanserepubliek'                      => 'do',
    'dronningmaudland'                           => 'nq',
    'duitsland'                                  => 'de',
    'eastgermany'                                => 'dd',
    'ecuador'                                    => 'ec',
    'egypte'                                     => 'eg',
    'elsalvador'                                 => 'sv',
    'equatoriaalguinea'                          => 'gq',
    'eritrea'                                    => 'er',
    'estland'                                    => 'ee',
    'ethiopië'                                  => 'et',
    'europeseunie'                               => 'qu',
    'faeröer'                                   => 'fo',
    'falklandeilanden'                           => 'fk',
    'fiji'                                       => 'fj',
    'filipijnen'                                 => 'ph',
    'finland'                                    => 'fi',
    'frankrijk'                                  => 'fr',
    'fransegebiedenindezuidelijkeindischeoceaan' => 'tf',
    'fransguyana'                                => 'gf',
    'franspolynesië'                            => 'pf',
    'frenchsouthernandantarcticterritories'      => 'fq',
    'gabon'                                      => 'ga',
    'gambia'                                     => 'gm',
    'georgië'                                   => 'ge',
    'ghana'                                      => 'gh',
    'gibraltar'                                  => 'gi',
    'grenada'                                    => 'gd',
    'griekenland'                                => 'gr',
    'groenland'                                  => 'gl',
    'guadeloupe'                                 => 'gp',
    'guam'                                       => 'gu',
    'guatemala'                                  => 'gt',
    'guernsey'                                   => 'gg',
    'guinee'                                     => 'gn',
    'guineebissau'                               => 'gw',
    'guyana'                                     => 'gy',
    'haïti'                                     => 'ht',
    'heardenmcdonaldeilanden'                    => 'hm',
    'honduras'                                   => 'hn',
    'hongarije'                                  => 'hu',
    'hongkong'                                   => 'hk',
    'ierland'                                    => 'ie',
    'ijsland'                                    => 'is',
    'india'                                      => 'in',
    'indonesië'                                 => 'id',
    'irak'                                       => 'iq',
    'iran'                                       => 'ir',
    'isleofman'                                  => 'im',
    'israël'                                    => 'il',
    'italië'                                    => 'it',
    'ivoorkust'                                  => 'ci',
    'jamaica'                                    => 'jm',
    'japan'                                      => 'jp',
    'jemen'                                      => 'ye',
    'jersey'                                     => 'je',
    'johnstonisland'                             => 'jt',
    'jordanië'                                  => 'jo',
    'kaapverdië'                                => 'cv',
    'kameroen'                                   => 'cm',
    'kazachstan'                                 => 'kz',
    'kenia'                                      => 'ke',
    'kirgizië'                                  => 'kg',
    'kiribati'                                   => 'ki',
    'koeweit'                                    => 'kw',
    'kroatië'                                   => 'hr',
    'laos'                                       => 'la',
    'lesotho'                                    => 'ls',
    'letland'                                    => 'lv',
    'libanon'                                    => 'lb',
    'liberia'                                    => 'lr',
    'libië'                                     => 'ly',
    'liechtenstein'                              => 'li',
    'litouwen'                                   => 'lt',
    'luxemburg'                                  => 'lu',
    'macao'                                      => 'mo',
    'macedonië'                                 => 'mk',
    'madagaskar'                                 => 'mg',
    'malawi'                                     => 'mw',
    'maldiven'                                   => 'mv',
    'maleisië'                                  => 'my',
    'mali'                                       => 'ml',
    'malta'                                      => 'mt',
    'marokko'                                    => 'ma',
    'marshalleilanden'                           => 'mh',
    'martinique'                                 => 'mq',
    'mauritanië'                                => 'mr',
    'mauritius'                                  => 'mu',
    'mayotte'                                    => 'yt',
    'metropolitanfrance'                         => 'fx',
    'mexico'                                     => 'mx',
    'micronesië'                                => 'fm',
    'midwayislands'                              => 'mi',
    'moldavië'                                  => 'md',
    'monaco'                                     => 'mc',
    'mongolië'                                  => 'mn',
    'montenegro'                                 => 'me',
    'montserrat'                                 => 'ms',
    'mozambique'                                 => 'mz',
    'myanmar'                                    => 'mm',
    'namibië'                                   => 'na',
    'nauru'                                      => 'nr',
    'nederland'                                  => 'nl',
    'nederlandseantillen'                        => 'an',
    'nepal'                                      => 'np',
    'neutralzone'                                => 'nt',
    'nicaragua'                                  => 'ni',
    'nieuwcaledonië'                            => 'nc',
    'nieuwzeeland'                               => 'nz',
    'niger'                                      => 'ne',
    'nigeria'                                    => 'ng',
    'niue'                                       => 'nu',
    'noordelijkemarianeneilanden'                => 'mp',
    'noordkorea'                                 => 'kp',
    'noorwegen'                                  => 'no',
    'norfolkeiland'                              => 'nf',
    'northvietnam'                               => 'vd',
    'oceaniëoverige'                            => 'qo',
    'oeganda'                                    => 'ug',
    'oekraïne'                                  => 'ua',
    'oezbekistan'                                => 'uz',
    'oman'                                       => 'om',
    'onbekendofonjuistgebied'                    => 'zz',
    'oostenrijk'                                 => 'at',
    'oosttimor'                                  => 'tl',
    'pacificislandstrustterritory'               => 'pc',
    'pakistan'                                   => 'pk',
    'palau'                                      => 'pw',
    'palestijnsgebied'                           => 'ps',
    'panama'                                     => 'pa',
    'panamacanalzone'                            => 'pz',
    'papoeanieuwguinea'                          => 'pg',
    'paraguay'                                   => 'py',
    'peoplesdemocraticrepublicofyemen'           => 'yd',
    'peru'                                       => 'pe',
    'pitcairn'                                   => 'pn',
    'polen'                                      => 'pl',
    'portugal'                                   => 'pt',
    'puertorico'                                 => 'pr',
    'qatar'                                      => 'qa',
    'roemenië'                                  => 'ro',
    'rusland'                                    => 'ru',
    'rwanda'                                     => 'rw',
    'réunion'                                   => 're',
    'saintbarthélemy'                           => 'bl',
    'saintkittsennevis'                          => 'kn',
    'saintlucia'                                 => 'lc',
    'saintpierreenmiquelon'                      => 'pm',
    'saintvincentendegrenadines'                 => 'vc',
    'salomonseilanden'                           => 'sb',
    'samoa'                                      => 'ws',
    'sanmarino'                                  => 'sm',
    'saoediarabië'                              => 'sa',
    'saotoméenprincipe'                         => 'st',
    'senegal'                                    => 'sn',
    'servië'                                    => 'rs',
    'serviëenmontenegro'                        => 'cs',
    'seychellen'                                 => 'sc',
    'sierraleone'                                => 'sl',
    'singapore'                                  => 'sg',
    'sinthelena'                                 => 'sh',
    'sintmaarten'                                => 'mf',
    'slovenië'                                  => 'si',
    'slowakije'                                  => 'sk',
    'soedan'                                     => 'sd',
    'somalië'                                   => 'so',
    'spanje'                                     => 'es',
    'srilanka'                                   => 'lk',
    'suriname'                                   => 'sr',
    'svalbardenjanmayen'                         => 'sj',
    'swaziland'                                  => 'sz',
    'syrië'                                     => 'sy',
    'tadzjikistan'                               => 'tj',
    'taiwan'                                     => 'tw',
    'tanzania'                                   => 'tz',
    'thailand'                                   => 'th',
    'togo'                                       => 'tg',
    'tokelau'                                    => 'tk',
    'tonga'                                      => 'to',
    'trinidadentobago'                           => 'tt',
    'tsjaad'                                     => 'td',
    'tsjechië'                                  => 'cz',
    'tunesië'                                   => 'tn',
    'turkije'                                    => 'tr',
    'turkmenistan'                               => 'tm',
    'turksencaicoseilanden'                      => 'tc',
    'tuvalu'                                     => 'tv',
    "u\.s\.miscellaneouspacificislands"          => 'pu',
    'unionofsovietsocialistrepublics'            => 'su',
    'uruguay'                                    => 'uy',
    'vanuatu'                                    => 'vu',
    'vaticaanstad'                               => 'va',
    'venezuela'                                  => 've',
    'verenigdearabischeemiraten'                 => 'ae',
    'verenigdestaten'                            => 'us',
    'verenigdkoninkrijk'                         => 'gb',
    'vietnam'                                    => 'vn',
    'wakeisland'                                 => 'wk',
    'wallisenfutuna'                             => 'wf',
    'westelijkesahara'                           => 'eh',
    'witrusland'                                 => 'by',
    'zambia'                                     => 'zm',
    'zimbabwe'                                   => 'zw',
    'zuidafrika'                                 => 'za',
    'zuidgeorgiëenzuidelijkesandwicheilanden'   => 'gs',
    'zuidkorea'                                  => 'kr',
    'zweden'                                     => 'se',
    'zwitserland'                                => 'ch',
    'Åland'                                     => 'ax',
);

1;

