package Locales::DB::Territory::es;

# Auto generated from CLDR

$Locales::DB::Territory::es::VERSION = '0.02';

$Locales::DB::Territory::es::cldr_version = '1.7.1';

%Locales::DB::Territory::es::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "Emiratos\ Árabes\ Unidos",
    'af' => 'Afganistán',
    'ag' => "Antigua\ y\ Barbuda",
    'ai' => 'Anguila',
    'al' => 'Albania',
    'am' => 'Armenia',
    'an' => "Antillas\ Neerlandesas",
    'ao' => 'Angola',
    'aq' => 'Antártida',
    'ar' => 'Argentina',
    'as' => "Samoa\ Americana",
    'at' => 'Austria',
    'au' => 'Australia',
    'aw' => 'Aruba',
    'ax' => "Islas\ Åland",
    'az' => 'Azerbaiyán',
    'ba' => "Bosnia\-Herzegovina",
    'bb' => 'Barbados',
    'bd' => 'Bangladesh',
    'be' => 'Bélgica',
    'bf' => "Burkina\ Faso",
    'bg' => 'Bulgaria',
    'bh' => 'Bahréin',
    'bi' => 'Burundi',
    'bj' => 'Benín',
    'bl' => "San\ Bartolomé",
    'bm' => 'Bermudas',
    'bn' => 'Brunéi',
    'bo' => 'Bolivia',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brasil',
    'bs' => 'Bahamas',
    'bt' => 'Bután',
    'bv' => "Isla\ Bouvet",
    'bw' => 'Botsuana',
    'by' => 'Bielorrusia',
    'bz' => 'Belice',
    'ca' => 'Canadá',
    'cc' => "Islas\ Cocos",
    'cd' => "República\ Democrática\ del\ Congo",
    'cf' => "República\ Centroafricana",
    'cg' => 'Congo',
    'ch' => 'Suiza',
    'ci' => "Costa\ de\ Marfil",
    'ck' => "Islas\ Cook",
    'cl' => 'Chile',
    'cm' => 'Camerún',
    'cn' => 'China',
    'co' => 'Colombia',
    'cr' => "Costa\ Rica",
    'cs' => "Serbia\ y\ Montenegro",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Cuba',
    'cv' => "Cabo\ Verde",
    'cx' => "Isla\ Christmas",
    'cy' => 'Chipre',
    'cz' => "República\ Checa",
    'dd' => "East\ Germany",
    'de' => 'Alemania',
    'dj' => 'Yibuti',
    'dk' => 'Dinamarca',
    'dm' => 'Dominica',
    'do' => "República\ Dominicana",
    'dz' => 'Argelia',
    'ec' => 'Ecuador',
    'ee' => 'Estonia',
    'eg' => 'Egipto',
    'eh' => "Sáhara\ Occidental",
    'er' => 'Eritrea',
    'es' => 'España',
    'et' => 'Etiopía',
    'fi' => 'Finlandia',
    'fj' => 'Fiyi',
    'fk' => "Islas\ Malvinas",
    'fm' => 'Micronesia',
    'fo' => "Islas\ Feroe",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Francia',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabón',
    'gb' => "Reino\ Unido",
    'gd' => 'Granada',
    'ge' => 'Georgia',
    'gf' => "Guayana\ Francesa",
    'gg' => 'Guernsey',
    'gh' => 'Ghana',
    'gi' => 'Gibraltar',
    'gl' => 'Groenlandia',
    'gm' => 'Gambia',
    'gn' => 'Guinea',
    'gp' => 'Guadalupe',
    'gq' => "Guinea\ Ecuatorial",
    'gr' => 'Grecia',
    'gs' => "Islas\ Georgia\ del\ Sur\ y\ Sandwich\ del\ Sur",
    'gt' => 'Guatemala',
    'gu' => 'Guam',
    'gw' => "Guinea\-Bissau",
    'gy' => 'Guyana',
    'hk' => "Hong\ Kong",
    'hm' => "Islas\ Heard\ y\ McDonald",
    'hn' => 'Honduras',
    'hr' => 'Croacia',
    'ht' => 'Haití',
    'hu' => 'Hungría',
    'id' => 'Indonesia',
    'ie' => 'Irlanda',
    'il' => 'Israel',
    'im' => "Isla\ de\ Man",
    'in' => 'India',
    'io' => "Territorio\ Británico\ del\ Océano\ Índico",
    'iq' => 'Iraq',
    'ir' => 'Irán',
    'is' => 'Islandia',
    'it' => 'Italia',
    'je' => 'Jersey',
    'jm' => 'Jamaica',
    'jo' => 'Jordania',
    'jp' => 'Japón',
    'jt' => "Johnston\ Island",
    'ke' => 'Kenia',
    'kg' => 'Kirguistán',
    'kh' => 'Camboya',
    'ki' => 'Kiribati',
    'km' => 'Comoras',
    'kn' => "San\ Cristóbal\ y\ Nieves",
    'kp' => "Corea\ del\ Norte",
    'kr' => "Corea\ del\ Sur",
    'kw' => 'Kuwait',
    'ky' => "Islas\ Caimán",
    'kz' => 'Kazajistán',
    'la' => 'Laos',
    'lb' => 'Líbano',
    'lc' => "Santa\ Lucía",
    'li' => 'Liechtenstein',
    'lk' => "Sri\ Lanka",
    'lr' => 'Liberia',
    'ls' => 'Lesoto',
    'lt' => 'Lituania',
    'lu' => 'Luxemburgo',
    'lv' => 'Letonia',
    'ly' => 'Libia',
    'ma' => 'Marruecos',
    'mc' => 'Mónaco',
    'md' => 'Moldavia',
    'me' => 'Montenegro',
    'mf' => "San\ Martín",
    'mg' => 'Madagascar',
    'mh' => "Islas\ Marshall",
    'mi' => "Midway\ Islands",
    'mk' => 'Macedonia',
    'ml' => 'Mali',
    'mm' => 'Myanmar',
    'mn' => 'Mongolia',
    'mo' => 'Macao',
    'mp' => "Islas\ Marianas\ del\ Norte",
    'mq' => 'Martinica',
    'mr' => 'Mauritania',
    'ms' => 'Montserrat',
    'mt' => 'Malta',
    'mu' => 'Mauricio',
    'mv' => 'Maldivas',
    'mw' => 'Malaui',
    'mx' => 'México',
    'my' => 'Malasia',
    'mz' => 'Mozambique',
    'na' => 'Namibia',
    'nc' => "Nueva\ Caledonia",
    'ne' => 'Níger',
    'nf' => "Isla\ Norfolk",
    'ng' => 'Nigeria',
    'ni' => 'Nicaragua',
    'nl' => "Países\ Bajos",
    'no' => 'Noruega',
    'np' => 'Nepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => "Isla\ Niue",
    'nz' => "Nueva\ Zelanda",
    'om' => 'Omán',
    'pa' => 'Panamá',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Perú',
    'pf' => "Polinesia\ Francesa",
    'pg' => "Papúa\ Nueva\ Guinea",
    'ph' => 'Filipinas',
    'pk' => 'Pakistán',
    'pl' => 'Polonia',
    'pm' => "San\ Pedro\ y\ Miquelón",
    'pn' => 'Pitcairn',
    'pr' => "Puerto\ Rico",
    'ps' => 'Palestina',
    'pt' => 'Portugal',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paraguay',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Qatar',
    'qo' => "Territorios\ alejados\ de\ Oceanía",
    'qu' => "Unión\ Europea",
    're' => 'Reunión',
    'ro' => 'Rumanía',
    'rs' => 'Serbia',
    'ru' => 'Rusia',
    'rw' => 'Ruanda',
    'sa' => "Arabia\ Saudí",
    'sb' => "Islas\ Salomón",
    'sc' => 'Seychelles',
    'sd' => 'Sudán',
    'se' => 'Suecia',
    'sg' => 'Singapur',
    'sh' => "Santa\ Elena",
    'si' => 'Eslovenia',
    'sj' => "Svalbard\ y\ Jan\ Mayen",
    'sk' => 'Eslovaquia',
    'sl' => "Sierra\ Leona",
    'sm' => "San\ Marino",
    'sn' => 'Senegal',
    'so' => 'Somalia',
    'sr' => 'Surinam',
    'st' => "Santo\ Tomé\ y\ Príncipe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salvador",
    'sy' => 'Siria',
    'sz' => 'Suazilandia',
    'tc' => "Islas\ Turcas\ y\ Caicos",
    'td' => 'Chad',
    'tf' => "Territorios\ Australes\ Franceses",
    'tg' => 'Togo',
    'th' => 'Tailandia',
    'tj' => 'Tayikistán',
    'tk' => 'Tokelau',
    'tl' => "Timor\ Oriental",
    'tm' => 'Turkmenistán',
    'tn' => 'Túnez',
    'to' => 'Tonga',
    'tr' => 'Turquía',
    'tt' => "Trinidad\ y\ Tobago",
    'tv' => 'Tuvalu',
    'tw' => 'Taiwán',
    'tz' => 'Tanzania',
    'ua' => 'Ucrania',
    'ug' => 'Uganda',
    'um' => "Islas\ menores\ alejadas\ de\ los\ Estados\ Unidos",
    'us' => "Estados\ Unidos",
    'uy' => 'Uruguay',
    'uz' => 'Uzbekistán',
    'va' => "Ciudad\ del\ Vaticano",
    'vc' => "San\ Vicente\ y\ las\ Granadinas",
    'vd' => "North\ Vietnam",
    've' => 'Venezuela',
    'vg' => "Islas\ Vírgenes\ Británicas",
    'vi' => "Islas\ Vírgenes\ de\ los\ Estados\ Unidos",
    'vn' => 'Vietnam',
    'vu' => 'Vanuatu',
    'wf' => "Wallis\ y\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Yemen',
    'yt' => 'Mayotte',
    'za' => 'Sudáfrica',
    'zm' => 'Zambia',
    'zw' => 'Zimbabue',
    'zz' => "Región\ desconocida\ o\ no\ válida",
);

%Locales::DB::Territory::es::name_to_code = (
    'afganistán'                            => 'af',
    'albania'                                => 'al',
    'alemania'                               => 'de',
    'andorra'                                => 'ad',
    'angola'                                 => 'ao',
    'anguila'                                => 'ai',
    'antiguaybarbuda'                        => 'ag',
    'antillasneerlandesas'                   => 'an',
    'antártida'                             => 'aq',
    'arabiasaudí'                           => 'sa',
    'argelia'                                => 'dz',
    'argentina'                              => 'ar',
    'armenia'                                => 'am',
    'aruba'                                  => 'aw',
    'australia'                              => 'au',
    'austria'                                => 'at',
    'azerbaiyán'                            => 'az',
    'bahamas'                                => 'bs',
    'bahréin'                               => 'bh',
    'bangladesh'                             => 'bd',
    'barbados'                               => 'bb',
    'belice'                                 => 'bz',
    'benín'                                 => 'bj',
    'bermudas'                               => 'bm',
    'bielorrusia'                            => 'by',
    'bolivia'                                => 'bo',
    'bosniaherzegovina'                      => 'ba',
    'botsuana'                               => 'bw',
    'brasil'                                 => 'br',
    'britishantarcticterritory'              => 'bq',
    'brunéi'                                => 'bn',
    'bulgaria'                               => 'bg',
    'burkinafaso'                            => 'bf',
    'burundi'                                => 'bi',
    'bután'                                 => 'bt',
    'bélgica'                               => 'be',
    'caboverde'                              => 'cv',
    'camboya'                                => 'kh',
    'camerún'                               => 'cm',
    'canadá'                                => 'ca',
    'cantonandenderburyislands'              => 'ct',
    'chad'                                   => 'td',
    'chile'                                  => 'cl',
    'china'                                  => 'cn',
    'chipre'                                 => 'cy',
    'ciudaddelvaticano'                      => 'va',
    'colombia'                               => 'co',
    'comoras'                                => 'km',
    'congo'                                  => 'cg',
    'coreadelnorte'                          => 'kp',
    'coreadelsur'                            => 'kr',
    'costademarfil'                          => 'ci',
    'costarica'                              => 'cr',
    'croacia'                                => 'hr',
    'cuba'                                   => 'cu',
    'dinamarca'                              => 'dk',
    'dominica'                               => 'dm',
    'dronningmaudland'                       => 'nq',
    'eastgermany'                            => 'dd',
    'ecuador'                                => 'ec',
    'egipto'                                 => 'eg',
    'elsalvador'                             => 'sv',
    'emiratosÁrabesunidos'                  => 'ae',
    'eritrea'                                => 'er',
    'eslovaquia'                             => 'sk',
    'eslovenia'                              => 'si',
    'españa'                                => 'es',
    'estadosunidos'                          => 'us',
    'estonia'                                => 'ee',
    'etiopía'                               => 'et',
    'filipinas'                              => 'ph',
    'finlandia'                              => 'fi',
    'fiyi'                                   => 'fj',
    'francia'                                => 'fr',
    'frenchsouthernandantarcticterritories'  => 'fq',
    'gabón'                                 => 'ga',
    'gambia'                                 => 'gm',
    'georgia'                                => 'ge',
    'ghana'                                  => 'gh',
    'gibraltar'                              => 'gi',
    'granada'                                => 'gd',
    'grecia'                                 => 'gr',
    'groenlandia'                            => 'gl',
    'guadalupe'                              => 'gp',
    'guam'                                   => 'gu',
    'guatemala'                              => 'gt',
    'guayanafrancesa'                        => 'gf',
    'guernsey'                               => 'gg',
    'guinea'                                 => 'gn',
    'guineabissau'                           => 'gw',
    'guineaecuatorial'                       => 'gq',
    'guyana'                                 => 'gy',
    'haití'                                 => 'ht',
    'honduras'                               => 'hn',
    'hongkong'                               => 'hk',
    'hungría'                               => 'hu',
    'india'                                  => 'in',
    'indonesia'                              => 'id',
    'iraq'                                   => 'iq',
    'irlanda'                                => 'ie',
    'irán'                                  => 'ir',
    'islabouvet'                             => 'bv',
    'islachristmas'                          => 'cx',
    'islademan'                              => 'im',
    'islandia'                               => 'is',
    'islaniue'                               => 'nu',
    'islanorfolk'                            => 'nf',
    'islascaimán'                           => 'ky',
    'islascocos'                             => 'cc',
    'islascook'                              => 'ck',
    'islasferoe'                             => 'fo',
    'islasgeorgiadelsurysandwichdelsur'      => 'gs',
    'islasheardymcdonald'                    => 'hm',
    'islasmalvinas'                          => 'fk',
    'islasmarianasdelnorte'                  => 'mp',
    'islasmarshall'                          => 'mh',
    'islasmenoresalejadasdelosestadosunidos' => 'um',
    'islassalomón'                          => 'sb',
    'islasturcasycaicos'                     => 'tc',
    'islasvírgenesbritánicas'              => 'vg',
    'islasvírgenesdelosestadosunidos'       => 'vi',
    'islasÅland'                            => 'ax',
    'israel'                                 => 'il',
    'italia'                                 => 'it',
    'jamaica'                                => 'jm',
    'japón'                                 => 'jp',
    'jersey'                                 => 'je',
    'johnstonisland'                         => 'jt',
    'jordania'                               => 'jo',
    'kazajistán'                            => 'kz',
    'kenia'                                  => 'ke',
    'kirguistán'                            => 'kg',
    'kiribati'                               => 'ki',
    'kuwait'                                 => 'kw',
    'laos'                                   => 'la',
    'lesoto'                                 => 'ls',
    'letonia'                                => 'lv',
    'liberia'                                => 'lr',
    'libia'                                  => 'ly',
    'liechtenstein'                          => 'li',
    'lituania'                               => 'lt',
    'luxemburgo'                             => 'lu',
    'líbano'                                => 'lb',
    'macao'                                  => 'mo',
    'macedonia'                              => 'mk',
    'madagascar'                             => 'mg',
    'malasia'                                => 'my',
    'malaui'                                 => 'mw',
    'maldivas'                               => 'mv',
    'mali'                                   => 'ml',
    'malta'                                  => 'mt',
    'marruecos'                              => 'ma',
    'martinica'                              => 'mq',
    'mauricio'                               => 'mu',
    'mauritania'                             => 'mr',
    'mayotte'                                => 'yt',
    'metropolitanfrance'                     => 'fx',
    'micronesia'                             => 'fm',
    'midwayislands'                          => 'mi',
    'moldavia'                               => 'md',
    'mongolia'                               => 'mn',
    'montenegro'                             => 'me',
    'montserrat'                             => 'ms',
    'mozambique'                             => 'mz',
    'myanmar'                                => 'mm',
    'méxico'                                => 'mx',
    'mónaco'                                => 'mc',
    'namibia'                                => 'na',
    'nauru'                                  => 'nr',
    'nepal'                                  => 'np',
    'neutralzone'                            => 'nt',
    'nicaragua'                              => 'ni',
    'nigeria'                                => 'ng',
    'northvietnam'                           => 'vd',
    'noruega'                                => 'no',
    'nuevacaledonia'                         => 'nc',
    'nuevazelanda'                           => 'nz',
    'níger'                                 => 'ne',
    'omán'                                  => 'om',
    'pacificislandstrustterritory'           => 'pc',
    'pakistán'                              => 'pk',
    'palau'                                  => 'pw',
    'palestina'                              => 'ps',
    'panamacanalzone'                        => 'pz',
    'panamá'                                => 'pa',
    'papúanuevaguinea'                      => 'pg',
    'paraguay'                               => 'py',
    'paísesbajos'                           => 'nl',
    'peoplesdemocraticrepublicofyemen'       => 'yd',
    'perú'                                  => 'pe',
    'pitcairn'                               => 'pn',
    'polinesiafrancesa'                      => 'pf',
    'polonia'                                => 'pl',
    'portugal'                               => 'pt',
    'puertorico'                             => 'pr',
    'qatar'                                  => 'qa',
    'regióndesconocidaonoválida'           => 'zz',
    'reinounido'                             => 'gb',
    'repúblicacentroafricana'               => 'cf',
    'repúblicacheca'                        => 'cz',
    'repúblicademocráticadelcongo'         => 'cd',
    'repúblicadominicana'                   => 'do',
    'reunión'                               => 're',
    'ruanda'                                 => 'rw',
    'rumanía'                               => 'ro',
    'rusia'                                  => 'ru',
    'samoa'                                  => 'ws',
    'samoaamericana'                         => 'as',
    'sanbartolomé'                          => 'bl',
    'sancristóbalynieves'                   => 'kn',
    'sanmarino'                              => 'sm',
    'sanmartín'                             => 'mf',
    'sanpedroymiquelón'                     => 'pm',
    'santaelena'                             => 'sh',
    'santalucía'                            => 'lc',
    'santotoméypríncipe'                   => 'st',
    'sanvicenteylasgranadinas'               => 'vc',
    'senegal'                                => 'sn',
    'serbia'                                 => 'rs',
    'serbiaymontenegro'                      => 'cs',
    'seychelles'                             => 'sc',
    'sierraleona'                            => 'sl',
    'singapur'                               => 'sg',
    'siria'                                  => 'sy',
    'somalia'                                => 'so',
    'srilanka'                               => 'lk',
    'suazilandia'                            => 'sz',
    'sudáfrica'                             => 'za',
    'sudán'                                 => 'sd',
    'suecia'                                 => 'se',
    'suiza'                                  => 'ch',
    'surinam'                                => 'sr',
    'svalbardyjanmayen'                      => 'sj',
    'sáharaoccidental'                      => 'eh',
    'tailandia'                              => 'th',
    'taiwán'                                => 'tw',
    'tanzania'                               => 'tz',
    'tayikistán'                            => 'tj',
    'territoriobritánicodelocéanoÍndico'  => 'io',
    'territoriosalejadosdeoceanía'          => 'qo',
    'territoriosaustralesfranceses'          => 'tf',
    'timororiental'                          => 'tl',
    'togo'                                   => 'tg',
    'tokelau'                                => 'tk',
    'tonga'                                  => 'to',
    'trinidadytobago'                        => 'tt',
    'turkmenistán'                          => 'tm',
    'turquía'                               => 'tr',
    'tuvalu'                                 => 'tv',
    'túnez'                                 => 'tn',
    "u\.s\.miscellaneouspacificislands"      => 'pu',
    'ucrania'                                => 'ua',
    'uganda'                                 => 'ug',
    'unionofsovietsocialistrepublics'        => 'su',
    'unióneuropea'                          => 'qu',
    'uruguay'                                => 'uy',
    'uzbekistán'                            => 'uz',
    'vanuatu'                                => 'vu',
    'venezuela'                              => 've',
    'vietnam'                                => 'vn',
    'wakeisland'                             => 'wk',
    'wallisyfutuna'                          => 'wf',
    'yemen'                                  => 'ye',
    'yibuti'                                 => 'dj',
    'zambia'                                 => 'zm',
    'zimbabue'                               => 'zw',
);

1;

