package Locales::DB::Territory::fur;

# Auto generated from CLDR

$Locales::DB::Territory::fur::VERSION = '0.02';

$Locales::DB::Territory::fur::cldr_version = '1.7.1';

%Locales::DB::Territory::fur::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "Emirâts\ araps\ unîts",
    'af' => 'Afghanistan',
    'ag' => "Antigua\ e\ Barbuda",
    'ai' => 'Anguilla',
    'al' => 'Albanie',
    'am' => 'Armenie',
    'an' => "Antilis\ olandesis",
    'ao' => 'Angola',
    'aq' => 'Antartic',
    'ar' => 'Argjentine',
    'as' => "Samoa\ merecanis",
    'at' => 'Austrie',
    'au' => 'Australie',
    'aw' => 'Aruba',
    'ax' => "Isulis\ Aland",
    'az' => 'Azerbaigian',
    'ba' => "Bosnie\ e\ Ercegovine",
    'bb' => 'Barbados',
    'bd' => 'Bangladesh',
    'be' => 'Belgjiche',
    'bf' => "Burkina\ Faso",
    'bg' => 'Bulgarie',
    'bh' => 'Bahrain',
    'bi' => 'Burundi',
    'bj' => 'Benin',
    'bl' => "Sant\ Barthélemy",
    'bm' => 'Bermuda',
    'bn' => 'Brunei',
    'bo' => 'Bolivie',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brasîl',
    'bs' => 'Bahamas',
    'bt' => 'Bhutan',
    'bv' => "Isule\ Bouvet",
    'bw' => 'Botswana',
    'by' => 'Bielorussie',
    'bz' => 'Belize',
    'ca' => 'Canade',
    'cc' => "Isulis\ Cocos",
    'cd' => "Republiche\ Democratiche\ dal\ Congo",
    'cf' => "Republiche\ centri\ africane",
    'cg' => 'Congo',
    'ch' => 'Svuizare',
    'ci' => "Cueste\ di\ Avoli",
    'ck' => "Isulis\ Cook",
    'cl' => 'Cile',
    'cm' => 'Camerun',
    'cn' => 'Cine',
    'co' => 'Colombie',
    'cr' => "Costa\ Rica",
    'cs' => "Serbia\ e\ Montenegro",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Cuba',
    'cv' => "Cjâf\ vert",
    'cx' => "Isule\ Christmas",
    'cy' => 'Cipri',
    'cz' => "Republiche\ ceche",
    'dd' => "East\ Germany",
    'de' => 'Gjermanie',
    'dj' => 'Gibuti',
    'dk' => 'Danimarcje',
    'dm' => 'Dominiche',
    'do' => "Republiche\ dominicane",
    'dz' => 'Alzerie',
    'ec' => 'Ecuador',
    'ee' => 'Estonie',
    'eg' => 'Egjit',
    'eh' => "Sahara\ ocidentâl",
    'er' => 'Eritree',
    'es' => 'Spagne',
    'et' => 'Etiopie',
    'fi' => 'Finlandie',
    'fj' => 'Fizi',
    'fk' => "Isulis\ Falkland",
    'fm' => 'Micronesie',
    'fo' => "Isulis\ Faroe",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'France',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabon',
    'gb' => "Ream\ unît",
    'gd' => 'Grenada',
    'ge' => 'Gjeorgjie',
    'gf' => "Guiana\ francês",
    'gg' => 'Guernsey',
    'gh' => 'Ghana',
    'gi' => 'Gjibraltar',
    'gl' => 'Groenlande',
    'gm' => 'Gambia',
    'gn' => 'Guinee',
    'gp' => 'Guadalupe',
    'gq' => "Guinee\ ecuatoriâl",
    'gr' => 'Grecie',
    'gs' => "Georgia\ dal\ Sud\ e\ Isulis\ Sandwich\ dal\ Sud",
    'gt' => 'Guatemala',
    'gu' => 'Guam',
    'gw' => "Guinea\-Bissau",
    'gy' => 'Guyana',
    'hk' => "Regjon\ aministrative\ speciâl\ de\ Cine\ di\ Hong\ Kong",
    'hm' => "Isule\ Heard\ e\ Isulis\ McDonald",
    'hn' => 'Honduras',
    'hr' => 'Cravuazie',
    'ht' => 'Haiti',
    'hu' => 'Ongjarie',
    'id' => 'Indonesie',
    'ie' => 'Irlande',
    'il' => 'Israêl',
    'im' => "Isule\ di\ Man",
    'in' => 'India',
    'io' => "Teritori\ britanic\ dal\ Ocean\ Indian",
    'iq' => 'Iraq',
    'ir' => 'Iran',
    'is' => 'Islande',
    'it' => 'Italie',
    'je' => 'Jersey',
    'jm' => 'Gjamaiche',
    'jo' => 'Jordanie',
    'jp' => 'Gjapon',
    'jt' => "Johnston\ Island",
    'ke' => 'Kenya',
    'kg' => 'Kirghizstan',
    'kh' => 'Camboze',
    'ki' => 'Kiribati',
    'km' => 'Comoris',
    'kn' => "San\ Kitts\ e\ Nevis",
    'kp' => "Coree\ dal\ nord",
    'kr' => "Coree\ dal\ sud",
    'kw' => 'Kuwait',
    'ky' => "Isulis\ Cayman",
    'kz' => 'Kazachistan',
    'la' => 'Laos',
    'lb' => 'Liban',
    'lc' => "Sante\ Lusie",
    'li' => 'Liechtenstein',
    'lk' => "Sri\ Lanka",
    'lr' => 'Liberie',
    'ls' => 'Lesotho',
    'lt' => 'Lituanie',
    'lu' => 'Lussemburc',
    'lv' => 'Letonie',
    'ly' => 'Libie',
    'ma' => 'Maroc',
    'mc' => 'Monaco',
    'md' => 'Moldavie',
    'me' => 'Montenegro',
    'mf' => "Sant\ Martin",
    'mg' => 'Madagascar',
    'mh' => "Isulis\ Marshall",
    'mi' => "Midway\ Islands",
    'mk' => 'Macedonie',
    'ml' => 'Mali',
    'mm' => 'Birmanie',
    'mn' => 'Mongolie',
    'mo' => "Regjon\ aministrative\ speciâl\ de\ Cine\ di\ Macao",
    'mp' => "Isulis\ Mariana\ dal\ Nord",
    'mq' => 'Martiniche',
    'mr' => 'Mauritanie',
    'ms' => 'Montserrat',
    'mt' => 'Malta',
    'mu' => 'Maurizi',
    'mv' => 'Maldivis',
    'mw' => 'Malawi',
    'mx' => 'Messic',
    'my' => 'Malaysia',
    'mz' => 'Mozambic',
    'na' => 'Namibie',
    'nc' => "Gnove\ Caledonie",
    'ne' => 'Niger',
    'nf' => "Isole\ Norfolk",
    'ng' => 'Nigerie',
    'ni' => 'Nicaragua',
    'nl' => "Paîs\ bas",
    'no' => 'Norvegje',
    'np' => 'Nepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "Gnove\ Zelande",
    'om' => 'Oman',
    'pa' => 'Panamà',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Perù',
    'pf' => "Polinesie\ francês",
    'pg' => "Papue\ Gnove\ Guinee",
    'ph' => 'Filipinis',
    'pk' => 'Pakistan',
    'pl' => 'Polonie',
    'pm' => "San\ Pierre\ e\ Miquelon",
    'pn' => 'Pitcairn',
    'pr' => "Porto\ Rico",
    'ps' => "Teritori\ palestinês",
    'pt' => 'Portugal',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paraguay',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Qatar',
    'qo' => "Oceanie\ periferiche",
    'qu' => "Union\ europeane",
    're' => 'Reunion',
    'ro' => 'Romanie',
    'rs' => 'Serbie',
    'ru' => 'Russie',
    'rw' => 'Ruande',
    'sa' => "Arabie\ Saudide",
    'sb' => "Isulis\ Salomon",
    'sc' => 'Seychelles',
    'sd' => 'Sudan',
    'se' => 'Svezie',
    'sg' => 'Singapore',
    'sh' => "Sante\ Eline",
    'si' => 'Slovenie',
    'sj' => "Svalbard\ e\ Jan\ Mayen",
    'sk' => 'Slovachie',
    'sl' => "Sierra\ Leone",
    'sm' => "San\ Marin",
    'sn' => 'Senegal',
    'so' => 'Somalie',
    'sr' => 'Suriname',
    'st' => "Sao\ Tomè\ e\ Principe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salvador",
    'sy' => 'Sirie',
    'sz' => 'Swaziland',
    'tc' => "Isulis\ Turks\ e\ Caicos",
    'td' => 'Çad',
    'tf' => "Teritoris\ meridionâi\ francês",
    'tg' => 'Togo',
    'th' => 'Tailandie',
    'tj' => 'Tazikistan',
    'tk' => 'Tokelau',
    'tl' => "Timor\ orientâl",
    'tm' => 'Turkmenistan',
    'tn' => 'Tunisie',
    'to' => 'Tonga',
    'tr' => 'Turchie',
    'tt' => "Trinidad\ e\ Tobago",
    'tv' => 'Tuvalu',
    'tw' => 'Taiwan',
    'tz' => 'Tanzanie',
    'ua' => 'Ucraine',
    'ug' => 'Uganda',
    'um' => "Isulis\ periferichis\ minôrs\ dai\ Stâts\ Unîts",
    'us' => "Stâts\ Unîts",
    'uy' => 'Uruguay',
    'uz' => 'Uzbechistan',
    'va' => 'Vatican',
    'vc' => "San\ Vincent\ e\ lis\ Grenadinis",
    'vd' => "North\ Vietnam",
    've' => 'Venezuela',
    'vg' => "Isulis\ vergjinis\ britanichis",
    'vi' => "Isulis\ vergjinis\ americanis",
    'vn' => 'Vietnam',
    'vu' => 'Vanuatu',
    'wf' => "Wallis\ e\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Yemen',
    'yt' => 'Mayotte',
    'za' => "Sud\ Afriche",
    'zm' => 'Zambia',
    'zw' => 'Zimbabwe',
    'zz' => "Regjon\ no\ cognossude\ o\ no\ valide",
);

%Locales::DB::Territory::fur::name_to_code = (
    'afghanistan'                                 => 'af',
    'albanie'                                     => 'al',
    'alzerie'                                     => 'dz',
    'andorra'                                     => 'ad',
    'angola'                                      => 'ao',
    'anguilla'                                    => 'ai',
    'antartic'                                    => 'aq',
    'antiguaebarbuda'                             => 'ag',
    'antilisolandesis'                            => 'an',
    'arabiesaudide'                               => 'sa',
    'argjentine'                                  => 'ar',
    'armenie'                                     => 'am',
    'aruba'                                       => 'aw',
    'australie'                                   => 'au',
    'austrie'                                     => 'at',
    'azerbaigian'                                 => 'az',
    'bahamas'                                     => 'bs',
    'bahrain'                                     => 'bh',
    'bangladesh'                                  => 'bd',
    'barbados'                                    => 'bb',
    'belgjiche'                                   => 'be',
    'belize'                                      => 'bz',
    'benin'                                       => 'bj',
    'bermuda'                                     => 'bm',
    'bhutan'                                      => 'bt',
    'bielorussie'                                 => 'by',
    'birmanie'                                    => 'mm',
    'bolivie'                                     => 'bo',
    'bosnieeercegovine'                           => 'ba',
    'botswana'                                    => 'bw',
    'brasîl'                                     => 'br',
    'britishantarcticterritory'                   => 'bq',
    'brunei'                                      => 'bn',
    'bulgarie'                                    => 'bg',
    'burkinafaso'                                 => 'bf',
    'burundi'                                     => 'bi',
    'camboze'                                     => 'kh',
    'camerun'                                     => 'cm',
    'canade'                                      => 'ca',
    'cantonandenderburyislands'                   => 'ct',
    'cile'                                        => 'cl',
    'cine'                                        => 'cn',
    'cipri'                                       => 'cy',
    'cjâfvert'                                   => 'cv',
    'colombie'                                    => 'co',
    'comoris'                                     => 'km',
    'congo'                                       => 'cg',
    'coreedalnord'                                => 'kp',
    'coreedalsud'                                 => 'kr',
    'costarica'                                   => 'cr',
    'cravuazie'                                   => 'hr',
    'cuba'                                        => 'cu',
    'cuestediavoli'                               => 'ci',
    'danimarcje'                                  => 'dk',
    'dominiche'                                   => 'dm',
    'dronningmaudland'                            => 'nq',
    'eastgermany'                                 => 'dd',
    'ecuador'                                     => 'ec',
    'egjit'                                       => 'eg',
    'elsalvador'                                  => 'sv',
    'emirâtsarapsunîts'                         => 'ae',
    'eritree'                                     => 'er',
    'estonie'                                     => 'ee',
    'etiopie'                                     => 'et',
    'filipinis'                                   => 'ph',
    'finlandie'                                   => 'fi',
    'fizi'                                        => 'fj',
    'france'                                      => 'fr',
    'frenchsouthernandantarcticterritories'       => 'fq',
    'gabon'                                       => 'ga',
    'gambia'                                      => 'gm',
    'georgiadalsudeisulissandwichdalsud'          => 'gs',
    'ghana'                                       => 'gh',
    'gibuti'                                      => 'dj',
    'gjamaiche'                                   => 'jm',
    'gjapon'                                      => 'jp',
    'gjeorgjie'                                   => 'ge',
    'gjermanie'                                   => 'de',
    'gjibraltar'                                  => 'gi',
    'gnovecaledonie'                              => 'nc',
    'gnovezelande'                                => 'nz',
    'grecie'                                      => 'gr',
    'grenada'                                     => 'gd',
    'groenlande'                                  => 'gl',
    'guadalupe'                                   => 'gp',
    'guam'                                        => 'gu',
    'guatemala'                                   => 'gt',
    'guernsey'                                    => 'gg',
    'guianafrancês'                              => 'gf',
    'guineabissau'                                => 'gw',
    'guinee'                                      => 'gn',
    'guineeecuatoriâl'                           => 'gq',
    'guyana'                                      => 'gy',
    'haiti'                                       => 'ht',
    'honduras'                                    => 'hn',
    'india'                                       => 'in',
    'indonesie'                                   => 'id',
    'iran'                                        => 'ir',
    'iraq'                                        => 'iq',
    'irlande'                                     => 'ie',
    'islande'                                     => 'is',
    'isolenorfolk'                                => 'nf',
    'israêl'                                     => 'il',
    'isulebouvet'                                 => 'bv',
    'isulechristmas'                              => 'cx',
    'isulediman'                                  => 'im',
    'isuleheardeisulismcdonald'                   => 'hm',
    'isulisaland'                                 => 'ax',
    'isuliscayman'                                => 'ky',
    'isuliscocos'                                 => 'cc',
    'isuliscook'                                  => 'ck',
    'isulisfalkland'                              => 'fk',
    'isulisfaroe'                                 => 'fo',
    'isulismarianadalnord'                        => 'mp',
    'isulismarshall'                              => 'mh',
    'isulisperiferichisminôrsdaistâtsunîts'    => 'um',
    'isulissalomon'                               => 'sb',
    'isulisturksecaicos'                          => 'tc',
    'isulisvergjinisamericanis'                   => 'vi',
    'isulisvergjinisbritanichis'                  => 'vg',
    'italie'                                      => 'it',
    'jersey'                                      => 'je',
    'johnstonisland'                              => 'jt',
    'jordanie'                                    => 'jo',
    'kazachistan'                                 => 'kz',
    'kenya'                                       => 'ke',
    'kirghizstan'                                 => 'kg',
    'kiribati'                                    => 'ki',
    'kuwait'                                      => 'kw',
    'laos'                                        => 'la',
    'lesotho'                                     => 'ls',
    'letonie'                                     => 'lv',
    'liban'                                       => 'lb',
    'liberie'                                     => 'lr',
    'libie'                                       => 'ly',
    'liechtenstein'                               => 'li',
    'lituanie'                                    => 'lt',
    'lussemburc'                                  => 'lu',
    'macedonie'                                   => 'mk',
    'madagascar'                                  => 'mg',
    'malawi'                                      => 'mw',
    'malaysia'                                    => 'my',
    'maldivis'                                    => 'mv',
    'mali'                                        => 'ml',
    'malta'                                       => 'mt',
    'maroc'                                       => 'ma',
    'martiniche'                                  => 'mq',
    'mauritanie'                                  => 'mr',
    'maurizi'                                     => 'mu',
    'mayotte'                                     => 'yt',
    'messic'                                      => 'mx',
    'metropolitanfrance'                          => 'fx',
    'micronesie'                                  => 'fm',
    'midwayislands'                               => 'mi',
    'moldavie'                                    => 'md',
    'monaco'                                      => 'mc',
    'mongolie'                                    => 'mn',
    'montenegro'                                  => 'me',
    'montserrat'                                  => 'ms',
    'mozambic'                                    => 'mz',
    'namibie'                                     => 'na',
    'nauru'                                       => 'nr',
    'nepal'                                       => 'np',
    'neutralzone'                                 => 'nt',
    'nicaragua'                                   => 'ni',
    'niger'                                       => 'ne',
    'nigerie'                                     => 'ng',
    'niue'                                        => 'nu',
    'northvietnam'                                => 'vd',
    'norvegje'                                    => 'no',
    'oceanieperiferiche'                          => 'qo',
    'oman'                                        => 'om',
    'ongjarie'                                    => 'hu',
    'pacificislandstrustterritory'                => 'pc',
    'pakistan'                                    => 'pk',
    'palau'                                       => 'pw',
    'panamacanalzone'                             => 'pz',
    'panamà'                                     => 'pa',
    'papuegnoveguinee'                            => 'pg',
    'paraguay'                                    => 'py',
    'paîsbas'                                    => 'nl',
    'peoplesdemocraticrepublicofyemen'            => 'yd',
    'perù'                                       => 'pe',
    'pitcairn'                                    => 'pn',
    'polinesiefrancês'                           => 'pf',
    'polonie'                                     => 'pl',
    'portorico'                                   => 'pr',
    'portugal'                                    => 'pt',
    'qatar'                                       => 'qa',
    'reamunît'                                   => 'gb',
    'regjonaministrativespeciâldecinedihongkong' => 'hk',
    'regjonaministrativespeciâldecinedimacao'    => 'mo',
    'regjonnocognossudeonovalide'                 => 'zz',
    'republicheceche'                             => 'cz',
    'republichecentriafricane'                    => 'cf',
    'republichedemocratichedalcongo'              => 'cd',
    'republichedominicane'                        => 'do',
    'reunion'                                     => 're',
    'romanie'                                     => 'ro',
    'ruande'                                      => 'rw',
    'russie'                                      => 'ru',
    'saharaocidentâl'                            => 'eh',
    'samoa'                                       => 'ws',
    'samoamerecanis'                              => 'as',
    'sankittsenevis'                              => 'kn',
    'sanmarin'                                    => 'sm',
    'sanpierreemiquelon'                          => 'pm',
    'santbarthélemy'                             => 'bl',
    'santeeline'                                  => 'sh',
    'santelusie'                                  => 'lc',
    'santmartin'                                  => 'mf',
    'sanvincentelisgrenadinis'                    => 'vc',
    'saotomèeprincipe'                           => 'st',
    'senegal'                                     => 'sn',
    'serbiaemontenegro'                           => 'cs',
    'serbie'                                      => 'rs',
    'seychelles'                                  => 'sc',
    'sierraleone'                                 => 'sl',
    'singapore'                                   => 'sg',
    'sirie'                                       => 'sy',
    'slovachie'                                   => 'sk',
    'slovenie'                                    => 'si',
    'somalie'                                     => 'so',
    'spagne'                                      => 'es',
    'srilanka'                                    => 'lk',
    'stâtsunîts'                                => 'us',
    'sudafriche'                                  => 'za',
    'sudan'                                       => 'sd',
    'suriname'                                    => 'sr',
    'svalbardejanmayen'                           => 'sj',
    'svezie'                                      => 'se',
    'svuizare'                                    => 'ch',
    'swaziland'                                   => 'sz',
    'tailandie'                                   => 'th',
    'taiwan'                                      => 'tw',
    'tanzanie'                                    => 'tz',
    'tazikistan'                                  => 'tj',
    'teritoribritanicdaloceanindian'              => 'io',
    'teritoripalestinês'                         => 'ps',
    'teritorismeridionâifrancês'                => 'tf',
    'timororientâl'                              => 'tl',
    'togo'                                        => 'tg',
    'tokelau'                                     => 'tk',
    'tonga'                                       => 'to',
    'trinidadetobago'                             => 'tt',
    'tunisie'                                     => 'tn',
    'turchie'                                     => 'tr',
    'turkmenistan'                                => 'tm',
    'tuvalu'                                      => 'tv',
    "u\.s\.miscellaneouspacificislands"           => 'pu',
    'ucraine'                                     => 'ua',
    'uganda'                                      => 'ug',
    'unioneuropeane'                              => 'qu',
    'unionofsovietsocialistrepublics'             => 'su',
    'uruguay'                                     => 'uy',
    'uzbechistan'                                 => 'uz',
    'vanuatu'                                     => 'vu',
    'vatican'                                     => 'va',
    'venezuela'                                   => 've',
    'vietnam'                                     => 'vn',
    'wakeisland'                                  => 'wk',
    'wallisefutuna'                               => 'wf',
    'yemen'                                       => 'ye',
    'zambia'                                      => 'zm',
    'zimbabwe'                                    => 'zw',
    'Çad'                                        => 'td',
);

1;

