package Locales::DB::Territory::fr_ca;

# Auto generated from CLDR

$Locales::DB::Territory::fr_ca::VERSION = '0.02';

$Locales::DB::Territory::fr_ca::cldr_version = '1.7.1';

%Locales::DB::Territory::fr_ca::code_to_name = (
    'ad' => 'Andorre',
    'ae' => "Émirats\ arabes\ unis",
    'af' => 'Afghanistan',
    'ag' => "Antigua\-et\-Barbuda",
    'ai' => 'Anguilla',
    'al' => 'Albanie',
    'am' => 'Arménie',
    'an' => "Antilles\ néerlandaises",
    'ao' => 'Angola',
    'aq' => 'Antarctique',
    'ar' => 'Argentine',
    'as' => "Samoa\ américaines",
    'at' => 'Autriche',
    'au' => 'Australie',
    'aw' => 'Aruba',
    'ax' => 'Åland',
    'az' => 'Azerbaïdjan',
    'ba' => "Bosnie\-Herzégovine",
    'bb' => 'Barbade',
    'bd' => 'Bangladesh',
    'be' => 'Belgique',
    'bf' => "Burkina\ Faso",
    'bg' => 'Bulgarie',
    'bh' => 'Bahreïn',
    'bi' => 'Burundi',
    'bj' => 'Bénin',
    'bl' => "Saint\-Barthélémy",
    'bm' => 'Bermudes',
    'bn' => 'Brunéi',
    'bo' => 'Bolivie',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brésil',
    'bs' => 'Bahamas',
    'bt' => 'Bhoutan',
    'bv' => "Île\ Bouvet",
    'bw' => 'Botswana',
    'by' => 'Bélarus',
    'bz' => 'Belize',
    'ca' => 'Canada',
    'cc' => "Îles\ Cocos\ \-\ Keeling",
    'cd' => "Congo\ \-\ Kinshasa",
    'cf' => "République\ centrafricaine",
    'cg' => "Congo\ \-\ Brazzaville",
    'ch' => 'Suisse',
    'ci' => "Côte\ d’Ivoire",
    'ck' => "Îles\ Cook",
    'cl' => 'Chili',
    'cm' => 'Cameroun',
    'cn' => 'Chine',
    'co' => 'Colombie',
    'cr' => "Costa\ Rica",
    'cs' => "Serbie\-et\-Monténégro",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Cuba',
    'cv' => "Cap\-Vert",
    'cx' => "Île\ Kiritimati",
    'cy' => 'Chypre',
    'cz' => "République\ tchèque",
    'dd' => "East\ Germany",
    'de' => 'Allemagne',
    'dj' => 'Djibouti',
    'dk' => 'Danemark',
    'dm' => 'Dominique',
    'do' => "République\ dominicaine",
    'dz' => 'Algérie',
    'ec' => 'Équateur',
    'ee' => 'Estonie',
    'eg' => 'Égypte',
    'eh' => "Sahara\ occidental",
    'er' => 'Érythrée',
    'es' => 'Espagne',
    'et' => 'Éthiopie',
    'fi' => 'Finlande',
    'fj' => 'Fidji',
    'fk' => "Îles\ Malouines",
    'fm' => "États\ fédérés\ de\ Micronésie",
    'fo' => "Îles\ Féroé",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'France',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabon',
    'gb' => "Royaume\-Uni",
    'gd' => 'Grenade',
    'ge' => 'Géorgie',
    'gf' => "Guyane\ française",
    'gg' => 'Guernesey',
    'gh' => 'Ghana',
    'gi' => 'Gibraltar',
    'gl' => 'Groenland',
    'gm' => 'Gambie',
    'gn' => 'Guinée',
    'gp' => 'Guadeloupe',
    'gq' => "Guinée\ équatoriale",
    'gr' => 'Grèce',
    'gs' => "Géorgie\ du\ Sud\ et\ les\ îles\ Sandwich\ du\ Sud",
    'gt' => 'Guatemala',
    'gu' => 'Guam',
    'gw' => "Guinée\-Bissau",
    'gy' => 'Guyana',
    'hk' => "Hong\ Kong",
    'hm' => "Îles\ Heard\ et\ MacDonald",
    'hn' => 'Honduras',
    'hr' => 'Croatie',
    'ht' => 'Haïti',
    'hu' => 'Hongrie',
    'id' => 'Indonésie',
    'ie' => 'Irlande',
    'il' => 'Israël',
    'im' => "Île\ de\ Man",
    'in' => 'Inde',
    'io' => "Territoire\ britannique\ de\ l’océan\ Indien",
    'iq' => 'Irak',
    'ir' => 'Iran',
    'is' => 'Islande',
    'it' => 'Italie',
    'je' => 'Jersey',
    'jm' => 'Jamaïque',
    'jo' => 'Jordanie',
    'jp' => 'Japon',
    'jt' => "Johnston\ Island",
    'ke' => 'Kenya',
    'kg' => 'Kirghizistan',
    'kh' => 'Cambodge',
    'ki' => 'Kiribati',
    'km' => 'Comores',
    'kn' => "Saint\-Christophe\-et\-Niévès",
    'kp' => "Corée\ du\ Nord",
    'kr' => "Corée\ du\ Sud",
    'kw' => 'Koweït',
    'ky' => "Îles\ Caïmanes",
    'kz' => 'Kazakhstan',
    'la' => 'Laos',
    'lb' => 'Liban',
    'lc' => "Sainte\-Lucie",
    'li' => 'Liechtenstein',
    'lk' => "Sri\ Lanka",
    'lr' => 'Libéria',
    'ls' => 'Lesotho',
    'lt' => 'Lituanie',
    'lu' => 'Luxembourg',
    'lv' => 'Lettonie',
    'ly' => 'Libye',
    'ma' => 'Maroc',
    'mc' => 'Monaco',
    'md' => 'Moldavie',
    'me' => 'Monténégro',
    'mf' => "Saint\-Martin",
    'mg' => 'Madagascar',
    'mh' => "Îles\ Marshall",
    'mi' => "Midway\ Islands",
    'mk' => 'Macédoine',
    'ml' => 'Mali',
    'mm' => 'Myanmar',
    'mn' => 'Mongolie',
    'mo' => 'Macao',
    'mp' => "Îles\ Mariannes\ du\ Nord",
    'mq' => 'Martinique',
    'mr' => 'Mauritanie',
    'ms' => 'Montserrat',
    'mt' => 'Malte',
    'mu' => 'Maurice',
    'mv' => 'Maldives',
    'mw' => 'Malawi',
    'mx' => 'Mexique',
    'my' => 'Malaisie',
    'mz' => 'Mozambique',
    'na' => 'Namibie',
    'nc' => "Nouvelle\-Calédonie",
    'ne' => 'Niger',
    'nf' => "Île\ Norfolk",
    'ng' => 'Nigéria',
    'ni' => 'Nicaragua',
    'nl' => "Pays\-Bas",
    'no' => 'Norvège',
    'np' => 'Népal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Nioué',
    'nz' => "Nouvelle\-Zélande",
    'om' => 'Oman',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Pérou',
    'pf' => "Polynésie\ française",
    'pg' => "Papouasie\-Nouvelle\-Guinée",
    'ph' => 'Philippines',
    'pk' => 'Pakistan',
    'pl' => 'Pologne',
    'pm' => "Saint\-Pierre\-et\-Miquelon",
    'pn' => 'Pitcairn',
    'pr' => "Porto\ Rico",
    'ps' => "Territoire\ palestinien",
    'pt' => 'Portugal',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palaos',
    'py' => 'Paraguay',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Qatar',
    'qo' => "régions\ éloignées\ de\ l’Océanie",
    'qu' => "Union\ européenne",
    're' => 'Réunion',
    'ro' => 'Roumanie',
    'rs' => 'Serbie',
    'ru' => 'Russie',
    'rw' => 'Rwanda',
    'sa' => "Arabie\ saoudite",
    'sb' => "Îles\ Salomon",
    'sc' => 'Seychelles',
    'sd' => 'Soudan',
    'se' => 'Suède',
    'sg' => 'Singapour',
    'sh' => "Sainte\-Hélène",
    'si' => 'Slovénie',
    'sj' => "Svalbard\ et\ Île\ Jan\ Mayen",
    'sk' => 'Slovaquie',
    'sl' => "Sierra\ Leone",
    'sm' => "Saint\-Marin",
    'sn' => 'Sénégal',
    'so' => 'Somalie',
    'sr' => 'Suriname',
    'st' => "São\ Tomé\-et\-Príncipe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salvador",
    'sy' => 'Syrie',
    'sz' => 'Swaziland',
    'tc' => "Îles\ Turks\ et\ Caïques",
    'td' => 'Tchad',
    'tf' => "Terres\ australes\ françaises",
    'tg' => 'Togo',
    'th' => 'Thaïlande',
    'tj' => 'Tadjikistan',
    'tk' => 'Tokelau',
    'tl' => "Timor\ oriental",
    'tm' => 'Turkménistan',
    'tn' => 'Tunisie',
    'to' => 'Tonga',
    'tr' => 'Turquie',
    'tt' => "Trinité\-et\-Tobago",
    'tv' => 'Tuvalu',
    'tw' => 'Taïwan',
    'tz' => 'Tanzanie',
    'ua' => 'Ukraine',
    'ug' => 'Ouganda',
    'um' => "Îles\ mineures\ éloignées\ des\ États\-Unis",
    'us' => "États\-Unis",
    'uy' => 'Uruguay',
    'uz' => 'Ouzbékistan',
    'va' => "État\ de\ la\ Cité\ du\ Vatican",
    'vc' => "Saint\-Vincent\-et\-les\ Grenadines",
    'vd' => "North\ Vietnam",
    've' => 'Venezuela',
    'vg' => "Îles\ Vierges\ britanniques",
    'vi' => "Îles\ Vierges\ des\ États\-Unis",
    'vn' => "Viêt\ Nam",
    'vu' => 'Vanuatu',
    'wf' => "Wallis\-et\-Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Yémen',
    'yt' => 'Mayotte',
    'za' => "Afrique\ du\ Sud",
    'zm' => 'Zambie',
    'zw' => 'Zimbabwe',
    'zz' => "\(région\ indéterminée\)",
);

%Locales::DB::Territory::fr_ca::name_to_code = (
    'afghanistan'                             => 'af',
    'afriquedusud'                            => 'za',
    'albanie'                                 => 'al',
    'algérie'                                => 'dz',
    'allemagne'                               => 'de',
    'andorre'                                 => 'ad',
    'angola'                                  => 'ao',
    'anguilla'                                => 'ai',
    'antarctique'                             => 'aq',
    'antiguaetbarbuda'                        => 'ag',
    'antillesnéerlandaises'                  => 'an',
    'arabiesaoudite'                          => 'sa',
    'argentine'                               => 'ar',
    'arménie'                                => 'am',
    'aruba'                                   => 'aw',
    'australie'                               => 'au',
    'autriche'                                => 'at',
    'azerbaïdjan'                            => 'az',
    'bahamas'                                 => 'bs',
    'bahreïn'                                => 'bh',
    'bangladesh'                              => 'bd',
    'barbade'                                 => 'bb',
    'belgique'                                => 'be',
    'belize'                                  => 'bz',
    'bermudes'                                => 'bm',
    'bhoutan'                                 => 'bt',
    'bolivie'                                 => 'bo',
    'bosnieherzégovine'                      => 'ba',
    'botswana'                                => 'bw',
    'britishantarcticterritory'               => 'bq',
    'brunéi'                                 => 'bn',
    'brésil'                                 => 'br',
    'bulgarie'                                => 'bg',
    'burkinafaso'                             => 'bf',
    'burundi'                                 => 'bi',
    'bélarus'                                => 'by',
    'bénin'                                  => 'bj',
    'cambodge'                                => 'kh',
    'cameroun'                                => 'cm',
    'canada'                                  => 'ca',
    'cantonandenderburyislands'               => 'ct',
    'capvert'                                 => 'cv',
    'chili'                                   => 'cl',
    'chine'                                   => 'cn',
    'chypre'                                  => 'cy',
    'colombie'                                => 'co',
    'comores'                                 => 'km',
    'congobrazzaville'                        => 'cg',
    'congokinshasa'                           => 'cd',
    'coréedunord'                            => 'kp',
    'coréedusud'                             => 'kr',
    'costarica'                               => 'cr',
    'croatie'                                 => 'hr',
    'cuba'                                    => 'cu',
    'côted’ivoire'                         => 'ci',
    'danemark'                                => 'dk',
    'djibouti'                                => 'dj',
    'dominique'                               => 'dm',
    'dronningmaudland'                        => 'nq',
    'eastgermany'                             => 'dd',
    'elsalvador'                              => 'sv',
    'espagne'                                 => 'es',
    'estonie'                                 => 'ee',
    'fidji'                                   => 'fj',
    'finlande'                                => 'fi',
    'france'                                  => 'fr',
    'frenchsouthernandantarcticterritories'   => 'fq',
    'gabon'                                   => 'ga',
    'gambie'                                  => 'gm',
    'ghana'                                   => 'gh',
    'gibraltar'                               => 'gi',
    'grenade'                                 => 'gd',
    'groenland'                               => 'gl',
    'grèce'                                  => 'gr',
    'guadeloupe'                              => 'gp',
    'guam'                                    => 'gu',
    'guatemala'                               => 'gt',
    'guernesey'                               => 'gg',
    'guinée'                                 => 'gn',
    'guinéebissau'                           => 'gw',
    'guinéeéquatoriale'                     => 'gq',
    'guyana'                                  => 'gy',
    'guyanefrançaise'                        => 'gf',
    'géorgie'                                => 'ge',
    'géorgiedusudetlesîlessandwichdusud'    => 'gs',
    'haïti'                                  => 'ht',
    'honduras'                                => 'hn',
    'hongkong'                                => 'hk',
    'hongrie'                                 => 'hu',
    'inde'                                    => 'in',
    'indonésie'                              => 'id',
    'irak'                                    => 'iq',
    'iran'                                    => 'ir',
    'irlande'                                 => 'ie',
    'islande'                                 => 'is',
    'israël'                                 => 'il',
    'italie'                                  => 'it',
    'jamaïque'                               => 'jm',
    'japon'                                   => 'jp',
    'jersey'                                  => 'je',
    'johnstonisland'                          => 'jt',
    'jordanie'                                => 'jo',
    'kazakhstan'                              => 'kz',
    'kenya'                                   => 'ke',
    'kirghizistan'                            => 'kg',
    'kiribati'                                => 'ki',
    'koweït'                                 => 'kw',
    'laos'                                    => 'la',
    'lesotho'                                 => 'ls',
    'lettonie'                                => 'lv',
    'liban'                                   => 'lb',
    'libye'                                   => 'ly',
    'libéria'                                => 'lr',
    'liechtenstein'                           => 'li',
    'lituanie'                                => 'lt',
    'luxembourg'                              => 'lu',
    'macao'                                   => 'mo',
    'macédoine'                              => 'mk',
    'madagascar'                              => 'mg',
    'malaisie'                                => 'my',
    'malawi'                                  => 'mw',
    'maldives'                                => 'mv',
    'mali'                                    => 'ml',
    'malte'                                   => 'mt',
    'maroc'                                   => 'ma',
    'martinique'                              => 'mq',
    'maurice'                                 => 'mu',
    'mauritanie'                              => 'mr',
    'mayotte'                                 => 'yt',
    'metropolitanfrance'                      => 'fx',
    'mexique'                                 => 'mx',
    'midwayislands'                           => 'mi',
    'moldavie'                                => 'md',
    'monaco'                                  => 'mc',
    'mongolie'                                => 'mn',
    'montserrat'                              => 'ms',
    'monténégro'                            => 'me',
    'mozambique'                              => 'mz',
    'myanmar'                                 => 'mm',
    'namibie'                                 => 'na',
    'nauru'                                   => 'nr',
    'neutralzone'                             => 'nt',
    'nicaragua'                               => 'ni',
    'niger'                                   => 'ne',
    'nigéria'                                => 'ng',
    'nioué'                                  => 'nu',
    'northvietnam'                            => 'vd',
    'norvège'                                => 'no',
    'nouvellecalédonie'                      => 'nc',
    'nouvellezélande'                        => 'nz',
    'népal'                                  => 'np',
    'oman'                                    => 'om',
    'ouganda'                                 => 'ug',
    'ouzbékistan'                            => 'uz',
    'pacificislandstrustterritory'            => 'pc',
    'pakistan'                                => 'pk',
    'palaos'                                  => 'pw',
    'panama'                                  => 'pa',
    'panamacanalzone'                         => 'pz',
    'papouasienouvelleguinée'                => 'pg',
    'paraguay'                                => 'py',
    'paysbas'                                 => 'nl',
    'peoplesdemocraticrepublicofyemen'        => 'yd',
    'philippines'                             => 'ph',
    'pitcairn'                                => 'pn',
    'pologne'                                 => 'pl',
    'polynésiefrançaise'                    => 'pf',
    'portorico'                               => 'pr',
    'portugal'                                => 'pt',
    'pérou'                                  => 'pe',
    'qatar'                                   => 'qa',
    'roumanie'                                => 'ro',
    'royaumeuni'                              => 'gb',
    'russie'                                  => 'ru',
    'rwanda'                                  => 'rw',
    'régionindéterminée'                   => 'zz',
    'régionséloignéesdel’océanie'       => 'qo',
    'républiquecentrafricaine'               => 'cf',
    'républiquedominicaine'                  => 'do',
    'républiquetchèque'                     => 'cz',
    'réunion'                                => 're',
    'saharaoccidental'                        => 'eh',
    'saintbarthélémy'                       => 'bl',
    'saintchristopheetniévès'               => 'kn',
    'saintehélène'                          => 'sh',
    'saintelucie'                             => 'lc',
    'saintmarin'                              => 'sm',
    'saintmartin'                             => 'mf',
    'saintpierreetmiquelon'                   => 'pm',
    'saintvincentetlesgrenadines'             => 'vc',
    'samoa'                                   => 'ws',
    'samoaaméricaines'                       => 'as',
    'serbie'                                  => 'rs',
    'serbieetmonténégro'                    => 'cs',
    'seychelles'                              => 'sc',
    'sierraleone'                             => 'sl',
    'singapour'                               => 'sg',
    'slovaquie'                               => 'sk',
    'slovénie'                               => 'si',
    'somalie'                                 => 'so',
    'soudan'                                  => 'sd',
    'srilanka'                                => 'lk',
    'suisse'                                  => 'ch',
    'suriname'                                => 'sr',
    'suède'                                  => 'se',
    'svalbardetÎlejanmayen'                  => 'sj',
    'swaziland'                               => 'sz',
    'syrie'                                   => 'sy',
    'sãotoméetpríncipe'                    => 'st',
    'sénégal'                               => 'sn',
    'tadjikistan'                             => 'tj',
    'tanzanie'                                => 'tz',
    'taïwan'                                 => 'tw',
    'tchad'                                   => 'td',
    'terresaustralesfrançaises'              => 'tf',
    'territoirebritanniquedel’océanindien' => 'io',
    'territoirepalestinien'                   => 'ps',
    'thaïlande'                              => 'th',
    'timororiental'                           => 'tl',
    'togo'                                    => 'tg',
    'tokelau'                                 => 'tk',
    'tonga'                                   => 'to',
    'trinitéettobago'                        => 'tt',
    'tunisie'                                 => 'tn',
    'turkménistan'                           => 'tm',
    'turquie'                                 => 'tr',
    'tuvalu'                                  => 'tv',
    "u\.s\.miscellaneouspacificislands"       => 'pu',
    'ukraine'                                 => 'ua',
    'unioneuropéenne'                        => 'qu',
    'unionofsovietsocialistrepublics'         => 'su',
    'uruguay'                                 => 'uy',
    'vanuatu'                                 => 'vu',
    'venezuela'                               => 've',
    'viêtnam'                                => 'vn',
    'wakeisland'                              => 'wk',
    'wallisetfutuna'                          => 'wf',
    'yémen'                                  => 'ye',
    'zambie'                                  => 'zm',
    'zimbabwe'                                => 'zw',
    'Åland'                                  => 'ax',
    'Égypte'                                 => 'eg',
    'Émiratsarabesunis'                      => 'ae',
    'Équateur'                               => 'ec',
    'Érythrée'                              => 'er',
    'Étatdelacitéduvatican'                 => 'va',
    'Étatsfédérésdemicronésie'           => 'fm',
    'Étatsunis'                              => 'us',
    'Éthiopie'                               => 'et',
    'Îlebouvet'                              => 'bv',
    'Îledeman'                               => 'im',
    'Îlekiritimati'                          => 'cx',
    'Îlenorfolk'                             => 'nf',
    'Îlescaïmanes'                          => 'ky',
    'Îlescocoskeeling'                       => 'cc',
    'Îlescook'                               => 'ck',
    'Îlesféroé'                            => 'fo',
    'Îlesheardetmacdonald'                   => 'hm',
    'Îlesmalouines'                          => 'fk',
    'Îlesmariannesdunord'                    => 'mp',
    'Îlesmarshall'                           => 'mh',
    'ÎlesmineureséloignéesdesÉtatsunis'   => 'um',
    'Îlessalomon'                            => 'sb',
    'Îlesturksetcaïques'                    => 'tc',
    'Îlesviergesbritanniques'                => 'vg',
    'ÎlesviergesdesÉtatsunis'               => 'vi',
);

1;

