package Locales::DB::Language::pt_br;

# Auto generated from CLDR

$Locales::DB::Language::pt_br::VERSION = '0.02';

$Locales::DB::Language::pt_br::cldr_version = '1.7.1';

%Locales::DB::Language::pt_br::misc_info = (
    'cldr_formats' => {
        'decimal'   => "\#\,\#\#0\.\#\#\#",
        'language'  => "Language\:\ \{0\}",
        'locale'    => "\{0\}\ \(\{1\}\)",
        'percent'   => "\#\,\#\#0\%",
        'territory' => "Region\:\ \{0\}"
    },
    'fallback'    => [],
    'orientation' => {
        'characters' => "left\-to\-right",
        'lines'      => "top\-to\-bottom"
    },
    'posix' => {
        'nostr'  => "no\:n",
        'yesstr' => "yes\:y"
    },
);

%Locales::DB::Language::pt_br::code_to_name = (
    'aa'    => 'afar',
    'ab'    => 'abcázio',
    'ace'   => 'achém',
    'ach'   => 'acoli',
    'ada'   => 'adangme',
    'ady'   => 'adigue',
    'ae'    => 'avéstico',
    'af'    => 'africâner',
    'afa'   => "idioma\ afro\-asiático",
    'afh'   => 'afrihili',
    'ain'   => 'ainu',
    'ak'    => 'akan',
    'akk'   => 'acadiano',
    'ale'   => 'aleúte',
    'alg'   => "idioma\ algonquiano",
    'alt'   => "altai\ do\ sul",
    'am'    => 'amárico',
    'an'    => 'aragonês',
    'ang'   => "inglês\ arcaico",
    'anp'   => 'angika',
    'apa'   => "idioma\ apache",
    'ar'    => 'árabe',
    'arc'   => 'aramaico',
    'arn'   => 'araucano',
    'arp'   => 'arapaho',
    'art'   => "idioma\ artificial",
    'arw'   => 'arauaqui',
    'as'    => 'assamês',
    'ast'   => 'asturiano',
    'ath'   => "idioma\ atabascano",
    'aus'   => "idioma\ australiano",
    'av'    => 'avaric',
    'awa'   => 'awadhi',
    'ay'    => 'aimara',
    'az'    => 'azerbaijano',
    'ba'    => 'bashkir',
    'bad'   => 'banda',
    'bai'   => "idioma\ bamileke",
    'bal'   => 'balúchi',
    'ban'   => 'balinês',
    'bas'   => 'basa',
    'bat'   => "idioma\ báltico",
    'be'    => "bielo\-russo",
    'bej'   => 'beja',
    'bem'   => 'bemba',
    'ber'   => 'berbere',
    'bg'    => 'búlgaro',
    'bh'    => 'biari',
    'bho'   => 'bhojpuri',
    'bi'    => 'bislamá',
    'bik'   => 'bikol',
    'bin'   => 'bini',
    'bla'   => 'siksika',
    'bm'    => 'bambara',
    'bn'    => 'bengali',
    'bnt'   => 'banto',
    'bo'    => 'tibetano',
    'br'    => 'bretão',
    'bra'   => 'braj',
    'bs'    => 'bósnio',
    'btk'   => 'bataque',
    'bua'   => 'buriat',
    'bug'   => 'buguinês',
    'byn'   => 'blin',
    'ca'    => 'catalão',
    'cad'   => 'caddo',
    'cai'   => "idioma\ indígena\ centro\-americano",
    'car'   => 'caribe',
    'cau'   => "idioma\ caucásico",
    'cch'   => 'atsam',
    'ce'    => 'checheno',
    'ceb'   => 'cebuano',
    'cel'   => "idioma\ celta",
    'ch'    => 'chamorro',
    'chb'   => 'chibcha',
    'chg'   => 'chagatai',
    'chk'   => 'chuukese',
    'chm'   => 'mari',
    'chn'   => "chinook\ jargon",
    'cho'   => 'choctaw',
    'chp'   => 'chipewyan',
    'chr'   => 'cherokee',
    'chy'   => 'cheiene',
    'cmc'   => "idioma\ chamic",
    'co'    => 'córsico',
    'cop'   => 'copta',
    'cpe'   => "crioulo\ ou\ pidgin\ baseado\ no\ inglês",
    'cpf'   => "crioulo\ ou\ pidgin\ baseado\ no\ francês",
    'cpp'   => "crioulo\ ou\ pidgin\ baseado\ no\ português",
    'cr'    => 'cree',
    'crh'   => "turco\ da\ Crimeia",
    'crp'   => "crioulo\ ou\ pidgin",
    'cs'    => 'tcheco',
    'csb'   => 'kashubian',
    'cu'    => "eslavo\ eclesiástico",
    'cus'   => "idioma\ cuchítico",
    'cv'    => 'chuvash',
    'cy'    => 'galês',
    'da'    => 'dinamarquês',
    'dak'   => 'dacota',
    'dar'   => 'dargwa',
    'day'   => 'dayak',
    'de'    => 'alemão',
    'de_at' => "alemão\ austríaco",
    'de_ch' => "alto\ alemão\ suíço",
    'del'   => 'delaware',
    'den'   => 'slave',
    'dgr'   => 'dogrib',
    'din'   => 'dinka',
    'doi'   => 'dogri',
    'dra'   => "idioma\ dravidiano",
    'dsb'   => "sérvio\ baixo",
    'dua'   => 'duala',
    'dum'   => "holandês\ médio",
    'dv'    => 'divehi',
    'dyu'   => 'diúla',
    'dz'    => 'dzonga',
    'ee'    => 'eve',
    'efi'   => 'efique',
    'egy'   => "egípcio\ arcaico",
    'eka'   => 'ekajuk',
    'el'    => 'grego',
    'elx'   => 'elamite',
    'en'    => 'inglês',
    'en_au' => "inglês\ australiano",
    'en_ca' => "inglês\ canadense",
    'en_gb' => "inglês\ britânico",
    'en_us' => "inglês\ americano",
    'enm'   => "inglês\ médio",
    'eo'    => 'esperanto',
    'es'    => 'espanhol',
    'es_es' => "espanhol\ ibérico",
    'et'    => 'estoniano',
    'eu'    => 'basco',
    'ewo'   => 'ewondo',
    'fa'    => 'persa',
    'fan'   => 'fangue',
    'fat'   => 'fanti',
    'ff'    => 'fula',
    'fi'    => 'finlandês',
    'fil'   => 'filipino',
    'fiu'   => "idioma\ fino\-úgrico",
    'fj'    => 'fijiano',
    'fo'    => 'feroês',
    'fon'   => 'fom',
    'fr'    => 'francês',
    'fr_ca' => "francês\ canadense",
    'fr_ch' => "francês\ suíço",
    'frm'   => "francês\ médio",
    'fro'   => "francês\ arcaico",
    'frr'   => "frísio\ setentrional",
    'frs'   => "frisão\ oriental",
    'fur'   => 'friulano',
    'fy'    => "frísio\ ocidental",
    'ga'    => 'irlandês',
    'gaa'   => 'ga',
    'gay'   => 'gayo',
    'gba'   => 'gbaia',
    'gd'    => "gaélico\ escocês",
    'gem'   => "idioma\ germânico",
    'gez'   => 'geez',
    'gil'   => 'gilbertês',
    'gl'    => 'galego',
    'gmh'   => "alemão\ médio\-alto",
    'gn'    => 'guarani',
    'goh'   => "alemão\ arcaico\ alto",
    'gon'   => 'gondi',
    'gor'   => 'gorontalo',
    'got'   => 'gótico',
    'grb'   => 'grebo',
    'grc'   => "grego\ arcaico",
    'gsw'   => "alemão\ suíço",
    'gu'    => 'guzerate',
    'gv'    => 'manx',
    'gwi'   => 'gwichʼin',
    'ha'    => 'hauçá',
    'hai'   => 'haida',
    'haw'   => 'havaiano',
    'he'    => 'hebraico',
    'hi'    => 'híndi',
    'hil'   => 'hiligaynon',
    'him'   => 'himachali',
    'hit'   => 'hitita',
    'hmn'   => 'hmong',
    'ho'    => "hiri\ motu",
    'hr'    => 'croata',
    'hsb'   => "sorábio\ superior",
    'ht'    => 'haitiano',
    'hu'    => 'húngaro',
    'hup'   => 'hupa',
    'hy'    => 'armênio',
    'hz'    => 'herero',
    'ia'    => 'interlíngua',
    'iba'   => 'iban',
    'id'    => 'indonésio',
    'ie'    => 'interlingue',
    'ig'    => 'ibo',
    'ii'    => "sichuan\ yi",
    'ijo'   => 'ijo',
    'ik'    => 'inupiaque',
    'ilo'   => 'ilocano',
    'inc'   => "idioma\ índico",
    'ine'   => "idioma\ indo\-europeu",
    'inh'   => 'inguche',
    'io'    => 'ido',
    'ira'   => 'iraniano',
    'iro'   => "idioma\ iroquês",
    'is'    => 'islandês',
    'it'    => 'italiano',
    'iu'    => 'inuktitut',
    'ja'    => 'japonês',
    'jbo'   => 'lojban',
    'jpr'   => "judaico\-persa",
    'jrb'   => "judaico\-arábico",
    'jv'    => 'javanês',
    'ka'    => 'georgiano',
    'kaa'   => "kara\-kalpak",
    'kab'   => 'kabyle',
    'kac'   => 'kachin',
    'kaj'   => 'jju',
    'kam'   => 'kamba',
    'kar'   => 'karen',
    'kaw'   => 'kawi',
    'kbd'   => 'kabardiano',
    'kcg'   => 'tyap',
    'kfo'   => 'koro',
    'kg'    => 'congolês',
    'kha'   => 'khasi',
    'khi'   => "idioma\ coisã",
    'kho'   => 'khotanês',
    'ki'    => 'quicuio',
    'kj'    => 'kuanyama',
    'kk'    => 'cazaque',
    'kl'    => 'groenlandês',
    'km'    => 'cmer',
    'kmb'   => 'quimbundo',
    'kn'    => 'canarês',
    'ko'    => 'coreano',
    'kok'   => 'concani',
    'kos'   => 'kosraean',
    'kpe'   => 'kpelle',
    'kr'    => 'canúri',
    'krc'   => "karachay\-balkar",
    'krl'   => "idioma\ carélio",
    'kro'   => 'kru',
    'kru'   => 'kurukh',
    'ks'    => 'caxemira',
    'ku'    => 'curdo',
    'kum'   => 'kumyk',
    'kut'   => 'kutenai',
    'kv'    => 'komi',
    'kw'    => 'córnico',
    'ky'    => 'quirguiz',
    'la'    => 'latim',
    'lad'   => 'ladino',
    'lah'   => 'lahnda',
    'lam'   => 'lamba',
    'lb'    => 'luxemburguês',
    'lez'   => 'lezghian',
    'lg'    => 'luganda',
    'li'    => 'limburguês',
    'ln'    => 'lingala',
    'lo'    => 'laosiano',
    'lol'   => 'mongo',
    'loz'   => 'lozi',
    'lt'    => 'lituano',
    'lu'    => "luba\-catanga",
    'lua'   => "luba\-lulua",
    'lui'   => 'luiseno',
    'lun'   => 'lunda',
    'luo'   => 'luo',
    'lus'   => 'lushai',
    'lv'    => 'letão',
    'mad'   => 'madurês',
    'mag'   => 'magahi',
    'mai'   => 'maithili',
    'mak'   => 'makasar',
    'man'   => 'mandinga',
    'map'   => 'austronésio',
    'mas'   => 'massai',
    'mdf'   => 'mocsa',
    'mdr'   => 'mandar',
    'men'   => 'mende',
    'mfe'   => 'Morisyen',
    'mg'    => 'malgaxe',
    'mga'   => "irlandês\ médio",
    'mh'    => 'marshalês',
    'mi'    => 'maori',
    'mic'   => 'miquemaque',
    'min'   => 'minangkabau',
    'mis'   => "idiomas\ diversos",
    'mk'    => 'macedônio',
    'mkh'   => "idioma\ mon\-khmer",
    'ml'    => 'malaiala',
    'mn'    => 'mongol',
    'mnc'   => 'manchu',
    'mni'   => 'manipuri',
    'mno'   => "idioma\ manobo",
    'mo'    => 'moldávio',
    'moh'   => 'mohawk',
    'mos'   => 'mossi',
    'mr'    => 'marata',
    'ms'    => 'malaio',
    'mt'    => 'maltês',
    'mul'   => "idiomas\ múltiplos",
    'mun'   => "idiomas\ munda",
    'mus'   => 'creek',
    'mwl'   => 'mirandês',
    'mwr'   => 'marwari',
    'my'    => 'birmanês',
    'myn'   => 'maia',
    'myv'   => 'erzya',
    'na'    => 'nauruano',
    'nah'   => 'náuatle',
    'nai'   => "idioma\ indígena\ norte\-americano",
    'nap'   => 'napolitano',
    'nb'    => "bokmål\ norueguês",
    'nd'    => "ndebele\ do\ norte",
    'nds'   => "baixo\-alemão",
    'ne'    => 'nepali',
    'new'   => 'newari',
    'ng'    => 'dongo',
    'nia'   => 'nias',
    'nic'   => "idioma\ cordofano\-nigeriano",
    'niu'   => 'niueano',
    'nl'    => 'holandês',
    'nl_be' => 'flamengo',
    'nn'    => "nynorsk\ norueguês",
    'no'    => 'norueguês',
    'nog'   => 'nogai',
    'non'   => "nórdico\ arcaico",
    'nqo'   => "n\'ko",
    'nr'    => "ndebele\ do\ sul",
    'nso'   => "soto\ setentrional",
    'nub'   => "idioma\ núbio",
    'nv'    => 'navajo',
    'nwc'   => "newari\ clássico",
    'ny'    => 'nianja',
    'nym'   => 'nyamwezi',
    'nyn'   => 'nyankole',
    'nyo'   => 'nyoro',
    'nzi'   => 'nzima',
    'oc'    => 'occitânico',
    'oj'    => 'ojibwa',
    'om'    => 'oromo',
    'or'    => 'oriya',
    'os'    => 'ossetic',
    'osa'   => 'osage',
    'ota'   => "turco\ otomano",
    'oto'   => "idioma\ otomano",
    'pa'    => 'panjabi',
    'paa'   => "idioma\ papuano",
    'pag'   => 'pangasinã',
    'pal'   => 'pálavi',
    'pam'   => 'pampanga',
    'pap'   => 'papiamento',
    'pau'   => 'palauano',
    'peo'   => "persa\ arcaico",
    'phi'   => "idioma\ filipino",
    'phn'   => 'fenício',
    'pi'    => 'páli',
    'pl'    => 'polonês',
    'pon'   => 'pohnpeian',
    'pra'   => "idioma\ prácrito",
    'pro'   => "provençal\ arcaico",
    'ps'    => 'pashto',
    'pt'    => 'português',
    'pt_br' => "português\ do\ Brasil",
    'pt_pt' => "português\ ibérico",
    'qu'    => 'quíchua',
    'raj'   => 'rajastani',
    'rap'   => 'rapanui',
    'rar'   => 'rarotongano',
    'rm'    => "reto\-romano",
    'rn'    => 'rundi',
    'ro'    => 'romeno',
    'roa'   => "idioma\ românico",
    'rom'   => 'romani',
    'ru'    => 'russo',
    'rup'   => 'aromeno',
    'rw'    => 'kinyarwanda',
    'sa'    => 'sânscrito',
    'sad'   => 'sandawe',
    'sah'   => 'iacuto',
    'sai'   => "idioma\ indígena\ sul\-americano",
    'sal'   => "idioma\ salisano",
    'sam'   => "aramaico\ samaritano",
    'sas'   => 'sasak',
    'sat'   => 'santali',
    'sc'    => 'sardo',
    'scn'   => 'siciliano',
    'sco'   => 'escocês',
    'sd'    => 'sindi',
    'se'    => "sami\ do\ norte",
    'sel'   => 'selkup',
    'sem'   => "idioma\ semítico",
    'sg'    => 'sango',
    'sga'   => "irlandês\ arcaico",
    'sgn'   => "linguagem\ de\ sinais",
    'sh'    => "servo\-croata",
    'shn'   => 'shan',
    'si'    => 'cingalês',
    'sid'   => 'sidamo',
    'sio'   => "idioma\ sioux",
    'sit'   => "idioma\ sino\-tibetano",
    'sk'    => 'eslovaco',
    'sl'    => 'esloveno',
    'sla'   => "idioma\ eslavo",
    'sm'    => 'samoano',
    'sma'   => "sami\ do\ sul",
    'smi'   => "idioma\ sami",
    'smj'   => "lule\ sami",
    'smn'   => "inari\ sami",
    'sms'   => "skolt\ sami",
    'sn'    => 'shona',
    'snk'   => 'soninquê',
    'so'    => 'somali',
    'sog'   => 'sogdiano',
    'son'   => 'songai',
    'sq'    => 'albanês',
    'sr'    => 'sérvio',
    'srn'   => "idioma\ surinamês",
    'srr'   => 'serere',
    'ss'    => 'swati',
    'ssa'   => "idioma\ nilo\-saariano",
    'st'    => "soto\ do\ sul",
    'su'    => 'sundanês',
    'suk'   => 'sukuma',
    'sus'   => 'sosso',
    'sux'   => 'sumério',
    'sv'    => 'sueco',
    'sw'    => 'suaili',
    'syc'   => "siríaco\ clássico",
    'syr'   => 'siríaco',
    'ta'    => 'tâmil',
    'tai'   => "idioma\ tailandês",
    'te'    => 'telugu',
    'tem'   => 'timne',
    'ter'   => 'tereno',
    'tet'   => 'tétum',
    'tg'    => 'tadjique',
    'th'    => 'tailandês',
    'ti'    => 'tigrínia',
    'tig'   => 'tigré',
    'tiv'   => 'tiv',
    'tk'    => 'turcomano',
    'tkl'   => 'toquelauano',
    'tl'    => 'tagalo',
    'tlh'   => 'klingon',
    'tli'   => 'tlinguite',
    'tmh'   => 'tamaxeque',
    'tn'    => 'tswana',
    'to'    => 'tonganês',
    'tog'   => "tonganês\ de\ Nyasa",
    'tpi'   => "tok\ pisin",
    'tr'    => 'turco',
    'trv'   => 'Taroko',
    'ts'    => 'tsonga',
    'tsi'   => 'tsimshian',
    'tt'    => 'tatar',
    'tum'   => 'tumbuka',
    'tup'   => "idioma\ tupi",
    'tut'   => "idioma\ altaico",
    'tvl'   => 'tuvaluano',
    'tw'    => 'twi',
    'ty'    => 'taitiano',
    'tyv'   => 'tuvinian',
    'udm'   => 'udmurt',
    'ug'    => 'uighur',
    'uga'   => 'ugarítico',
    'uk'    => 'ucraniano',
    'umb'   => 'umbundu',
    'und'   => "idioma\ inválido\ ou\ desconhecido",
    'ur'    => 'urdu',
    'uz'    => 'usbeque',
    'vai'   => 'vai',
    've'    => 'venda',
    'vi'    => 'vietnamita',
    'vo'    => 'volapuque',
    'vot'   => 'votic',
    'wa'    => 'valão',
    'wak'   => "idioma\ wakashan",
    'wal'   => 'walamo',
    'war'   => 'waray',
    'was'   => 'washo',
    'wen'   => "idioma\ sorábio",
    'wo'    => 'uólofe',
    'xal'   => 'kalmyk',
    'xh'    => 'xosa',
    'yao'   => 'yao',
    'yap'   => 'yapese',
    'yi'    => 'iídiche',
    'yo'    => 'ioruba',
    'ypk'   => "idioma\ iúpique",
    'za'    => 'zhuang',
    'zap'   => 'zapoteca',
    'zbl'   => "símbolos\ blis",
    'zen'   => 'zenaga',
    'zh'    => 'chinês',
    'znd'   => 'zande',
    'zu'    => 'zulu',
    'zun'   => 'zunhi',
    'zxx'   => "sem\ conteúdo\ linguístico",
    'zza'   => 'zaza',
);

%Locales::DB::Language::pt_br::name_to_code = (
    'abcázio'                           => 'ab',
    'acadiano'                           => 'akk',
    'achém'                             => 'ace',
    'acoli'                              => 'ach',
    'adangme'                            => 'ada',
    'adigue'                             => 'ady',
    'afar'                               => 'aa',
    'africâner'                         => 'af',
    'afrihili'                           => 'afh',
    'aimara'                             => 'ay',
    'ainu'                               => 'ain',
    'akan'                               => 'ak',
    'albanês'                           => 'sq',
    'alemão'                            => 'de',
    'alemãoarcaicoalto'                 => 'goh',
    'alemãoaustríaco'                  => 'de_at',
    'alemãomédioalto'                  => 'gmh',
    'alemãosuíço'                     => 'gsw',
    'aleúte'                            => 'ale',
    'altaidosul'                         => 'alt',
    'altoalemãosuíço'                 => 'de_ch',
    'amárico'                           => 'am',
    'angika'                             => 'anp',
    'aragonês'                          => 'an',
    'aramaico'                           => 'arc',
    'aramaicosamaritano'                 => 'sam',
    'arapaho'                            => 'arp',
    'arauaqui'                           => 'arw',
    'araucano'                           => 'arn',
    'armênio'                           => 'hy',
    'aromeno'                            => 'rup',
    'assamês'                           => 'as',
    'asturiano'                          => 'ast',
    'atsam'                              => 'cch',
    'austronésio'                       => 'map',
    'avaric'                             => 'av',
    'avéstico'                          => 'ae',
    'awadhi'                             => 'awa',
    'azerbaijano'                        => 'az',
    'baixoalemão'                       => 'nds',
    'balinês'                           => 'ban',
    'balúchi'                           => 'bal',
    'bambara'                            => 'bm',
    'banda'                              => 'bad',
    'banto'                              => 'bnt',
    'basa'                               => 'bas',
    'basco'                              => 'eu',
    'bashkir'                            => 'ba',
    'bataque'                            => 'btk',
    'beja'                               => 'bej',
    'bemba'                              => 'bem',
    'bengali'                            => 'bn',
    'berbere'                            => 'ber',
    'bhojpuri'                           => 'bho',
    'biari'                              => 'bh',
    'bielorusso'                         => 'be',
    'bikol'                              => 'bik',
    'bini'                               => 'bin',
    'birmanês'                          => 'my',
    'bislamá'                           => 'bi',
    'blin'                               => 'byn',
    'bokmålnorueguês'                  => 'nb',
    'braj'                               => 'bra',
    'bretão'                            => 'br',
    'buguinês'                          => 'bug',
    'buriat'                             => 'bua',
    'bósnio'                            => 'bs',
    'búlgaro'                           => 'bg',
    'caddo'                              => 'cad',
    'canarês'                           => 'kn',
    'canúri'                            => 'kr',
    'caribe'                             => 'car',
    'catalão'                           => 'ca',
    'caxemira'                           => 'ks',
    'cazaque'                            => 'kk',
    'cebuano'                            => 'ceb',
    'chagatai'                           => 'chg',
    'chamorro'                           => 'ch',
    'checheno'                           => 'ce',
    'cheiene'                            => 'chy',
    'cherokee'                           => 'chr',
    'chibcha'                            => 'chb',
    'chinookjargon'                      => 'chn',
    'chinês'                            => 'zh',
    'chipewyan'                          => 'chp',
    'choctaw'                            => 'cho',
    'chuukese'                           => 'chk',
    'chuvash'                            => 'cv',
    'cingalês'                          => 'si',
    'cmer'                               => 'km',
    'concani'                            => 'kok',
    'congolês'                          => 'kg',
    'copta'                              => 'cop',
    'coreano'                            => 'ko',
    'cree'                               => 'cr',
    'creek'                              => 'mus',
    'crioulooupidgin'                    => 'crp',
    'crioulooupidginbaseadonofrancês'   => 'cpf',
    'crioulooupidginbaseadonoinglês'    => 'cpe',
    'crioulooupidginbaseadonoportuguês' => 'cpp',
    'croata'                             => 'hr',
    'curdo'                              => 'ku',
    'córnico'                           => 'kw',
    'córsico'                           => 'co',
    'dacota'                             => 'dak',
    'dargwa'                             => 'dar',
    'dayak'                              => 'day',
    'delaware'                           => 'del',
    'dinamarquês'                       => 'da',
    'dinka'                              => 'din',
    'divehi'                             => 'dv',
    'diúla'                             => 'dyu',
    'dogri'                              => 'doi',
    'dogrib'                             => 'dgr',
    'dongo'                              => 'ng',
    'duala'                              => 'dua',
    'dzonga'                             => 'dz',
    'efique'                             => 'efi',
    'egípcioarcaico'                    => 'egy',
    'ekajuk'                             => 'eka',
    'elamite'                            => 'elx',
    'erzya'                              => 'myv',
    'escocês'                           => 'sco',
    'eslavoeclesiástico'                => 'cu',
    'eslovaco'                           => 'sk',
    'esloveno'                           => 'sl',
    'espanhol'                           => 'es',
    'espanholibérico'                   => 'es_es',
    'esperanto'                          => 'eo',
    'estoniano'                          => 'et',
    'eve'                                => 'ee',
    'ewondo'                             => 'ewo',
    'fangue'                             => 'fan',
    'fanti'                              => 'fat',
    'fenício'                           => 'phn',
    'feroês'                            => 'fo',
    'fijiano'                            => 'fj',
    'filipino'                           => 'fil',
    'finlandês'                         => 'fi',
    'flamengo'                           => 'nl_be',
    'fom'                                => 'fon',
    'francês'                           => 'fr',
    'francêsarcaico'                    => 'fro',
    'francêscanadense'                  => 'fr_ca',
    'francêsmédio'                     => 'frm',
    'francêssuíço'                    => 'fr_ch',
    'frisãooriental'                    => 'frs',
    'friulano'                           => 'fur',
    'frísioocidental'                   => 'fy',
    'frísiosetentrional'                => 'frr',
    'fula'                               => 'ff',
    'ga'                                 => 'gaa',
    'galego'                             => 'gl',
    'galês'                             => 'cy',
    'gayo'                               => 'gay',
    'gaélicoescocês'                   => 'gd',
    'gbaia'                              => 'gba',
    'geez'                               => 'gez',
    'georgiano'                          => 'ka',
    'gilbertês'                         => 'gil',
    'gondi'                              => 'gon',
    'gorontalo'                          => 'gor',
    'grebo'                              => 'grb',
    'grego'                              => 'el',
    'gregoarcaico'                       => 'grc',
    'groenlandês'                       => 'kl',
    'guarani'                            => 'gn',
    'guzerate'                           => 'gu',
    'gwichʼin'                          => 'gwi',
    'gótico'                            => 'got',
    'haida'                              => 'hai',
    'haitiano'                           => 'ht',
    'hauçá'                            => 'ha',
    'havaiano'                           => 'haw',
    'hebraico'                           => 'he',
    'herero'                             => 'hz',
    'hiligaynon'                         => 'hil',
    'himachali'                          => 'him',
    'hirimotu'                           => 'ho',
    'hitita'                             => 'hit',
    'hmong'                              => 'hmn',
    'holandês'                          => 'nl',
    'holandêsmédio'                    => 'dum',
    'hupa'                               => 'hup',
    'híndi'                             => 'hi',
    'húngaro'                           => 'hu',
    'iacuto'                             => 'sah',
    'iban'                               => 'iba',
    'ibo'                                => 'ig',
    'idiomaafroasiático'                => 'afa',
    'idiomaalgonquiano'                  => 'alg',
    'idiomaaltaico'                      => 'tut',
    'idiomaapache'                       => 'apa',
    'idiomaartificial'                   => 'art',
    'idiomaatabascano'                   => 'ath',
    'idiomaaustraliano'                  => 'aus',
    'idiomabamileke'                     => 'bai',
    'idiomabáltico'                     => 'bat',
    'idiomacarélio'                     => 'krl',
    'idiomacaucásico'                   => 'cau',
    'idiomacelta'                        => 'cel',
    'idiomachamic'                       => 'cmc',
    'idiomacoisã'                       => 'khi',
    'idiomacordofanonigeriano'           => 'nic',
    'idiomacuchítico'                   => 'cus',
    'idiomadravidiano'                   => 'dra',
    'idiomaeslavo'                       => 'sla',
    'idiomafilipino'                     => 'phi',
    'idiomafinoúgrico'                  => 'fiu',
    'idiomagermânico'                   => 'gem',
    'idiomaindoeuropeu'                  => 'ine',
    'idiomaindígenacentroamericano'     => 'cai',
    'idiomaindígenanorteamericano'      => 'nai',
    'idiomaindígenasulamericano'        => 'sai',
    'idiomainválidooudesconhecido'      => 'und',
    'idiomairoquês'                     => 'iro',
    'idiomaiúpique'                     => 'ypk',
    'idiomamanobo'                       => 'mno',
    'idiomamonkhmer'                     => 'mkh',
    'idiomanilosaariano'                 => 'ssa',
    'idiomanúbio'                       => 'nub',
    'idiomaotomano'                      => 'oto',
    'idiomapapuano'                      => 'paa',
    'idiomaprácrito'                    => 'pra',
    'idiomaromânico'                    => 'roa',
    'idiomasalisano'                     => 'sal',
    'idiomasami'                         => 'smi',
    'idiomasdiversos'                    => 'mis',
    'idiomasemítico'                    => 'sem',
    'idiomasinotibetano'                 => 'sit',
    'idiomasioux'                        => 'sio',
    'idiomasmunda'                       => 'mun',
    'idiomasmúltiplos'                  => 'mul',
    'idiomasorábio'                     => 'wen',
    'idiomasurinamês'                   => 'srn',
    'idiomatailandês'                   => 'tai',
    'idiomatupi'                         => 'tup',
    'idiomawakashan'                     => 'wak',
    'idiomaíndico'                      => 'inc',
    'ido'                                => 'io',
    'ijo'                                => 'ijo',
    'ilocano'                            => 'ilo',
    'inarisami'                          => 'smn',
    'indonésio'                         => 'id',
    'inglês'                            => 'en',
    'inglêsamericano'                   => 'en_us',
    'inglêsarcaico'                     => 'ang',
    'inglêsaustraliano'                 => 'en_au',
    'inglêsbritânico'                  => 'en_gb',
    'inglêscanadense'                   => 'en_ca',
    'inglêsmédio'                      => 'enm',
    'inguche'                            => 'inh',
    'interlingue'                        => 'ie',
    'interlíngua'                       => 'ia',
    'inuktitut'                          => 'iu',
    'inupiaque'                          => 'ik',
    'ioruba'                             => 'yo',
    'iraniano'                           => 'ira',
    'irlandês'                          => 'ga',
    'irlandêsarcaico'                   => 'sga',
    'irlandêsmédio'                    => 'mga',
    'islandês'                          => 'is',
    'italiano'                           => 'it',
    'iídiche'                           => 'yi',
    'japonês'                           => 'ja',
    'javanês'                           => 'jv',
    'jju'                                => 'kaj',
    'judaicoarábico'                    => 'jrb',
    'judaicopersa'                       => 'jpr',
    'kabardiano'                         => 'kbd',
    'kabyle'                             => 'kab',
    'kachin'                             => 'kac',
    'kalmyk'                             => 'xal',
    'kamba'                              => 'kam',
    'karachaybalkar'                     => 'krc',
    'karakalpak'                         => 'kaa',
    'karen'                              => 'kar',
    'kashubian'                          => 'csb',
    'kawi'                               => 'kaw',
    'khasi'                              => 'kha',
    'khotanês'                          => 'kho',
    'kinyarwanda'                        => 'rw',
    'klingon'                            => 'tlh',
    'komi'                               => 'kv',
    'koro'                               => 'kfo',
    'kosraean'                           => 'kos',
    'kpelle'                             => 'kpe',
    'kru'                                => 'kro',
    'kuanyama'                           => 'kj',
    'kumyk'                              => 'kum',
    'kurukh'                             => 'kru',
    'kutenai'                            => 'kut',
    'ladino'                             => 'lad',
    'lahnda'                             => 'lah',
    'lamba'                              => 'lam',
    'laosiano'                           => 'lo',
    'latim'                              => 'la',
    'letão'                             => 'lv',
    'lezghian'                           => 'lez',
    'limburguês'                        => 'li',
    'lingala'                            => 'ln',
    'linguagemdesinais'                  => 'sgn',
    'lituano'                            => 'lt',
    'lojban'                             => 'jbo',
    'lozi'                               => 'loz',
    'lubacatanga'                        => 'lu',
    'lubalulua'                          => 'lua',
    'luganda'                            => 'lg',
    'luiseno'                            => 'lui',
    'lulesami'                           => 'smj',
    'lunda'                              => 'lun',
    'luo'                                => 'luo',
    'lushai'                             => 'lus',
    'luxemburguês'                      => 'lb',
    'macedônio'                         => 'mk',
    'madurês'                           => 'mad',
    'magahi'                             => 'mag',
    'maia'                               => 'myn',
    'maithili'                           => 'mai',
    'makasar'                            => 'mak',
    'malaiala'                           => 'ml',
    'malaio'                             => 'ms',
    'malgaxe'                            => 'mg',
    'maltês'                            => 'mt',
    'manchu'                             => 'mnc',
    'mandar'                             => 'mdr',
    'mandinga'                           => 'man',
    'manipuri'                           => 'mni',
    'manx'                               => 'gv',
    'maori'                              => 'mi',
    'marata'                             => 'mr',
    'mari'                               => 'chm',
    'marshalês'                         => 'mh',
    'marwari'                            => 'mwr',
    'massai'                             => 'mas',
    'mende'                              => 'men',
    'minangkabau'                        => 'min',
    'miquemaque'                         => 'mic',
    'mirandês'                          => 'mwl',
    'mocsa'                              => 'mdf',
    'mohawk'                             => 'moh',
    'moldávio'                          => 'mo',
    'mongo'                              => 'lol',
    'mongol'                             => 'mn',
    'morisyen'                           => 'mfe',
    'mossi'                              => 'mos',
    'napolitano'                         => 'nap',
    'nauruano'                           => 'na',
    'navajo'                             => 'nv',
    'ndebeledonorte'                     => 'nd',
    'ndebeledosul'                       => 'nr',
    'nepali'                             => 'ne',
    'newari'                             => 'new',
    'newariclássico'                    => 'nwc',
    'nianja'                             => 'ny',
    'nias'                               => 'nia',
    'niueano'                            => 'niu',
    'nko'                                => 'nqo',
    'nogai'                              => 'nog',
    'norueguês'                         => 'no',
    'nyamwezi'                           => 'nym',
    'nyankole'                           => 'nyn',
    'nynorsknorueguês'                  => 'nn',
    'nyoro'                              => 'nyo',
    'nzima'                              => 'nzi',
    'náuatle'                           => 'nah',
    'nórdicoarcaico'                    => 'non',
    'occitânico'                        => 'oc',
    'ojibwa'                             => 'oj',
    'oriya'                              => 'or',
    'oromo'                              => 'om',
    'osage'                              => 'osa',
    'ossetic'                            => 'os',
    'palauano'                           => 'pau',
    'pampanga'                           => 'pam',
    'pangasinã'                         => 'pag',
    'panjabi'                            => 'pa',
    'papiamento'                         => 'pap',
    'pashto'                             => 'ps',
    'persa'                              => 'fa',
    'persaarcaico'                       => 'peo',
    'pohnpeian'                          => 'pon',
    'polonês'                           => 'pl',
    'português'                         => 'pt',
    'portuguêsdobrasil'                 => 'pt_br',
    'portuguêsibérico'                 => 'pt_pt',
    'provençalarcaico'                  => 'pro',
    'pálavi'                            => 'pal',
    'páli'                              => 'pi',
    'quicuio'                            => 'ki',
    'quimbundo'                          => 'kmb',
    'quirguiz'                           => 'ky',
    'quíchua'                           => 'qu',
    'rajastani'                          => 'raj',
    'rapanui'                            => 'rap',
    'rarotongano'                        => 'rar',
    'retoromano'                         => 'rm',
    'romani'                             => 'rom',
    'romeno'                             => 'ro',
    'rundi'                              => 'rn',
    'russo'                              => 'ru',
    'samidonorte'                        => 'se',
    'samidosul'                          => 'sma',
    'samoano'                            => 'sm',
    'sandawe'                            => 'sad',
    'sango'                              => 'sg',
    'santali'                            => 'sat',
    'sardo'                              => 'sc',
    'sasak'                              => 'sas',
    'selkup'                             => 'sel',
    'semconteúdolinguístico'           => 'zxx',
    'serere'                             => 'srr',
    'servocroata'                        => 'sh',
    'shan'                               => 'shn',
    'shona'                              => 'sn',
    'sichuanyi'                          => 'ii',
    'siciliano'                          => 'scn',
    'sidamo'                             => 'sid',
    'siksika'                            => 'bla',
    'sindi'                              => 'sd',
    'siríaco'                           => 'syr',
    'siríacoclássico'                  => 'syc',
    'skoltsami'                          => 'sms',
    'slave'                              => 'den',
    'sogdiano'                           => 'sog',
    'somali'                             => 'so',
    'songai'                             => 'son',
    'soninquê'                          => 'snk',
    'sorábiosuperior'                   => 'hsb',
    'sosso'                              => 'sus',
    'sotodosul'                          => 'st',
    'sotosetentrional'                   => 'nso',
    'suaili'                             => 'sw',
    'sueco'                              => 'sv',
    'sukuma'                             => 'suk',
    'sumério'                           => 'sux',
    'sundanês'                          => 'su',
    'swati'                              => 'ss',
    'sânscrito'                         => 'sa',
    'sérvio'                            => 'sr',
    'sérviobaixo'                       => 'dsb',
    'símbolosblis'                      => 'zbl',
    'tadjique'                           => 'tg',
    'tagalo'                             => 'tl',
    'tailandês'                         => 'th',
    'taitiano'                           => 'ty',
    'tamaxeque'                          => 'tmh',
    'taroko'                             => 'trv',
    'tatar'                              => 'tt',
    'tcheco'                             => 'cs',
    'telugu'                             => 'te',
    'tereno'                             => 'ter',
    'tibetano'                           => 'bo',
    'tigré'                             => 'tig',
    'tigrínia'                          => 'ti',
    'timne'                              => 'tem',
    'tiv'                                => 'tiv',
    'tlinguite'                          => 'tli',
    'tokpisin'                           => 'tpi',
    'tonganês'                          => 'to',
    'tonganêsdenyasa'                   => 'tog',
    'toquelauano'                        => 'tkl',
    'tsimshian'                          => 'tsi',
    'tsonga'                             => 'ts',
    'tswana'                             => 'tn',
    'tumbuka'                            => 'tum',
    'turco'                              => 'tr',
    'turcodacrimeia'                     => 'crh',
    'turcomano'                          => 'tk',
    'turcootomano'                       => 'ota',
    'tuvaluano'                          => 'tvl',
    'tuvinian'                           => 'tyv',
    'twi'                                => 'tw',
    'tyap'                               => 'kcg',
    'tâmil'                             => 'ta',
    'tétum'                             => 'tet',
    'ucraniano'                          => 'uk',
    'udmurt'                             => 'udm',
    'ugarítico'                         => 'uga',
    'uighur'                             => 'ug',
    'umbundu'                            => 'umb',
    'urdu'                               => 'ur',
    'usbeque'                            => 'uz',
    'uólofe'                            => 'wo',
    'vai'                                => 'vai',
    'valão'                             => 'wa',
    'venda'                              => 've',
    'vietnamita'                         => 'vi',
    'volapuque'                          => 'vo',
    'votic'                              => 'vot',
    'walamo'                             => 'wal',
    'waray'                              => 'war',
    'washo'                              => 'was',
    'xosa'                               => 'xh',
    'yao'                                => 'yao',
    'yapese'                             => 'yap',
    'zande'                              => 'znd',
    'zapoteca'                           => 'zap',
    'zaza'                               => 'zza',
    'zenaga'                             => 'zen',
    'zhuang'                             => 'za',
    'zulu'                               => 'zu',
    'zunhi'                              => 'zun',
    'árabe'                             => 'ar',
);

1;
