package Locales::DB::Territory::gsw;

# Auto generated from CLDR

$Locales::DB::Territory::gsw::VERSION = '0.02';

$Locales::DB::Territory::gsw::cldr_version = '1.7.1';

%Locales::DB::Territory::gsw::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "Veräinigti\ Arabischi\ Emiräät",
    'af' => 'Afganischtan',
    'ag' => "Antigua\ und\ Barbuda",
    'ai' => 'Anguilla',
    'al' => 'Albaanie',
    'am' => 'Armeenie',
    'an' => "Niderländischi\ Antille",
    'ao' => 'Angoola',
    'aq' => 'Antarktis',
    'ar' => 'Argentiinie',
    'as' => "Amerikaanisch\-Samoa",
    'at' => 'Ööschtriich',
    'au' => 'Auschtraalie',
    'aw' => 'Aruba',
    'ax' => "Aaland\-Insle",
    'az' => 'Aserbäidschan',
    'ba' => "Bosnie\ und\ Herzegowina",
    'bb' => 'Barbados',
    'bd' => 'Bangladesch',
    'be' => 'Belgie',
    'bf' => "Burkina\ Faaso",
    'bg' => 'Bulgaarie',
    'bh' => 'Bachräin',
    'bi' => 'Burundi',
    'bj' => 'Benin',
    'bl' => "St\.\ Barthelemi",
    'bm' => 'Bermuuda',
    'bn' => "Brunäi\ Tarussalam",
    'bo' => 'Boliivie',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brasilie',
    'bs' => 'Bahaamas',
    'bt' => 'Bhutan',
    'bv' => "Bouvet\-Insle",
    'bw' => 'Botswana',
    'by' => 'Wiissrussland',
    'bz' => 'Belize',
    'ca' => 'Kanada',
    'cc' => "Kokos\-Insle",
    'cd' => "Temokraatischi\ Republik\ Kongo",
    'cf' => "Zentraalafrikaanischi\ Republik",
    'cg' => 'Kongo',
    'ch' => 'Schwiiz',
    'ci' => 'Elfebäiküschte',
    'ck' => "Cook\-Insle",
    'cl' => 'Tschile',
    'cm' => 'Kamerun',
    'cn' => 'Chiina',
    'co' => 'Kolumbie',
    'cr' => "Coschta\ Rica",
    'cs' => "Särbie\ und\ Monteneegro",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Kuba',
    'cv' => "Kap\ Verde",
    'cx' => "Wienachts\-Insle",
    'cy' => 'Tsüpere',
    'cz' => "Tschechischi\ Republik",
    'dd' => "East\ Germany",
    'de' => 'Tüütschland',
    'dj' => 'Tschibuuti',
    'dk' => 'Tänemark',
    'dm' => 'Tominica',
    'do' => "Tominikaanischi\ Republik",
    'dz' => 'Algeerie',
    'ec' => 'Ecuador',
    'ee' => 'Eestland',
    'eg' => 'Ägüpte',
    'eh' => 'Weschtsahara',
    'er' => 'Äritreea',
    'es' => 'Schpanie',
    'et' => 'Äzioopie',
    'fi' => 'Finnland',
    'fj' => 'Fitschi',
    'fk' => "Falkland\-Insle",
    'fm' => 'Mikroneesie',
    'fo' => 'Färöer',
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Frankriich',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabun',
    'gb' => "Veräinigts\ Chönigriich",
    'gd' => 'Grenada',
    'ge' => 'Geoorgie',
    'gf' => "Französisch\-Guäjaana",
    'gg' => 'Gäärnsi',
    'gh' => 'Gaana',
    'gi' => 'Gibraltar',
    'gl' => 'Gröönland',
    'gm' => 'Gambia',
    'gn' => 'Gineea',
    'gp' => 'Guadälup',
    'gq' => 'Äquatoriaalgineea',
    'gr' => 'Griecheland',
    'gs' => "Süüdgeorgie\ und\ d’süüdlichi\ Sändwitsch\-Insle",
    'gt' => 'Guatemaala',
    'gu' => 'Guam',
    'gw' => "Gineea\-Bissau",
    'gy' => 'Guäjaana',
    'hk' => 'Hongkong',
    'hm' => "Höörd\-\ und\ MäcDonald\-Insle",
    'hn' => 'Honduras',
    'hr' => 'Kroaazie',
    'ht' => 'Haiti',
    'hu' => 'Ungarn',
    'id' => 'Indoneesie',
    'ie' => 'Irland',
    'il' => 'Israel',
    'im' => "Insle\ vo\ Män",
    'in' => 'Indie',
    'io' => "Britischs\ Territoorium\ im\ Indische\ Oozean",
    'iq' => 'Iraak',
    'ir' => 'Iraan',
    'is' => 'Iisland',
    'it' => 'Itaalie',
    'je' => 'Dschörsi',
    'jm' => 'Dschamäika',
    'jo' => 'Jordaanie',
    'jp' => 'Japan',
    'jt' => "Johnston\ Island",
    'ke' => 'Keenia',
    'kg' => 'Kirgiisischtan',
    'kh' => 'Kambodscha',
    'ki' => 'Kiribaati',
    'km' => 'Komoore',
    'kn' => "St\.\ Kitts\ und\ Niuwis",
    'kp' => "Demokraatischi\ Volksrepublik\ Koreea",
    'kr' => "Republik\ Koreea",
    'kw' => 'Kuwäit',
    'ky' => "Käimän\-Insle",
    'kz' => 'Kasachschtan',
    'la' => 'Laaos',
    'lb' => 'Libanon',
    'lc' => "Sankta\ Lutschiia",
    'li' => 'Liächteschtäi',
    'lk' => "Schri\ Lanka",
    'lr' => 'Libeeria',
    'ls' => 'Lesooto',
    'lt' => 'Littaue',
    'lu' => 'Luxemburg',
    'lv' => 'Lettland',
    'ly' => 'Lüübie',
    'ma' => 'Marokko',
    'mc' => 'Monaco',
    'md' => "Republik\ Moldau",
    'me' => 'Monteneegro',
    'mf' => "St\.\ Martin",
    'mg' => 'Madagaschkar',
    'mh' => 'Marshallinsle',
    'mi' => "Midway\ Islands",
    'mk' => 'Mazedoonie',
    'ml' => 'Maali',
    'mm' => 'Müanmar',
    'mn' => 'Mongolei',
    'mo' => 'Macao',
    'mp' => "Nördlichi\ Mariaane",
    'mq' => 'Martinigg',
    'mr' => 'Mauretaanie',
    'ms' => 'Moosörrat',
    'mt' => 'Malta',
    'mu' => 'Mauriizius',
    'mv' => 'Malediiwe',
    'mw' => 'Malaawi',
    'mx' => 'Mexiko',
    'my' => 'Malaisia',
    'mz' => 'Mosambik',
    'na' => 'Namiibia',
    'nc' => 'Nöikaledoonie',
    'ne' => 'Niger',
    'nf' => "Norfolk\-Insle",
    'ng' => 'Nigeeria',
    'ni' => 'Nicaraagua',
    'nl' => 'Niderland',
    'no' => 'Norweege',
    'np' => 'Neepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => 'Nöiseeland',
    'om' => 'Omaan',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Peru',
    'pf' => "Französisch\-Polineesie",
    'pg' => "Papua\-Neuguinea",
    'ph' => 'Philippiine',
    'pk' => 'Pakischtan',
    'pl' => 'Poole',
    'pm' => "St\.\ Pierr\ und\ Miggelo",
    'pn' => 'Pitggäärn',
    'pr' => "Puerto\ Riggo",
    'ps' => "Paläschtinänsischi\ Gebiet",
    'pt' => 'Portugal',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paraguai',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Ggatar',
    'qo' => "Üssers\ Ozeaanie",
    'qu' => "Europääischi\ Unioon",
    're' => 'Reünioon',
    'ro' => 'Rumäänie',
    'rs' => 'Särbie',
    'ru' => "Russischi\ Föderazioon",
    'rw' => 'Ruanda',
    'sa' => "Saudi\-Araabie",
    'sb' => 'Salomoone',
    'sc' => 'Seischälle',
    'sd' => 'Sudan',
    'se' => 'Schweede',
    'sg' => 'Singapuur',
    'sh' => "St\.\ Helena",
    'si' => 'Sloweenie',
    'sj' => "Svalbard\ und\ Jaan\ Määie",
    'sk' => 'Slowakäi',
    'sl' => "Sierra\ Leoone",
    'sm' => "San\ Mariino",
    'sn' => 'Senegal',
    'so' => 'Somaalia',
    'sr' => 'Surinam',
    'st' => "Sao\ Tome\ und\ Prinssipe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salvador",
    'sy' => 'Süürie',
    'sz' => 'Swasiland',
    'tc' => "Törks\-\ und\ Gaiggos\-Insle",
    'td' => 'Tschad',
    'tf' => "Französischi\ Süüd\-\ und\ Antarktisgebiet",
    'tg' => 'Toogo',
    'th' => 'Thailand',
    'tj' => 'Tadschikischtan',
    'tk' => 'Tokelau',
    'tl' => 'Oschttimor',
    'tm' => 'Turkmeenischtan',
    'tn' => 'Tuneesie',
    'to' => 'Tonga',
    'tr' => 'Türggei',
    'tt' => "Trinidad\ und\ Tobaago",
    'tv' => 'Tuvalu',
    'tw' => 'Taiwan',
    'tz' => 'Tansaniia',
    'ua' => 'Ukraiine',
    'ug' => 'Uganda',
    'um' => "Amerikanisch\-Ozeaanie",
    'us' => "Veräinigti\ Schtaate",
    'uy' => 'Uruguay',
    'uz' => 'Uschbeekischtan',
    'va' => 'Vatikanstadt',
    'vc' => "Sankt\ Wässä\ und\ d’Grönadiine",
    'vd' => "North\ Vietnam",
    've' => 'Venezueela',
    'vg' => "Britischi\ Jungfere\-Insle",
    'vi' => "Amerikaanischi\ Jungfere\-Insle",
    'vn' => 'Wietnam',
    'vu' => 'Wanuatu',
    'wf' => "Wallis\ und\ Futuuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samooa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Jeeme',
    'yt' => 'Majott',
    'za' => 'Süüdafrika',
    'zm' => 'Sambia',
    'zw' => 'Simbabwe',
    'zz' => "Unbekannti\ oder\ ungültigi\ Regioon",
);

%Locales::DB::Territory::gsw::name_to_code = (
    'aalandinsle'                                     => 'ax',
    'afganischtan'                                    => 'af',
    'albaanie'                                        => 'al',
    'algeerie'                                        => 'dz',
    'amerikaanischijungfereinsle'                     => 'vi',
    'amerikaanischsamoa'                              => 'as',
    'amerikanischozeaanie'                            => 'um',
    'andorra'                                         => 'ad',
    'angoola'                                         => 'ao',
    'anguilla'                                        => 'ai',
    'antarktis'                                       => 'aq',
    'antiguaundbarbuda'                               => 'ag',
    'argentiinie'                                     => 'ar',
    'armeenie'                                        => 'am',
    'aruba'                                           => 'aw',
    'aserbäidschan'                                  => 'az',
    'auschtraalie'                                    => 'au',
    'bachräin'                                       => 'bh',
    'bahaamas'                                        => 'bs',
    'bangladesch'                                     => 'bd',
    'barbados'                                        => 'bb',
    'belgie'                                          => 'be',
    'belize'                                          => 'bz',
    'benin'                                           => 'bj',
    'bermuuda'                                        => 'bm',
    'bhutan'                                          => 'bt',
    'boliivie'                                        => 'bo',
    'bosnieundherzegowina'                            => 'ba',
    'botswana'                                        => 'bw',
    'bouvetinsle'                                     => 'bv',
    'brasilie'                                        => 'br',
    'britischijungfereinsle'                          => 'vg',
    'britischsterritooriumimindischeoozean'           => 'io',
    'britishantarcticterritory'                       => 'bq',
    'brunäitarussalam'                               => 'bn',
    'bulgaarie'                                       => 'bg',
    'burkinafaaso'                                    => 'bf',
    'burundi'                                         => 'bi',
    'cantonandenderburyislands'                       => 'ct',
    'chiina'                                          => 'cn',
    'cookinsle'                                       => 'ck',
    'coschtarica'                                     => 'cr',
    'demokraatischivolksrepublikkoreea'               => 'kp',
    'dronningmaudland'                                => 'nq',
    'dschamäika'                                     => 'jm',
    'dschörsi'                                       => 'je',
    'eastgermany'                                     => 'dd',
    'ecuador'                                         => 'ec',
    'eestland'                                        => 'ee',
    'elfebäiküschte'                                => 'ci',
    'elsalvador'                                      => 'sv',
    'europääischiunioon'                            => 'qu',
    'falklandinsle'                                   => 'fk',
    'finnland'                                        => 'fi',
    'fitschi'                                         => 'fj',
    'frankriich'                                      => 'fr',
    'französischguäjaana'                           => 'gf',
    'französischisüüdundantarktisgebiet'           => 'tf',
    'französischpolineesie'                          => 'pf',
    'frenchsouthernandantarcticterritories'           => 'fq',
    'färöer'                                        => 'fo',
    'gaana'                                           => 'gh',
    'gabun'                                           => 'ga',
    'gambia'                                          => 'gm',
    'geoorgie'                                        => 'ge',
    'ggatar'                                          => 'qa',
    'gibraltar'                                       => 'gi',
    'gineea'                                          => 'gn',
    'gineeabissau'                                    => 'gw',
    'grenada'                                         => 'gd',
    'griecheland'                                     => 'gr',
    'gröönland'                                     => 'gl',
    'guadälup'                                       => 'gp',
    'guam'                                            => 'gu',
    'guatemaala'                                      => 'gt',
    'guäjaana'                                       => 'gy',
    'gäärnsi'                                       => 'gg',
    'haiti'                                           => 'ht',
    'honduras'                                        => 'hn',
    'hongkong'                                        => 'hk',
    'höördundmäcdonaldinsle'                       => 'hm',
    'iisland'                                         => 'is',
    'indie'                                           => 'in',
    'indoneesie'                                      => 'id',
    'inslevomän'                                     => 'im',
    'iraak'                                           => 'iq',
    'iraan'                                           => 'ir',
    'irland'                                          => 'ie',
    'israel'                                          => 'il',
    'itaalie'                                         => 'it',
    'japan'                                           => 'jp',
    'jeeme'                                           => 'ye',
    'johnstonisland'                                  => 'jt',
    'jordaanie'                                       => 'jo',
    'kambodscha'                                      => 'kh',
    'kamerun'                                         => 'cm',
    'kanada'                                          => 'ca',
    'kapverde'                                        => 'cv',
    'kasachschtan'                                    => 'kz',
    'keenia'                                          => 'ke',
    'kirgiisischtan'                                  => 'kg',
    'kiribaati'                                       => 'ki',
    'kokosinsle'                                      => 'cc',
    'kolumbie'                                        => 'co',
    'komoore'                                         => 'km',
    'kongo'                                           => 'cg',
    'kroaazie'                                        => 'hr',
    'kuba'                                            => 'cu',
    'kuwäit'                                         => 'kw',
    'käimäninsle'                                   => 'ky',
    'laaos'                                           => 'la',
    'lesooto'                                         => 'ls',
    'lettland'                                        => 'lv',
    'libanon'                                         => 'lb',
    'libeeria'                                        => 'lr',
    'littaue'                                         => 'lt',
    'liächteschtäi'                                 => 'li',
    'luxemburg'                                       => 'lu',
    'lüübie'                                        => 'ly',
    'maali'                                           => 'ml',
    'macao'                                           => 'mo',
    'madagaschkar'                                    => 'mg',
    'majott'                                          => 'yt',
    'malaawi'                                         => 'mw',
    'malaisia'                                        => 'my',
    'malediiwe'                                       => 'mv',
    'malta'                                           => 'mt',
    'marokko'                                         => 'ma',
    'marshallinsle'                                   => 'mh',
    'martinigg'                                       => 'mq',
    'mauretaanie'                                     => 'mr',
    'mauriizius'                                      => 'mu',
    'mazedoonie'                                      => 'mk',
    'metropolitanfrance'                              => 'fx',
    'mexiko'                                          => 'mx',
    'midwayislands'                                   => 'mi',
    'mikroneesie'                                     => 'fm',
    'monaco'                                          => 'mc',
    'mongolei'                                        => 'mn',
    'monteneegro'                                     => 'me',
    'moosörrat'                                      => 'ms',
    'mosambik'                                        => 'mz',
    'müanmar'                                        => 'mm',
    'namiibia'                                        => 'na',
    'nauru'                                           => 'nr',
    'neepal'                                          => 'np',
    'neutralzone'                                     => 'nt',
    'nicaraagua'                                      => 'ni',
    'niderland'                                       => 'nl',
    'niderländischiantille'                          => 'an',
    'nigeeria'                                        => 'ng',
    'niger'                                           => 'ne',
    'niue'                                            => 'nu',
    'norfolkinsle'                                    => 'nf',
    'northvietnam'                                    => 'vd',
    'norweege'                                        => 'no',
    'nöikaledoonie'                                  => 'nc',
    'nöiseeland'                                     => 'nz',
    'nördlichimariaane'                              => 'mp',
    'omaan'                                           => 'om',
    'oschttimor'                                      => 'tl',
    'pacificislandstrustterritory'                    => 'pc',
    'pakischtan'                                      => 'pk',
    'palau'                                           => 'pw',
    'paläschtinänsischigebiet'                      => 'ps',
    'panama'                                          => 'pa',
    'panamacanalzone'                                 => 'pz',
    'papuaneuguinea'                                  => 'pg',
    'paraguai'                                        => 'py',
    'peoplesdemocraticrepublicofyemen'                => 'yd',
    'peru'                                            => 'pe',
    'philippiine'                                     => 'ph',
    'pitggäärn'                                     => 'pn',
    'poole'                                           => 'pl',
    'portugal'                                        => 'pt',
    'puertoriggo'                                     => 'pr',
    'republikkoreea'                                  => 'kr',
    'republikmoldau'                                  => 'md',
    'reünioon'                                       => 're',
    'ruanda'                                          => 'rw',
    'rumäänie'                                      => 'ro',
    'russischiföderazioon'                           => 'ru',
    'salomoone'                                       => 'sb',
    'sambia'                                          => 'zm',
    'samooa'                                          => 'ws',
    'sanktalutschiia'                                 => 'lc',
    'sanktwässäundd’grönadiine'                  => 'vc',
    'sanmariino'                                      => 'sm',
    'saotomeundprinssipe'                             => 'st',
    'saudiaraabie'                                    => 'sa',
    'schpanie'                                        => 'es',
    'schrilanka'                                      => 'lk',
    'schweede'                                        => 'se',
    'schwiiz'                                         => 'ch',
    'seischälle'                                     => 'sc',
    'senegal'                                         => 'sn',
    'sierraleoone'                                    => 'sl',
    'simbabwe'                                        => 'zw',
    'singapuur'                                       => 'sg',
    'slowakäi'                                       => 'sk',
    'sloweenie'                                       => 'si',
    'somaalia'                                        => 'so',
    "st\.barthelemi"                                  => 'bl',
    "st\.helena"                                      => 'sh',
    "st\.kittsundniuwis"                              => 'kn',
    "st\.martin"                                      => 'mf',
    "st\.pierrundmiggelo"                             => 'pm',
    'sudan'                                           => 'sd',
    'surinam'                                         => 'sr',
    'svalbardundjaanmääie'                          => 'sj',
    'swasiland'                                       => 'sz',
    'särbie'                                         => 'rs',
    'särbieundmonteneegro'                           => 'cs',
    'süüdafrika'                                    => 'za',
    'süüdgeorgieundd’süüdlichisändwitschinsle' => 'gs',
    'süürie'                                        => 'sy',
    'tadschikischtan'                                 => 'tj',
    'taiwan'                                          => 'tw',
    'tansaniia'                                       => 'tz',
    'temokraatischirepublikkongo'                     => 'cd',
    'thailand'                                        => 'th',
    'tokelau'                                         => 'tk',
    'tominica'                                        => 'dm',
    'tominikaanischirepublik'                         => 'do',
    'tonga'                                           => 'to',
    'toogo'                                           => 'tg',
    'trinidadundtobaago'                              => 'tt',
    'tschad'                                          => 'td',
    'tschechischirepublik'                            => 'cz',
    'tschibuuti'                                      => 'dj',
    'tschile'                                         => 'cl',
    'tsüpere'                                        => 'cy',
    'tuneesie'                                        => 'tn',
    'turkmeenischtan'                                 => 'tm',
    'tuvalu'                                          => 'tv',
    'tänemark'                                       => 'dk',
    'törksundgaiggosinsle'                           => 'tc',
    'türggei'                                        => 'tr',
    'tüütschland'                                   => 'de',
    "u\.s\.miscellaneouspacificislands"               => 'pu',
    'uganda'                                          => 'ug',
    'ukraiine'                                        => 'ua',
    'unbekanntioderungültigiregioon'                 => 'zz',
    'ungarn'                                          => 'hu',
    'unionofsovietsocialistrepublics'                 => 'su',
    'uruguay'                                         => 'uy',
    'uschbeekischtan'                                 => 'uz',
    'vatikanstadt'                                    => 'va',
    'venezueela'                                      => 've',
    'veräinigtiarabischiemiräät'                   => 'ae',
    'veräinigtischtaate'                             => 'us',
    'veräinigtschönigriich'                         => 'gb',
    'wakeisland'                                      => 'wk',
    'wallisundfutuuna'                                => 'wf',
    'wanuatu'                                         => 'vu',
    'weschtsahara'                                    => 'eh',
    'wienachtsinsle'                                  => 'cx',
    'wietnam'                                         => 'vn',
    'wiissrussland'                                   => 'by',
    'zentraalafrikaanischirepublik'                   => 'cf',
    'Ägüpte'                                        => 'eg',
    'Äquatoriaalgineea'                              => 'gq',
    'Äritreea'                                       => 'er',
    'Äzioopie'                                       => 'et',
    'Ööschtriich'                                   => 'at',
    'Üssersozeaanie'                                 => 'qo',
);

1;

