package Locales::DB::Territory::nb;

# Auto generated from CLDR

$Locales::DB::Territory::nb::VERSION = '0.02';

$Locales::DB::Territory::nb::cldr_version = '1.7.1';

%Locales::DB::Territory::nb::code_to_name = (
    'ad' => 'Andorra',
    'ae' => "De\ forente\ arabiske\ emirater",
    'af' => 'Afghanistan',
    'ag' => "Antigua\ og\ Barbuda",
    'ai' => 'Anguilla',
    'al' => 'Albania',
    'am' => 'Armenia',
    'an' => "De\ nederlandske\ antiller",
    'ao' => 'Angola',
    'aq' => 'Antarktis',
    'ar' => 'Argentina',
    'as' => "Amerikansk\ Samoa",
    'at' => 'Østerrike',
    'au' => 'Australia',
    'aw' => 'Aruba',
    'ax' => 'Åland',
    'az' => 'Aserbajdsjan',
    'ba' => "Bosnia\-Hercegovina",
    'bb' => 'Barbados',
    'bd' => 'Bangladesh',
    'be' => 'Belgia',
    'bf' => "Burkina\ Faso",
    'bg' => 'Bulgaria',
    'bh' => 'Bahrain',
    'bi' => 'Burundi',
    'bj' => 'Benin',
    'bl' => "Saint\ Barthélemy",
    'bm' => 'Bermuda',
    'bn' => "Brunei\ Darussalam",
    'bo' => 'Bolivia',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'Brasil',
    'bs' => 'Bahamas',
    'bt' => 'Bhutan',
    'bv' => 'Bouvetøya',
    'bw' => 'Botswana',
    'by' => 'Hviterussland',
    'bz' => 'Belize',
    'ca' => 'Canada',
    'cc' => 'Kokosøyene',
    'cd' => "Kongo\-Kinshasa",
    'cf' => "Den\ sentralafrikanske\ republikk",
    'cg' => "Kongo\-Brazzaville",
    'ch' => 'Sveits',
    'ci' => 'Elfenbenskysten',
    'ck' => 'Cookøyene',
    'cl' => 'Chile',
    'cm' => 'Kamerun',
    'cn' => 'Kina',
    'co' => 'Colombia',
    'cr' => "Costa\ Rica",
    'cs' => "Serbia\ og\ Montenegro",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'Cuba',
    'cv' => "Kapp\ Verde",
    'cx' => 'Christmasøya',
    'cy' => 'Kypros',
    'cz' => 'Tsjekkia',
    'dd' => "East\ Germany",
    'de' => 'Tyskland',
    'dj' => 'Djibouti',
    'dk' => 'Danmark',
    'dm' => 'Dominica',
    'do' => "Den\ dominikanske\ republikk",
    'dz' => 'Algerie',
    'ec' => 'Ecuador',
    'ee' => 'Estland',
    'eg' => 'Egypt',
    'eh' => "Vest\-Sahara",
    'er' => 'Eritrea',
    'es' => 'Spania',
    'et' => 'Etiopia',
    'fi' => 'Finland',
    'fj' => 'Fiji',
    'fk' => 'Falklandsøyene',
    'fm' => 'Mikronesiaføderasjonen',
    'fo' => 'Færøyene',
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'Frankrike',
    'fx' => "Metropolitan\ France",
    'ga' => 'Gabon',
    'gb' => 'Storbritannia',
    'gd' => 'Grenada',
    'ge' => 'Georgia',
    'gf' => "Fransk\ Guyana",
    'gg' => 'Guernsey',
    'gh' => 'Ghana',
    'gi' => 'Gibraltar',
    'gl' => 'Grønland',
    'gm' => 'Gambia',
    'gn' => 'Guinea',
    'gp' => 'Guadeloupe',
    'gq' => "Ekvatorial\-Guinea",
    'gr' => 'Hellas',
    'gs' => "Sør\-Georgia\ og\ de\ sørlige\ Sandwich\-øyene",
    'gt' => 'Guatemala',
    'gu' => 'Guam',
    'gw' => "Guinea\-Bissau",
    'gy' => 'Guyana',
    'hk' => 'Hongkong',
    'hm' => "Heardøya\ og\ McDonaldøyene",
    'hn' => 'Honduras',
    'hr' => 'Kroatia',
    'ht' => 'Haiti',
    'hu' => 'Ungarn',
    'id' => 'Indonesia',
    'ie' => 'Irland',
    'il' => 'Israel',
    'im' => 'Man',
    'in' => 'India',
    'io' => "Britiske\ territorier\ i\ Indiahavet",
    'iq' => 'Irak',
    'ir' => 'Iran',
    'is' => 'Island',
    'it' => 'Italia',
    'je' => 'Jersey',
    'jm' => 'Jamaica',
    'jo' => 'Jordan',
    'jp' => 'Japan',
    'jt' => "Johnston\ Island",
    'ke' => 'Kenya',
    'kg' => 'Kirgisistan',
    'kh' => 'Kambodsja',
    'ki' => 'Kiribati',
    'km' => 'Komorene',
    'kn' => "St\.\ Kitts\ og\ Nevis",
    'kp' => "Nord\-Korea",
    'kr' => "Sør\-Korea",
    'kw' => 'Kuwait',
    'ky' => 'Caymanøyene',
    'kz' => 'Kasakhstan',
    'la' => 'Laos',
    'lb' => 'Libanon',
    'lc' => "St\.\ Lucia",
    'li' => 'Liechtenstein',
    'lk' => "Sri\ Lanka",
    'lr' => 'Liberia',
    'ls' => 'Lesotho',
    'lt' => 'Litauen',
    'lu' => 'Luxembourg',
    'lv' => 'Latvia',
    'ly' => 'Libya',
    'ma' => 'Marokko',
    'mc' => 'Monaco',
    'md' => 'Moldova',
    'me' => 'Montenegro',
    'mf' => "Saint\ Martin",
    'mg' => 'Madagaskar',
    'mh' => 'Marshalløyene',
    'mi' => "Midway\ Islands",
    'mk' => 'Makedonia',
    'ml' => 'Mali',
    'mm' => 'Myanmar',
    'mn' => 'Mongolia',
    'mo' => 'Macao',
    'mp' => "Nord\-Marianene",
    'mq' => 'Martinique',
    'mr' => 'Mauritania',
    'ms' => 'Montserrat',
    'mt' => 'Malta',
    'mu' => 'Mauritius',
    'mv' => 'Maldivene',
    'mw' => 'Malawi',
    'mx' => 'Mexico',
    'my' => 'Malaysia',
    'mz' => 'Mosambik',
    'na' => 'Namibia',
    'nc' => "Ny\-Caledonia",
    'ne' => 'Niger',
    'nf' => 'Norfolkøya',
    'ng' => 'Nigeria',
    'ni' => 'Nicaragua',
    'nl' => 'Nederland',
    'no' => 'Norge',
    'np' => 'Nepal',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'Nauru',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "New\ Zealand",
    'om' => 'Oman',
    'pa' => 'Panama',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'Peru',
    'pf' => "Fransk\ Polynesia",
    'pg' => "Papua\ Ny\-Guinea",
    'ph' => 'Filippinene',
    'pk' => 'Pakistan',
    'pl' => 'Polen',
    'pm' => "St\.\ Pierre\ og\ Miquelon",
    'pn' => 'Pitcairn',
    'pr' => "Puerto\ Rico",
    'ps' => "Palestinsk\ territorium",
    'pt' => 'Portugal',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'Palau',
    'py' => 'Paraguay',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'Qatar',
    'qo' => "avsidesliggende\ Oceania",
    'qu' => "Den\ europeiske\ union",
    're' => 'Reunion',
    'ro' => 'Romania',
    'rs' => 'Serbia',
    'ru' => 'Russland',
    'rw' => 'Rwanda',
    'sa' => "Saudi\-Arabia",
    'sb' => 'Salomonøyene',
    'sc' => 'Seychellene',
    'sd' => 'Sudan',
    'se' => 'Sverige',
    'sg' => 'Singapore',
    'sh' => "St\.\ Helena",
    'si' => 'Slovenia',
    'sj' => "Svalbard\ og\ Jan\ Mayen",
    'sk' => 'Slovakia',
    'sl' => "Sierra\ Leone",
    'sm' => "San\ Marino",
    'sn' => 'Senegal',
    'so' => 'Somalia',
    'sr' => 'Surinam',
    'st' => "São\ Tomé\ og\ Príncipe",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => "El\ Salvador",
    'sy' => 'Syria',
    'sz' => 'Swaziland',
    'tc' => "Turks\-\ og\ Caicosøyene",
    'td' => 'Tsjad',
    'tf' => "De\ franske\ sørterritorier",
    'tg' => 'Togo',
    'th' => 'Thailand',
    'tj' => 'Tadsjikistan',
    'tk' => 'Tokelau',
    'tl' => "Øst\-Timor",
    'tm' => 'Turkmenistan',
    'tn' => 'Tunisia',
    'to' => 'Tonga',
    'tr' => 'Tyrkia',
    'tt' => "Trinidad\ og\ Tobago",
    'tv' => 'Tuvalu',
    'tw' => 'Taiwan',
    'tz' => 'Tanzania',
    'ua' => 'Ukraina',
    'ug' => 'Uganda',
    'um' => "USAs\ ytre\ småøyer",
    'us' => 'USA',
    'uy' => 'Uruguay',
    'uz' => 'Usbekistan',
    'va' => 'Vatikanstaten',
    'vc' => "St\.\ Vincent\ og\ Grenadinene",
    'vd' => "North\ Vietnam",
    've' => 'Venezuela',
    'vg' => "De\ britiske\ jomfruøyene",
    'vi' => "De\ amerikanske\ jomfruøyene",
    'vn' => 'Vietnam',
    'vu' => 'Vanuatu',
    'wf' => "Wallis\ og\ Futuna",
    'wk' => "Wake\ Island",
    'ws' => 'Samoa',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'Jemen',
    'yt' => 'Mayotte',
    'za' => "Sør\-Afrika",
    'zm' => 'Zambia',
    'zw' => 'Zimbabwe',
    'zz' => "ukjent\ eller\ ugyldig\ område",
);

%Locales::DB::Territory::nb::name_to_code = (
    'afghanistan'                           => 'af',
    'albania'                               => 'al',
    'algerie'                               => 'dz',
    'amerikansksamoa'                       => 'as',
    'andorra'                               => 'ad',
    'angola'                                => 'ao',
    'anguilla'                              => 'ai',
    'antarktis'                             => 'aq',
    'antiguaogbarbuda'                      => 'ag',
    'argentina'                             => 'ar',
    'armenia'                               => 'am',
    'aruba'                                 => 'aw',
    'aserbajdsjan'                          => 'az',
    'australia'                             => 'au',
    'avsidesliggendeoceania'                => 'qo',
    'bahamas'                               => 'bs',
    'bahrain'                               => 'bh',
    'bangladesh'                            => 'bd',
    'barbados'                              => 'bb',
    'belgia'                                => 'be',
    'belize'                                => 'bz',
    'benin'                                 => 'bj',
    'bermuda'                               => 'bm',
    'bhutan'                                => 'bt',
    'bolivia'                               => 'bo',
    'bosniahercegovina'                     => 'ba',
    'botswana'                              => 'bw',
    'bouvetøya'                            => 'bv',
    'brasil'                                => 'br',
    'britishantarcticterritory'             => 'bq',
    'britisketerritorieriindiahavet'        => 'io',
    'bruneidarussalam'                      => 'bn',
    'bulgaria'                              => 'bg',
    'burkinafaso'                           => 'bf',
    'burundi'                               => 'bi',
    'canada'                                => 'ca',
    'cantonandenderburyislands'             => 'ct',
    'caymanøyene'                          => 'ky',
    'chile'                                 => 'cl',
    'christmasøya'                         => 'cx',
    'colombia'                              => 'co',
    'cookøyene'                            => 'ck',
    'costarica'                             => 'cr',
    'cuba'                                  => 'cu',
    'danmark'                               => 'dk',
    'deamerikanskejomfruøyene'             => 'vi',
    'debritiskejomfruøyene'                => 'vg',
    'deforentearabiskeemirater'             => 'ae',
    'defranskesørterritorier'              => 'tf',
    'dendominikanskerepublikk'              => 'do',
    'denederlandskeantiller'                => 'an',
    'deneuropeiskeunion'                    => 'qu',
    'densentralafrikanskerepublikk'         => 'cf',
    'djibouti'                              => 'dj',
    'dominica'                              => 'dm',
    'dronningmaudland'                      => 'nq',
    'eastgermany'                           => 'dd',
    'ecuador'                               => 'ec',
    'egypt'                                 => 'eg',
    'ekvatorialguinea'                      => 'gq',
    'elfenbenskysten'                       => 'ci',
    'elsalvador'                            => 'sv',
    'eritrea'                               => 'er',
    'estland'                               => 'ee',
    'etiopia'                               => 'et',
    'falklandsøyene'                       => 'fk',
    'fiji'                                  => 'fj',
    'filippinene'                           => 'ph',
    'finland'                               => 'fi',
    'frankrike'                             => 'fr',
    'franskguyana'                          => 'gf',
    'franskpolynesia'                       => 'pf',
    'frenchsouthernandantarcticterritories' => 'fq',
    'færøyene'                            => 'fo',
    'gabon'                                 => 'ga',
    'gambia'                                => 'gm',
    'georgia'                               => 'ge',
    'ghana'                                 => 'gh',
    'gibraltar'                             => 'gi',
    'grenada'                               => 'gd',
    'grønland'                             => 'gl',
    'guadeloupe'                            => 'gp',
    'guam'                                  => 'gu',
    'guatemala'                             => 'gt',
    'guernsey'                              => 'gg',
    'guinea'                                => 'gn',
    'guineabissau'                          => 'gw',
    'guyana'                                => 'gy',
    'haiti'                                 => 'ht',
    'heardøyaogmcdonaldøyene'             => 'hm',
    'hellas'                                => 'gr',
    'honduras'                              => 'hn',
    'hongkong'                              => 'hk',
    'hviterussland'                         => 'by',
    'india'                                 => 'in',
    'indonesia'                             => 'id',
    'irak'                                  => 'iq',
    'iran'                                  => 'ir',
    'irland'                                => 'ie',
    'island'                                => 'is',
    'israel'                                => 'il',
    'italia'                                => 'it',
    'jamaica'                               => 'jm',
    'japan'                                 => 'jp',
    'jemen'                                 => 'ye',
    'jersey'                                => 'je',
    'johnstonisland'                        => 'jt',
    'jordan'                                => 'jo',
    'kambodsja'                             => 'kh',
    'kamerun'                               => 'cm',
    'kappverde'                             => 'cv',
    'kasakhstan'                            => 'kz',
    'kenya'                                 => 'ke',
    'kina'                                  => 'cn',
    'kirgisistan'                           => 'kg',
    'kiribati'                              => 'ki',
    'kokosøyene'                           => 'cc',
    'komorene'                              => 'km',
    'kongobrazzaville'                      => 'cg',
    'kongokinshasa'                         => 'cd',
    'kroatia'                               => 'hr',
    'kuwait'                                => 'kw',
    'kypros'                                => 'cy',
    'laos'                                  => 'la',
    'latvia'                                => 'lv',
    'lesotho'                               => 'ls',
    'libanon'                               => 'lb',
    'liberia'                               => 'lr',
    'libya'                                 => 'ly',
    'liechtenstein'                         => 'li',
    'litauen'                               => 'lt',
    'luxembourg'                            => 'lu',
    'macao'                                 => 'mo',
    'madagaskar'                            => 'mg',
    'makedonia'                             => 'mk',
    'malawi'                                => 'mw',
    'malaysia'                              => 'my',
    'maldivene'                             => 'mv',
    'mali'                                  => 'ml',
    'malta'                                 => 'mt',
    'man'                                   => 'im',
    'marokko'                               => 'ma',
    'marshalløyene'                        => 'mh',
    'martinique'                            => 'mq',
    'mauritania'                            => 'mr',
    'mauritius'                             => 'mu',
    'mayotte'                               => 'yt',
    'metropolitanfrance'                    => 'fx',
    'mexico'                                => 'mx',
    'midwayislands'                         => 'mi',
    'mikronesiaføderasjonen'               => 'fm',
    'moldova'                               => 'md',
    'monaco'                                => 'mc',
    'mongolia'                              => 'mn',
    'montenegro'                            => 'me',
    'montserrat'                            => 'ms',
    'mosambik'                              => 'mz',
    'myanmar'                               => 'mm',
    'namibia'                               => 'na',
    'nauru'                                 => 'nr',
    'nederland'                             => 'nl',
    'nepal'                                 => 'np',
    'neutralzone'                           => 'nt',
    'newzealand'                            => 'nz',
    'nicaragua'                             => 'ni',
    'niger'                                 => 'ne',
    'nigeria'                               => 'ng',
    'niue'                                  => 'nu',
    'nordkorea'                             => 'kp',
    'nordmarianene'                         => 'mp',
    'norfolkøya'                           => 'nf',
    'norge'                                 => 'no',
    'northvietnam'                          => 'vd',
    'nycaledonia'                           => 'nc',
    'oman'                                  => 'om',
    'pacificislandstrustterritory'          => 'pc',
    'pakistan'                              => 'pk',
    'palau'                                 => 'pw',
    'palestinskterritorium'                 => 'ps',
    'panama'                                => 'pa',
    'panamacanalzone'                       => 'pz',
    'papuanyguinea'                         => 'pg',
    'paraguay'                              => 'py',
    'peoplesdemocraticrepublicofyemen'      => 'yd',
    'peru'                                  => 'pe',
    'pitcairn'                              => 'pn',
    'polen'                                 => 'pl',
    'portugal'                              => 'pt',
    'puertorico'                            => 'pr',
    'qatar'                                 => 'qa',
    'reunion'                               => 're',
    'romania'                               => 'ro',
    'russland'                              => 'ru',
    'rwanda'                                => 'rw',
    'saintbarthélemy'                      => 'bl',
    'saintmartin'                           => 'mf',
    'salomonøyene'                         => 'sb',
    'samoa'                                 => 'ws',
    'sanmarino'                             => 'sm',
    'saudiarabia'                           => 'sa',
    'senegal'                               => 'sn',
    'serbia'                                => 'rs',
    'serbiaogmontenegro'                    => 'cs',
    'seychellene'                           => 'sc',
    'sierraleone'                           => 'sl',
    'singapore'                             => 'sg',
    'slovakia'                              => 'sk',
    'slovenia'                              => 'si',
    'somalia'                               => 'so',
    'spania'                                => 'es',
    'srilanka'                              => 'lk',
    "st\.helena"                            => 'sh',
    "st\.kittsognevis"                      => 'kn',
    "st\.lucia"                             => 'lc',
    "st\.pierreogmiquelon"                  => 'pm',
    "st\.vincentoggrenadinene"              => 'vc',
    'storbritannia'                         => 'gb',
    'sudan'                                 => 'sd',
    'surinam'                               => 'sr',
    'svalbardogjanmayen'                    => 'sj',
    'sveits'                                => 'ch',
    'sverige'                               => 'se',
    'swaziland'                             => 'sz',
    'syria'                                 => 'sy',
    'sãotoméogpríncipe'                  => 'st',
    'sørafrika'                            => 'za',
    'sørgeorgiaogdesørligesandwichøyene' => 'gs',
    'sørkorea'                             => 'kr',
    'tadsjikistan'                          => 'tj',
    'taiwan'                                => 'tw',
    'tanzania'                              => 'tz',
    'thailand'                              => 'th',
    'togo'                                  => 'tg',
    'tokelau'                               => 'tk',
    'tonga'                                 => 'to',
    'trinidadogtobago'                      => 'tt',
    'tsjad'                                 => 'td',
    'tsjekkia'                              => 'cz',
    'tunisia'                               => 'tn',
    'turkmenistan'                          => 'tm',
    'turksogcaicosøyene'                   => 'tc',
    'tuvalu'                                => 'tv',
    'tyrkia'                                => 'tr',
    'tyskland'                              => 'de',
    "u\.s\.miscellaneouspacificislands"     => 'pu',
    'uganda'                                => 'ug',
    'ukjentellerugyldigområde'             => 'zz',
    'ukraina'                               => 'ua',
    'ungarn'                                => 'hu',
    'unionofsovietsocialistrepublics'       => 'su',
    'uruguay'                               => 'uy',
    'usa'                                   => 'us',
    'usasytresmåøyer'                     => 'um',
    'usbekistan'                            => 'uz',
    'vanuatu'                               => 'vu',
    'vatikanstaten'                         => 'va',
    'venezuela'                             => 've',
    'vestsahara'                            => 'eh',
    'vietnam'                               => 'vn',
    'wakeisland'                            => 'wk',
    'wallisogfutuna'                        => 'wf',
    'zambia'                                => 'zm',
    'zimbabwe'                              => 'zw',
    'Åland'                                => 'ax',
    'Østerrike'                            => 'at',
    'Østtimor'                             => 'tl',
);

1;

