package Locales::DB::Territory::ka;

# Auto generated from CLDR

$Locales::DB::Territory::ka::VERSION = '0.02';

$Locales::DB::Territory::ka::cldr_version = '1.7.1';

%Locales::DB::Territory::ka::code_to_name = (
    'ad' => 'ანდორა',
    'ae' => "არაბეთის\ გაერთიანებული\ ემირატები",
    'af' => 'ავღანეთი',
    'ag' => "ანტიგუა\ და\ ბარბუდა",
    'ai' => 'ანგვილა',
    'al' => 'ალბანეთი',
    'am' => 'სომხეთი',
    'an' => "ნიდერლანდების\ ანტილები",
    'ao' => 'ანგოლა',
    'aq' => 'ანტარქტიკა',
    'ar' => 'არგენტინა',
    'as' => "ამერიკული\ სამოა",
    'at' => 'ავსტრია',
    'au' => 'ავსტრალია',
    'aw' => 'არუბა',
    'ax' => "ალანდის\ კუნძულები",
    'az' => 'აზერბაიჯანი',
    'ba' => "ბოსნია\ და\ ჰერცეგოვინა",
    'bb' => 'ბარბადოსი',
    'bd' => 'ბანგლადეში',
    'be' => 'ბელგია',
    'bf' => "ბურკინა\-ფასო",
    'bg' => 'ბულგარეთი',
    'bh' => 'ბაჰრეინი',
    'bi' => 'ბურუნდი',
    'bj' => 'ბენინი',
    'bl' => "Saint\ Barth\Ã\©lemy",
    'bm' => 'ბერმუდა',
    'bn' => 'ბრუნეი',
    'bo' => 'ბოლივია',
    'bq' => "British\ Antarctic\ Territory",
    'br' => 'ბრაზილია',
    'bs' => "ბაჰამის\ კუნძულები",
    'bt' => 'ბუტანი',
    'bv' => "ბუვეს\ კუნძული",
    'bw' => 'ბოტსვანა',
    'by' => 'ბელორუსია',
    'bz' => 'ბელიზი',
    'ca' => 'კანადა',
    'cc' => "Cocos\ \[Keeling\]\ Islands",
    'cd' => "კონგო\ \-\ კინშასა",
    'cf' => "ცენტრალური\ აფრიკის\ რესპუბლიკა",
    'cg' => 'კონგო',
    'ch' => 'შვეიცარია',
    'ci' => "სპილოს\ ძვლის\ სანაპირო",
    'ck' => "კუკის\ კუნძულები",
    'cl' => 'ჩილე',
    'cm' => 'კამერუნი',
    'cn' => 'ჩინეთი',
    'co' => 'კოლუმბია',
    'cr' => "კოსტა\-რიკა",
    'cs' => "სერბია\ და\ მონტენეგრო",
    'ct' => "Canton\ and\ Enderbury\ Islands",
    'cu' => 'კუბა',
    'cv' => "კაბო\-ვერდე",
    'cx' => "შობის\ კუნძული",
    'cy' => 'კვიპროსი',
    'cz' => "ჩეხეთის\ რესპუბლიკა",
    'dd' => "East\ Germany",
    'de' => 'გერმანია',
    'dj' => 'ჯიბუტი',
    'dk' => 'დანია',
    'dm' => 'დომინიკა',
    'do' => "დომინიკანის\ რესპუბლიკა",
    'dz' => 'ალჟირი',
    'ec' => 'ეკვადორი',
    'ee' => 'ესტონეთი',
    'eg' => 'ეგვიპტე',
    'eh' => "დასავლეთი\ საჰარა",
    'er' => 'ერიტრეა',
    'es' => 'ესპანეთი',
    'et' => 'ეთიოპია',
    'fi' => 'ფინეთი',
    'fj' => 'ფიჯი',
    'fk' => "ფალკლენდის\ კუნძულები",
    'fm' => 'მიკრონეზია',
    'fo' => "ფაროს\ კუნძულები",
    'fq' => "French\ Southern\ and\ Antarctic\ Territories",
    'fr' => 'საფრანგეთი',
    'fx' => "Metropolitan\ France",
    'ga' => 'გაბონი',
    'gb' => "დიდი\ ბრიტანეთი",
    'gd' => 'გრენადა',
    'ge' => 'საქართველო',
    'gf' => "French\ Guiana",
    'gg' => 'Guernsey',
    'gh' => 'განა',
    'gi' => 'გიბრალტარი',
    'gl' => 'გრენლანდია',
    'gm' => 'გამბია',
    'gn' => 'გვინეა',
    'gp' => 'გვადელუპე',
    'gq' => "ეკვატორული\ გვინეა",
    'gr' => 'საბერძნეთი',
    'gs' => "სამხრეთი\ ჯორჯია\ და\ სამხრეთ\ სენდვიჩის\ კუნძულები",
    'gt' => 'გვატემალა',
    'gu' => 'გუამი',
    'gw' => "გვინეა\-ბისაუ",
    'gy' => 'გაიანა',
    'hk' => "ჰონგ\ კონგი",
    'hm' => "ჰერდის\ კუნძული\ და\ მაკდონალდის\ კუნძულები",
    'hn' => 'ჰონდურასი',
    'hr' => 'ჰორვატია',
    'ht' => 'ჰაიტი',
    'hu' => 'უნგრეთი',
    'id' => 'ინდონეზია',
    'ie' => 'ირლანდია',
    'il' => 'ისრაელი',
    'im' => "მანის\ კუნძული",
    'in' => 'ინდოეთი',
    'io' => "ბრიტანული\ ტერიტორია\ ინდოეთის\ ოკეანეში",
    'iq' => 'ერაყი',
    'ir' => 'ირანი',
    'is' => 'ისლანდია',
    'it' => 'იტალია',
    'je' => 'ჯერსი',
    'jm' => 'იამაიკა',
    'jo' => 'იორდანია',
    'jp' => 'იაპონია',
    'jt' => "Johnston\ Island",
    'ke' => 'კენია',
    'kg' => 'ყირგიზეთი',
    'kh' => 'კამბოჯა',
    'ki' => 'კირიბატი',
    'km' => "კომორის\ კუნძულები",
    'kn' => "სენტ\-კიტსი\ და\ ნევისი",
    'kp' => "ჩრდილოეთი\ კორეა",
    'kr' => "სამხრეთი\ კორეა",
    'kw' => 'კუვეიტი',
    'ky' => "კაიმანის\ კუნძულები",
    'kz' => 'ყაზახეთი',
    'la' => 'ლაოსი',
    'lb' => 'ლიბანი',
    'lc' => "სენტ\-ლუსია",
    'li' => 'ლიხტენშტაინი',
    'lk' => "შრი\-ლანკა",
    'lr' => 'ლიბერია',
    'ls' => 'ლესოთო',
    'lt' => 'ლიტვა',
    'lu' => 'ლუქსემბურგი',
    'lv' => 'ლატვია',
    'ly' => 'ლიბია',
    'ma' => 'მაროკო',
    'mc' => 'მონაკო',
    'md' => 'მოლდოვა',
    'me' => 'მონტენეგრო',
    'mf' => "Saint\ Martin",
    'mg' => 'მადაგასკარი',
    'mh' => "მარშალის\ კუნძულები",
    'mi' => "Midway\ Islands",
    'mk' => 'მაკედონია',
    'ml' => 'მალი',
    'mm' => 'მიანმარი',
    'mn' => 'მონღოლეთი',
    'mo' => 'მაკაო',
    'mp' => "Northern\ Mariana\ Islands",
    'mq' => 'მარტინიკი',
    'mr' => 'მავრიტანია',
    'ms' => 'მონსერატი',
    'mt' => 'მალტა',
    'mu' => 'მავრიკია',
    'mv' => "მალდივის\ კუნძულები",
    'mw' => 'მალავი',
    'mx' => 'მექსიკა',
    'my' => 'მალაიზია',
    'mz' => 'მოზამბიკი',
    'na' => 'ნამიბია',
    'nc' => "ახალი\ კალედონია",
    'ne' => 'ნიგერი',
    'nf' => "ნორფოლკის\ კუნძული",
    'ng' => 'ნიგერია',
    'ni' => 'ნიკარაგუა',
    'nl' => 'ნიდერლანდები',
    'no' => 'ნორვეგია',
    'np' => 'ნეპალი',
    'nq' => "Dronning\ Maud\ Land",
    'nr' => 'ნაურუ',
    'nt' => "Neutral\ Zone",
    'nu' => 'Niue',
    'nz' => "ახალი\ ზელანდია",
    'om' => 'ომანი',
    'pa' => 'პანამა',
    'pc' => "Pacific\ Islands\ Trust\ Territory",
    'pe' => 'პერუ',
    'pf' => "ფრანგული\ პოლინეზია",
    'pg' => "პაპუა\-ახალი\ გვინეა",
    'ph' => 'ფილიპინები',
    'pk' => 'პაკისტანი',
    'pl' => 'პოლონეთი',
    'pm' => "სენტ\-პიერი\ და\ მიქელონი",
    'pn' => "Pitcairn\ Islands",
    'pr' => "პუერტო\ რიკო",
    'ps' => "პალესტინის\ ტერიტორია",
    'pt' => 'პორტუგალია',
    'pu' => "U\.S\.\ Miscellaneous\ Pacific\ Islands",
    'pw' => 'პალაუ',
    'py' => 'პარაგვაი',
    'pz' => "Panama\ Canal\ Zone",
    'qa' => 'კატარი',
    'qo' => "დაშორებული\ ოკეანია",
    'qu' => 'ევროკავშირი',
    're' => 'რეიუნიონი',
    'ro' => 'რუმინეთი',
    'rs' => 'სერბია',
    'ru' => 'რუსეთი',
    'rw' => 'რუანდა',
    'sa' => "საუდის\ არაბეთი",
    'sb' => "სოლომონის\ კუნძულები",
    'sc' => "სეიშელის\ კუნძულები",
    'sd' => 'სუდანი',
    'se' => 'შვეცია',
    'sg' => 'სინგაპური',
    'sh' => "წმინდა\ ელენეს\ კუნძული",
    'si' => 'სლოვენია',
    'sj' => "Svalbard\ and\ Jan\ Mayen",
    'sk' => 'სლოვაკეთი',
    'sl' => "სიერა\-ლეონე",
    'sm' => "სან\-მარინო",
    'sn' => 'სენეგალი',
    'so' => 'სომალი',
    'sr' => 'სურინამი',
    'st' => "საო\-ტომე\ და\ პრინსიპი",
    'su' => "Union\ of\ Soviet\ Socialist\ Republics",
    'sv' => 'სალვადორი',
    'sy' => 'სირია',
    'sz' => 'სვაზილენდი',
    'tc' => "Turks\ and\ Caicos\ Islands",
    'td' => 'ჩადი',
    'tf' => "ფრანგული\ სამხრეთის\ ტერიტორიები",
    'tg' => 'ტოგო',
    'th' => 'ტაილანდი',
    'tj' => 'ტაჯიკეთი',
    'tk' => 'Tokelau',
    'tl' => "აღმოსავლეთი\ ტიმორი",
    'tm' => 'თურქმენეთი',
    'tn' => 'ტუნისი',
    'to' => 'ტონგა',
    'tr' => 'თურქეთი',
    'tt' => "ტრინიდადი\ და\ ტობაგო",
    'tv' => 'ტუვალუ',
    'tw' => 'ტაივანი',
    'tz' => 'ტანზანია',
    'ua' => 'უკრაინა',
    'ug' => 'უგანდა',
    'um' => "შეერთებული\ შტატების\ მცირე\ დაშორებული\ კუნძულები",
    'us' => "ამერიკის\ შეერთებული\ შტატები",
    'uy' => 'ურუგვაი',
    'uz' => 'უზბეკეთი',
    'va' => 'ვატიკანი',
    'vc' => "სენტ\-ვინსენტი\ და\ გრენადინები",
    'vd' => "North\ Vietnam",
    've' => 'ვენესუელა',
    'vg' => "British\ Virgin\ Islands",
    'vi' => "U\.S\.\ Virgin\ Islands",
    'vn' => 'ვიეტნამი',
    'vu' => 'ვანუატუ',
    'wf' => "ვალისი\ და\ ფუტუნა",
    'wk' => "Wake\ Island",
    'ws' => 'სამოა',
    'yd' => "People\'s\ Democratic\ Republic\ of\ Yemen",
    'ye' => 'იემენი',
    'yt' => 'Mayotte',
    'za' => "სამხრეთ\ აფრიკა",
    'zm' => 'ზამბია',
    'zw' => 'ზიმბაბვე',
    'zz' => "უცნობი\ ან\ არასწორი\ რეგიონი",
);

%Locales::DB::Territory::ka::name_to_code = (
    'britishantarcticterritory'                                                                                                      => 'bq',
    'britishvirginislands'                                                                                                           => 'vg',
    'cantonandenderburyislands'                                                                                                      => 'ct',
    'cocoskeelingislands'                                                                                                            => 'cc',
    'dronningmaudland'                                                                                                               => 'nq',
    'eastgermany'                                                                                                                    => 'dd',
    'frenchguiana'                                                                                                                   => 'gf',
    'frenchsouthernandantarcticterritories'                                                                                          => 'fq',
    'guernsey'                                                                                                                       => 'gg',
    'johnstonisland'                                                                                                                 => 'jt',
    'mayotte'                                                                                                                        => 'yt',
    'metropolitanfrance'                                                                                                             => 'fx',
    'midwayislands'                                                                                                                  => 'mi',
    'neutralzone'                                                                                                                    => 'nt',
    'niue'                                                                                                                           => 'nu',
    'northernmarianaislands'                                                                                                         => 'mp',
    'northvietnam'                                                                                                                   => 'vd',
    'pacificislandstrustterritory'                                                                                                   => 'pc',
    'panamacanalzone'                                                                                                                => 'pz',
    'peoplesdemocraticrepublicofyemen'                                                                                               => 'yd',
    'pitcairnislands'                                                                                                                => 'pn',
    "saintbarth\Ã\©lemy"                                                                                                           => 'bl',
    'saintmartin'                                                                                                                    => 'mf',
    'svalbardandjanmayen'                                                                                                            => 'sj',
    'tokelau'                                                                                                                        => 'tk',
    'turksandcaicosislands'                                                                                                          => 'tc',
    "u\.s\.miscellaneouspacificislands"                                                                                              => 'pu',
    "u\.s\.virginislands"                                                                                                            => 'vi',
    'unionofsovietsocialistrepublics'                                                                                                => 'su',
    'wakeisland'                                                                                                                     => 'wk',
    'ავსტრალია'                                                                                                    => 'au',
    'ავსტრია'                                                                                                          => 'at',
    'ავღანეთი'                                                                                                       => 'af',
    'აზერბაიჯანი'                                                                                              => 'az',
    'ალანდისკუნძულები'                                                                               => 'ax',
    'ალბანეთი'                                                                                                       => 'al',
    'ალჟირი'                                                                                                             => 'dz',
    'ამერიკისშეერთებულიშტატები'                                                    => 'us',
    'ამერიკულისამოა'                                                                                     => 'as',
    'ანგვილა'                                                                                                          => 'ai',
    'ანგოლა'                                                                                                             => 'ao',
    'ანდორა'                                                                                                             => 'ad',
    'ანტარქტიკა'                                                                                                 => 'aq',
    'ანტიგუადაბარბუდა'                                                                               => 'ag',
    'არაბეთისგაერთიანებულიემირატები'                                     => 'ae',
    'არგენტინა'                                                                                                    => 'ar',
    'არუბა'                                                                                                                => 'aw',
    'აღმოსავლეთიტიმორი'                                                                            => 'tl',
    'ახალიზელანდია'                                                                                        => 'nz',
    'ახალიკალედონია'                                                                                     => 'nc',
    'ბანგლადეში'                                                                                                 => 'bd',
    'ბარბადოსი'                                                                                                    => 'bb',
    'ბაჰამისკუნძულები'                                                                               => 'bs',
    'ბაჰრეინი'                                                                                                       => 'bh',
    'ბელგია'                                                                                                             => 'be',
    'ბელიზი'                                                                                                             => 'bz',
    'ბელორუსია'                                                                                                    => 'by',
    'ბენინი'                                                                                                             => 'bj',
    'ბერმუდა'                                                                                                          => 'bm',
    'ბოლივია'                                                                                                          => 'bo',
    'ბოსნიადაჰერცეგოვინა'                                                                      => 'ba',
    'ბოტსვანა'                                                                                                       => 'bw',
    'ბრაზილია'                                                                                                       => 'br',
    'ბრიტანულიტერიტორიაინდოეთისოკეანეში'                         => 'io',
    'ბრუნეი'                                                                                                             => 'bn',
    'ბუვესკუნძული'                                                                                           => 'bv',
    'ბულგარეთი'                                                                                                    => 'bg',
    'ბურკინაფასო'                                                                                              => 'bf',
    'ბურუნდი'                                                                                                          => 'bi',
    'ბუტანი'                                                                                                             => 'bt',
    'გაბონი'                                                                                                             => 'ga',
    'გაიანა'                                                                                                             => 'gy',
    'გამბია'                                                                                                             => 'gm',
    'განა'                                                                                                                   => 'gh',
    'გერმანია'                                                                                                       => 'de',
    'გვადელუპე'                                                                                                    => 'gp',
    'გვატემალა'                                                                                                    => 'gt',
    'გვინეა'                                                                                                             => 'gn',
    'გვინეაბისაუ'                                                                                              => 'gw',
    'გიბრალტარი'                                                                                                 => 'gi',
    'გრენადა'                                                                                                          => 'gd',
    'გრენლანდია'                                                                                                 => 'gl',
    'გუამი'                                                                                                                => 'gu',
    'დანია'                                                                                                                => 'dk',
    'დასავლეთისაჰარა'                                                                                  => 'eh',
    'დაშორებულიოკეანია'                                                                            => 'qo',
    'დიდიბრიტანეთი'                                                                                        => 'gb',
    'დომინიკა'                                                                                                       => 'dm',
    'დომინიკანისრესპუბლიკა'                                                                => 'do',
    'ეგვიპტე'                                                                                                          => 'eg',
    'ევროკავშირი'                                                                                              => 'qu',
    'ეთიოპია'                                                                                                          => 'et',
    'ეკვადორი'                                                                                                       => 'ec',
    'ეკვატორულიგვინეა'                                                                               => 'gq',
    'ერაყი'                                                                                                                => 'iq',
    'ერიტრეა'                                                                                                          => 'er',
    'ესპანეთი'                                                                                                       => 'es',
    'ესტონეთი'                                                                                                       => 'ee',
    'ვალისიდაფუტუნა'                                                                                     => 'wf',
    'ვანუატუ'                                                                                                          => 'vu',
    'ვატიკანი'                                                                                                       => 'va',
    'ვენესუელა'                                                                                                    => 've',
    'ვიეტნამი'                                                                                                       => 'vn',
    'ზამბია'                                                                                                             => 'zm',
    'ზიმბაბვე'                                                                                                       => 'zw',
    'თურქეთი'                                                                                                          => 'tr',
    'თურქმენეთი'                                                                                                 => 'tm',
    'იამაიკა'                                                                                                          => 'jm',
    'იაპონია'                                                                                                          => 'jp',
    'იემენი'                                                                                                             => 'ye',
    'ინდოეთი'                                                                                                          => 'in',
    'ინდონეზია'                                                                                                    => 'id',
    'იორდანია'                                                                                                       => 'jo',
    'ირანი'                                                                                                                => 'ir',
    'ირლანდია'                                                                                                       => 'ie',
    'ისლანდია'                                                                                                       => 'is',
    'ისრაელი'                                                                                                          => 'il',
    'იტალია'                                                                                                             => 'it',
    'კაბოვერდე'                                                                                                    => 'cv',
    'კაიმანისკუნძულები'                                                                            => 'ky',
    'კამბოჯა'                                                                                                          => 'kh',
    'კამერუნი'                                                                                                       => 'cm',
    'კანადა'                                                                                                             => 'ca',
    'კატარი'                                                                                                             => 'qa',
    'კენია'                                                                                                                => 'ke',
    'კვიპროსი'                                                                                                       => 'cy',
    'კირიბატი'                                                                                                       => 'ki',
    'კოლუმბია'                                                                                                       => 'co',
    'კომორისკუნძულები'                                                                               => 'km',
    'კონგო'                                                                                                                => 'cg',
    'კონგოკინშასა'                                                                                           => 'cd',
    'კოსტარიკა'                                                                                                    => 'cr',
    'კუბა'                                                                                                                   => 'cu',
    'კუვეიტი'                                                                                                          => 'kw',
    'კუკისკუნძულები'                                                                                     => 'ck',
    'ლაოსი'                                                                                                                => 'la',
    'ლატვია'                                                                                                             => 'lv',
    'ლესოთო'                                                                                                             => 'ls',
    'ლიბანი'                                                                                                             => 'lb',
    'ლიბერია'                                                                                                          => 'lr',
    'ლიბია'                                                                                                                => 'ly',
    'ლიტვა'                                                                                                                => 'lt',
    'ლიხტენშტაინი'                                                                                           => 'li',
    'ლუქსემბურგი'                                                                                              => 'lu',
    'მადაგასკარი'                                                                                              => 'mg',
    'მავრიკია'                                                                                                       => 'mu',
    'მავრიტანია'                                                                                                 => 'mr',
    'მაკაო'                                                                                                                => 'mo',
    'მაკედონია'                                                                                                    => 'mk',
    'მალავი'                                                                                                             => 'mw',
    'მალაიზია'                                                                                                       => 'my',
    'მალდივისკუნძულები'                                                                            => 'mv',
    'მალი'                                                                                                                   => 'ml',
    'მალტა'                                                                                                                => 'mt',
    'მანისკუნძული'                                                                                           => 'im',
    'მაროკო'                                                                                                             => 'ma',
    'მარტინიკი'                                                                                                    => 'mq',
    'მარშალისკუნძულები'                                                                            => 'mh',
    'მექსიკა'                                                                                                          => 'mx',
    'მიანმარი'                                                                                                       => 'mm',
    'მიკრონეზია'                                                                                                 => 'fm',
    'მოზამბიკი'                                                                                                    => 'mz',
    'მოლდოვა'                                                                                                          => 'md',
    'მონაკო'                                                                                                             => 'mc',
    'მონსერატი'                                                                                                    => 'ms',
    'მონტენეგრო'                                                                                                 => 'me',
    'მონღოლეთი'                                                                                                    => 'mn',
    'ნამიბია'                                                                                                          => 'na',
    'ნაურუ'                                                                                                                => 'nr',
    'ნეპალი'                                                                                                             => 'np',
    'ნიგერი'                                                                                                             => 'ne',
    'ნიგერია'                                                                                                          => 'ng',
    'ნიდერლანდები'                                                                                           => 'nl',
    'ნიდერლანდებისანტილები'                                                                => 'an',
    'ნიკარაგუა'                                                                                                    => 'ni',
    'ნორვეგია'                                                                                                       => 'no',
    'ნორფოლკისკუნძული'                                                                               => 'nf',
    'ომანი'                                                                                                                => 'om',
    'პაკისტანი'                                                                                                    => 'pk',
    'პალაუ'                                                                                                                => 'pw',
    'პალესტინისტერიტორია'                                                                      => 'ps',
    'პანამა'                                                                                                             => 'pa',
    'პაპუაახალიგვინეა'                                                                               => 'pg',
    'პარაგვაი'                                                                                                       => 'py',
    'პერუ'                                                                                                                   => 'pe',
    'პოლონეთი'                                                                                                       => 'pl',
    'პორტუგალია'                                                                                                 => 'pt',
    'პუერტორიკო'                                                                                                 => 'pr',
    'რეიუნიონი'                                                                                                    => 're',
    'რუანდა'                                                                                                             => 'rw',
    'რუმინეთი'                                                                                                       => 'ro',
    'რუსეთი'                                                                                                             => 'ru',
    'საბერძნეთი'                                                                                                 => 'gr',
    'სალვადორი'                                                                                                    => 'sv',
    'სამოა'                                                                                                                => 'ws',
    'სამხრეთაფრიკა'                                                                                        => 'za',
    'სამხრეთიკორეა'                                                                                        => 'kr',
    'სამხრეთიჯორჯიადასამხრეთსენდვიჩისკუნძულები'    => 'gs',
    'სანმარინო'                                                                                                    => 'sm',
    'საოტომედაპრინსიპი'                                                                            => 'st',
    'საუდისარაბეთი'                                                                                        => 'sa',
    'საფრანგეთი'                                                                                                 => 'fr',
    'საქართველო'                                                                                                 => 'ge',
    'სეიშელისკუნძულები'                                                                            => 'sc',
    'სენეგალი'                                                                                                       => 'sn',
    'სენტვინსენტიდაგრენადინები'                                                    => 'vc',
    'სენტკიტსიდანევისი'                                                                            => 'kn',
    'სენტლუსია'                                                                                                    => 'lc',
    'სენტპიერიდამიქელონი'                                                                      => 'pm',
    'სერბია'                                                                                                             => 'rs',
    'სერბიადამონტენეგრო'                                                                         => 'cs',
    'სვაზილენდი'                                                                                                 => 'sz',
    'სიერალეონე'                                                                                                 => 'sl',
    'სინგაპური'                                                                                                    => 'sg',
    'სირია'                                                                                                                => 'sy',
    'სლოვაკეთი'                                                                                                    => 'sk',
    'სლოვენია'                                                                                                       => 'si',
    'სოლომონისკუნძულები'                                                                         => 'sb',
    'სომალი'                                                                                                             => 'so',
    'სომხეთი'                                                                                                          => 'am',
    'სპილოსძვლისსანაპირო'                                                                      => 'ci',
    'სუდანი'                                                                                                             => 'sd',
    'სურინამი'                                                                                                       => 'sr',
    'ტაივანი'                                                                                                          => 'tw',
    'ტაილანდი'                                                                                                       => 'th',
    'ტანზანია'                                                                                                       => 'tz',
    'ტაჯიკეთი'                                                                                                       => 'tj',
    'ტოგო'                                                                                                                   => 'tg',
    'ტონგა'                                                                                                                => 'to',
    'ტრინიდადიდატობაგო'                                                                            => 'tt',
    'ტუვალუ'                                                                                                             => 'tv',
    'ტუნისი'                                                                                                             => 'tn',
    'უგანდა'                                                                                                             => 'ug',
    'უზბეკეთი'                                                                                                       => 'uz',
    'უკრაინა'                                                                                                          => 'ua',
    'უნგრეთი'                                                                                                          => 'hu',
    'ურუგვაი'                                                                                                          => 'uy',
    'უცნობიანარასწორირეგიონი'                                                          => 'zz',
    'ფალკლენდისკუნძულები'                                                                      => 'fk',
    'ფაროსკუნძულები'                                                                                     => 'fo',
    'ფილიპინები'                                                                                                 => 'ph',
    'ფინეთი'                                                                                                             => 'fi',
    'ფიჯი'                                                                                                                   => 'fj',
    'ფრანგულიპოლინეზია'                                                                            => 'pf',
    'ფრანგულისამხრეთისტერიტორიები'                                           => 'tf',
    'ყაზახეთი'                                                                                                       => 'kz',
    'ყირგიზეთი'                                                                                                    => 'kg',
    'შეერთებულიშტატებისმცირედაშორებულიკუნძულები' => 'um',
    'შვეიცარია'                                                                                                    => 'ch',
    'შვეცია'                                                                                                             => 'se',
    'შობისკუნძული'                                                                                           => 'cx',
    'შრილანკა'                                                                                                       => 'lk',
    'ჩადი'                                                                                                                   => 'td',
    'ჩეხეთისრესპუბლიკა'                                                                            => 'cz',
    'ჩილე'                                                                                                                   => 'cl',
    'ჩინეთი'                                                                                                             => 'cn',
    'ჩრდილოეთიკორეა'                                                                                     => 'kp',
    'ცენტრალურიაფრიკისრესპუბლიკა'                                              => 'cf',
    'წმინდაელენესკუნძული'                                                                      => 'sh',
    'ჯერსი'                                                                                                                => 'je',
    'ჯიბუტი'                                                                                                             => 'dj',
    'ჰაიტი'                                                                                                                => 'ht',
    'ჰერდისკუნძულიდამაკდონალდისკუნძულები'                      => 'hm',
    'ჰონგკონგი'                                                                                                    => 'hk',
    'ჰონდურასი'                                                                                                    => 'hn',
    'ჰორვატია'                                                                                                       => 'hr',
);

1;

